(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   2993623,      91497]*)
(*NotebookOutlinePosition[   3249503,      98201]*)
(*  CellTagsIndexPosition[   3241775,      97971]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["The FeynCalc Book", "Title",
  TextAlignment->Center],

Cell[TextData[StyleBox["FeynCalc 4.1",
  FontWeight->"Bold"]], "Subtitle",
  PageBreakBelow->True,
  TextAlignment->Center],

Cell["Tools for Feynman diagram calculations", "Subtitle",
  TextAlignment->Center],

Cell["Rolf Mertig", "Subsubtitle",
  TextAlignment->Center],

Cell[TextData[{
  "HTML version: ",
  ButtonBox["http://www.feyncalc.org/",
    ButtonData:>{
      URL[ "http://www.feyncalc.org/"], None},
    ButtonStyle->"Hyperlink",
    ButtonNote->"http://www.feyncalc.org/"]
}], "Subsubtitle",
  TextAlignment->Center],

Cell[CellGroupData[{

Cell["Introduction", "Section",
  PageBreakAbove->True,
  CellTags->{"Short Overview", "intro"}],

Cell[TextData[{
  "FeynCalc 4.1 is a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 3.0 or 4.0 package for algebraic calculations in high energy physics. \
Tools are provided for Lorentz index contraction, Dirac algebra manipulation, \
color factor calculation, automatic Feynman rule derivation, general \
noncommutative algebra as well as various look-up tables for Feynman \
parameter integrals, Mellin transforms (e.g. all integrals - except 57,58 and \
59, and correcting a minor misprint in 14) of Appendix 7 from ",
  ButtonBox["hep-ph/9810241",
    ButtonData:>{
      URL[ "http://xxx.lanl.gov/abs/hep-ph/9810241"], None},
    ButtonStyle->"Hyperlink"],
  " are tabulated in ",
  ButtonBox["Integrate2",
    ButtonData:>"Integrate2",
    ButtonStyle->"AddOnsLink"],
  " , convolutions and Feynman rules. Furthermore special translation \
facilities are provided to change the FeynCalc syntax to and from FORM \
syntax. Optimized FORTRAN generation can be done with ",
  ButtonBox["Isolate",
    ButtonData:>"Isolate",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["Write2",
    ButtonData:>"Write2",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Text",
  CellTags->"intro"],

Cell[TextData[{
  "The more important functions for input of objects like ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox["p", "\[Mu]"], ",", 
          SuperscriptBox["\[Gamma]", "\[Nu]"], ",", 
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", " ", "\[Nu]"}]], ",", " ", 
          SuperscriptBox["\[CurlyEpsilon]", 
            RowBox[{"\[Mu]", " ", "\[Nu]", " ", "\[Rho]", " ", "\[Sigma]"}]], 
          ",", " ", 
          RowBox[{"etc", "."}]}], TraditionalForm]]],
  " (abbreviations in parentheses) are: ",
  ButtonBox["DiracMatrix",
    ButtonData:>"DiracMatrix",
    ButtonStyle->"AddOnsLink"],
  " (",
  ButtonBox["GA",
    ButtonData:>"GA",
    ButtonStyle->"AddOnsLink"],
  "), ",
  ButtonBox["DiracSlash",
    ButtonData:>"DiracSlash",
    ButtonStyle->"AddOnsLink"],
  " (",
  ButtonBox["GS",
    ButtonData:>"GS",
    ButtonStyle->"AddOnsLink"],
  "), ",
  ButtonBox["FourVector",
    ButtonData:>"FourVector",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FourVector"],
  " (",
  ButtonBox["FV",
    ButtonData:>"FV",
    ButtonStyle->"AddOnsLink"],
  "), ",
  ButtonBox["LeviCivita",
    ButtonData:>"LeviCivita",
    ButtonStyle->"AddOnsLink"],
  " (",
  ButtonBox["LC",
    ButtonData:>"LC",
    ButtonStyle->"AddOnsLink"],
  "), ",
  ButtonBox["MetricTensor",
    ButtonData:>"MetricTensor",
    ButtonStyle->"AddOnsLink"],
  " (",
  ButtonBox["MT",
    ButtonData:>"MT",
    ButtonStyle->"AddOnsLink"],
  "), ",
  ButtonBox["Spinor",
    ButtonData:>"Spinor",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["SUNDelta",
    ButtonData:>"SUNDelta",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["SUNF",
    ButtonData:>"SUNF",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ScalarProduct",
    ButtonData:>"ScalarProduct",
    ButtonStyle->"AddOnsLink"],
  " (",
  ButtonBox["SP",
    ButtonData:>"SP",
    ButtonStyle->"AddOnsLink"],
  "). "
}], "Text",
  CellTags->"intro"],

Cell["The more important functions for manipulations are:", "Text",
  CellTags->"intro"],

Cell[TextData[{
  ButtonBox["Contract",
    ButtonData:>"Contract",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Tr",
    ButtonData:>"Tr",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["DiracSimplify",
    ButtonData:>"DiracSimplify",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["DiracTrick",
    ButtonData:>"DiracTrick",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Calc",
    ButtonData:>"Calc",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Convolute",
    ButtonData:>"Convolute",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["FeynRule",
    ButtonData:>"FeynRule",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Integrate2",
    ButtonData:>"Integrate2",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["FeynCalc2FORM",
    ButtonData:>"FeynCalc2FORM",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["PaVeReduce",
    ButtonData:>"PaVeReduce",
    ButtonStyle->"AddOnsLink"],
  " ,",
  ButtonBox["SimplifyPolyLog",
    ButtonData:>"SimplifyPolyLog",
    ButtonStyle->"AddOnsLink"],
  " , ",
  ButtonBox["SUNSimplify",
    ButtonData:>"SUNSimplify",
    ButtonStyle->"AddOnsLink"],
  " , ",
  ButtonBox["Isolate",
    ButtonData:>"Isolate",
    ButtonStyle->"AddOnsLink"],
  " , ",
  ButtonBox["Collect2",
    ButtonData:>"Collect2",
    ButtonStyle->"AddOnsLink"],
  " , ",
  ButtonBox["OneLoopSimplify",
    ButtonData:>"OneLoopSimplify",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Series2",
    ButtonData:>"Series2",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Series2"],
  " , ",
  ButtonBox["ScalarProductCancel",
    ButtonData:>"ScalarProductCancel",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Text",
  CellTags->"intro"],

Cell[TextData[{
  "FeynCalc 4.1 is still compatible with FeynArts 2.2 if the FeynArts \
function ToFA1Convention is used on the generated amplitudes. The functions \
OneLoop and OneLoopSum for calculation of Standard Model (-like) 1-loop \
diagrams still work in FeynCalc 3.1 but they have not been developed much \
further compared to the FeynCalc 1.0 version. While ",
  ButtonBox["OneLoop",
    ButtonData:>"OneLoop",
    ButtonStyle->"AddOnsLink"],
  " and OneLoopSum still work fine for self-energy, triangle and box diagrams \
not too complicated the reader should be aware of the package FormCalc which \
is more effective for the adventurous researcher calculating thousands of \
diagrams involving four external gauge bosons. Notice however that FormCalc \
does not reduce the Passarino-Veltman integrals to scalar integrals. Also \
FormCalc is limited to the 't Hooft Feynman gauge. FeynCalc provides the \
possibility to reduce Passarino-Veltman integrals to scalar integrals \
algebraically by the function ",
  ButtonBox["PaVeReduce",
    ButtonData:>"PaVeReduce",
    ButtonStyle->"AddOnsLink"],
  " ."
}], "Text",
  CellTags->"intro"],

Cell[TextData[{
  "On a Pentium II 300 MHz computer with 128 MB of RAM running ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 3.0 for Linux this noteboook needs less than 15 minutes to evaluate and \
less than 16 MB of memory."
}], "Text",
  CellTags->"intro"],

Cell[TextData[{
  "FeynCalc automatically loads any tarcer*.mx file from the tarcer \
directory. For a description of TARCER see ",
  ButtonBox["hep-ph/9801383",
    ButtonData:>{
      URL[ "http://xxx.lanl.gov/abs/hep-ph/9801383"], None},
    ButtonStyle->"Hyperlink"],
  " or the published version in Computer Physics Communications 111 (1998) \
265-273."
}], "Text",
  CellTags->"intro"],

Cell["\<\
For more detailed information concerning FeynCalc functions you can \
investigate all of the source code in the FeynCalc.m file in the \
HighEnergyPhysics directory and the further packages in the directories \
fctools, fctables, general, qcd, tarcer and others. A complete list of \
FeynCalc objects is stored in the variable $FeynCalcStuff. Not all functions \
are documented in this notebook. Some are either very special ones (e.g. for \
tools for 2-loop QCD diagrams originating in twist-2 OPE) or still \
experimental.\
\>", "Text",
  CellTags->"intro"],

Cell[TextData[{
  "The ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox["\[Gamma]", "5"], TraditionalForm]]],
  "scheme used in OneLoop is the naive one, i.e., ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"{", 
            RowBox[{
              SuperscriptBox["\[Gamma]", "5"], ",", 
              SuperscriptBox["\[Gamma]", "\[Mu]"]}], ")"}], "=", "0"}], 
        TraditionalForm]]],
  " in 4 and D dimensions. See also ",
  ButtonBox["ToLarin",
    ButtonData:>"ToLarin",
    ButtonStyle->"AddOnsLink"]
}], "Text",
  CellTags->"intro"],

Cell["The metric used is the one from Bjorken and Drell (+---).", "Text",
  CellTags->"intro"],

Cell[TextData[{
  "For suggestions and bug reports please see ",
  ButtonBox["http://www.feyncalc.org",
    ButtonData:>{
      URL[ "http://www.feyncalc.org"], None},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Starting FeynCalc", "Section",
  CellTags->{"Load FeynCalc", "start"}],

Cell[TextData[{
  "If the directory \"HighEnergyPhysics\" has been put in the directory \
\"Applications\" in your ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " installation tree, you should be able to load FeynCalc from a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " session with no further ado."
}], "Text",
  CellTags->"start"],

Cell["This loads FeynCalc:", "MathCaption",
  CellTags->"start"],

Cell[BoxData[
    RowBox[{"<<", "HighEnergyPhysics`FeynCalc`"}]], "Input",
  CellLabel->"In[5]:=  (16:33:37 on 8/23/02)",
  CellTags->"start"],

Cell[TextData[{
  "You can also put the last input line into your \"init.m\" file. This will \
cause automatic loading of FeynCalc on every ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " startup."
}], "Text",
  CellTags->"start"],

Cell[TextData[{
  "By loading FeynCalc the setting of the default output format type is \
automatically set to TraditionalForm. You might want to reverse this after \
quitting FeynCalc by clicking on the ",
  StyleBox["Cell", "TextNormal",
    FontWeight->"Bold"],
  " menu, then go to the ",
  StyleBox["Default Output Format Type ", "TextNormal",
    FontWeight->"Bold"],
  "item and select ",
  StyleBox["StandardForm",
    FontWeight->"Bold"],
  ", or by evaluating ",
  StyleBox["SetOptions[$FrontEnd,\"CommonDefaultFormatTypes\"\[Rule]{\"Output\
\"\[Rule]StandardForm}]", "Input"],
  "."
}], "Text",
  CellTags->"start"],

Cell[TextData[{
  "This defines typesetting rules for ",
  StyleBox["q1",
    FontFamily->"Courier"],
  " and ",
  StyleBox["q2",
    FontFamily->"Courier"],
  " for the output format type TraditionalForm:"
}], "MathCaption",
  CellTags->"start"],

Cell[BoxData[
    RowBox[{
      RowBox[{"q1", "/:", 
        RowBox[{"MakeBoxes", "[", 
          RowBox[{"q1", ",", "TraditionalForm"}], "]"}], ":=", 
        RowBox[{"InterpretationBox", "[", 
          RowBox[{
            RowBox[{"SubscriptBox", "[", 
              RowBox[{"q", ",", "1"}], "]"}], ",", "q1"}], "]"}]}], 
      ";"}]], "Input",
  CellLabel->"In[6]:=  (16:33:56 on 8/23/02)",
  CellTags->"start"],

Cell[BoxData[
    RowBox[{
      RowBox[{"q2", "/:", 
        RowBox[{"MakeBoxes", "[", 
          RowBox[{"q2", ",", "TraditionalForm"}], "]"}], ":=", 
        RowBox[{"InterpretationBox", "[", 
          RowBox[{
            RowBox[{"SubscriptBox", "[", 
              RowBox[{"q", ",", "2"}], "]"}], ",", "q2"}], "]"}]}], 
      ";"}]], "Input",
  CellLabel->"In[7]:=  (16:33:58 on 8/23/02)",
  CellTags->"start"],

Cell[TextData[{
  "Evaluating ",
  StyleBox["q1",
    FontFamily->"Courier"],
  " and ",
  StyleBox["q2",
    FontFamily->"Courier"],
  " now returns formatted TraditionalForm output:"
}], "MathCaption",
  CellTags->"start"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"q1", ",", "q2"}], "}"}]], "Input",
  CellLabel->"In[8]:=  (16:34:04 on 8/23/02)",
  CellTags->"start"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          InterpretationBox[
            SubscriptBox["q", "1"],
            q1], ",", 
          InterpretationBox[
            SubscriptBox["q", "2"],
            q2]}], "}"}], TraditionalForm]], "Output",
  CellLabel->"Out[8]=  (16:34:04 on 8/23/02)"]
}, Open  ]],

Cell["\<\
Enforcing StandardForm gives 'raw' output usable for copying, pasting and \
re-evaluating:\
\>", "MathCaption",
  CellTags->"start"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "StandardForm"}]], "Input",
  CellLabel->"In[9]:=  (16:34:08 on 8/23/02)",
  CellTags->"start"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"q1", ",", "q2"}], "}"}]], "Output",
  CellLabel->"Out[9]//StandardForm=  (16:34:08 on 8/23/02)"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Extras", "Section",
  PageBreakAbove->True,
  CellTags->"About Extras"],

Cell[TextData[{
  "In the directory  \"HighEnergyPhysics\" are various files and \
subdirectories belonging to packages which are not necessary to run \
'standard' FeynCalc calculations. These packages are not loaded by default \
when starting FeynCalc. Loading them can be switched on and off by setting \
appropiate variables to ",
  StyleBox["False",
    FontFamily->"Courier"],
  " or ",
  StyleBox["True",
    FontFamily->"Courier"],
  "."
}], "Text",
  CellTags->"About Extras"],

Cell["\<\
E.g. evaluating this before loading FeynCalc causes FeynCalc to load the \
subpackage TARCER:\
\>", "MathCaption",
  CellTags->"About Extras"],

Cell[BoxData[
    RowBox[{
      RowBox[{"$LoadTARCER", "=", "True"}], ";"}]], "Input",
  CellTags->"About Extras"],

Cell["\<\
You can also put the last input line into your \"FCConfig.m\" file.\
\>", "Text",
  CellTags->"About Extras"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {
                  StyleBox["$LoadTARCER",
                    FontFamily->"Courier"], 
                  RowBox[{
                  "Specifiese", " ", "if", " ", "TARCER", " ", "should", " ", 
                    "be", " ", "loaded", " ", "by", " ", "FeynCalc"}]},
                {
                  StyleBox["$LoadPhi",
                    FontFamily->"Courier"], 
                  RowBox[{
                  "Specifiese", " ", "if", " ", "Phi", " ", "should", " ", 
                    "be", " ", "loaded", " ", "by", " ", "FeynCalc"}]},
                {
                  StyleBox["$LoadFeynArts",
                    FontFamily->"Courier"], 
                  RowBox[{
                  "Specifiese", " ", "if", " ", "FeynArts", " ", "should", 
                    " ", "be", " ", "loaded", " ", "by", " ", "FeynCalc"}]}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text",
  Background->None,
  CellTags->"About Extras"],

Cell["Variables switching loading of extra packages on and off. ", "Caption",
  CellTags->"About Extras"],

Cell[CellGroupData[{

Cell[TextData[{
  "TARCER -\n",
  "A ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " program for the reduction of two-loop propagator integrals"
}], "Subsection",
  CellTags->"tarcer"],

Cell["R. Mertig, R. Scharf", "InspectorLevel2",
  CellTags->"tarcer"],

Cell[TextData[{
  ButtonBox["hep-ph/9801383",
    ButtonData:>{
      URL[ "http://xxx.lanl.gov/abs/hep-ph/9801383"], None},
    ButtonStyle->"Hyperlink"],
  " at Los Alamos"
}], "Text",
  CellDingbat->"\[GrayCircle]",
  CellTags->"tarcer"],

Cell["\<\
published in Computer Physics Communications 111 (1998) 265-173\
\>", "Text",
  CellDingbat->"\[GrayCircle]",
  CellTags->"tarcer"],

Cell["Loading TARCER", "Subsubsection",
  CellTags->"tarcer"],

Cell[TextData[{
  "If FeynCalc is not needed, simply evaluate the file \"TARCER.nb\". This \
produces a file of the form \"tarcer*.mx\". Later it is then only necessary \
to load this file (e.g. ",
  StyleBox["<<\"tarcer06.mx\"",
    FontFamily->"Courier"],
  "). You can later change parameters in \"TARCER.nb\" and reevaluate it. \
Alternatively you can get a preproduced .mx file at ",
  ButtonBox["http://www.feyncalc.org/tarcer",
    ButtonData:>{
      URL[ "http://www.feyncalc.org/tarcer"], None},
    ButtonStyle->"Hyperlink",
    ButtonNote->"http://www.feyncalc.org/tarcer"],
  "."
}], "Text",
  CellTags->"tarcer"],

Cell["To have FeynCalc load TARCER, evaluate", "Text",
  CellTags->"tarcer"],

Cell[BoxData[
    RowBox[{
      RowBox[{"$LoadTARCER", "=", "True"}], ";"}]], "Input",
  CellTags->"tarcer"],

Cell[TextData[{
  "before ",
  ButtonBox["loading FeynCalc",
    ButtonData:>"Starting FeynCalc",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Start FeynCalc"],
  ". You can also put the last input line into your \"FCConfig.m\" file."
}], "Text",
  CellTags->"tarcer"],

Cell[TextData[{
  "An example notebook is also available at ",
  ButtonBox["http://www.feyncalc.org/tarcer",
    ButtonData:>{
      URL[ "http://www.feyncalc.org/tarcer"], None},
    ButtonStyle->"Hyperlink",
    ButtonNote->"http://www.feyncalc.org/tarcer"],
  "."
}], "Text",
  CellTags->"tarcer"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Phi -\nA ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " package for ChPT calculations"
}], "Subsection",
  CellTags->"phi"],

Cell["F. J. Orellana", "InspectorLevel2",
  CellTags->"phi"],

Cell[TextData[{
  "Phi is a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " package for manipulating covariant derivatives etc. of effective theories \
like Chiral Perturbation Theory. Moreover it provides an alternative way of \
creating coupling definitions for FeynArts. This is convenient if one needs \
to generate a large number of Feynman rules from different lagrangians."
}], "Text",
  CellTags->"phi"],

Cell["To have FeynCalc load Phi, evaluate", "Text",
  CellTags->"phi"],

Cell[BoxData[
    RowBox[{
      RowBox[{"$LoadPhi", "=", "True"}], ";"}]], "Input",
  CellTags->"phi"],

Cell[TextData[{
  "before ",
  ButtonBox["loading FeynCalc",
    ButtonData:>"Starting FeynCalc",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Start FeynCalc"],
  ". You can also put the last input line into your \"FCConfig.m\" file."
}], "Text",
  CellTags->"phi"],

Cell[TextData[{
  "More information is available at ",
  ButtonBox["http://www.feyncalc.org/phi",
    ButtonData:>{
      URL[ "http://www.feyncalc.org/phi"], None},
    ButtonStyle->"Hyperlink",
    ButtonNote->"http://www.feyncalc.org/phi"],
  "."
}], "Text",
  CellTags->"phi"]
}, Closed]],

Cell[CellGroupData[{

Cell["FeynArts", "Subsection",
  CellTags->"fa"],

Cell["\<\
FeynArts is a Mathematica package written by Hagen Eck, Sepp Kueblbeck, and \
Thomas Hahn for the generation and visualization of Feynman diagrams and \
amplitudes.\
\>", "Text",
  CellTags->"fa"],

Cell["\<\
One use of FeynCalc and FeynArts together is to use FeynCalc to process the \
output you get from FeynArts. Another use is to use FeynCalc and Phi to \
generate the many Feynman rules needed in effective theories like ChPT and \
feed them to FeynArts.\
\>", "Text",
  CellTags->"fa"],

Cell[TextData[{
  "To have FeynArts loaded by FeynCalc, you need first of all to get FeynArts \
at ",
  ButtonBox["http://www.feynarts.de",
    ButtonData:>{
      URL[ "http://www.feynarts.de"], None},
    ButtonStyle->"Hyperlink",
    ButtonNote->"Download FeynArts"],
  " and put it in the directory \"HighEnergyPhysics\" following the \
instructions on ",
  ButtonBox["http://www.feyncalc.org/phi",
    ButtonData:>{
      URL[ "http://www.feyncalc.org/phi"], None},
    ButtonStyle->"Hyperlink",
    ButtonNote->"http://www.feyncalc.org/phi"],
  ". Then evaluate"
}], "Text",
  CellTags->"fa"],

Cell[BoxData[
    RowBox[{
      RowBox[{"$LoadPhi", "=", "True"}], ";"}]], "Input",
  CellTags->"fa"],

Cell[TextData[{
  "before ",
  ButtonBox["loading FeynCalc",
    ButtonData:>"Starting FeynCalc",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Start FeynCalc"],
  ". You can also put the last input line into your \"FCConfig.m\" file."
}], "Text",
  CellTags->"fa"],

Cell[TextData[{
  "More information about FeynArts is available at ",
  ButtonBox["http://www.feynarts.de",
    ButtonData:>{
      URL[ "http://www.feynarts.de"], None},
    ButtonStyle->"Hyperlink",
    ButtonNote->"Download FeynArts"],
  ". More information about using FeynArts, FeynCalc and Phi is available at \
",
  ButtonBox["http://www.feyncalc.org/phi",
    ButtonData:>{
      URL[ "http://www.feyncalc.org/phi"], None},
    ButtonStyle->"Hyperlink",
    ButtonNote->"http://www.feyncalc.org/phi"],
  "."
}], "Text",
  CellTags->"fa"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Example Calculations", "Section",
  PageBreakAbove->True,
  CellTags->{"Example Calculations", "ex"}],

Cell[TextData[{
  "This section is under development ... Please send suggestions to ",
  ButtonBox["feyncalc@feyncalc.org",
    ButtonData:>{
      URL[ "mailto:feyncalc@feyncalc.org"], None},
    ButtonStyle->"Hyperlink",
    ButtonNote->"http://www.feyncalc.org/examples"],
  " and/or upload at ",
  ButtonBox["www.feyncalc.org/examples",
    ButtonData:>{
      URL[ "http://www.feyncalc.org/examples"], None},
    ButtonStyle->"Hyperlink",
    ButtonNote->"http://www.feyncalc.org/examples"],
  "..."
}], "Commentary",
  CellTags->"ex"],

Cell[TextData[{
  "The examples are from various areas of research or education. More are \
welcome. See also ",
  ButtonBox["www.feyncalc.org/examples",
    ButtonData:>{
      URL[ "http://www.feyncalc.org/examples"], None},
    ButtonStyle->"Hyperlink",
    ButtonNote->"http://www.feyncalc.org/examples"],
  "."
}], "Text",
  CellTags->"ex"],

Cell[CellGroupData[{

Cell[TextData[{
  "Tree level ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[Gamma]", " ", "\[Gamma]"}], " ", "\[Rule]", " ", 
          RowBox[{
            SuperscriptBox["e", "+"], 
            SuperscriptBox["e", "-"]}]}], TraditionalForm]]],
  " in the standard model"
}], "Subsection",
  CellTags->"Tree level"],

Cell[TextData[{
  "Tree level pair production ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[Gamma]", " ", "\[Gamma]"}], " ", "\[Rule]", " ", 
          RowBox[{
            SuperscriptBox["e", "+"], 
            SuperscriptBox["e", "-"]}]}], TraditionalForm]]]
}], "Text",
  CellTags->"Tree level"],

Cell["Define typesetting rules for p1, p2, k1, k2", "Text",
  CellTags->"Tree level"],

Cell["\<\
p1/: MakeBoxes[p1, fmt_] := InterpretationBox[SubscriptBox[p, 1], p1]\
\>", "Input",
  CellLabel->"In[23]:=  (21:45:30 on 5/16/01)",
  CellTags->"Tree level"],

Cell["\<\
k1/: MakeBoxes[k1, fmt_] := InterpretationBox[SubscriptBox[k, 1], k1]\
\>", "Input",
  CellLabel->"In[24]:=  (21:45:31 on 5/16/01)",
  CellTags->"Tree level"],

Cell["\<\
p2/: MakeBoxes[p2, fmt_] := InterpretationBox[SubscriptBox[p, 2], p2]\
\>", "Input",
  CellLabel->"In[25]:=  (21:45:31 on 5/16/01)",
  CellTags->"Tree level"],

Cell["\<\
k2/: MakeBoxes[k2, fmt_] := InterpretationBox[SubscriptBox[k, 2], k2]\
\>", "Input",
  CellLabel->"In[26]:=  (21:45:31 on 5/16/01)",
  CellTags->"Tree level"],

Cell["Define slashes of external momenta to save future typing.", "Text",
  CellTags->"Tree level"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"{", 
        RowBox[{"p1sl", ",", "p2sl", ",", "k1sl", ",", "k2sl"}], "}"}], "=", 
      RowBox[{"DiracSlash", "/@", 
        RowBox[{"{", 
          RowBox[{"p1", ",", "p2", ",", "k1", ",", "k2"}], "}"}]}]}]], "Input",\

  CellLabel->"In[27]:=  (21:45:31 on 5/16/01)",
  CellTags->"Tree level"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{
            FormBox["\<\"\[Gamma]\"\>",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox[
              SubscriptBox[
                StyleBox["\<\"p\"\>",
                  FontSlant->"Italic"], "1"],
              "TraditionalForm"]}], ",", 
          RowBox[{
            FormBox["\<\"\[Gamma]\"\>",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox[
              SubscriptBox[
                StyleBox["\<\"p\"\>",
                  FontSlant->"Italic"], "2"],
              "TraditionalForm"]}], ",", 
          RowBox[{
            FormBox["\<\"\[Gamma]\"\>",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox[
              InterpretationBox[
                SubscriptBox["k", "1"],
                k1],
              "TraditionalForm"]}], ",", 
          RowBox[{
            FormBox["\<\"\[Gamma]\"\>",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox[
              InterpretationBox[
                SubscriptBox["k", "2"],
                k2],
              "TraditionalForm"]}]}], "}"}], TraditionalForm]], "Output",
  CellLabel->"Out[27]=  (21:45:31 on 5/16/01)"]
}, Open  ]],

Cell[TextData[{
  "Kinematic definitions so that only ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox["p", "1"], ".", 
          SubscriptBox["k", "1"]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox["p", "1"], ".", 
          SubscriptBox["k", "2"]}], TraditionalForm]]],
  " appear in final results. I.e., define ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubsuperscriptBox["p", "1", "2"], "=", 
          RowBox[{
            SubsuperscriptBox["p", "2", "2"], "=", " ", 
            SuperscriptBox["m", "2"]}]}], TraditionalForm]]],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubsuperscriptBox["k", "1", "2"], "=", 
          RowBox[{
            SubsuperscriptBox["k", "2", "2"], "=", " ", "0"}]}], 
        TraditionalForm]]],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubscriptBox["k", "1"], "\[CenterDot]", 
            SubscriptBox["k", "2"]}], " ", "=", " ", 
          RowBox[{
            RowBox[{
              SubscriptBox["p", "1"], "\[CenterDot]", 
              SubscriptBox["p", "2"]}], "+", 
            SuperscriptBox["m", "2"]}]}], TraditionalForm]]],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubscriptBox["k", "1"], "\[CenterDot]", 
            SubscriptBox["p", "2"]}], " ", "=", " ", 
          RowBox[{
            SubscriptBox["k", "2"], "\[CenterDot]", 
            SubscriptBox["p", "1"]}]}], TraditionalForm]]],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubscriptBox["k", "2"], "\[CenterDot]", 
            SubscriptBox["p", "2"]}], " ", "=", " ", 
          RowBox[{
            SubscriptBox["k", "1"], "\[CenterDot]", 
            SubscriptBox["p", "1"]}]}], TraditionalForm]]],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubscriptBox["p", "1"], "\[CenterDot]", 
            SubscriptBox["p", "2"]}], "=", " ", 
          RowBox[{
            RowBox[{
              SubscriptBox["k", "2"], "\[CenterDot]", 
              SubscriptBox["p", "1"]}], "-", 
            SuperscriptBox["m", "2"], "+", 
            RowBox[{
              SubscriptBox["k", "1"], "\[CenterDot]", 
              SubscriptBox["p", "1"]}]}]}], TraditionalForm]]]
}], "Text",
  CellTags->"Tree level"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"ScalarProduct", "[", 
          RowBox[{"p1", ",", "p1"}], "]"}], "=", 
        RowBox[{
          RowBox[{"ScalarProduct", "[", 
            RowBox[{"p2", ",", "p2"}], "]"}], "=", 
          SuperscriptBox["m", "2"]}]}], ";"}]], "Input",
  CellLabel->"In[28]:=  (21:45:31 on 5/16/01)",
  CellTags->"Tree level"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"ScalarProduct", "[", 
          RowBox[{"k1", ",", "k1"}], "]"}], "=", 
        RowBox[{
          RowBox[{"ScalarProduct", "[", 
            RowBox[{"k2", ",", "k2"}], "]"}], "=", "0"}]}], ";"}]], "Input",
  CellLabel->"In[29]:=  (21:45:31 on 5/16/01)",
  CellTags->"Tree level"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"ScalarProduct", "[", 
          RowBox[{"k1", ",", "k2"}], "]"}], "=", 
        RowBox[{
          RowBox[{"ScalarProduct", "[", 
            RowBox[{"p1", ",", "p2"}], "]"}], "+", 
          SuperscriptBox["m", "2"]}]}], ";"}]], "Input",
  CellLabel->"In[30]:=  (21:45:31 on 5/16/01)",
  CellTags->"Tree level"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"ScalarProduct", "[", 
          RowBox[{"k1", ",", "p2"}], "]"}], "=", 
        RowBox[{"ScalarProduct", "[", 
          RowBox[{"k2", ",", "p1"}], "]"}]}], ";"}]], "Input",
  CellLabel->"In[31]:=  (21:45:31 on 5/16/01)",
  CellTags->"Tree level"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"ScalarProduct", "[", 
          RowBox[{"k2", ",", "p2"}], "]"}], "=", 
        RowBox[{"ScalarProduct", "[", 
          RowBox[{"k1", ",", "p1"}], "]"}]}], ";"}]], "Input",
  CellLabel->"In[32]:=  (21:45:32 on 5/16/01)",
  CellTags->"Tree level"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"ScalarProduct", "[", 
          RowBox[{"p1", ",", "p2"}], "]"}], "=", 
        RowBox[{
          RowBox[{"ScalarProduct", "[", 
            RowBox[{"k2", ",", "p1"}], "]"}], "-", 
          SuperscriptBox["m", "2"], "+", 
          RowBox[{"ScalarProduct", "[", 
            RowBox[{"k1", ",", "p1"}], "]"}]}]}], ";"}]], "Input",
  CellLabel->"In[33]:=  (21:45:32 on 5/16/01)",
  CellTags->"Tree level"],

Cell["Define the amplitudes.", "Text",
  CellTags->"Tree level"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"f1", "=", 
      RowBox[{
        RowBox[{"DiracMatrix", "[", "\[Mu]", "]"}], ".", 
        RowBox[{"(", 
          RowBox[{"p1sl", "-", "k1sl", "+", "m"}], ")"}], ".", 
        RowBox[{"DiracMatrix", "[", "\[Nu]", "]"}]}]}]], "Input",
  CellLabel->"In[34]:=  (21:45:32 on 5/16/01)",
  CellTags->"Tree level"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        RowBox[{"(", 
          RowBox[{"m", "-", 
            RowBox[{
              FormBox["\<\"\[Gamma]\"\>",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox[
                InterpretationBox[
                  SubscriptBox["k", "1"],
                  k1],
                "TraditionalForm"]}], "+", 
            RowBox[{
              FormBox["\<\"\[Gamma]\"\>",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox[
                SubscriptBox[
                  StyleBox["\<\"p\"\>",
                    FontSlant->"Italic"], "1"],
                "TraditionalForm"]}]}], ")"}], ".", 
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Nu]",
              "TraditionalForm"],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[34]=  (21:45:32 on 5/16/01)"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"f2", "=", 
      RowBox[{
        RowBox[{"DiracMatrix", "[", "\[Nu]", "]"}], ".", 
        RowBox[{"(", 
          RowBox[{"p1sl", "-", "k2sl", "+", "m"}], ")"}], ".", 
        RowBox[{"DiracMatrix", "[", "\[Mu]", "]"}]}]}]], "Input",
  CellLabel->"In[35]:=  (21:45:32 on 5/16/01)",
  CellTags->"Tree level"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Nu]",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        RowBox[{"(", 
          RowBox[{"m", "-", 
            RowBox[{
              FormBox["\<\"\[Gamma]\"\>",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox[
                InterpretationBox[
                  SubscriptBox["k", "2"],
                  k2],
                "TraditionalForm"]}], "+", 
            RowBox[{
              FormBox["\<\"\[Gamma]\"\>",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox[
                SubscriptBox[
                  StyleBox["\<\"p\"\>",
                    FontSlant->"Italic"], "1"],
                "TraditionalForm"]}]}], ")"}], ".", 
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[35]=  (21:45:32 on 5/16/01)"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"f3", "=", 
      RowBox[{
        RowBox[{"DiracMatrix", "[", "\[Nu]", "]"}], ".", 
        RowBox[{"(", 
          RowBox[{"p1sl", "-", "k1sl", "+", "m"}], ")"}], ".", 
        RowBox[{"DiracMatrix", "[", "\[Mu]", "]"}]}]}]], "Input",
  CellLabel->"In[36]:=  (21:45:32 on 5/16/01)",
  CellTags->"Tree level"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Nu]",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        RowBox[{"(", 
          RowBox[{"m", "-", 
            RowBox[{
              FormBox["\<\"\[Gamma]\"\>",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox[
                InterpretationBox[
                  SubscriptBox["k", "1"],
                  k1],
                "TraditionalForm"]}], "+", 
            RowBox[{
              FormBox["\<\"\[Gamma]\"\>",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox[
                SubscriptBox[
                  StyleBox["\<\"p\"\>",
                    FontSlant->"Italic"], "1"],
                "TraditionalForm"]}]}], ")"}], ".", 
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[36]=  (21:45:32 on 5/16/01)"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"f4", "=", 
      RowBox[{
        RowBox[{"DiracMatrix", "[", "\[Mu]", "]"}], ".", 
        RowBox[{"(", 
          RowBox[{"p1sl", "-", "k2sl", "+", "m"}], ")"}], ".", 
        RowBox[{"DiracMatrix", "[", "\[Nu]", "]"}]}]}]], "Input",
  CellLabel->"In[37]:=  (21:45:32 on 5/16/01)",
  CellTags->"Tree level"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        RowBox[{"(", 
          RowBox[{"m", "-", 
            RowBox[{
              FormBox["\<\"\[Gamma]\"\>",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox[
                InterpretationBox[
                  SubscriptBox["k", "2"],
                  k2],
                "TraditionalForm"]}], "+", 
            RowBox[{
              FormBox["\<\"\[Gamma]\"\>",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox[
                SubscriptBox[
                  StyleBox["\<\"p\"\>",
                    FontSlant->"Italic"], "1"],
                "TraditionalForm"]}]}], ")"}], ".", 
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Nu]",
              "TraditionalForm"],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[37]=  (21:45:32 on 5/16/01)"]
}, Open  ]],

Cell[" Calculation of the four traces.", "Text",
  CellTags->"Tree level"],

Cell[CellGroupData[{

Cell["tr1 = Tr[(p1sl + m) . f1 . (p2sl - m) . f3]", "Input",
  CellLabel->"In[38]:=  (21:45:32 on 5/16/01)",
  CellTags->"Tree level"],

Cell[BoxData[
    FormBox[
      RowBox[{"4", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"-", "8"}], " ", 
              SuperscriptBox["m", "4"]}], "+", 
            RowBox[{"8", " ", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubscriptBox["k", "1"],
                    k1],
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox[
                  SubscriptBox[
                    StyleBox["\<\"p\"\>",
                      FontSlant->"Italic"], "1"],
                  "TraditionalForm"]}], " ", 
              SuperscriptBox["m", "2"]}], "+", 
            RowBox[{"8", " ", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubscriptBox["k", "1"],
                    k1],
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox[
                  SubscriptBox[
                    StyleBox["\<\"p\"\>",
                      FontSlant->"Italic"], "1"],
                  "TraditionalForm"]}], " ", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubscriptBox["k", "2"],
                    k2],
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox[
                  SubscriptBox[
                    StyleBox["\<\"p\"\>",
                      FontSlant->"Italic"], "1"],
                  "TraditionalForm"]}]}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[38]=  (21:45:33 on 5/16/01)"]
}, Open  ]],

Cell[CellGroupData[{

Cell["tr2 = Tr[(p1sl + m) . f1 . (p2sl - m) . f4]", "Input",
  CellLabel->"In[39]:=  (21:45:33 on 5/16/01)",
  CellTags->"Tree level"],

Cell[BoxData[
    FormBox[
      RowBox[{"4", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"-", "8"}], " ", 
              SuperscriptBox["m", "4"]}], "+", 
            RowBox[{"4", " ", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubscriptBox["k", "1"],
                    k1],
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox[
                  SubscriptBox[
                    StyleBox["\<\"p\"\>",
                      FontSlant->"Italic"], "1"],
                  "TraditionalForm"]}], " ", 
              SuperscriptBox["m", "2"]}], "+", 
            RowBox[{"4", " ", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubscriptBox["k", "2"],
                    k2],
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox[
                  SubscriptBox[
                    StyleBox["\<\"p\"\>",
                      FontSlant->"Italic"], "1"],
                  "TraditionalForm"]}], " ", 
              SuperscriptBox["m", "2"]}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[39]=  (21:45:33 on 5/16/01)"]
}, Open  ]],

Cell[CellGroupData[{

Cell["tr3 = Tr[(p1sl + m) . f2 . (p2sl - m) . f3]", "Input",
  CellLabel->"In[40]:=  (21:45:33 on 5/16/01)",
  CellTags->"Tree level"],

Cell[BoxData[
    FormBox[
      RowBox[{"4", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"-", "8"}], " ", 
              SuperscriptBox["m", "4"]}], "+", 
            RowBox[{"4", " ", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubscriptBox["k", "1"],
                    k1],
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox[
                  SubscriptBox[
                    StyleBox["\<\"p\"\>",
                      FontSlant->"Italic"], "1"],
                  "TraditionalForm"]}], " ", 
              SuperscriptBox["m", "2"]}], "+", 
            RowBox[{"4", " ", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubscriptBox["k", "2"],
                    k2],
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox[
                  SubscriptBox[
                    StyleBox["\<\"p\"\>",
                      FontSlant->"Italic"], "1"],
                  "TraditionalForm"]}], " ", 
              SuperscriptBox["m", "2"]}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[40]=  (21:45:34 on 5/16/01)"]
}, Open  ]],

Cell[CellGroupData[{

Cell["tr4 = Tr[(p1sl + m) . f2 . (p2sl - m) . f4]", "Input",
  CellLabel->"In[41]:=  (21:45:34 on 5/16/01)",
  CellTags->"Tree level"],

Cell[BoxData[
    FormBox[
      RowBox[{"4", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"-", "8"}], " ", 
              SuperscriptBox["m", "4"]}], "+", 
            RowBox[{"8", " ", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubscriptBox["k", "2"],
                    k2],
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox[
                  SubscriptBox[
                    StyleBox["\<\"p\"\>",
                      FontSlant->"Italic"], "1"],
                  "TraditionalForm"]}], " ", 
              SuperscriptBox["m", "2"]}], "+", 
            RowBox[{"8", " ", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubscriptBox["k", "1"],
                    k1],
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox[
                  SubscriptBox[
                    StyleBox["\<\"p\"\>",
                      FontSlant->"Italic"], "1"],
                  "TraditionalForm"]}], " ", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubscriptBox["k", "2"],
                    k2],
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox[
                  SubscriptBox[
                    StyleBox["\<\"p\"\>",
                      FontSlant->"Italic"], "1"],
                  "TraditionalForm"]}]}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[41]=  (21:45:34 on 5/16/01)"]
}, Open  ]],

Cell["Divide by the denominators and add everything up.", "Text",
  CellTags->"Tree level"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"matrixsq", "=", 
      RowBox[{
        FractionBox["tr1", 
          SuperscriptBox[
            RowBox[{"ScalarProduct", "[", 
              RowBox[{
                RowBox[{"2", " ", "p1"}], ",", "k1"}], "]"}], "2"]], "+", 
        FractionBox["tr4", 
          SuperscriptBox[
            RowBox[{"ScalarProduct", "[", 
              RowBox[{
                RowBox[{"2", " ", "p1"}], ",", "k2"}], "]"}], "2"]], "+", 
        FractionBox[
          RowBox[{"tr2", "+", "tr3"}], 
          RowBox[{
            RowBox[{"ScalarProduct", "[", 
              RowBox[{
                RowBox[{"2", " ", "p1"}], ",", "k1"}], "]"}], " ", 
            RowBox[{"ScalarProduct", "[", 
              RowBox[{
                RowBox[{"2", " ", "p1"}], ",", "k2"}], "]"}]}]]}]}]], "Input",\

  CellLabel->"In[42]:=  (21:45:34 on 5/16/01)",
  CellTags->"Tree level"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{"2", " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"-", "8"}], " ", 
                  SuperscriptBox["m", "4"]}], "+", 
                RowBox[{"4", " ", 
                  RowBox[{
                    FormBox[
                      InterpretationBox[
                        SubscriptBox["k", "1"],
                        k1],
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox[
                      SubscriptBox[
                        StyleBox["\<\"p\"\>",
                          FontSlant->"Italic"], "1"],
                      "TraditionalForm"]}], " ", 
                  SuperscriptBox["m", "2"]}], "+", 
                RowBox[{"4", " ", 
                  RowBox[{
                    FormBox[
                      InterpretationBox[
                        SubscriptBox["k", "2"],
                        k2],
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox[
                      SubscriptBox[
                        StyleBox["\<\"p\"\>",
                          FontSlant->"Italic"], "1"],
                      "TraditionalForm"]}], " ", 
                  SuperscriptBox["m", "2"]}]}], ")"}]}], 
          RowBox[{
            RowBox[{
              FormBox[
                InterpretationBox[
                  SubscriptBox["k", "1"],
                  k1],
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox[
                SubscriptBox[
                  StyleBox["\<\"p\"\>",
                    FontSlant->"Italic"], "1"],
                "TraditionalForm"]}], " ", 
            RowBox[{
              FormBox[
                InterpretationBox[
                  SubscriptBox["k", "2"],
                  k2],
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox[
                SubscriptBox[
                  StyleBox["\<\"p\"\>",
                    FontSlant->"Italic"], "1"],
                "TraditionalForm"]}]}]], "+", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"-", "8"}], " ", 
              SuperscriptBox["m", "4"]}], "+", 
            RowBox[{"8", " ", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubscriptBox["k", "1"],
                    k1],
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox[
                  SubscriptBox[
                    StyleBox["\<\"p\"\>",
                      FontSlant->"Italic"], "1"],
                  "TraditionalForm"]}], " ", 
              SuperscriptBox["m", "2"]}], "+", 
            RowBox[{"8", " ", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubscriptBox["k", "1"],
                    k1],
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox[
                  SubscriptBox[
                    StyleBox["\<\"p\"\>",
                      FontSlant->"Italic"], "1"],
                  "TraditionalForm"]}], " ", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubscriptBox["k", "2"],
                    k2],
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox[
                  SubscriptBox[
                    StyleBox["\<\"p\"\>",
                      FontSlant->"Italic"], "1"],
                  "TraditionalForm"]}]}]}], 
          SuperscriptBox[
            RowBox[{"(", 
              FormBox[
                RowBox[{
                  FormBox[
                    InterpretationBox[
                      SubscriptBox["k", "1"],
                      k1],
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox[
                    SubscriptBox[
                      StyleBox["\<\"p\"\>",
                        FontSlant->"Italic"], "1"],
                    "TraditionalForm"]}],
                "TraditionalForm"], ")"}], "2"]], "+", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"-", "8"}], " ", 
              SuperscriptBox["m", "4"]}], "+", 
            RowBox[{"8", " ", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubscriptBox["k", "2"],
                    k2],
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox[
                  SubscriptBox[
                    StyleBox["\<\"p\"\>",
                      FontSlant->"Italic"], "1"],
                  "TraditionalForm"]}], " ", 
              SuperscriptBox["m", "2"]}], "+", 
            RowBox[{"8", " ", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubscriptBox["k", "1"],
                    k1],
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox[
                  SubscriptBox[
                    StyleBox["\<\"p\"\>",
                      FontSlant->"Italic"], "1"],
                  "TraditionalForm"]}], " ", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubscriptBox["k", "2"],
                    k2],
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox[
                  SubscriptBox[
                    StyleBox["\<\"p\"\>",
                      FontSlant->"Italic"], "1"],
                  "TraditionalForm"]}]}]}], 
          SuperscriptBox[
            RowBox[{"(", 
              FormBox[
                RowBox[{
                  FormBox[
                    InterpretationBox[
                      SubscriptBox["k", "2"],
                      k2],
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox[
                    SubscriptBox[
                      StyleBox["\<\"p\"\>",
                        FontSlant->"Italic"], "1"],
                    "TraditionalForm"]}],
                "TraditionalForm"], ")"}], "2"]]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[42]=  (21:45:34 on 5/16/01)"]
}, Open  ]],

Cell["Collect with respect to powers of m.", "Text",
  CellTags->"Tree level"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"r", "=", 
      RowBox[{"Collect2", "[", 
        RowBox[{"matrixsq", ",", "m"}], "]"}]}]], "Input",
  CellLabel->"In[43]:=  (21:45:34 on 5/16/01)",
  CellTags->"Tree level"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          FractionBox[
            RowBox[{"8", " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      FormBox[
                        InterpretationBox[
                          SubscriptBox["k", "1"],
                          k1],
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox[
                          StyleBox["\<\"p\"\>",
                            FontSlant->"Italic"], "1"],
                        "TraditionalForm"]}], "+", 
                    RowBox[{
                      FormBox[
                        InterpretationBox[
                          SubscriptBox["k", "2"],
                          k2],
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox[
                          StyleBox["\<\"p\"\>",
                            FontSlant->"Italic"], "1"],
                        "TraditionalForm"]}]}], ")"}], "2"], " ", 
              SuperscriptBox["m", "4"]}], 
            RowBox[{
              SuperscriptBox[
                RowBox[{"(", 
                  FormBox[
                    RowBox[{
                      FormBox[
                        InterpretationBox[
                          SubscriptBox["k", "1"],
                          k1],
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox[
                          StyleBox["\<\"p\"\>",
                            FontSlant->"Italic"], "1"],
                        "TraditionalForm"]}],
                    "TraditionalForm"], ")"}], "2"], " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  FormBox[
                    RowBox[{
                      FormBox[
                        InterpretationBox[
                          SubscriptBox["k", "2"],
                          k2],
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox[
                          StyleBox["\<\"p\"\>",
                            FontSlant->"Italic"], "1"],
                        "TraditionalForm"]}],
                    "TraditionalForm"], ")"}], "2"]}]]}], "+", 
        FractionBox[
          RowBox[{"16", " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  FormBox[
                    InterpretationBox[
                      SubscriptBox["k", "1"],
                      k1],
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox[
                    SubscriptBox[
                      StyleBox["\<\"p\"\>",
                        FontSlant->"Italic"], "1"],
                    "TraditionalForm"]}], "+", 
                RowBox[{
                  FormBox[
                    InterpretationBox[
                      SubscriptBox["k", "2"],
                      k2],
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox[
                    SubscriptBox[
                      StyleBox["\<\"p\"\>",
                        FontSlant->"Italic"], "1"],
                    "TraditionalForm"]}]}], ")"}], " ", 
            SuperscriptBox["m", "2"]}], 
          RowBox[{
            RowBox[{
              FormBox[
                InterpretationBox[
                  SubscriptBox["k", "1"],
                  k1],
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox[
                SubscriptBox[
                  StyleBox["\<\"p\"\>",
                    FontSlant->"Italic"], "1"],
                "TraditionalForm"]}], " ", 
            RowBox[{
              FormBox[
                InterpretationBox[
                  SubscriptBox["k", "2"],
                  k2],
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox[
                SubscriptBox[
                  StyleBox["\<\"p\"\>",
                    FontSlant->"Italic"], "1"],
                "TraditionalForm"]}]}]], "+", 
        FractionBox[
          RowBox[{"8", " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{
                        FormBox[
                          InterpretationBox[
                            SubscriptBox["k", "1"],
                            k1],
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox[
                          SubscriptBox[
                            StyleBox["\<\"p\"\>",
                              FontSlant->"Italic"], "1"],
                          "TraditionalForm"]}],
                      "TraditionalForm"], ")"}], "2"], "+", 
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{
                        FormBox[
                          InterpretationBox[
                            SubscriptBox["k", "2"],
                            k2],
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox[
                          SubscriptBox[
                            StyleBox["\<\"p\"\>",
                              FontSlant->"Italic"], "1"],
                          "TraditionalForm"]}],
                      "TraditionalForm"], ")"}], "2"]}], ")"}]}], 
          RowBox[{
            RowBox[{
              FormBox[
                InterpretationBox[
                  SubscriptBox["k", "1"],
                  k1],
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox[
                SubscriptBox[
                  StyleBox["\<\"p\"\>",
                    FontSlant->"Italic"], "1"],
                "TraditionalForm"]}], " ", 
            RowBox[{
              FormBox[
                InterpretationBox[
                  SubscriptBox["k", "2"],
                  k2],
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox[
                SubscriptBox[
                  StyleBox["\<\"p\"\>",
                    FontSlant->"Italic"], "1"],
                "TraditionalForm"]}]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[43]=  (21:45:35 on 5/16/01)"]
}, Open  ]],

Cell["\<\
This is a possibility to check the symmetry in k1 and k2 explicitly.\
\>", "Text",
  CellTags->"Tree level"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"(", 
      RowBox[{"r", " ", "-", " ", 
        RowBox[{"(", 
          RowBox[{"r", " ", "/.", " ", 
            RowBox[{"{", " ", 
              RowBox[{
                RowBox[{"k1", "\[RuleDelayed]", "k2"}], ",", " ", 
                RowBox[{"k2", "\[RuleDelayed]", "k1"}]}], "}"}]}], ")"}]}], 
      ")"}]], "Input",
  CellLabel->"In[44]:=  (21:45:35 on 5/16/01)",
  CellTags->"Tree level"],

Cell[BoxData[
    FormBox["0", TraditionalForm]], "Output",
  CellLabel->"Out[44]=  (21:45:35 on 5/16/01)"]
}, Open  ]],

Cell["\<\
Remove the definitions for the scalar products and for the typesetting \
definitions.\
\>", "Text",
  CellTags->"Tree level"],

Cell[BoxData[
    RowBox[{"ClearScalarProducts", ";", " ", 
      RowBox[{"Clear", "[", 
        RowBox[{"p1", ",", "p2", ",", "k1", ",", "k2", ",", "r"}], "]"}], 
      ";"}]], "Input",
  CellLabel->"In[45]:=  (21:45:35 on 5/16/01)",
  CellTags->"Tree level"],

Cell[TextData[{
  "See also: ",
  ButtonBox["ClearScalarProducts",
    ButtonData:>"ClearScalarProducts",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Collect2",
    ButtonData:>"Collect2",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["DiracMatrix",
    ButtonData:>"DiracMatrix",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["DiracSlash",
    ButtonData:>"DiracSlash",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ScalarProduct",
    ButtonData:>"ScalarProduct",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Tr",
    ButtonData:>"Tr",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Text",
  CellTags->"Tree level"]
}, Closed]],

Cell[CellGroupData[{

Cell["A moment integral", "Subsection",
  CellTags->"A moment integral"],

Cell[TextData[{
  "Moments of ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["A",
                FontSlant->"Plain"], "^"],
            FontSlant->"Plain"], "qq", 
          RowBox[{"NS", ",", "PHYS"}]], TraditionalForm]]],
  " from ",
  ButtonBox["hep-ph/9801224",
    ButtonData:>{
      URL[ "http://xxx.lanl.gov/abs/hep-ph/9801224"], None},
    ButtonStyle->"Hyperlink"]
}], "Text",
  CellTags->"A moment integral"],

Cell["\<\
This is an example of integration and of translation from FORM syntax.\
\>", "Text",
  CellTags->"A moment integral"],

Cell[TextData[{
  "Due to current conservation the first moment of ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["A",
                FontSlant->"Plain"], "^"],
            FontSlant->"Plain"], "qq", 
          RowBox[{"NS", ",", "PHYS"}]], TraditionalForm]]],
  "should vanish."
}], "Text",
  CellTags->"A moment integral"],

Cell["Translate FORM output (jqq12.log) to FeynCalc", "Text",
  CellTags->"A moment integral"],

Cell[TextData[{
  "The FORM file ",
  "jqq12.log ",
  "was generated by one of the authors of ",
  ButtonBox["hep-ph/9801224",
    ButtonData:>{
      URL[ "http://xxx.lanl.gov/abs/hep-ph/9801224"], None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text",
  CellTags->"A moment integral"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"e", " ", "=", " ", "Epsilon"}]], "Input",
  CellLabel->"In[47]:=  (21:48:35 on 5/16/01)",
  CellTags->"A moment integral"],

Cell[BoxData[
    FormBox[
      TagBox["\[CurlyEpsilon]",
        TraditionalForm], TraditionalForm]], "Output",
  CellLabel->"Out[47]=  (21:48:35 on 5/16/01)"]
}, Open  ]],

Cell["\<\
Special FORM convenctions like ln(1-x) can be translated automatically by \
FORM2FeynCalc, but they have to be listed once in the option Replace of \
FORM2FeynCalc :\
\>", "Text",
  CellTags->"A moment integral"],

Cell[BoxData[
    RowBox[{
      RowBox[{"SetOptions", "[", 
        RowBox[{"FORM2FeynCalc", ",", 
          RowBox[{"Replace", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{"\"\<ln(x)\>\"", "\[Rule]", "\"\<Log[x]\>\""}], ",", 
                RowBox[{"\"\<ln(1+x)\>\"", "\[Rule]", "\"\<Log[1+x]\>\""}], 
                ",", 
                RowBox[{"\"\<ln(1-x)\>\"", "\[Rule]", "\"\<Log[1-x]\>\""}], 
                ",", 
                RowBox[{"\"\<Li2(-x)\>\"", "\[Rule]", "\"\<Li2[-x]\>\""}], 
                ",", 
                RowBox[{"\"\<Li2(1-x)\>\"", "\[Rule]", "\"\<Li2[1-x]\>\""}], 
                ",", 
                RowBox[{"\"\<Li3(1-x)\>\"", "\[Rule]", "\"\<Li3[1-x]\>\""}], 
                ",", 
                RowBox[{"\"\<Li3(-x)\>\"", "\[Rule]", "\"\<Li3[-x]\>\""}], 
                ",", 
                RowBox[{
                "\"\<S12(1-x)\>\"", "\[Rule]", "\"\<Nielsen[1,2,1-x]\>\""}], 
                ",", 
                RowBox[{
                "\"\<S12(-x)\>\"", "\[Rule]", "\"\<Nielsen[1,2,-x]\>\""}], 
                ",", 
                RowBox[{
                "\"\<S12(x^2)\>\"", "\[Rule]", "\"\<Nielsen[1,2,x^2]\>\""}], 
                ",", 
                RowBox[{"\"\<Z2\>\"", "\[Rule]", "\"\<Zeta2\>\""}], ",", 
                RowBox[{"\"\<Z3\>\"", "\[Rule]", "\"\<Zeta[3]\>\""}], ",", 
                RowBox[{"\"\<[1+x]^-1\>\"", "\[Rule]", "\"\<(1+x)^-1\>\""}], 
                ",", 
                RowBox[{
                "\"\<[(1-x)+]^-1\>\"", "\[Rule]", "\"\<(1-x)^-1\>\""}], ",", 
                RowBox[{"\"\<[1-x]^-1\>\"", "\[Rule]", "\"\<(1-x)^-1\>\""}], 
                ",", 
                RowBox[{
                "\"\<delta\>\"", "\[Rule]", "\"\<DeltaFunction[1-x]\>\""}], 
                ",", 
                RowBox[{"\"\<Ca\>\"", "\[Rule]", "\"\<CA\>\""}], ",", 
                RowBox[{"\"\<Cf\>\"", "\[Rule]", "\"\<CF\>\""}]}], "}"}]}], 
          ",", 
          RowBox[{"Dot", "\[Rule]", "Times"}], ",", 
          RowBox[{"HoldForm", "\[Rule]", "False"}]}], "]"}], ";"}]], "Input",
  CellLabel->"In[48]:=  (21:48:35 on 5/16/01)",
  CellTags->"A moment integral"],

Cell["\<\
Copy the FORM output from jqq12.log into the next cell and put \
FORM2CFeynCalc[\" \"]//ReleaseHold around it.\
\>", "Text",
  CellTags->"A moment integral"],

Cell["\<\
aqq=FORM2FeynCalc[\"

          + [(-1)^m]*e^-1*O1*Ca*Cf * (
          - 8
          + 4*x*Z2
          + 8*x
          + 8*Z2*[1+x]^-1
          - 4*Z2
          - 4*ln(x)
          - 4*ln(x)*x
          - 8*ln(x)*ln(1 + x)
          + 8*ln(x)*ln(1 + x)*x
          + 16*ln(x)*ln(1 + x)*[1+x]^-1
          + 2*ln(x)*ln(x)
          - 2*ln(x)*ln(x)*x
          - 4*ln(x)*ln(x)*[1+x]^-1
          - 8*Li2( - x)
          + 8*Li2( - x)*x
          + 16*Li2( - x)*[1+x]^-1
          )

       + [(-1)^m]*e^-1*O1*Cf^2 * (
          + 16
          - 8*x*Z2
          - 16*x
          - 16*Z2*[1+x]^-1
          + 8*Z2
          + 8*ln(x)
          + 8*ln(x)*x
          + 16*ln(x)*ln(1 + x)
          - 16*ln(x)*ln(1 + x)*x
          - 32*ln(x)*ln(1 + x)*[1+x]^-1
          - 4*ln(x)*ln(x)
          + 4*ln(x)*ln(x)*x
          + 8*ln(x)*ln(x)*[1+x]^-1
          + 16*Li2( - x)
          - 16*Li2( - x)*x
          - 32*Li2( - x)*[1+x]^-1
          )

       + [(-1)^m]*O1*Ca*Cf * (
          - 41/3
          - 6*x*Z2
          - 2*x*Z3
          + 41/3*x
          + 16/3*x^2*Z2
          + 6*Z2
          + 4*Z3*[1+x]^-1
          - 6*Z3
          - 8*ln(1 - x)
          + 8*ln(1 - x)*x
          - 8*ln(1 - x)*Li2(1 - x)
          + 8*ln(1 - x)*Li2(1 - x)*x
          + 16*ln(1 - x)*Li2(1 - x)*[1+x]^-1
          + 8*ln(1 + x)*x*Z2
          + 8*ln(1 + x)*Z2*[1+x]^-1
          - 8*ln(1 + x)*Li2(1 - x)
          + 8*ln(1 + x)*Li2(1 - x)*x
          + 16*ln(1 + x)*Li2(1 - x)*[1+x]^-1
          + 16*ln(1 + x)*Li2( - x)*x
          + 16*ln(1 + x)*Li2( - x)*[1+x]^-1
          - 37/3*ln(x)
          - 25/3*ln(x)*x
          - 4*ln(x)*ln(1 - x)
          - 4*ln(x)*ln(1 - x)*x
          - 4*ln(x)*ln(1 - x)*ln(1 - x)
          + 4*ln(x)*ln(1 - x)*ln(1 - x)*x
          + 8*ln(x)*ln(1 - x)*ln(1 - x)*[1+x]^-1
          - 8*ln(x)*ln(1 - x)*ln(1 + x)
          + 8*ln(x)*ln(1 - x)*ln(1 + x)*x
          + 16*ln(x)*ln(1 - x)*ln(1 + x)*[1+x]^-1
          + 4/3*ln(x)*ln(1 + x)*x^-1
          + 4*ln(x)*ln(1 + x)*x
          + 16/3*ln(x)*ln(1 + x)*x^2
          + 8*ln(x)*ln(1 + x)*ln(1 + x)*x
          + 8*ln(x)*ln(1 + x)*ln(1 + x)*[1+x]^-1
          - 6*ln(x)*ln(x)
          - 8/3*ln(x)*ln(x)*x^2
          + 2*ln(x)*ln(x)*ln(1 - x)
          - 2*ln(x)*ln(x)*ln(1 - x)*x
          - 4*ln(x)*ln(x)*ln(1 - x)*[1+x]^-1
          - 6*ln(x)*ln(x)*ln(1 + x)
          + 2*ln(x)*ln(x)*ln(1 + x)*x
          + 8*ln(x)*ln(x)*ln(1 + x)*[1+x]^-1
          + ln(x)*ln(x)*ln(x)
          - ln(x)*ln(x)*ln(x)*x
          - 2*ln(x)*ln(x)*ln(x)*[1+x]^-1
          + 4*ln(x)*Li2(1 - x)
          - 4*ln(x)*Li2(1 - x)*x
          - 8*ln(x)*Li2(1 - x)*[1+x]^-1
          - 4*ln(x)*Li2( - x)
          + 4*ln(x)*Li2( - x)*x
          + 8*ln(x)*Li2( - x)*[1+x]^-1
          - 4*Li2(1 - x)
          - 4*Li2(1 - x)*x
          + 4/3*Li2( - x)*x^-1
          + 4*Li2( - x)*x
          + 16/3*Li2( - x)*x^2
          + 8*Li3(1 - x)
          - 8*Li3(1 - x)*x
          - 16*Li3(1 - x)*[1+x]^-1
          - 4*Li3( - x)
          - 4*Li3( - x)*x
          + 4*S12(1 - x)
          - 4*S12(1 - x)*x
          - 8*S12(1 - x)*[1+x]^-1
          - 8*S12( - x)
          + 24*S12( - x)*x
          + 32*S12( - x)*[1+x]^-1
          + 4*S12(x^2)
          - 4*S12(x^2)*x
          - 8*S12(x^2)*[1+x]^-1
          )

       + [(-1)^m]*O1*Cf^2 * (
          + 82/3
          + 12*x*Z2
          + 4*x*Z3
          - 82/3*x
          - 32/3*x^2*Z2
          - 12*Z2
          - 8*Z3*[1+x]^-1
          + 12*Z3
          + 16*ln(1 - x)
          - 16*ln(1 - x)*x
          + 16*ln(1 - x)*Li2(1 - x)
          - 16*ln(1 - x)*Li2(1 - x)*x
          - 32*ln(1 - x)*Li2(1 - x)*[1+x]^-1
          - 16*ln(1 + x)*x*Z2
          - 16*ln(1 + x)*Z2*[1+x]^-1
          + 16*ln(1 + x)*Li2(1 - x)
          - 16*ln(1 + x)*Li2(1 - x)*x
          - 32*ln(1 + x)*Li2(1 - x)*[1+x]^-1
          - 32*ln(1 + x)*Li2( - x)*x
          - 32*ln(1 + x)*Li2( - x)*[1+x]^-1
          + 74/3*ln(x)
          + 50/3*ln(x)*x
          + 8*ln(x)*ln(1 - x)
          + 8*ln(x)*ln(1 - x)*x
          + 8*ln(x)*ln(1 - x)*ln(1 - x)
          - 8*ln(x)*ln(1 - x)*ln(1 - x)*x
          - 16*ln(x)*ln(1 - x)*ln(1 - x)*[1+x]^-1
          + 16*ln(x)*ln(1 - x)*ln(1 + x)
          - 16*ln(x)*ln(1 - x)*ln(1 + x)*x
          - 32*ln(x)*ln(1 - x)*ln(1 + x)*[1+x]^-1
          - 8/3*ln(x)*ln(1 + x)*x^-1
          - 8*ln(x)*ln(1 + x)*x
          - 32/3*ln(x)*ln(1 + x)*x^2
          - 16*ln(x)*ln(1 + x)*ln(1 + x)*x
          - 16*ln(x)*ln(1 + x)*ln(1 + x)*[1+x]^-1
          + 12*ln(x)*ln(x)
          + 16/3*ln(x)*ln(x)*x^2
          - 4*ln(x)*ln(x)*ln(1 - x)
          + 4*ln(x)*ln(x)*ln(1 - x)*x
          + 8*ln(x)*ln(x)*ln(1 - x)*[1+x]^-1
          + 12*ln(x)*ln(x)*ln(1 + x)
          - 4*ln(x)*ln(x)*ln(1 + x)*x
          - 16*ln(x)*ln(x)*ln(1 + x)*[1+x]^-1
          - 2*ln(x)*ln(x)*ln(x)
          + 2*ln(x)*ln(x)*ln(x)*x
          + 4*ln(x)*ln(x)*ln(x)*[1+x]^-1
          - 8*ln(x)*Li2(1 - x)
          + 8*ln(x)*Li2(1 - x)*x
          + 16*ln(x)*Li2(1 - x)*[1+x]^-1
          + 8*ln(x)*Li2( - x)
          - 8*ln(x)*Li2( - x)*x
          - 16*ln(x)*Li2( - x)*[1+x]^-1
          + 8*Li2(1 - x)
          + 8*Li2(1 - x)*x
          - 8/3*Li2( - x)*x^-1
          - 8*Li2( - x)*x
          - 32/3*Li2( - x)*x^2
          - 16*Li3(1 - x)
          + 16*Li3(1 - x)*x
          + 32*Li3(1 - x)*[1+x]^-1
          + 8*Li3( - x)
          + 8*Li3( - x)*x
          - 8*S12(1 - x)
          + 8*S12(1 - x)*x
          + 16*S12(1 - x)*[1+x]^-1
          + 16*S12( - x)
          - 48*S12( - x)*x
          - 64*S12( - x)*[1+x]^-1
          - 8*S12(x^2)
          + 8*S12(x^2)*x
          + 16*S12(x^2)*[1+x]^-1
          )

       + [(-1)^m]*O2*Ca*Cf * (
          + 8/3
          - 8/3*x
          - 16/3*x^2*Z2
          - 8/3*ln(x)
          + 16/3*ln(x)*x
          + 8/3*ln(x)*ln(1 + x)*x^-1
          - 8*ln(x)*ln(1 + x)*x
          - 16/3*ln(x)*ln(1 + x)*x^2
          + 8/3*ln(x)*ln(x)*x^2
          + 8/3*Li2( - x)*x^-1
          - 8*Li2( - x)*x
          - 16/3*Li2( - x)*x^2
          )

       + [(-1)^m]*O2*Cf^2 * (
          - 16/3
          + 16/3*x
          + 32/3*x^2*Z2
          + 16/3*ln(x)
          - 32/3*ln(x)*x
          - 16/3*ln(x)*ln(1 + x)*x^-1
          + 16*ln(x)*ln(1 + x)*x
          + 32/3*ln(x)*ln(1 + x)*x^2
          - 16/3*ln(x)*ln(x)*x^2
          - 16/3*Li2( - x)*x^-1
          + 16*Li2( - x)*x
          + 32/3*Li2( - x)*x^2
          )

       + e^-2*delta*O1*Ca*Cf * (
          - 22
          )

       + e^-2*delta*O1*Cf*Tf * (
          + 8
          )

       + e^-2*delta*O1*Cf^2 * (
          - 18
          + 32*Z2
          )

       + e^-2*O1*Ca*Cf * (
          + 44/3
          + 44/3*x
          - 88/3*[(1-x)+]^-1
          )

       + e^-2*O1*Cf*Tf * (
          - 16/3
          - 16/3*x
          + 32/3*[(1-x)+]^-1
          )

       + e^-2*O1*Cf^2 * (
          + 40
          + 8*x
          - 48*[(1-x)+]^-1
          + 32*ln(1 - x)
          + 32*ln(1 - x)*x
          - 64*ln(1 - x)*[(1-x)+]^-1
          - 24*ln(x)
          - 24*ln(x)*x
          + 32*ln(x)*[1-x]^-1
          )

       + e^-1*delta*O1*Ca*Cf * (
          + 325/6
          - 44/3*Z2
          - 12*Z3
          )

       + e^-1*delta*O1*Cf*Tf * (
          - 58/3
          + 16/3*Z2
          )

       + e^-1*delta*O1*Cf^2 * (
          + 87/2
          - 36*Z2
          - 8*Z3
          )

       + e^-1*O1*Ca*Cf * (
          - 158/9
          + 4*x*Z2
          + 22/9*x
          - 8*Z2*[(1-x)+]^-1
          + 4*Z2
          + 238/9*[(1-x)+]^-1
          + 44/3*ln(1 - x)
          + 44/3*ln(1 - x)*x
          - 88/3*ln(1 - x)*[(1-x)+]^-1
          + 34/3*ln(x)
          + 34/3*ln(x)*x
          - 44/3*ln(x)*[1-x]^-1
          - 2*ln(x)*ln(x)
          - 2*ln(x)*ln(x)*x
          + 4*ln(x)*ln(x)*[1-x]^-1
          )

       + e^-1*O1*Cf*Tf * (
          + 88/9
          - 56/9*x
          - 56/9*[(1-x)+]^-1
          - 16/3*ln(1 - x)
          - 16/3*ln(1 - x)*x
          + 32/3*ln(1 - x)*[(1-x)+]^-1
          - 8/3*ln(x)
          - 8/3*ln(x)*x
          + 16/3*ln(x)*[1-x]^-1
          )

       + e^-1*O1*Cf^2 * (
          - 40
          - 4*x
          + 56*[(1-x)+]^-1
          - 4*ln(1 - x)
          + 44*ln(1 - x)*x
          - 24*ln(1 - x)*[(1-x)+]^-1
          + 24*ln(1 - x)*ln(1 - x)
          + 24*ln(1 - x)*ln(1 - x)*x
          - 48*ln(1 - x)*ln(1 - x)*[(1-x)+]^-1
          + 36*ln(x)
          - 20*ln(x)*x
          - 36*ln(x)*[1-x]^-1
          - 16*ln(x)*ln(1 - x)*[1-x]^-1
          - 14*ln(x)*ln(x)
          - 14*ln(x)*ln(x)*x
          + 16*ln(x)*ln(x)*[1-x]^-1
          - 8*Li2(1 - x)
          - 8*Li2(1 - x)*x
          )

       + e^-1*O2*Ca*Cf * (
          + 20/3
          - 88/3*x
          )

       + e^-1*O2*Cf*Tf * (
          - 16/3
          + 32/3*x
          )

       + e^-1*O2*Cf^2 * (
          - 16
          - 8*x
          - 32*ln(1 - x)*x
          + 16*ln(x)*x
          )

       + delta*O1*Ca*Cf * (
          - 7081/72
          + 301/18*Z2
          + 49/5*Z2^2
          + 28*Z3
          )

       + delta*O1*Cf*Tf * (
          + 569/18
          - 46/9*Z2
          - 8*Z3
          )

       + delta*O1*Cf^2 * (
          - 541/8
          + 97/2*Z2
          - 74/5*Z2^2
          + 54*Z3
          )

       + O1*Ca*Cf * (
          + 941/27
          + 17/3*x*Z2
          - 8*x*Z3
          - 580/27*x
          - 16/3*x^2*Z2
          - 24*x^2*Z3
          - 28/3*Z2*[(1-x)+]^-1
          - 1/3*Z2
          + 12*Z3*[1-x]^-1
          + 22*Z3*[(1-x)+]^-1
          - 20*Z3
          - 670/27*[(1-x)+]^-1
          - 122/9*ln(1 - x)
          + 6*ln(1 - x)*x*Z2
          - 32/9*ln(1 - x)*x
          + 8*ln(1 - x)*x^2*Z2
          - 10*ln(1 - x)*Z2*[(1-x)+]^-1
          + 2*ln(1 - x)*Z2
          + 238/9*ln(1 - x)*[(1-x)+]^-1
          + 22/3*ln(1 - x)*ln(1 - x)
          + 22/3*ln(1 - x)*ln(1 - x)*x
          - 44/3*ln(1 - x)*ln(1 - x)*[(1-x)+]^-1
          + 2*ln(1 - x)*Li2(1 - x)
          - 2*ln(1 - x)*Li2(1 - x)*x
          + 8*ln(1 - x)*Li2(1 - x)*x^2
          - 2*ln(1 - x)*Li2(1 - x)*[1-x]^-1
          + 14/9*ln(x)
          - 2*ln(x)*x*Z2
          + 176/9*ln(x)*x
          - 8*ln(x)*x^2*Z2
          + 10*ln(x)*Z2*[1-x]^-1
          - 6*ln(x)*Z2
          + 101/9*ln(x)*[1-x]^-1
          + 28/3*ln(x)*ln(1 - x)
          + 10/3*ln(x)*ln(1 - x)*x
          - 38/3*ln(x)*ln(1 - x)*[1-x]^-1
          - 12*ln(x)*ln(1 + x)
          - 4/3*ln(x)*ln(1 + x)*x^-1
          - 16*ln(x)*ln(1 + x)*x
          - 16/3*ln(x)*ln(1 + x)*x^2
          + 47/6*ln(x)*ln(x)
          + 47/6*ln(x)*ln(x)*x
          + 8/3*ln(x)*ln(x)*x^2
          - 11/3*ln(x)*ln(x)*[1-x]^-1
          + ln(x)*ln(x)*ln(1 - x)
          - ln(x)*ln(x)*ln(1 - x)*x
          + 4*ln(x)*ln(x)*ln(1 - x)*x^2
          - ln(x)*ln(x)*ln(1 - x)*[1-x]^-1
          - ln(x)*ln(x)*ln(x)
          - ln(x)*ln(x)*ln(x)*x
          + 2*ln(x)*ln(x)*ln(x)*[1-x]^-1
          + 8*ln(x)*Li2(1 - x)
          + 16*ln(x)*Li2(1 - x)*x^2
          - 12*ln(x)*Li2(1 - x)*[1-x]^-1
          + 8*ln(x)*Li2( - x)
          - 8*ln(x)*Li2( - x)*[1-x]^-1
          - 12*Li2(1 - x)*x
          + 4*Li2(1 - x)*[1-x]^-1
          - 12*Li2( - x)
          - 4/3*Li2( - x)*x^-1
          - 16*Li2( - x)*x
          - 16/3*Li2( - x)*x^2
          - 6*Li3(1 - x)
          + 6*Li3(1 - x)*x
          - 24*Li3(1 - x)*x^2
          + 6*Li3(1 - x)*[1-x]^-1
          - 16*Li3( - x)
          + 16*Li3( - x)*[1-x]^-1
          + 14*S12(1 - x)
          - 6*S12(1 - x)*x
          + 24*S12(1 - x)*x^2
          - 14*S12(1 - x)*[1-x]^-1
          )

       + O1*Cf*Tf * (
          - 88/27
          - 4/3*x*Z2
          + 20/27*x
          + 8/3*Z2*[(1-x)+]^-1
          - 4/3*Z2
          + 128/27*[(1-x)+]^-1
          + 88/9*ln(1 - x)
          - 56/9*ln(1 - x)*x
          - 56/9*ln(1 - x)*[(1-x)+]^-1
          - 8/3*ln(1 - x)*ln(1 - x)
          - 8/3*ln(1 - x)*ln(1 - x)*x
          + 16/3*ln(1 - x)*ln(1 - x)*[(1-x)+]^-1
          + 44/9*ln(x)
          - 28/9*ln(x)*x
          - 28/9*ln(x)*[1-x]^-1
          - 8/3*ln(x)*ln(1 - x)
          - 8/3*ln(x)*ln(1 - x)*x
          + 16/3*ln(x)*ln(1 - x)*[1-x]^-1
          - 2/3*ln(x)*ln(x)
          - 2/3*ln(x)*ln(x)*x
          + 4/3*ln(x)*ln(x)*[1-x]^-1
          )

       + O1*Cf^2 * (
          + 188/3
          - 4*x*Z2
          - 24*x*Z3
          + 4/3*x
          + 32/3*x^2*Z2
          + 48*x^2*Z3
          - 4*Z2*[(1-x)+]^-1
          + 20*Z2
          - 24*Z3*[1-x]^-1
          + 24*Z3
          - 56*[(1-x)+]^-1
          - 38*ln(1 - x)
          + 8*ln(1 - x)*x*Z2
          + 38*ln(1 - x)*x
          - 16*ln(1 - x)*x^2*Z2
          - 8*ln(1 - x)*Z2*[(1-x)+]^-1
          + 8*ln(1 - x)*Z2
          + 28*ln(1 - x)*[(1-x)+]^-1
          - 13*ln(1 - x)*ln(1 - x)
          + 31*ln(1 - x)*ln(1 - x)*x
          - 6*ln(1 - x)*ln(1 - x)*[(1-x)+]^-1
          + 28/3*ln(1 - x)*ln(1 - x)*ln(1 - x)
          + 28/3*ln(1 - x)*ln(1 - x)*ln(1 - x)*x
          - 56/3*ln(1 - x)*ln(1 - x)*ln(1 - x)*[(1-x)+]^-1
          - 12*ln(1 - x)*Li2(1 - x)
          + 4*ln(1 - x)*Li2(1 - x)*x
          - 16*ln(1 - x)*Li2(1 - x)*x^2
          - 68/3*ln(x)
          - 14*ln(x)*x*Z2
          - 68/3*ln(x)*x
          + 16*ln(x)*x^2*Z2
          + 2*ln(x)*Z2
          + 44*ln(x)*[1-x]^-1
          - 6*ln(x)*ln(1 - x)
          + 34*ln(x)*ln(1 - x)*x
          - 20*ln(x)*ln(1 - x)*[1-x]^-1
          + 6*ln(x)*ln(1 - x)*ln(1 - x)
          + 6*ln(x)*ln(1 - x)*ln(1 - x)*x
          - 20*ln(x)*ln(1 - x)*ln(1 - x)*[1-x]^-1
          + 24*ln(x)*ln(1 + x)
          + 8/3*ln(x)*ln(1 + x)*x^-1
          + 32*ln(x)*ln(1 + x)*x
          + 32/3*ln(x)*ln(1 + x)*x^2
          + 11*ln(x)*ln(x)
          - 23*ln(x)*ln(x)*x
          - 16/3*ln(x)*ln(x)*x^2
          - 15*ln(x)*ln(x)*[1-x]^-1
          - 6*ln(x)*ln(x)*ln(1 - x)
          + 2*ln(x)*ln(x)*ln(1 - x)*x
          - 8*ln(x)*ln(x)*ln(1 - x)*x^2
          - 4*ln(x)*ln(x)*ln(1 - x)*[1-x]^-1
          - 5*ln(x)*ln(x)*ln(x)
          - 5*ln(x)*ln(x)*ln(x)*x
          + 16/3*ln(x)*ln(x)*ln(x)*[1-x]^-1
          - 8*ln(x)*Li2(1 - x)
          + 24*ln(x)*Li2(1 - x)*x
          - 32*ln(x)*Li2(1 - x)*x^2
          - 16*ln(x)*Li2(1 - x)*[1-x]^-1
          - 16*ln(x)*Li2( - x)
          + 16*ln(x)*Li2( - x)*[1-x]^-1
          - 24*Li2(1 - x)
          + 48*Li2(1 - x)*x
          - 4*Li2(1 - x)*[1-x]^-1
          + 24*Li2( - x)
          + 8/3*Li2( - x)*x^-1
          + 32*Li2( - x)*x
          + 32/3*Li2( - x)*x^2
          + 20*Li3(1 - x)
          - 28*Li3(1 - x)*x
          + 48*Li3(1 - x)*x^2
          + 32*Li3( - x)
          - 32*Li3( - x)*[1-x]^-1
          - 8*S12(1 - x)
          + 56*S12(1 - x)*x
          - 48*S12(1 - x)*x^2
          - 32*S12(1 - x)*[1-x]^-1
          )

       + O2*Ca*Cf * (
          - 26/9
          - 8*x*Z2
          - 24*x*Z3
          + 232/9*x
          + 16/3*x^2*Z2
          + 24*x^2*Z3
          + 4*Z2
          - 16/3*ln(1 - x)
          + 8*ln(1 - x)*x*Z2
          - 64/3*ln(1 - x)*x
          - 8*ln(1 - x)*x^2*Z2
          + 8*ln(1 - x)*Li2(1 - x)*x
          - 8*ln(1 - x)*Li2(1 - x)*x^2
          + 6*ln(x)
          - 8*ln(x)*x*Z2
          - 28*ln(x)*x
          + 8*ln(x)*x^2*Z2
          - 4*ln(x)*ln(1 - x)
          + 8*ln(x)*ln(1 - x)*x
          - 8/3*ln(x)*ln(1 + x)*x^-1
          + 8*ln(x)*ln(1 + x)*x
          + 16/3*ln(x)*ln(1 + x)*x^2
          - 8/3*ln(x)*ln(x)*x^2
          + 4*ln(x)*ln(x)*ln(1 - x)*x
          - 4*ln(x)*ln(x)*ln(1 - x)*x^2
          + 16*ln(x)*Li2(1 - x)*x
          - 16*ln(x)*Li2(1 - x)*x^2
          - 8*Li2(1 - x)
          + 16*Li2(1 - x)*x
          - 8/3*Li2( - x)*x^-1
          + 8*Li2( - x)*x
          + 16/3*Li2( - x)*x^2
          - 24*Li3(1 - x)*x
          + 24*Li3(1 - x)*x^2
          + 24*S12(1 - x)*x
          - 24*S12(1 - x)*x^2
          )

       + O2*Cf*Tf * (
          - 8/9
          - 32/9*x
          - 16/3*ln(1 - x)
          + 32/3*ln(1 - x)*x
          - 8/3*ln(x)
          + 16/3*ln(x)*x
          )

       + O2*Cf^2 * (
          - 32/3
          + 16*x*Z2
          + 48*x*Z3
          - 16/3*x
          - 32/3*x^2*Z2
          - 48*x^2*Z3
          - 8*Z2
          - 16*ln(1 - x)*x*Z2
          - 44*ln(1 - x)*x
          + 16*ln(1 - x)*x^2*Z2
          - 24*ln(1 - x)*ln(1 - x)*x
          - 16*ln(1 - x)*Li2(1 - x)*x
          + 16*ln(1 - x)*Li2(1 - x)*x^2
          - 40/3*ln(x)
          + 16*ln(x)*x*Z2
          + 68/3*ln(x)*x
          - 16*ln(x)*x^2*Z2
          + 8*ln(x)*ln(1 - x)
          - 32*ln(x)*ln(1 - x)*x
          + 16/3*ln(x)*ln(1 + x)*x^-1
          - 16*ln(x)*ln(1 + x)*x
          - 32/3*ln(x)*ln(1 + x)*x^2
          + 12*ln(x)*ln(x)*x
          + 16/3*ln(x)*ln(x)*x^2
          - 8*ln(x)*ln(x)*ln(1 - x)*x
          + 8*ln(x)*ln(x)*ln(1 - x)*x^2
          - 32*ln(x)*Li2(1 - x)*x
          + 32*ln(x)*Li2(1 - x)*x^2
          + 16*Li2(1 - x)
          - 48*Li2(1 - x)*x
          + 16/3*Li2( - x)*x^-1
          - 16*Li2( - x)*x
          - 32/3*Li2( - x)*x^2
          + 48*Li3(1 - x)*x
          - 48*Li3(1 - x)*x^2
          - 48*S12(1 - x)*x
          + 48*S12(1 - x)*x^2
          )
          
          \"]//ReleaseHold;\
\>", "Input",
  CellLabel->"In[49]:=  (21:48:36 on 5/16/01)",
  CellTags->"A moment integral"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Short", "[", "aqq", "]"}]], "Input",
  CellLabel->"In[50]:=  (21:48:37 on 5/16/01)",
  CellTags->"A moment integral"],

Cell[BoxData[
    FormBox[
      TagBox[
        RowBox[{
          FractionBox[
            RowBox[{"O1", " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"32", " ", 
                    RowBox[{"\[Zeta]", "(", "2", ")"}]}], "-", "18"}], ")"}], 
              " ", 
              RowBox[{"\[Delta]", "(", 
                FormBox[
                  RowBox[{"1", "-", "x"}],
                  "TraditionalForm"], ")"}], " ", 
              SubsuperscriptBox["C", "F", "2"]}], 
            SuperscriptBox[
              TagBox["\[CurlyEpsilon]",
                TraditionalForm], "2"]], "+", 
          RowBox[{"\[LeftSkeleton]", "29", "\[RightSkeleton]"}], "+", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "m"], " ", 
            SubscriptBox["C", "A"], " ", "O1", " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"-", "x"}], " ", 
                  RowBox[{
                    SuperscriptBox["log", "3"], "(", "x", ")"}]}], "-", 
                FractionBox[
                  RowBox[{"2", " ", 
                    RowBox[{
                      SuperscriptBox[
                        RowBox[{"\[LeftSkeleton]", "3", "\[RightSkeleton]"}], 
                        "3"], "(", "x", ")"}]}], 
                  RowBox[{"x", "+", "1"}]], "+", 
                RowBox[{"\[LeftSkeleton]", "101", "\[RightSkeleton]"}]}], 
              ")"}], " ", 
            SubscriptBox["C", "F"]}]}],
        Short], TraditionalForm]], "Output",
  CellLabel->"Out[50]//Short=  (21:48:38 on 5/16/01)"]
}, Open  ]],

Cell["\<\
Comment: By default all bracketed FORM expressions are translated to a Hold[] \
expression.\
\>", "Commentary",
  CellTags->"A moment integral"],

Cell[CellGroupData[{

Cell["FORM2FeynCalc[\"-[(-1)^m]\"]", "Input",
  CellLabel->"In[51]:=  (21:48:38 on 5/16/01)",
  CellTags->"A moment integral"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        RowBox[{"Hold", "[", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "m"], "]"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[51]=  (21:48:38 on 5/16/01)"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "ReleaseHold"}]], "Input",
  CellLabel->"In[52]:=  (21:48:38 on 5/16/01)",
  CellTags->"A moment integral"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "m"]}], TraditionalForm]], "Output",
  CellLabel->"Out[52]=  (21:48:38 on 5/16/01)"]
}, Open  ]],

Cell["Calculate moments", "Text",
  CellTags->"A moment integral"],

Cell["\<\
The first moment should be zero, which is verified by Integrate2 in a \
reasonable amount of time. The variable O2 can be set to zero since it is the \
coefficient of unphysical matrix elements.\
\>", "Text",
  CellTags->"A moment integral"],

Cell[TextData[{
  "This calculates for m=1 the integral ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubsuperscriptBox["\[Integral]", "0", 
              RowBox[{"1", " "}]], " ", 
            RowBox[{
              SubsuperscriptBox[
                StyleBox[
                  OverscriptBox[
                    StyleBox["A",
                      FontSlant->"Plain"], "^"],
                  FontSlant->"Plain"], "qq", 
                RowBox[{"NS", ",", "PHYS"}]], " ", 
              RowBox[{"\[DifferentialD]", "x"}]}]}], " "}], 
        TraditionalForm]]]
}], "Text",
  CellTags->"A moment integral"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Timing", "[", 
      RowBox[{"Integrate2", "[", 
        RowBox[{
          RowBox[{
            RowBox[{"aqq", "/.", 
              RowBox[{"m", "\[Rule]", "1"}]}], "/.", 
            RowBox[{"O2", "\[Rule]", "0"}]}], ",", 
          RowBox[{"{", 
            RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}]], "Input",\

  CellLabel->"In[53]:=  (21:48:38 on 5/16/01)",
  CellTags->"A moment integral"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"9.343999999999994`", " ", "Second"}], ",", "0"}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[53]=  (21:48:48 on 5/16/01)"]
}, Open  ]],

Cell["\<\
If you know that no partial fraction decomposition has to be done then \
Integrate3 will be much faster on an expanded or collected integral:\
\>", "Text",
  CellTags->"A moment integral"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Timing", "[", 
      RowBox[{"Expand", "[", 
        RowBox[{"Integrate3", "[", 
          RowBox[{
            RowBox[{"Expand", "[", 
              RowBox[{
                RowBox[{"aqq", "/.", 
                  RowBox[{"m", "\[Rule]", "1"}]}], "/.", 
                RowBox[{"O2", "\[Rule]", "0"}]}], "]"}], ",", 
            RowBox[{"{", 
              RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], 
      "]"}]], "Input",
  CellLabel->"In[54]:=  (21:48:48 on 5/16/01)",
  CellTags->"A moment integral"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"1.642000000000003`", " ", "Second"}], ",", "0"}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[54]=  (21:48:50 on 5/16/01)"]
}, Open  ]],

Cell["Define an auxiliary typesetting function.", "Text",
  CellTags->"A moment integral"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"MakeBoxes", "[", 
          RowBox[{
            RowBox[{"big", "[", "a_", "]"}], ",", " ", "f_"}], "]"}], " ", ":=",
         " ", 
        RowBox[{"StyleBox", "[", 
          RowBox[{
            RowBox[{"MakeBoxes", "[", 
              RowBox[{"a", ",", " ", "f"}], "]"}], ",", " ", 
            RowBox[{"FontColor", " ", "->", " ", 
              RowBox[{"RGBColor", "[", 
                RowBox[{"0", ",", " ", "0", ",", " ", "1"}], "]"}]}], ",", 
            " ", " ", " ", 
            RowBox[{"FontSize", " ", "->", " ", "18"}]}], "]"}]}], 
      ";"}]], "Input",
  CellLabel->"In[55]:=  (21:48:50 on 5/16/01)",
  CellTags->"A moment integral"],

Cell["The second moment takes a little bit longer.", "Text",
  CellTags->"A moment integral"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Timing", "[", 
        RowBox[{"Collect2", "[", 
          RowBox[{
            RowBox[{"Integrate2", "[", 
              RowBox[{
                RowBox[{
                  RowBox[{
                    RowBox[{
                      RowBox[{"x", " ", "aqq"}], "/.", 
                      RowBox[{"m", "\[Rule]", "2"}]}], "/.", 
                    RowBox[{"O2", "\[Rule]", "0"}]}], "/.", 
                  RowBox[{"O1", "\[Rule]", "1"}]}], ",", 
                RowBox[{"{", 
                  RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}], ",", 
            RowBox[{"{", 
              RowBox[{"CA", ",", "CF", ",", "Tf"}], "}"}], ",", 
            RowBox[{"Factoring", "\[Rule]", "False"}]}], "]"}], "]"}], "/.", 
      " ", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{
            RowBox[{"CA", " ", "CF"}], " ", "\[RuleDelayed]", " ", 
            RowBox[{"big", "[", " ", 
              RowBox[{"CA", " ", "CF"}], "]"}]}], ",", 
          RowBox[{
            RowBox[{"CF", "^", "2"}], "\[RuleDelayed]", 
            RowBox[{"big", "[", 
              RowBox[{"CF", "^", "2"}], "]"}]}], ",", 
          RowBox[{
            RowBox[{"a_", " ", "CF", " ", "Tf"}], " ", "\[RuleDelayed]", 
            RowBox[{"HoldForm", "[", " ", 
              RowBox[{
                RowBox[{"big", "[", 
                  RowBox[{"CF", " ", "Tf"}], "]"}], " ", "a"}], "]"}]}]}], 
        "}"}]}]], "Input",
  CellLabel->"In[56]:=  (21:48:50 on 5/16/01)",
  CellTags->"A moment integral"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"11.186`", " ", "Second"}], ",", 
          RowBox[{
            TagBox[
              RowBox[{
                RowBox[{"(", 
                  StyleBox[
                    RowBox[{
                      SubscriptBox["C", "F"], " ", 
                      SubscriptBox["T", "f"]}],
                    FontSize->18,
                    FontColor->RGBColor[0, 0, 1]], ")"}], " ", 
                RowBox[{"(", 
                  RowBox[{
                    FractionBox[
                      RowBox[{"16", " ", 
                        RowBox[{"\[Zeta]", "(", "2", ")"}]}], "9"], "+", 
                    FractionBox["376", 
                      RowBox[{"27", " ", 
                        TagBox["\[CurlyEpsilon]",
                          TraditionalForm]}]], "-", 
                    FractionBox["64", 
                      RowBox[{"9", " ", 
                        SuperscriptBox[
                          TagBox["\[CurlyEpsilon]",
                            TraditionalForm], "2"]}]], "-", 
                    FractionBox["2086", "81"]}], ")"}]}],
              HoldForm], "+", 
            RowBox[{
              RowBox[{"(", 
                StyleBox[
                  RowBox[{
                    SubscriptBox["C", "A"], " ", 
                    SubscriptBox["C", "F"]}],
                  FontSize->18,
                  FontColor->RGBColor[0, 0, 1]], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"-", 
                    FractionBox[
                      RowBox[{"44", " ", 
                        RowBox[{"\[Zeta]", "(", "2", ")"}]}], "9"]}], "-", 
                  FractionBox["1166", 
                    RowBox[{"27", " ", 
                      TagBox["\[CurlyEpsilon]",
                        TraditionalForm]}]], "+", 
                  FractionBox["176", 
                    RowBox[{"9", " ", 
                      SuperscriptBox[
                        TagBox["\[CurlyEpsilon]",
                          TraditionalForm], "2"]}]], "-", 
                  RowBox[{"12", " ", 
                    TagBox[
                      RowBox[{"\[Zeta]", "(", 
                        TagBox["3",
                          (Editable -> True)], ")"}],
                      InterpretTemplate[ Zeta[ #]&]]}], "+", 
                  FractionBox["12133", "162"]}], ")"}]}], "+", 
            RowBox[{
              StyleBox[
                SubsuperscriptBox["C", "F", "2"],
                FontSize->18,
                FontColor->RGBColor[0, 0, 1]], " ", 
              RowBox[{"(", 
                RowBox[{
                  FractionBox[
                    RowBox[{"32", " ", 
                      RowBox[{"\[Zeta]", "(", "2", ")"}]}], "9"], "+", 
                  FractionBox["752", 
                    RowBox[{"27", " ", 
                      TagBox["\[CurlyEpsilon]",
                        TraditionalForm]}]], "-", 
                  FractionBox["128", 
                    RowBox[{"9", " ", 
                      SuperscriptBox[
                        TagBox["\[CurlyEpsilon]",
                          TraditionalForm], "2"]}]], "+", 
                  RowBox[{"8", " ", 
                    TagBox[
                      RowBox[{"\[Zeta]", "(", 
                        TagBox["3",
                          (Editable -> True)], ")"}],
                      InterpretTemplate[ Zeta[ #]&]]}], "-", 
                  FractionBox["3452", "81"]}], ")"}]}]}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[56]=  (21:49:02 on 5/16/01)"]
}, Open  ]],

Cell["\<\
Try to do the general Mellin transform (replace m by OPEm, which has special \
properties).\
\>", "Text",
  CellTags->"A moment integral"],

Cell[BoxData[
    RowBox[{
      RowBox[{"gqq", " ", "=", " ", 
        RowBox[{"Collect2", "[", 
          RowBox[{
            RowBox[{
              RowBox[{
                RowBox[{
                  SuperscriptBox["x", 
                    RowBox[{"OPEm", "-", "1"}]], 
                  RowBox[{"(", 
                    RowBox[{"aqq", "/.", 
                      RowBox[{"m", "\[Rule]", "OPEm"}]}], ")"}]}], "/.", 
                RowBox[{"O2", "\[Rule]", "0"}]}], "/.", 
              RowBox[{"O1", "\[Rule]", "1"}]}], ",", "x"}], "]"}]}], 
      ";"}]], "Input",
  CellLabel->"In[57]:=  (21:49:02 on 5/16/01)",
  CellTags->"A moment integral"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"gqq", "//", "Length"}]], "Input",
  CellLabel->"In[58]:=  (21:49:06 on 5/16/01)",
  CellTags->"A moment integral"],

Cell[BoxData[
    FormBox["102", TraditionalForm]], "Output",
  CellLabel->"Out[58]=  (21:49:06 on 5/16/01)"]
}, Open  ]],

Cell["\<\
There are 102 integrals. However, some of the Mellin transforms cannot be \
done at the moment.\
\>", "Text",
  CellTags->"A moment integral"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ww", "=", 
        RowBox[{"Integrate3", "[", 
          RowBox[{"gqq", ",", 
            RowBox[{"{", 
              RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]}], 
      ";"}]], "Input",
  CellLabel->"In[59]:=  (21:49:06 on 5/16/01)",
  CellTags->"A moment integral"],

Cell["\<\
If an integral cannot be performed the head Hold[Integrate3] is substituted \
for Integrate3. Thus, in order to find the list of integrals not done you can \
do:\
\>", "Text",
  CellTags->"A moment integral"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Cases2", "[", 
      RowBox[{"ww", ",", 
        RowBox[{"Hold", "[", "Integrate3", "]"}]}], "]"}]], "Input",
  CellLabel->"In[60]:=  (21:49:07 on 5/16/01)",
  CellTags->"A moment integral"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{
            RowBox[{"Hold", "[", "Integrate3", "]"}], "[", 
            RowBox[{
              RowBox[{
                SuperscriptBox["x", 
                  RowBox[{"m", "-", "1"}]], " ", 
                RowBox[{
                  SubscriptBox["S", 
                    RowBox[{
                      FormBox["1",
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox["2",
                        "TraditionalForm"]}]], "(", 
                  FormBox[
                    SuperscriptBox["x", "2"],
                    "TraditionalForm"], ")"}]}], ",", 
              RowBox[{"{", 
                RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}], ",", 
          RowBox[{
            RowBox[{"Hold", "[", "Integrate3", "]"}], "[", 
            RowBox[{
              RowBox[{
                SuperscriptBox["x", "m"], " ", 
                RowBox[{
                  SubscriptBox["S", 
                    RowBox[{
                      FormBox["1",
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox["2",
                        "TraditionalForm"]}]], "(", 
                  FormBox[
                    SuperscriptBox["x", "2"],
                    "TraditionalForm"], ")"}]}], ",", 
              RowBox[{"{", 
                RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}], ",", 
          RowBox[{
            RowBox[{"Hold", "[", "Integrate3", "]"}], "[", 
            RowBox[{
              FractionBox[
                RowBox[{
                  SuperscriptBox["x", 
                    RowBox[{"m", "-", "1"}]], " ", 
                  RowBox[{
                    SubscriptBox["S", 
                      RowBox[{
                        FormBox["1",
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox["2",
                          "TraditionalForm"]}]], "(", 
                    FormBox[
                      SuperscriptBox["x", "2"],
                      "TraditionalForm"], ")"}]}], 
                RowBox[{"x", "+", "1"}]], ",", 
              RowBox[{"{", 
                RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}], ",", 
          RowBox[{
            RowBox[{"Hold", "[", "Integrate3", "]"}], "[", 
            RowBox[{
              FractionBox[
                RowBox[{
                  SuperscriptBox["x", 
                    RowBox[{"m", "-", "1"}]], " ", 
                  RowBox[{"log", "(", 
                    RowBox[{"1", "-", "x"}], ")"}], " ", 
                  RowBox[{
                    SubscriptBox["Li", "2"], "(", 
                    RowBox[{"1", "-", "x"}], ")"}]}], 
                RowBox[{"x", "+", "1"}]], ",", 
              RowBox[{"{", 
                RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}], ",", 
          RowBox[{
            RowBox[{"Hold", "[", "Integrate3", "]"}], "[", 
            RowBox[{
              RowBox[{
                SuperscriptBox["x", 
                  RowBox[{"m", "-", "1"}]], " ", 
                RowBox[{"log", "(", 
                  RowBox[{"x", "+", "1"}], ")"}], " ", 
                RowBox[{
                  SubscriptBox["Li", "2"], "(", 
                  RowBox[{"1", "-", "x"}], ")"}]}], ",", 
              RowBox[{"{", 
                RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}], ",", 
          RowBox[{
            RowBox[{"Hold", "[", "Integrate3", "]"}], "[", 
            RowBox[{
              RowBox[{
                SuperscriptBox["x", "m"], " ", 
                RowBox[{"log", "(", 
                  RowBox[{"x", "+", "1"}], ")"}], " ", 
                RowBox[{
                  SubscriptBox["Li", "2"], "(", 
                  RowBox[{"1", "-", "x"}], ")"}]}], ",", 
              RowBox[{"{", 
                RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}], ",", 
          RowBox[{
            RowBox[{"Hold", "[", "Integrate3", "]"}], "[", 
            RowBox[{
              FractionBox[
                RowBox[{
                  SuperscriptBox["x", 
                    RowBox[{"m", "-", "1"}]], " ", 
                  RowBox[{"log", "(", 
                    RowBox[{"x", "+", "1"}], ")"}], " ", 
                  RowBox[{
                    SubscriptBox["Li", "2"], "(", 
                    RowBox[{"1", "-", "x"}], ")"}]}], 
                RowBox[{"x", "+", "1"}]], ",", 
              RowBox[{"{", 
                RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[60]=  (21:49:08 on 5/16/01)"]
}, Open  ]],

Cell[TextData[{
  "Change the appearance and retain only those integrals with ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox["x", 
            RowBox[{"m", "-", "1"}]], ":"}], TraditionalForm]]]
}], "Text",
  CellTags->"A moment integral"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Select2", "[", 
        RowBox[{"%", ",", 
          SuperscriptBox["x", 
            RowBox[{"OPEm", "-", "1"}]]}], "]"}], "/.", " ", 
      RowBox[{
        RowBox[{
          RowBox[{"Hold", "[", "Integrate3", "]"}], "[", "z__", "]"}], 
        "\[RuleDelayed]", " ", 
        RowBox[{"HoldForm", "[", 
          RowBox[{"Integrate", "[", "z", "]"}], "]"}]}]}]], "Input",
  CellLabel->"In[61]:=  (21:49:08 on 5/16/01)",
  CellTags->"A moment integral"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          TagBox[
            RowBox[{
              SubsuperscriptBox["\[Integral]", "0", "1"], 
              RowBox[{
                RowBox[{
                  SuperscriptBox["x", 
                    RowBox[{"m", "-", "1"}]], " ", 
                  RowBox[{
                    SubscriptBox["S", 
                      RowBox[{
                        FormBox["1",
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox["2",
                          "TraditionalForm"]}]], "(", 
                    FormBox[
                      SuperscriptBox["x", "2"],
                      "TraditionalForm"], ")"}]}], 
                RowBox[{"\[DifferentialD]", "x"}]}]}],
            HoldForm], ",", 
          TagBox[
            RowBox[{
              SubsuperscriptBox["\[Integral]", "0", "1"], 
              RowBox[{
                FractionBox[
                  RowBox[{
                    SuperscriptBox["x", 
                      RowBox[{"m", "-", "1"}]], " ", 
                    RowBox[{
                      SubscriptBox["S", 
                        RowBox[{
                          FormBox["1",
                            "TraditionalForm"], "\[NoBreak]", 
                          FormBox["2",
                            "TraditionalForm"]}]], "(", 
                      FormBox[
                        SuperscriptBox["x", "2"],
                        "TraditionalForm"], ")"}]}], 
                  RowBox[{"x", "+", "1"}]], 
                RowBox[{"\[DifferentialD]", "x"}]}]}],
            HoldForm], ",", 
          TagBox[
            RowBox[{
              SubsuperscriptBox["\[Integral]", "0", "1"], 
              RowBox[{
                FractionBox[
                  RowBox[{
                    SuperscriptBox["x", 
                      RowBox[{"m", "-", "1"}]], " ", 
                    RowBox[{"log", "(", 
                      RowBox[{"1", "-", "x"}], ")"}], " ", 
                    RowBox[{
                      SubscriptBox["Li", "2"], "(", 
                      RowBox[{"1", "-", "x"}], ")"}]}], 
                  RowBox[{"x", "+", "1"}]], 
                RowBox[{"\[DifferentialD]", "x"}]}]}],
            HoldForm], ",", 
          TagBox[
            RowBox[{
              SubsuperscriptBox["\[Integral]", "0", "1"], 
              RowBox[{
                RowBox[{
                  SuperscriptBox["x", 
                    RowBox[{"m", "-", "1"}]], " ", 
                  RowBox[{"log", "(", 
                    RowBox[{"x", "+", "1"}], ")"}], " ", 
                  RowBox[{
                    SubscriptBox["Li", "2"], "(", 
                    RowBox[{"1", "-", "x"}], ")"}]}], 
                RowBox[{"\[DifferentialD]", "x"}]}]}],
            HoldForm], ",", 
          TagBox[
            RowBox[{
              SubsuperscriptBox["\[Integral]", "0", "1"], 
              RowBox[{
                FractionBox[
                  RowBox[{
                    SuperscriptBox["x", 
                      RowBox[{"m", "-", "1"}]], " ", 
                    RowBox[{"log", "(", 
                      RowBox[{"x", "+", "1"}], ")"}], " ", 
                    RowBox[{
                      SubscriptBox["Li", "2"], "(", 
                      RowBox[{"1", "-", "x"}], ")"}]}], 
                  RowBox[{"x", "+", "1"}]], 
                RowBox[{"\[DifferentialD]", "x"}]}]}],
            HoldForm]}], "}"}], TraditionalForm]], "Output",
  CellLabel->"Out[61]=  (21:49:08 on 5/16/01)"]
}, Open  ]],

Cell["\<\
If you do know the answers for these integrals please share the knowledge.\
\>", "Text",
  CellTags->"A moment integral"],

Cell[BoxData[
    RowBox[{"Clear", "[", 
      RowBox[{"e", ",", "ww", ",", "gqq", ",", "big", ",", "aqq"}], 
      "]"}]], "Input",
  CellLabel->"In[62]:=  (21:49:08 on 5/16/01)",
  CellTags->"A moment integral"],

Cell[BoxData[
    RowBox[{
      RowBox[{"SetOptions", "[", 
        RowBox[{"FORM2FeynCalc", ",", 
          RowBox[{"Replace", "\[Rule]", 
            RowBox[{"{", "}"}]}]}], "]"}], ";"}]], "Input",
  CellLabel->"In[63]:=  (21:49:08 on 5/16/01)",
  CellTags->"A moment integral"],

Cell[TextData[{
  "See also: ",
  ButtonBox["CA",
    ButtonData:>"CA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["CF",
    ButtonData:>"CF",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Cases2",
    ButtonData:>"Cases2",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Collect2",
    ButtonData:>"Collect2",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["DeltaFunction",
    ButtonData:>"DeltaFunction",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Epsilon",
    ButtonData:>"Epsilon",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["FORM2FeynCalc",
    ButtonData:>"FORM2FeynCalc",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Integrate2",
    ButtonData:>"Integrate3",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Integrate3",
    ButtonData:>"Integrate3",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Li2",
    ButtonData:>"Li2",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Li3",
    ButtonData:>"Li3",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Nielsen",
    ButtonData:>"Nielsen",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Zeta2",
    ButtonData:>"Zeta2",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Text",
  CellTags->"A moment integral"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Reference Guide", "Section",
  CellTags->"Reference Guide"],

Cell[CellGroupData[{

Cell["Evaluation time and memory usage", "Commentary"],

Cell["\<\
This is only for timing purposes and can be omitted in general.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"absolutestarttime", "=", 
      RowBox[{"AbsoluteTime", "[", "]"}]}]], "Input",
  CellLabel->"In[64]:=  (21:51:49 on 5/16/01)"],

Cell[BoxData[
    FormBox["3.199038709`15.5256*^9", TraditionalForm]], "Output",
  CellLabel->"Out[64]=  (21:51:49 on 5/16/01)"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["A0", "ObjectName",
  PageBreakAbove->True,
  CellTags->"A0"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"A0"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"A0", "[", 
            SuperscriptBox["m", "2"], "]"}], " ", "is", "the", "Passarino"}], 
        "-", 
        RowBox[{"Veltman", "one"}], "-", 
        RowBox[{"point", " ", " ", "integral", " ", " ", 
          SubscriptBox["A", "0."]}]}], TraditionalForm]]]], "Text",
  CellTags->"A0"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", " ", "A0", "]"}]], "Input",
  CellLabel->"In[65]:=  (21:51:49 on 5/16/01)",
  CellTags->"A0"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"A0ToB0", "\[Rule]", "True"}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[65]=  (21:51:49 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["B0",
    ButtonData:>"B0",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"B0"],
  ", ",
  ButtonBox["C0",
    ButtonData:>"C0",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"C0"],
  ", ",
  ButtonBox["D0",
    ButtonData:>"D0",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"D0"],
  ", ",
  ButtonBox["PaVe",
    ButtonData:>"PaVe",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"PaVe"],
  "."
}], "Text",
  CellTags->"A0"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"A0"],

Cell[TextData[{
  "By default any ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["A", "0"], TraditionalForm]]],
  " is expressed in terms of ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["B", "0"], TraditionalForm]]],
  "'s."
}], "Text",
  CellTags->"A0"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"A0", "[", 
      SuperscriptBox["m", "2"], "]"}]], "Input",
  CellLabel->"In[66]:=  (21:51:49 on 5/16/01)",
  CellTags->"A0"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            SubscriptBox["B", "0"], "(", "0", ",", 
            SuperscriptBox["m", "2"], ",", 
            SuperscriptBox["m", "2"], ")"}], " ", 
          SuperscriptBox["m", "2"]}], "+", 
        SuperscriptBox["m", "2"]}], TraditionalForm]], "Output",
  CellLabel->"Out[66]=  (21:51:49 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"A0", "[", 
      RowBox[{
        SuperscriptBox["m", "2"], ",", 
        RowBox[{"A0ToB0", "\[Rule]", "False"}]}], "]"}]], "Input",
  CellLabel->"In[67]:=  (21:51:49 on 5/16/01)",
  CellTags->"A0"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            SubscriptBox["B", "0"], "(", "0", ",", 
            SuperscriptBox["m", "2"], ",", 
            SuperscriptBox["m", "2"], ")"}], " ", 
          SuperscriptBox["m", "2"]}], "+", 
        SuperscriptBox["m", "2"]}], TraditionalForm]], "Output",
  CellLabel->"Out[67]=  (21:51:49 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "According to the rules of dimensional regularization ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox["A", "0"], "(", "0", ")"}], TraditionalForm]]],
  " is set to 0."
}], "Text",
  CellTags->"A0"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"A0", "[", "0", "]"}]], "Input",
  CellLabel->"In[68]:=  (21:51:49 on 5/16/01)",
  CellTags->"A0"],

Cell[BoxData[
    FormBox["0", TraditionalForm]], "Output",
  CellLabel->"Out[68]=  (21:51:49 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"A0", "[", 
      RowBox[{"SmallVariable", "[", 
        RowBox[{"M", "^", "2"}], "]"}], "]"}]], "Input",
  CellLabel->"In[69]:=  (21:51:49 on 5/16/01)",
  CellTags->"A0"],

Cell[BoxData[
    FormBox["0", TraditionalForm]], "Output",
  CellLabel->"Out[69]=  (21:51:49 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Amplitudes", "ObjectName",
  CellTags->"Amplitudes"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"Amplitudes"],

Cell["\<\
Amplitudes[name] is a database of Feynman amplitudes. Gauge \[Rule] 1 means \
`t Hooft Feynman gauge; Polarization \[Rule] 0 gives unpolarized OPE-type \
amplitudes, Polarization \[Rule] 1 the polarized ones.\
\>", "Text",
  CellTags->"Amplitudes"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "Amplitudes", "]"}]], "Input",
  CellLabel->"In[70]:=  (21:51:49 on 5/16/01)",
  CellTags->"Amplitudes"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
          RowBox[{"Gauge", "\[Rule]", "1"}], ",", 
          RowBox[{"QuarkMass", "\[Rule]", "0"}], ",", 
          RowBox[{"Polarization", "\[Rule]", "1"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[70]=  (21:51:49 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["FeynAmp",
    ButtonData:>"FeynAmp",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FeynAmp"],
  "."
}], "Text",
  CellTags->"Amplitudes"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"Amplitudes"],

Cell["This is the amplitude of a gluon self-energy diagram.", "Text",
  CellTags->"Amplitudes"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Amplitudes", "[", "\"\<se1g1\>\"", "]"}]], "Input",
  CellLabel->"In[71]:=  (21:51:50 on 5/16/01)",
  CellTags->"Amplitudes"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            SubsuperscriptBox["g", "s", "2"], " ", 
            RowBox[{
              SuperscriptBox["V", 
                RowBox[{
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], "(", 
              RowBox[{
                FormBox[
                  RowBox[{"-", "p"}],
                  "TraditionalForm"], "\[NoBreak]", 
                RowBox[{",", " "}], "\[NoBreak]", 
                FormBox[
                  RowBox[{"p", "-", "q"}],
                  "TraditionalForm"], "\[NoBreak]", 
                RowBox[{",", " "}], "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}], ")"}], " ", 
            RowBox[{
              SuperscriptBox["V", 
                RowBox[{
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Alpha]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Beta]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], "(", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", 
                RowBox[{",", " "}], "\[NoBreak]", 
                FormBox[
                  RowBox[{"q", "-", "p"}],
                  "TraditionalForm"], "\[NoBreak]", 
                RowBox[{",", " "}], "\[NoBreak]", 
                FormBox[
                  RowBox[{"-", "q"}],
                  "TraditionalForm"]}], ")"}], " ", 
            SuperscriptBox["g", 
              RowBox[{
                FormBox[
                  FormBox["\[Alpha]",
                    "TraditionalForm"],
                  "TraditionalForm"], "\[NoBreak]", 
                FormBox[
                  FormBox["\[Rho]",
                    "TraditionalForm"],
                  "TraditionalForm"]}]], " ", 
            SuperscriptBox["g", 
              RowBox[{
                FormBox[
                  FormBox["\[Beta]",
                    "TraditionalForm"],
                  "TraditionalForm"], "\[NoBreak]", 
                FormBox[
                  FormBox["\[Sigma]",
                    "TraditionalForm"],
                  "TraditionalForm"]}]], " ", 
            SubscriptBox["\[Delta]", 
              RowBox[{
                FormBox[
                  FormBox["c",
                    "TraditionalForm"],
                  "TraditionalForm"], "\[NoBreak]", 
                FormBox[
                  FormBox["d",
                    "TraditionalForm"],
                  "TraditionalForm"]}]], " ", 
            SubscriptBox["\[Delta]", 
              RowBox[{
                FormBox[
                  FormBox["e",
                    "TraditionalForm"],
                  "TraditionalForm"], "\[NoBreak]", 
                FormBox[
                  FormBox["f",
                    "TraditionalForm"],
                  "TraditionalForm"]}]], " ", 
            SubscriptBox["f", 
              RowBox[{
                FormBox[
                  FormBox["a",
                    "TraditionalForm"],
                  "TraditionalForm"], "\[NoBreak]", 
                FormBox[
                  FormBox["c",
                    "TraditionalForm"],
                  "TraditionalForm"], "\[NoBreak]", 
                FormBox[
                  FormBox["e",
                    "TraditionalForm"],
                  "TraditionalForm"]}]], " ", 
            SubscriptBox["f", 
              RowBox[{
                FormBox[
                  FormBox["b",
                    "TraditionalForm"],
                  "TraditionalForm"], "\[NoBreak]", 
                FormBox[
                  FormBox["d",
                    "TraditionalForm"],
                  "TraditionalForm"], "\[NoBreak]", 
                FormBox[
                  FormBox["f",
                    "TraditionalForm"],
                  "TraditionalForm"]}]]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"p", "-", "q"}], ")"}], "2"], " ", 
            SuperscriptBox["q", "2"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[71]=  (21:51:50 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Explicit", "[", "%", "]"}]], "Input",
  CellLabel->"In[72]:=  (21:51:50 on 5/16/01)",
  CellTags->"Amplitudes"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        RowBox[{
          FractionBox["1", 
            RowBox[{
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"p", "-", "q"}], ")"}], "2"], " ", 
              SuperscriptBox["q", "2"]}]], 
          RowBox[{"(", 
            RowBox[{
              SubsuperscriptBox["g", "s", "2"], " ", 
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Alpha]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Beta]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"-", 
                      SuperscriptBox[
                        FormBox["p",
                          "TraditionalForm"], 
                        FormBox[
                          FormBox["\[Alpha]",
                            "TraditionalForm"],
                          "TraditionalForm"]]}], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Beta]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}], "-", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["\[Alpha]",
                          "TraditionalForm"],
                        "TraditionalForm"]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Beta]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}], "+", 
                  RowBox[{"2", " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Alpha]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["\[Beta]",
                          "TraditionalForm"],
                        "TraditionalForm"]]}], "-", 
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Alpha]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["\[Beta]",
                          "TraditionalForm"],
                        "TraditionalForm"]]}], "-", 
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Alpha]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Beta]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"]]}], "+", 
                  RowBox[{"2", " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Alpha]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Beta]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"]]}]}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Rho]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Sigma]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}], "-", 
                  RowBox[{"2", " ", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Rho]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Sigma]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}], "+", 
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Sigma]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["\[Rho]",
                          "TraditionalForm"],
                        "TraditionalForm"]]}], "+", 
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Sigma]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["\[Rho]",
                          "TraditionalForm"],
                        "TraditionalForm"]]}], "-", 
                  RowBox[{"2", " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Rho]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["\[Sigma]",
                          "TraditionalForm"],
                        "TraditionalForm"]]}], "+", 
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Rho]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["\[Sigma]",
                          "TraditionalForm"],
                        "TraditionalForm"]]}]}], ")"}], " ", 
              SubscriptBox["\[Delta]", 
                RowBox[{
                  FormBox[
                    FormBox["c",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["d",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SubscriptBox["\[Delta]", 
                RowBox[{
                  FormBox[
                    FormBox["e",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["f",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["a",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["c",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["e",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["b",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["d",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["f",
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}], ")"}]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[72]=  (21:51:50 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "This is the amplitude for graph 6.2 from the paper Z.Phys C ",
  StyleBox["70:",
    FontWeight->"Bold"],
  "637-654, 1996",
  StyleBox[".",
    FontWeight->"Bold"]
}], "Text",
  CellTags->"Amplitudes"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FeynAmp", "[", 
      RowBox[{"q1", ",", "q2", ",", 
        RowBox[{"EpsEvaluate", "[", 
          RowBox[{"Trick", "[", 
            RowBox[{"Explicit", "[", 
              RowBox[{"Amplitudes", "[", "\"\<gg2\>\"", "]"}], "]"}], "]"}], 
          "]"}]}], "]"}]], "Input",
  CellLabel->"In[73]:=  (21:51:50 on 5/16/01)",
  CellTags->"Amplitudes"],

Cell[BoxData[
    FormBox[
      RowBox[{"\[Integral]", 
        RowBox[{
          StyleBox[
            RowBox[{
              SuperscriptBox["\[DifferentialD]", "D"], 
              FormBox[
                SubscriptBox[
                  StyleBox["\<\"q\"\>",
                    FontSlant->"Italic"], "1"],
                "TraditionalForm"]}],
            ZeroWidthTimes->True], "\[Integral]", 
          RowBox[{
            SuperscriptBox["\[DifferentialD]", "D"], 
            FormBox[
              SubscriptBox[
                StyleBox["\<\"q\"\>",
                  FontSlant->"Italic"], "2"],
              "TraditionalForm"]}]}], "(", 
        FormBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"2", " ", "\[ImaginaryI]", " ", 
                SubsuperscriptBox["g", "s", "4"], " ", 
                SuperscriptBox["\[Epsilon]", 
                  RowBox[{
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Lambda]", "1"],
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Lambda]", "5"],
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      SubscriptBox[
                        StyleBox["\<\"q\"\>",
                          FontSlant->"Italic"], "2"],
                      "TraditionalForm"]}]], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      RowBox[{"-", 
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], 
                          FormBox[
                            FormBox["\[Nu]",
                              "TraditionalForm"],
                            "TraditionalForm"]]}], " ", 
                      SuperscriptBox["g", 
                        RowBox[{
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "7"],
                              "TraditionalForm"],
                            "TraditionalForm"], "\[NoBreak]", 
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "10"],
                              "TraditionalForm"],
                            "TraditionalForm"]}]]}], "+", 
                    RowBox[{"2", " ", 
                      SubsuperscriptBox[
                        StyleBox["\<\"q\"\>",
                          FontSlant->"Italic"], "1", 
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"]], " ", 
                      SuperscriptBox["g", 
                        RowBox[{
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "7"],
                              "TraditionalForm"],
                            "TraditionalForm"], "\[NoBreak]", 
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "10"],
                              "TraditionalForm"],
                            "TraditionalForm"]}]]}], "+", 
                    RowBox[{"2", " ", 
                      SuperscriptBox["g", 
                        RowBox[{
                          FormBox[
                            FormBox["\[Nu]",
                              "TraditionalForm"],
                            "TraditionalForm"], "\[NoBreak]", 
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "10"],
                              "TraditionalForm"],
                            "TraditionalForm"]}]], " ", 
                      SuperscriptBox[
                        FormBox["p",
                          "TraditionalForm"], 
                        FormBox[
                          FormBox[
                            SubscriptBox["\[Lambda]", "7"],
                            "TraditionalForm"],
                          "TraditionalForm"]]}], "-", 
                    RowBox[{
                      SuperscriptBox["g", 
                        RowBox[{
                          FormBox[
                            FormBox["\[Nu]",
                              "TraditionalForm"],
                            "TraditionalForm"], "\[NoBreak]", 
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "10"],
                              "TraditionalForm"],
                            "TraditionalForm"]}]], " ", 
                      SubsuperscriptBox[
                        StyleBox["\<\"q\"\>",
                          FontSlant->"Italic"], "1", 
                        FormBox[
                          FormBox[
                            SubscriptBox["\[Lambda]", "7"],
                            "TraditionalForm"],
                          "TraditionalForm"]]}], "-", 
                    RowBox[{
                      SuperscriptBox["g", 
                        RowBox[{
                          FormBox[
                            FormBox["\[Nu]",
                              "TraditionalForm"],
                            "TraditionalForm"], "\[NoBreak]", 
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "7"],
                              "TraditionalForm"],
                            "TraditionalForm"]}]], " ", 
                      SuperscriptBox[
                        FormBox["p",
                          "TraditionalForm"], 
                        FormBox[
                          FormBox[
                            SubscriptBox["\[Lambda]", "10"],
                            "TraditionalForm"],
                          "TraditionalForm"]]}], "-", 
                    RowBox[{
                      SuperscriptBox["g", 
                        RowBox[{
                          FormBox[
                            FormBox["\[Nu]",
                              "TraditionalForm"],
                            "TraditionalForm"], "\[NoBreak]", 
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "7"],
                              "TraditionalForm"],
                            "TraditionalForm"]}]], " ", 
                      SubsuperscriptBox[
                        StyleBox["\<\"q\"\>",
                          FontSlant->"Italic"], "1", 
                        FormBox[
                          FormBox[
                            SubscriptBox["\[Lambda]", "10"],
                            "TraditionalForm"],
                          "TraditionalForm"]]}]}], ")"}], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      SuperscriptBox[
                        FormBox["p",
                          "TraditionalForm"], 
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"]], " ", 
                      SuperscriptBox["g", 
                        RowBox[{
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "1"],
                              "TraditionalForm"],
                            "TraditionalForm"], "\[NoBreak]", 
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "11"],
                              "TraditionalForm"],
                            "TraditionalForm"]}]]}], "-", 
                    RowBox[{"2", " ", 
                      SubsuperscriptBox[
                        StyleBox["\<\"q\"\>",
                          FontSlant->"Italic"], "2", 
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"]], " ", 
                      SuperscriptBox["g", 
                        RowBox[{
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "1"],
                              "TraditionalForm"],
                            "TraditionalForm"], "\[NoBreak]", 
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "11"],
                              "TraditionalForm"],
                            "TraditionalForm"]}]]}], "-", 
                    RowBox[{"2", " ", 
                      SuperscriptBox["g", 
                        RowBox[{
                          FormBox[
                            FormBox["\[Mu]",
                              "TraditionalForm"],
                            "TraditionalForm"], "\[NoBreak]", 
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "11"],
                              "TraditionalForm"],
                            "TraditionalForm"]}]], " ", 
                      SuperscriptBox[
                        FormBox["p",
                          "TraditionalForm"], 
                        FormBox[
                          FormBox[
                            SubscriptBox["\[Lambda]", "1"],
                            "TraditionalForm"],
                          "TraditionalForm"]]}], "+", 
                    RowBox[{
                      SuperscriptBox["g", 
                        RowBox[{
                          FormBox[
                            FormBox["\[Mu]",
                              "TraditionalForm"],
                            "TraditionalForm"], "\[NoBreak]", 
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "11"],
                              "TraditionalForm"],
                            "TraditionalForm"]}]], " ", 
                      SubsuperscriptBox[
                        StyleBox["\<\"q\"\>",
                          FontSlant->"Italic"], "2", 
                        FormBox[
                          FormBox[
                            SubscriptBox["\[Lambda]", "1"],
                            "TraditionalForm"],
                          "TraditionalForm"]]}], "+", 
                    RowBox[{
                      SuperscriptBox["g", 
                        RowBox[{
                          FormBox[
                            FormBox["\[Mu]",
                              "TraditionalForm"],
                            "TraditionalForm"], "\[NoBreak]", 
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "1"],
                              "TraditionalForm"],
                            "TraditionalForm"]}]], " ", 
                      SuperscriptBox[
                        FormBox["p",
                          "TraditionalForm"], 
                        FormBox[
                          FormBox[
                            SubscriptBox["\[Lambda]", "11"],
                            "TraditionalForm"],
                          "TraditionalForm"]]}], "+", 
                    RowBox[{
                      SuperscriptBox["g", 
                        RowBox[{
                          FormBox[
                            FormBox["\[Mu]",
                              "TraditionalForm"],
                            "TraditionalForm"], "\[NoBreak]", 
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "1"],
                              "TraditionalForm"],
                            "TraditionalForm"]}]], " ", 
                      SubsuperscriptBox[
                        StyleBox["\<\"q\"\>",
                          FontSlant->"Italic"], "2", 
                        FormBox[
                          FormBox[
                            SubscriptBox["\[Lambda]", "11"],
                            "TraditionalForm"],
                          "TraditionalForm"]]}]}], ")"}], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      RowBox[{"-", "2"}], " ", 
                      SubsuperscriptBox[
                        StyleBox["\<\"q\"\>",
                          FontSlant->"Italic"], "1", 
                        FormBox[
                          FormBox[
                            SubscriptBox["\[Lambda]", "5"],
                            "TraditionalForm"],
                          "TraditionalForm"]], " ", 
                      SuperscriptBox["g", 
                        RowBox[{
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "7"],
                              "TraditionalForm"],
                            "TraditionalForm"], "\[NoBreak]", 
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "12"],
                              "TraditionalForm"],
                            "TraditionalForm"]}]]}], "+", 
                    RowBox[{
                      SubsuperscriptBox[
                        StyleBox["\<\"q\"\>",
                          FontSlant->"Italic"], "2", 
                        FormBox[
                          FormBox[
                            SubscriptBox["\[Lambda]", "5"],
                            "TraditionalForm"],
                          "TraditionalForm"]], " ", 
                      SuperscriptBox["g", 
                        RowBox[{
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "7"],
                              "TraditionalForm"],
                            "TraditionalForm"], "\[NoBreak]", 
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "12"],
                              "TraditionalForm"],
                            "TraditionalForm"]}]]}], "+", 
                    RowBox[{
                      SuperscriptBox["g", 
                        RowBox[{
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "5"],
                              "TraditionalForm"],
                            "TraditionalForm"], "\[NoBreak]", 
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "12"],
                              "TraditionalForm"],
                            "TraditionalForm"]}]], " ", 
                      SubsuperscriptBox[
                        StyleBox["\<\"q\"\>",
                          FontSlant->"Italic"], "1", 
                        FormBox[
                          FormBox[
                            SubscriptBox["\[Lambda]", "7"],
                            "TraditionalForm"],
                          "TraditionalForm"]]}], "-", 
                    RowBox[{"2", " ", 
                      SuperscriptBox["g", 
                        RowBox[{
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "5"],
                              "TraditionalForm"],
                            "TraditionalForm"], "\[NoBreak]", 
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "12"],
                              "TraditionalForm"],
                            "TraditionalForm"]}]], " ", 
                      SubsuperscriptBox[
                        StyleBox["\<\"q\"\>",
                          FontSlant->"Italic"], "2", 
                        FormBox[
                          FormBox[
                            SubscriptBox["\[Lambda]", "7"],
                            "TraditionalForm"],
                          "TraditionalForm"]]}], "+", 
                    RowBox[{
                      SuperscriptBox["g", 
                        RowBox[{
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "5"],
                              "TraditionalForm"],
                            "TraditionalForm"], "\[NoBreak]", 
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "7"],
                              "TraditionalForm"],
                            "TraditionalForm"]}]], " ", 
                      SubsuperscriptBox[
                        StyleBox["\<\"q\"\>",
                          FontSlant->"Italic"], "1", 
                        FormBox[
                          FormBox[
                            SubscriptBox["\[Lambda]", "12"],
                            "TraditionalForm"],
                          "TraditionalForm"]]}], "+", 
                    RowBox[{
                      SuperscriptBox["g", 
                        RowBox[{
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "5"],
                              "TraditionalForm"],
                            "TraditionalForm"], "\[NoBreak]", 
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "7"],
                              "TraditionalForm"],
                            "TraditionalForm"]}]], " ", 
                      SubsuperscriptBox[
                        StyleBox["\<\"q\"\>",
                          FontSlant->"Italic"], "2", 
                        FormBox[
                          FormBox[
                            SubscriptBox["\[Lambda]", "12"],
                            "TraditionalForm"],
                          "TraditionalForm"]]}]}], ")"}], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      RowBox[{"-", 
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], 
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "10"],
                              "TraditionalForm"],
                            "TraditionalForm"]]}], " ", 
                      SuperscriptBox["g", 
                        RowBox[{
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "11"],
                              "TraditionalForm"],
                            "TraditionalForm"], "\[NoBreak]", 
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "12"],
                              "TraditionalForm"],
                            "TraditionalForm"]}]]}], "-", 
                    RowBox[{
                      SubsuperscriptBox[
                        StyleBox["\<\"q\"\>",
                          FontSlant->"Italic"], "1", 
                        FormBox[
                          FormBox[
                            SubscriptBox["\[Lambda]", "10"],
                            "TraditionalForm"],
                          "TraditionalForm"]], " ", 
                      SuperscriptBox["g", 
                        RowBox[{
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "11"],
                              "TraditionalForm"],
                            "TraditionalForm"], "\[NoBreak]", 
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "12"],
                              "TraditionalForm"],
                            "TraditionalForm"]}]]}], "+", 
                    RowBox[{"2", " ", 
                      SubsuperscriptBox[
                        StyleBox["\<\"q\"\>",
                          FontSlant->"Italic"], "2", 
                        FormBox[
                          FormBox[
                            SubscriptBox["\[Lambda]", "10"],
                            "TraditionalForm"],
                          "TraditionalForm"]], " ", 
                      SuperscriptBox["g", 
                        RowBox[{
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "11"],
                              "TraditionalForm"],
                            "TraditionalForm"], "\[NoBreak]", 
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "12"],
                              "TraditionalForm"],
                            "TraditionalForm"]}]]}], "-", 
                    RowBox[{
                      SuperscriptBox["g", 
                        RowBox[{
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "10"],
                              "TraditionalForm"],
                            "TraditionalForm"], "\[NoBreak]", 
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "12"],
                              "TraditionalForm"],
                            "TraditionalForm"]}]], " ", 
                      SuperscriptBox[
                        FormBox["p",
                          "TraditionalForm"], 
                        FormBox[
                          FormBox[
                            SubscriptBox["\[Lambda]", "11"],
                            "TraditionalForm"],
                          "TraditionalForm"]]}], "+", 
                    RowBox[{"2", " ", 
                      SuperscriptBox["g", 
                        RowBox[{
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "10"],
                              "TraditionalForm"],
                            "TraditionalForm"], "\[NoBreak]", 
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "12"],
                              "TraditionalForm"],
                            "TraditionalForm"]}]], " ", 
                      SubsuperscriptBox[
                        StyleBox["\<\"q\"\>",
                          FontSlant->"Italic"], "1", 
                        FormBox[
                          FormBox[
                            SubscriptBox["\[Lambda]", "11"],
                            "TraditionalForm"],
                          "TraditionalForm"]]}], "-", 
                    RowBox[{
                      SuperscriptBox["g", 
                        RowBox[{
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "10"],
                              "TraditionalForm"],
                            "TraditionalForm"], "\[NoBreak]", 
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "12"],
                              "TraditionalForm"],
                            "TraditionalForm"]}]], " ", 
                      SubsuperscriptBox[
                        StyleBox["\<\"q\"\>",
                          FontSlant->"Italic"], "2", 
                        FormBox[
                          FormBox[
                            SubscriptBox["\[Lambda]", "11"],
                            "TraditionalForm"],
                          "TraditionalForm"]]}], "+", 
                    RowBox[{"2", " ", 
                      SuperscriptBox["g", 
                        RowBox[{
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "10"],
                              "TraditionalForm"],
                            "TraditionalForm"], "\[NoBreak]", 
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "11"],
                              "TraditionalForm"],
                            "TraditionalForm"]}]], " ", 
                      SuperscriptBox[
                        FormBox["p",
                          "TraditionalForm"], 
                        FormBox[
                          FormBox[
                            SubscriptBox["\[Lambda]", "12"],
                            "TraditionalForm"],
                          "TraditionalForm"]]}], "-", 
                    RowBox[{
                      SuperscriptBox["g", 
                        RowBox[{
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "10"],
                              "TraditionalForm"],
                            "TraditionalForm"], "\[NoBreak]", 
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "11"],
                              "TraditionalForm"],
                            "TraditionalForm"]}]], " ", 
                      SubsuperscriptBox[
                        StyleBox["\<\"q\"\>",
                          FontSlant->"Italic"], "1", 
                        FormBox[
                          FormBox[
                            SubscriptBox["\[Lambda]", "12"],
                            "TraditionalForm"],
                          "TraditionalForm"]]}], "-", 
                    RowBox[{
                      SuperscriptBox["g", 
                        RowBox[{
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "10"],
                              "TraditionalForm"],
                            "TraditionalForm"], "\[NoBreak]", 
                          FormBox[
                            FormBox[
                              SubscriptBox["\[Lambda]", "11"],
                              "TraditionalForm"],
                            "TraditionalForm"]}]], " ", 
                      SubsuperscriptBox[
                        StyleBox["\<\"q\"\>",
                          FontSlant->"Italic"], "2", 
                        FormBox[
                          FormBox[
                            SubscriptBox["\[Lambda]", "12"],
                            "TraditionalForm"],
                          "TraditionalForm"]]}]}], ")"}], " ", 
                RowBox[{"(", 
                  RowBox[{"1", "-", 
                    FormBox[
                      SuperscriptBox[
                        RowBox[{"(", 
                          RowBox[{"-", "1"}], ")"}], "m"],
                      "TraditionalForm"]}], ")"}], " ", 
                FormBox[
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox[
                          SubscriptBox[
                            StyleBox["\<\"q\"\>",
                              FontSlant->"Italic"], "2"],
                          "TraditionalForm"]}], ")"}], 
                    RowBox[{"m", "-", "1"}]],
                  "TraditionalForm"], " ", 
                SubscriptBox["f", 
                  RowBox[{
                    FormBox[
                      FormBox["a",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\<\"c\"\>", "5"],
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\<\"c\"\>", "11"],
                        "TraditionalForm"],
                      "TraditionalForm"]}]], " ", 
                SubscriptBox["f", 
                  RowBox[{
                    FormBox[
                      FormBox["b",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\<\"c\"\>", "7"],
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\<\"c\"\>", "10"],
                        "TraditionalForm"],
                      "TraditionalForm"]}]], " ", 
                SubscriptBox["f", 
                  RowBox[{
                    FormBox[
                      FormBox[
                        SubscriptBox["\<\"c\"\>", "5"],
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\<\"c\"\>", "7"],
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\<\"c\"\>", "12"],
                        "TraditionalForm"],
                      "TraditionalForm"]}]], " ", 
                SubscriptBox["f", 
                  RowBox[{
                    FormBox[
                      FormBox[
                        SubscriptBox["\<\"c\"\>", "10"],
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\<\"c\"\>", "11"],
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\<\"c\"\>", "12"],
                        "TraditionalForm"],
                      "TraditionalForm"]}]]}], ")"}], "/", 
            RowBox[{
              SubsuperscriptBox[
                StyleBox["\<\"q\"\>",
                  FontSlant->"Italic"], "1", "2"], ".", 
              SubsuperscriptBox[
                StyleBox["\<\"q\"\>",
                  FontSlant->"Italic"], "2", "2"], ".", 
              SubsuperscriptBox[
                StyleBox["\<\"q\"\>",
                  FontSlant->"Italic"], "2", "2"], ".", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["\<\"q\"\>",
                        FontSlant->"Italic"], "2"], "-", "p"}], ")"}], "2"], 
              ".", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["\<\"q\"\>",
                        FontSlant->"Italic"], "1"], "-", 
                    SubscriptBox[
                      StyleBox["\<\"q\"\>",
                        FontSlant->"Italic"], "2"]}], ")"}], "2"], ".", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["\<\"q\"\>",
                        FontSlant->"Italic"], "1"], "-", "p"}], ")"}], 
                "2"]}]}],
          "TraditionalForm"], ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[73]=  (21:51:51 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Amputate", "ObjectName",
  CellTags->"Amputate"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"Amputate"],

Cell["\<\
Amputate[exp,q1,q2,...] amputates Eps and DiracGamma. Amputate[exp,q1,q2,Pair\
\[Rule]{p}] amputates also p.q1 and p.q2; Pair\[Rule]All amputates all except \
OPEDelta.\
\>", "Text",
  CellTags->"Amputate"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "Amputate", "]"}]], "Input",
  CellLabel->"In[74]:=  (21:51:51 on 5/16/01)",
  CellTags->"Amputate"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
          RowBox[{"Pair", "\[Rule]", 
            RowBox[{"{", "}"}]}], ",", 
          RowBox[{"Unique", "\[Rule]", "True"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[74]=  (21:51:51 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also:  ",
  ButtonBox["DiracGamma",
    ButtonData:>"DiracGamma",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracGamma"],
  ", ",
  ButtonBox["DiracMatrix",
    ButtonData:>"DiracMatrix",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracMatrix"],
  ", ",
  ButtonBox["DiracSimplify",
    ButtonData:>"DiracSimplify",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracSimplify"],
  ", ",
  ButtonBox["DiracSlash",
    ButtonData:>"DiracSlash",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracSlash"],
  ", ",
  ButtonBox["DiracTrick",
    ButtonData:>"DiracTrick",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracTrick"],
  "."
}], "Text",
  CellTags->"Amputate"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"Amputate"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"DiracSlash", "[", "p", "]"}], ".", 
      RowBox[{"DiracSlash", "[", "q", "]"}]}]], "Input",
  CellLabel->"In[75]:=  (21:51:52 on 5/16/01)",
  CellTags->"Amputate"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            FormBox["\<\"\[Gamma]\"\>",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["p",
              "TraditionalForm"]}], ")"}], ".", 
        RowBox[{"(", 
          RowBox[{
            FormBox["\<\"\[Gamma]\"\>",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["q",
              "TraditionalForm"]}], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[75]=  (21:51:52 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Amputate", "[", 
      RowBox[{"%", ",", "q"}], "]"}]], "Input",
  CellLabel->"In[76]:=  (21:51:52 on 5/16/01)",
  CellTags->"Amputate"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              FormBox["\<\"\[Gamma]\"\>",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox["p",
                "TraditionalForm"]}], ")"}], ".", 
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox[
                RowBox[{"$AL$41", "\[InvisibleApplication]", 
                  RowBox[{"(", "1", ")"}]}],
                "TraditionalForm"],
              "TraditionalForm"]]}], " ", 
        SuperscriptBox[
          FormBox["q",
            "TraditionalForm"], 
          FormBox[
            FormBox[
              RowBox[{"$AL$41", "\[InvisibleApplication]", 
                RowBox[{"(", "1", ")"}]}],
              "TraditionalForm"],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[76]=  (21:51:52 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["AnomalousDimension", "ObjectName",
  CellTags->"AnomalousDimension"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"AnomalousDimension"],

Cell["\<\
AnomalousDimension[name] is a incomplete database of anomalous dimensions of \
twist 2 operators.\
\>", "Text",
  CellTags->"AnomalousDimension"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "AnomalousDimension", "]"}]], "Input",
  CellLabel->"In[77]:=  (21:51:52 on 5/16/01)",
  CellTags->"AnomalousDimension"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"Polarization", "\[Rule]", "1"}], ",", 
          RowBox[{"Simplify", "\[Rule]", "FullSimplify"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[77]=  (21:51:52 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  ButtonBox["SplittingFunction",
    ButtonData:>"SplittingFunction",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SplittingFunction"],
  ", ",
  ButtonBox["SumS",
    ButtonData:>"SumS",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SumS"],
  ", ",
  ButtonBox["SumT",
    ButtonData:>"SumT",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SumT"],
  "."
}], "Text",
  CellTags->"AnomalousDimension"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"AnomalousDimension"],

Cell["Polarized case", "Text",
  CellTags->"AnomalousDimension"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SetOptions", "[", " ", 
      RowBox[{"AnomalousDimension", ",", 
        RowBox[{"Polarization", "\[Rule]", "1"}]}], "]"}]], "Input",
  CellLabel->"In[78]:=  (21:51:52 on 5/16/01)",
  CellTags->"AnomalousDimension"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"Polarization", "\[Rule]", "1"}], ",", 
          RowBox[{"Simplify", "\[Rule]", "FullSimplify"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[78]=  (21:51:52 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[Gamma]", 
          RowBox[{"NS", ",", "qq", " "}], 
          RowBox[{"(", "0", ")", " "}]], TraditionalForm]]],
  "polarized"
}], "Text",
  CellTags->"AnomalousDimension"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"AnomalousDimension", "[", "gnsqq0", "]"}]], "Input",
  CellLabel->"In[79]:=  (21:51:52 on 5/16/01)",
  CellTags->"AnomalousDimension"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["C", "F"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"8", " ", 
              RowBox[{
                SubscriptBox["S", "1"], "(", 
                FormBox[
                  RowBox[{"m", "-", "1"}],
                  "TraditionalForm"], ")"}]}], "+", 
            FractionBox["4", "m"], "+", 
            FractionBox["4", 
              RowBox[{"m", "+", "1"}]], "-", "6"}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[79]=  (21:51:52 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[Gamma]", 
          RowBox[{"S", ",", "qg", " "}], 
          RowBox[{"(", "0", ")", " "}]], TraditionalForm]]],
  "polarized"
}], "Text",
  CellTags->"AnomalousDimension"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"AnomalousDimension", "[", "gsqg0", "]"}]], "Input",
  CellLabel->"In[80]:=  (21:51:52 on 5/16/01)",
  CellTags->"AnomalousDimension"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            FractionBox["8", "m"], "-", 
            FractionBox["16", 
              RowBox[{"m", "+", "1"}]]}], ")"}], " ", 
        SubscriptBox["T", "f"]}], TraditionalForm]], "Output",
  CellLabel->"Out[80]=  (21:51:52 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[Gamma]", 
          RowBox[{"S", ",", "gq", " "}], 
          RowBox[{"(", "0", ")", " "}]], TraditionalForm]]],
  "polarized"
}], "Text",
  CellTags->"AnomalousDimension"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"AnomalousDimension", "[", "gsgq0", "]"}]], "Input",
  CellLabel->"In[81]:=  (21:51:52 on 5/16/01)",
  CellTags->"AnomalousDimension"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["C", "F"], " ", 
        RowBox[{"(", 
          RowBox[{
            FractionBox["4", 
              RowBox[{"m", "+", "1"}]], "-", 
            FractionBox["8", "m"]}], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[81]=  (21:51:52 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[Gamma]", 
          RowBox[{"S", ",", "gg", " "}], 
          RowBox[{"(", "0", ")", " "}]], TraditionalForm]]],
  "polarized"
}], "Text",
  CellTags->"AnomalousDimension"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"AnomalousDimension", "[", "gsgg0", "]"}]], "Input",
  CellLabel->"In[82]:=  (21:51:52 on 5/16/01)",
  CellTags->"AnomalousDimension"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{"8", " ", 
            SubscriptBox["T", "f"]}], "3"], "+", 
        RowBox[{
          SubscriptBox["C", "A"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"8", " ", 
                RowBox[{
                  SubscriptBox["S", "1"], "(", 
                  FormBox[
                    RowBox[{"m", "-", "1"}],
                    "TraditionalForm"], ")"}]}], "-", 
              FractionBox["8", "m"], "+", 
              FractionBox["16", 
                RowBox[{"m", "+", "1"}]], "-", 
              FractionBox["22", "3"]}], ")"}]}]}], TraditionalForm]], "Output",\

  CellLabel->"Out[82]=  (21:51:52 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[Gamma]", 
          RowBox[{"PS", ",", "qq", " "}], 
          RowBox[{"(", "0", ")", " "}]], TraditionalForm]]],
  "polarized"
}], "Text",
  CellTags->"AnomalousDimension"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"AnomalousDimension", "[", "gpsqq1", "]"}]], "Input",
  CellLabel->"In[83]:=  (21:51:52 on 5/16/01)",
  CellTags->"AnomalousDimension"],

Cell[BoxData[
    FormBox[
      RowBox[{"16", " ", 
        SubscriptBox["C", "F"], " ", 
        RowBox[{"(", 
          RowBox[{
            FractionBox["1", 
              RowBox[{"m", "+", "1"}]], "+", 
            FractionBox["3", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"m", "+", "1"}], ")"}], "2"]], "+", 
            FractionBox["2", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"m", "+", "1"}], ")"}], "3"]], "-", 
            FractionBox["1", "m"], "-", 
            FractionBox["1", 
              SuperscriptBox["m", "2"]], "+", 
            FractionBox["2", 
              SuperscriptBox["m", "3"]]}], ")"}], " ", 
        SubscriptBox["T", "f"]}], TraditionalForm]], "Output",
  CellLabel->"Out[83]=  (21:51:52 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[Gamma]", 
          RowBox[{"NS", ",", "qq", " "}], 
          RowBox[{"(", "1", ")", " "}]], TraditionalForm]]],
  "polarized"
}], "Text",
  CellTags->"AnomalousDimension"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"AnomalousDimension", "[", "gnsqq1", "]"}]], "Input",
  CellLabel->"In[84]:=  (21:51:52 on 5/16/01)",
  CellTags->"AnomalousDimension"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"-", 
            RowBox[{"(", 
              RowBox[{
                FractionBox[
                  RowBox[{"16", " ", 
                    RowBox[{
                      SubscriptBox["S", "1"], "(", 
                      FormBox[
                        RowBox[{"m", "-", "1"}],
                        "TraditionalForm"], ")"}]}], 
                  SuperscriptBox["m", "2"]], "+", 
                FractionBox[
                  RowBox[{"16", " ", 
                    RowBox[{
                      SubscriptBox["S", "1"], "(", 
                      FormBox[
                        RowBox[{"m", "-", "1"}],
                        "TraditionalForm"], ")"}]}], 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{"m", "+", "1"}], ")"}], "2"]], "+", 
                FractionBox[
                  RowBox[{"16", " ", 
                    RowBox[{
                      SubscriptBox["S", "2"], "(", 
                      FormBox[
                        RowBox[{"m", "-", "1"}],
                        "TraditionalForm"], ")"}]}], "m"], "+", 
                FractionBox[
                  RowBox[{"16", " ", 
                    RowBox[{
                      SubscriptBox["S", "2"], "(", 
                      FormBox[
                        RowBox[{"m", "-", "1"}],
                        "TraditionalForm"], ")"}]}], 
                  RowBox[{"m", "+", "1"}]], "-", 
                RowBox[{"24", " ", 
                  RowBox[{
                    SubscriptBox["S", "2"], "(", 
                    FormBox[
                      RowBox[{"m", "-", "1"}],
                      "TraditionalForm"], ")"}]}], "+", 
                RowBox[{"32", " ", 
                  RowBox[{
                    SubscriptBox["S", "12"], "(", 
                    FormBox[
                      RowBox[{"m", "-", "1"}],
                      "TraditionalForm"], ")"}]}], "+", 
                RowBox[{"32", " ", 
                  RowBox[{
                    SubscriptBox["S", "21"], "(", 
                    FormBox[
                      RowBox[{"m", "-", "1"}],
                      "TraditionalForm"], ")"}]}], "+", 
                FractionBox[
                  RowBox[{"32", " ", 
                    RowBox[{
                      SubscriptBox[
                        OverscriptBox["S", "~"], "2"], "(", 
                      FormBox[
                        RowBox[{"m", "-", "1"}],
                        "TraditionalForm"], ")"}]}], "m"], "+", 
                FractionBox[
                  RowBox[{"32", " ", 
                    RowBox[{
                      SubscriptBox[
                        OverscriptBox["S", "~"], "2"], "(", 
                      FormBox[
                        RowBox[{"m", "-", "1"}],
                        "TraditionalForm"], ")"}]}], 
                  RowBox[{"m", "+", "1"}]], "-", 
                RowBox[{"32", " ", 
                  RowBox[{
                    SubscriptBox[
                      OverscriptBox["S", "~"], "3"], "(", 
                    FormBox[
                      RowBox[{"m", "-", "1"}],
                      "TraditionalForm"], ")"}]}], "+", 
                RowBox[{"64", " ", 
                  RowBox[{
                    SubscriptBox[
                      OverscriptBox["S", "~"], "12"], "(", 
                    FormBox[
                      RowBox[{"m", "-", "1"}],
                      "TraditionalForm"], ")"}]}], "-", 
                FractionBox["40", "m"], "+", 
                FractionBox["40", 
                  RowBox[{"m", "+", "1"}]], "+", 
                FractionBox["16", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{"m", "+", "1"}], ")"}], "2"]], "+", 
                FractionBox["8", 
                  SuperscriptBox["m", "3"]], "+", 
                FractionBox["40", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{"m", "+", "1"}], ")"}], "3"]], "+", "3"}], 
              ")"}]}], " ", 
          SubsuperscriptBox["C", "F", "2"]}], "-", 
        RowBox[{
          SubscriptBox["N", "f"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                FractionBox["80", "9"], " ", 
                RowBox[{
                  SubscriptBox["S", "1"], "(", 
                  FormBox[
                    RowBox[{"m", "-", "1"}],
                    "TraditionalForm"], ")"}]}], "-", 
              RowBox[{
                FractionBox["16", "3"], " ", 
                RowBox[{
                  SubscriptBox["S", "2"], "(", 
                  FormBox[
                    RowBox[{"m", "-", "1"}],
                    "TraditionalForm"], ")"}]}], "-", 
              FractionBox["8", 
                RowBox[{"9", " ", "m"}]], "+", 
              FractionBox["88", 
                RowBox[{"9", " ", 
                  RowBox[{"(", 
                    RowBox[{"m", "+", "1"}], ")"}]}]], "-", 
              FractionBox["8", 
                RowBox[{"3", " ", 
                  SuperscriptBox["m", "2"]}]], "-", 
              FractionBox["8", 
                RowBox[{"3", " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{"m", "+", "1"}], ")"}], "2"]}]], "-", 
              FractionBox["2", "3"]}], ")"}], " ", 
          SubscriptBox["C", "F"]}], "-", 
        RowBox[{
          SubscriptBox["C", "A"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  FractionBox["536", "9"]}], " ", 
                RowBox[{
                  SubscriptBox["S", "1"], "(", 
                  FormBox[
                    RowBox[{"m", "-", "1"}],
                    "TraditionalForm"], ")"}]}], "+", 
              RowBox[{
                FractionBox["88", "3"], " ", 
                RowBox[{
                  SubscriptBox["S", "2"], "(", 
                  FormBox[
                    RowBox[{"m", "-", "1"}],
                    "TraditionalForm"], ")"}]}], "-", 
              RowBox[{"16", " ", 
                RowBox[{
                  SubscriptBox["S", "3"], "(", 
                  FormBox[
                    RowBox[{"m", "-", "1"}],
                    "TraditionalForm"], ")"}]}], "-", 
              FractionBox[
                RowBox[{"16", " ", 
                  RowBox[{
                    SubscriptBox[
                      OverscriptBox["S", "~"], "2"], "(", 
                    FormBox[
                      RowBox[{"m", "-", "1"}],
                      "TraditionalForm"], ")"}]}], "m"], "-", 
              FractionBox[
                RowBox[{"16", " ", 
                  RowBox[{
                    SubscriptBox[
                      OverscriptBox["S", "~"], "2"], "(", 
                    FormBox[
                      RowBox[{"m", "-", "1"}],
                      "TraditionalForm"], ")"}]}], 
                RowBox[{"m", "+", "1"}]], "+", 
              RowBox[{"16", " ", 
                RowBox[{
                  SubscriptBox[
                    OverscriptBox["S", "~"], "3"], "(", 
                  FormBox[
                    RowBox[{"m", "-", "1"}],
                    "TraditionalForm"], ")"}]}], "-", 
              RowBox[{"32", " ", 
                RowBox[{
                  SubscriptBox[
                    OverscriptBox["S", "~"], "12"], "(", 
                  FormBox[
                    RowBox[{"m", "-", "1"}],
                    "TraditionalForm"], ")"}]}], "+", 
              FractionBox["212", 
                RowBox[{"9", " ", "m"}]], "-", 
              FractionBox["748", 
                RowBox[{"9", " ", 
                  RowBox[{"(", 
                    RowBox[{"m", "+", "1"}], ")"}]}]], "+", 
              FractionBox["44", 
                RowBox[{"3", " ", 
                  SuperscriptBox["m", "2"]}]], "-", 
              FractionBox["4", 
                RowBox[{"3", " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{"m", "+", "1"}], ")"}], "2"]}]], "-", 
              FractionBox["16", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"m", "+", "1"}], ")"}], "3"]], "+", 
              FractionBox["17", "3"]}], ")"}], " ", 
          SubscriptBox["C", "F"]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[84]=  (21:51:52 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[Gamma]", 
          RowBox[{"S", ",", "qg", " "}], 
          RowBox[{"(", "1", ")", " "}]], TraditionalForm]]],
  "polarized"
}], "Text",
  CellTags->"AnomalousDimension"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"AnomalousDimension", "[", "gsqg1", "]"}]], "Input",
  CellLabel->"In[85]:=  (21:51:52 on 5/16/01)",
  CellTags->"AnomalousDimension"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"8", " ", 
          SubscriptBox["C", "F"], " ", 
          SubscriptBox["T", "f"], " ", 
          RowBox[{"(", 
            RowBox[{
              FractionBox[
                RowBox[{"2", " ", 
                  RowBox[{
                    SubsuperscriptBox["S", "1", "2"], "(", 
                    FormBox[
                      RowBox[{"m", "-", "1"}],
                      "TraditionalForm"], ")"}]}], "m"], "-", 
              FractionBox[
                RowBox[{"4", " ", 
                  RowBox[{
                    SubsuperscriptBox["S", "1", "2"], "(", 
                    FormBox[
                      RowBox[{"m", "-", "1"}],
                      "TraditionalForm"], ")"}]}], 
                RowBox[{"m", "+", "1"}]], "-", 
              FractionBox[
                RowBox[{"2", " ", 
                  RowBox[{
                    SubscriptBox["S", "2"], "(", 
                    FormBox[
                      RowBox[{"m", "-", "1"}],
                      "TraditionalForm"], ")"}]}], "m"], "+", 
              FractionBox[
                RowBox[{"4", " ", 
                  RowBox[{
                    SubscriptBox["S", "2"], "(", 
                    FormBox[
                      RowBox[{"m", "-", "1"}],
                      "TraditionalForm"], ")"}]}], 
                RowBox[{"m", "+", "1"}]], "+", 
              FractionBox["14", "m"], "-", 
              FractionBox["19", 
                RowBox[{"m", "+", "1"}]], "-", 
              FractionBox["1", 
                SuperscriptBox["m", "2"]], "-", 
              FractionBox["8", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"m", "+", "1"}], ")"}], "2"]], "-", 
              FractionBox["2", 
                SuperscriptBox["m", "3"]], "+", 
              FractionBox["4", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"m", "+", "1"}], ")"}], "3"]]}], ")"}]}], "+", 
        RowBox[{"16", " ", 
          SubscriptBox["C", "A"], " ", 
          SubscriptBox["T", "f"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                FractionBox[
                  RowBox[{
                    SubsuperscriptBox["S", "1", "2"], "(", 
                    FormBox[
                      RowBox[{"m", "-", "1"}],
                      "TraditionalForm"], ")"}], "m"]}], "+", 
              FractionBox[
                RowBox[{"2", " ", 
                  RowBox[{
                    SubsuperscriptBox["S", "1", "2"], "(", 
                    FormBox[
                      RowBox[{"m", "-", "1"}],
                      "TraditionalForm"], ")"}]}], 
                RowBox[{"m", "+", "1"}]], "-", 
              FractionBox[
                RowBox[{"2", " ", 
                  RowBox[{
                    SubscriptBox["S", "1"], "(", 
                    FormBox[
                      RowBox[{"m", "-", "1"}],
                      "TraditionalForm"], ")"}]}], 
                SuperscriptBox["m", "2"]], "+", 
              FractionBox[
                RowBox[{"4", " ", 
                  RowBox[{
                    SubscriptBox["S", "1"], "(", 
                    FormBox[
                      RowBox[{"m", "-", "1"}],
                      "TraditionalForm"], ")"}]}], 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"m", "+", "1"}], ")"}], "2"]], "-", 
              FractionBox[
                RowBox[{
                  SubscriptBox["S", "2"], "(", 
                  FormBox[
                    RowBox[{"m", "-", "1"}],
                    "TraditionalForm"], ")"}], "m"], "+", 
              FractionBox[
                RowBox[{"2", " ", 
                  RowBox[{
                    SubscriptBox["S", "2"], "(", 
                    FormBox[
                      RowBox[{"m", "-", "1"}],
                      "TraditionalForm"], ")"}]}], 
                RowBox[{"m", "+", "1"}]], "-", 
              FractionBox[
                RowBox[{"2", " ", 
                  RowBox[{
                    SubscriptBox[
                      OverscriptBox["S", "~"], "2"], "(", 
                    FormBox[
                      RowBox[{"m", "-", "1"}],
                      "TraditionalForm"], ")"}]}], "m"], "+", 
              FractionBox[
                RowBox[{"4", " ", 
                  RowBox[{
                    SubscriptBox[
                      OverscriptBox["S", "~"], "2"], "(", 
                    FormBox[
                      RowBox[{"m", "-", "1"}],
                      "TraditionalForm"], ")"}]}], 
                RowBox[{"m", "+", "1"}]], "-", 
              FractionBox["4", "m"], "+", 
              FractionBox["3", 
                RowBox[{"m", "+", "1"}]], "-", 
              FractionBox["3", 
                SuperscriptBox["m", "2"]], "+", 
              FractionBox["8", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"m", "+", "1"}], ")"}], "2"]], "+", 
              FractionBox["2", 
                SuperscriptBox["m", "3"]], "+", 
              FractionBox["12", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"m", "+", "1"}], ")"}], "3"]]}], ")"}]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[85]=  (21:51:52 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[Gamma]", 
          RowBox[{"S", ",", "gq", " "}], 
          RowBox[{"(", "1", ")", " "}]], TraditionalForm]]],
  "polarized"
}], "Text",
  CellTags->"AnomalousDimension"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"AnomalousDimension", "[", "gsgq1", "]"}]], "Input",
  CellLabel->"In[86]:=  (21:51:52 on 5/16/01)",
  CellTags->"AnomalousDimension"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"4", " ", 
          RowBox[{"(", 
            RowBox[{
              FractionBox[
                RowBox[{"4", " ", 
                  RowBox[{
                    SubsuperscriptBox["S", "1", "2"], "(", 
                    FormBox[
                      RowBox[{"m", "-", "1"}],
                      "TraditionalForm"], ")"}]}], "m"], "-", 
              FractionBox[
                RowBox[{"2", " ", 
                  RowBox[{
                    SubsuperscriptBox["S", "1", "2"], "(", 
                    FormBox[
                      RowBox[{"m", "-", "1"}],
                      "TraditionalForm"], ")"}]}], 
                RowBox[{"m", "+", "1"}]], "-", 
              FractionBox[
                RowBox[{"8", " ", 
                  RowBox[{
                    SubscriptBox["S", "1"], "(", 
                    FormBox[
                      RowBox[{"m", "-", "1"}],
                      "TraditionalForm"], ")"}]}], "m"], "+", 
              FractionBox[
                RowBox[{"2", " ", 
                  RowBox[{
                    SubscriptBox["S", "1"], "(", 
                    FormBox[
                      RowBox[{"m", "-", "1"}],
                      "TraditionalForm"], ")"}]}], 
                RowBox[{"m", "+", "1"}]], "+", 
              FractionBox[
                RowBox[{"8", " ", 
                  RowBox[{
                    SubscriptBox["S", "1"], "(", 
                    FormBox[
                      RowBox[{"m", "-", "1"}],
                      "TraditionalForm"], ")"}]}], 
                SuperscriptBox["m", "2"]], "-", 
              FractionBox[
                RowBox[{"4", " ", 
                  RowBox[{
                    SubscriptBox["S", "1"], "(", 
                    FormBox[
                      RowBox[{"m", "-", "1"}],
                      "TraditionalForm"], ")"}]}], 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"m", "+", "1"}], ")"}], "2"]], "+", 
              FractionBox[
                RowBox[{"4", " ", 
                  RowBox[{
                    SubscriptBox["S", "2"], "(", 
                    FormBox[
                      RowBox[{"m", "-", "1"}],
                      "TraditionalForm"], ")"}]}], "m"], "-", 
              FractionBox[
                RowBox[{"2", " ", 
                  RowBox[{
                    SubscriptBox["S", "2"], "(", 
                    FormBox[
                      RowBox[{"m", "-", "1"}],
                      "TraditionalForm"], ")"}]}], 
                RowBox[{"m", "+", "1"}]], "+", 
              FractionBox["15", "m"], "-", 
              FractionBox["6", 
                RowBox[{"m", "+", "1"}]], "-", 
              FractionBox["12", 
                SuperscriptBox["m", "2"]], "+", 
              FractionBox["3", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"m", "+", "1"}], ")"}], "2"]], "+", 
              FractionBox["4", 
                SuperscriptBox["m", "3"]], "-", 
              FractionBox["2", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"m", "+", "1"}], ")"}], "3"]]}], ")"}], " ", 
          SubsuperscriptBox["C", "F", "2"]}], "+", 
        RowBox[{"32", " ", 
          SubscriptBox["T", "f"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                FractionBox[
                  RowBox[{"2", " ", 
                    RowBox[{
                      SubscriptBox["S", "1"], "(", 
                      FormBox[
                        RowBox[{"m", "-", "1"}],
                        "TraditionalForm"], ")"}]}], 
                  RowBox[{"3", " ", "m"}]]}], "+", 
              FractionBox[
                RowBox[{
                  SubscriptBox["S", "1"], "(", 
                  FormBox[
                    RowBox[{"m", "-", "1"}],
                    "TraditionalForm"], ")"}], 
                RowBox[{"3", " ", 
                  RowBox[{"(", 
                    RowBox[{"m", "+", "1"}], ")"}]}]], "+", 
              FractionBox["7", 
                RowBox[{"9", " ", "m"}]], "-", 
              FractionBox["2", 
                RowBox[{"9", " ", 
                  RowBox[{"(", 
                    RowBox[{"m", "+", "1"}], ")"}]}]], "-", 
              FractionBox["2", 
                RowBox[{"3", " ", 
                  SuperscriptBox["m", "2"]}]], "+", 
              FractionBox["1", 
                RowBox[{"3", " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{"m", "+", "1"}], ")"}], "2"]}]]}], ")"}], " ", 
          SubscriptBox["C", "F"]}], "+", 
        RowBox[{"8", " ", 
          SubscriptBox["C", "A"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                FractionBox[
                  RowBox[{"2", " ", 
                    RowBox[{
                      SubsuperscriptBox["S", "1", "2"], "(", 
                      FormBox[
                        RowBox[{"m", "-", "1"}],
                        "TraditionalForm"], ")"}]}], "m"]}], "+", 
              FractionBox[
                RowBox[{
                  SubsuperscriptBox["S", "1", "2"], "(", 
                  FormBox[
                    RowBox[{"m", "-", "1"}],
                    "TraditionalForm"], ")"}], 
                RowBox[{"m", "+", "1"}]], "+", 
              FractionBox[
                RowBox[{"16", " ", 
                  RowBox[{
                    SubscriptBox["S", "1"], "(", 
                    FormBox[
                      RowBox[{"m", "-", "1"}],
                      "TraditionalForm"], ")"}]}], 
                RowBox[{"3", " ", "m"}]], "-", 
              FractionBox[
                RowBox[{"5", " ", 
                  RowBox[{
                    SubscriptBox["S", "1"], "(", 
                    FormBox[
                      RowBox[{"m", "-", "1"}],
                      "TraditionalForm"], ")"}]}], 
                RowBox[{"3", " ", 
                  RowBox[{"(", 
                    RowBox[{"m", "+", "1"}], ")"}]}]], "+", 
              FractionBox[
                RowBox[{"2", " ", 
                  RowBox[{
                    SubscriptBox["S", "2"], "(", 
                    FormBox[
                      RowBox[{"m", "-", "1"}],
                      "TraditionalForm"], ")"}]}], "m"], "-", 
              FractionBox[
                RowBox[{
                  SubscriptBox["S", "2"], "(", 
                  FormBox[
                    RowBox[{"m", "-", "1"}],
                    "TraditionalForm"], ")"}], 
                RowBox[{"m", "+", "1"}]], "+", 
              FractionBox[
                RowBox[{"4", " ", 
                  RowBox[{
                    SubscriptBox[
                      OverscriptBox["S", "~"], "2"], "(", 
                    FormBox[
                      RowBox[{"m", "-", "1"}],
                      "TraditionalForm"], ")"}]}], "m"], "-", 
              FractionBox[
                RowBox[{"2", " ", 
                  RowBox[{
                    SubscriptBox[
                      OverscriptBox["S", "~"], "2"], "(", 
                    FormBox[
                      RowBox[{"m", "-", "1"}],
                      "TraditionalForm"], ")"}]}], 
                RowBox[{"m", "+", "1"}]], "-", 
              FractionBox["56", 
                RowBox[{"9", " ", "m"}]], "-", 
              FractionBox["20", 
                RowBox[{"9", " ", 
                  RowBox[{"(", 
                    RowBox[{"m", "+", "1"}], ")"}]}]], "+", 
              FractionBox["28", 
                RowBox[{"3", " ", 
                  SuperscriptBox["m", "2"]}]], "-", 
              FractionBox["38", 
                RowBox[{"3", " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{"m", "+", "1"}], ")"}], "2"]}]], "-", 
              FractionBox["4", 
                SuperscriptBox["m", "3"]], "-", 
              FractionBox["6", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"m", "+", "1"}], ")"}], "3"]]}], ")"}], " ", 
          SubscriptBox["C", "F"]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[86]=  (21:51:52 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[Gamma]", 
          RowBox[{"S", ",", "gg", " "}], 
          RowBox[{"(", "1", ")", " "}]], TraditionalForm]]],
  "polarized"
}], "Text",
  CellTags->"AnomalousDimension"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"AnomalousDimension", "[", "gsgg1", "]"}]], "Input",
  CellLabel->"In[87]:=  (21:51:52 on 5/16/01)",
  CellTags->"AnomalousDimension"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"4", " ", 
          RowBox[{"(", 
            RowBox[{
              FractionBox[
                RowBox[{"8", " ", 
                  RowBox[{
                    SubscriptBox["S", "1"], "(", 
                    FormBox[
                      RowBox[{"m", "-", "1"}],
                      "TraditionalForm"], ")"}]}], 
                SuperscriptBox["m", "2"]], "-", 
              FractionBox[
                RowBox[{"16", " ", 
                  RowBox[{
                    SubscriptBox["S", "1"], "(", 
                    FormBox[
                      RowBox[{"m", "-", "1"}],
                      "TraditionalForm"], ")"}]}], 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"m", "+", "1"}], ")"}], "2"]], "+", 
              RowBox[{
                FractionBox["134", "9"], " ", 
                RowBox[{
                  SubscriptBox["S", "1"], "(", 
                  FormBox[
                    RowBox[{"m", "-", "1"}],
                    "TraditionalForm"], ")"}]}], "+", 
              FractionBox[
                RowBox[{"8", " ", 
                  RowBox[{
                    SubscriptBox["S", "2"], "(", 
                    FormBox[
                      RowBox[{"m", "-", "1"}],
                      "TraditionalForm"], ")"}]}], "m"], "-", 
              FractionBox[
                RowBox[{"16", " ", 
                  RowBox[{
                    SubscriptBox["S", "2"], "(", 
                    FormBox[
                      RowBox[{"m", "-", "1"}],
                      "TraditionalForm"], ")"}]}], 
                RowBox[{"m", "+", "1"}]], "+", 
              RowBox[{"4", " ", 
                RowBox[{
                  SubscriptBox["S", "3"], "(", 
                  FormBox[
                    RowBox[{"m", "-", "1"}],
                    "TraditionalForm"], ")"}]}], "-", 
              RowBox[{"8", " ", 
                RowBox[{
                  SubscriptBox["S", "12"], "(", 
                  FormBox[
                    RowBox[{"m", "-", "1"}],
                    "TraditionalForm"], ")"}]}], "-", 
              RowBox[{"8", " ", 
                RowBox[{
                  SubscriptBox["S", "21"], "(", 
                  FormBox[
                    RowBox[{"m", "-", "1"}],
                    "TraditionalForm"], ")"}]}], "+", 
              FractionBox[
                RowBox[{"8", " ", 
                  RowBox[{
                    SubscriptBox[
                      OverscriptBox["S", "~"], "2"], "(", 
                    FormBox[
                      RowBox[{"m", "-", "1"}],
                      "TraditionalForm"], ")"}]}], "m"], "-", 
              FractionBox[
                RowBox[{"16", " ", 
                  RowBox[{
                    SubscriptBox[
                      OverscriptBox["S", "~"], "2"], "(", 
                    FormBox[
                      RowBox[{"m", "-", "1"}],
                      "TraditionalForm"], ")"}]}], 
                RowBox[{"m", "+", "1"}]], "+", 
              RowBox[{"4", " ", 
                RowBox[{
                  SubscriptBox[
                    OverscriptBox["S", "~"], "3"], "(", 
                  FormBox[
                    RowBox[{"m", "-", "1"}],
                    "TraditionalForm"], ")"}]}], "-", 
              RowBox[{"8", " ", 
                RowBox[{
                  SubscriptBox[
                    OverscriptBox["S", "~"], "12"], "(", 
                  FormBox[
                    RowBox[{"m", "-", "1"}],
                    "TraditionalForm"], ")"}]}], "-", 
              FractionBox["107", 
                RowBox[{"9", " ", "m"}]], "+", 
              FractionBox["241", 
                RowBox[{"9", " ", 
                  RowBox[{"(", 
                    RowBox[{"m", "+", "1"}], ")"}]}]], "+", 
              FractionBox["58", 
                RowBox[{"3", " ", 
                  SuperscriptBox["m", "2"]}]], "-", 
              FractionBox["86", 
                RowBox[{"3", " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{"m", "+", "1"}], ")"}], "2"]}]], "-", 
              FractionBox["8", 
                SuperscriptBox["m", "3"]], "-", 
              FractionBox["48", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"m", "+", "1"}], ")"}], "3"]], "-", 
              FractionBox["16", "3"]}], ")"}], " ", 
          SubsuperscriptBox["C", "A", "2"]}], "+", 
        RowBox[{"32", " ", 
          SubscriptBox["T", "f"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  FractionBox["5", "9"]}], " ", 
                RowBox[{
                  SubscriptBox["S", "1"], "(", 
                  FormBox[
                    RowBox[{"m", "-", "1"}],
                    "TraditionalForm"], ")"}]}], "+", 
              FractionBox["14", 
                RowBox[{"9", " ", "m"}]], "-", 
              FractionBox["19", 
                RowBox[{"9", " ", 
                  RowBox[{"(", 
                    RowBox[{"m", "+", "1"}], ")"}]}]], "-", 
              FractionBox["1", 
                RowBox[{"3", " ", 
                  SuperscriptBox["m", "2"]}]], "-", 
              FractionBox["1", 
                RowBox[{"3", " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{"m", "+", "1"}], ")"}], "2"]}]], "+", 
              FractionBox["1", "3"]}], ")"}], " ", 
          SubscriptBox["C", "A"]}], "+", 
        RowBox[{"8", " ", 
          SubscriptBox["C", "F"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                FractionBox["10", 
                  RowBox[{"m", "+", "1"}]]}], "+", 
              FractionBox["2", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"m", "+", "1"}], ")"}], "2"]], "+", 
              FractionBox["4", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"m", "+", "1"}], ")"}], "3"]], "+", "1", "+", 
              FractionBox["10", "m"], "-", 
              FractionBox["10", 
                SuperscriptBox["m", "2"]], "+", 
              FractionBox["4", 
                SuperscriptBox["m", "3"]]}], ")"}], " ", 
          SubscriptBox["T", "f"]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[87]=  (21:51:52 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[Gamma]", 
          RowBox[{"S", ",", "gg", " "}], 
          RowBox[{"(", "1", ")", " "}]], TraditionalForm]]],
  "polarized (different representation)"
}], "Text",
  CellTags->"AnomalousDimension"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"AnomalousDimension", "[", "GSGG1", "]"}]], "Input",
  CellLabel->"In[88]:=  (21:51:52 on 5/16/01)",
  CellTags->"AnomalousDimension"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"4", " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                FractionBox[
                  RowBox[{
                    RowBox[{"m", " ", 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{"m", " ", 
                            RowBox[{"(", 
                              RowBox[{
                                RowBox[{"m", " ", 
                                  RowBox[{"(", 
                                    RowBox[{
                                      RowBox[{"m", " ", 
                                        RowBox[{"(", 
                                        RowBox[{
                                        RowBox[{"48", " ", "m", " ", 
                                        RowBox[{"(", 
                                        RowBox[{"m", "+", "3"}], ")"}]}], "+",
                                         "469"}], ")"}]}], "+", "698"}], 
                                    ")"}]}], "+", "7"}], ")"}]}], "+", 
                          "258"}], ")"}]}], "+", "144"}], 
                  RowBox[{"9", " ", 
                    SuperscriptBox["m", "3"], " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{"m", "+", "1"}], ")"}], "3"]}]]}], "+", 
              FractionBox[
                RowBox[{"8", " ", 
                  RowBox[{
                    SubsuperscriptBox["S", "2", "'"], "\[NoBreak]", "(", 
                    "\[NoBreak]", 
                    FormBox[
                      FractionBox["m", "2"],
                      "TraditionalForm"], "\[NoBreak]", ")"}]}], 
                RowBox[{"m", " ", 
                  RowBox[{"(", 
                    RowBox[{"m", "+", "1"}], ")"}]}]], "-", 
              RowBox[{
                SubsuperscriptBox["S", "3", "'"], "\[NoBreak]", "(", 
                "\[NoBreak]", 
                FormBox[
                  FractionBox["m", "2"],
                  "TraditionalForm"], "\[NoBreak]", ")"}], "+", 
              FractionBox[
                RowBox[{"2", " ", 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"m", " ", 
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{"67", " ", "m", " ", 
                              SuperscriptBox[
                                RowBox[{"(", 
                                  RowBox[{"m", "+", "1"}], ")"}], "2"]}], "+",
                             "144"}], ")"}]}], "+", "72"}], ")"}], " ", 
                  RowBox[{
                    SubscriptBox["S", "1"], "(", 
                    FormBox["m",
                      "TraditionalForm"], ")"}]}], 
                RowBox[{"9", " ", 
                  SuperscriptBox["m", "2"], " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{"m", "+", "1"}], ")"}], "2"]}]], "-", 
              RowBox[{"4", " ", 
                RowBox[{
                  SubsuperscriptBox["S", "2", "'"], "\[NoBreak]", "(", 
                  "\[NoBreak]", 
                  FormBox[
                    FractionBox["m", "2"],
                    "TraditionalForm"], "\[NoBreak]", ")"}], " ", 
                RowBox[{
                  SubscriptBox["S", "1"], "(", 
                  FormBox["m",
                    "TraditionalForm"], ")"}]}], "+", 
              RowBox[{"8", " ", 
                RowBox[{
                  OverscriptBox["S", "~"], "(", 
                  FormBox["m",
                    "TraditionalForm"], ")"}]}]}], ")"}], " ", 
          SubsuperscriptBox["C", "A", "2"]}], "+", 
        RowBox[{"32", " ", 
          SubscriptBox["T", "f"], " ", 
          RowBox[{"(", 
            RowBox[{
              FractionBox[
                RowBox[{
                  RowBox[{"m", " ", 
                    RowBox[{"(", 
                      RowBox[{"m", "+", "1"}], ")"}], " ", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{"3", " ", "m", " ", 
                          RowBox[{"(", 
                            RowBox[{"m", "+", "1"}], ")"}]}], "+", "13"}], 
                      ")"}]}], "-", "3"}], 
                RowBox[{"9", " ", 
                  SuperscriptBox["m", "2"], " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{"m", "+", "1"}], ")"}], "2"]}]], "-", 
              FractionBox[
                RowBox[{"5", " ", 
                  RowBox[{
                    SubscriptBox["S", "1"], "(", 
                    FormBox["m",
                      "TraditionalForm"], ")"}]}], "9"]}], ")"}], " ", 
          SubscriptBox["C", "A"]}], "+", 
        FractionBox[
          RowBox[{"8", " ", 
            SubscriptBox["C", "F"], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"m", " ", 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"m", " ", 
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{"m", " ", 
                              RowBox[{"(", 
                                RowBox[{
                                  RowBox[{"m", " ", 
                                    RowBox[{"(", 
                                      RowBox[{
                                        RowBox[{"m", " ", 
                                        RowBox[{"(", 
                                        RowBox[{"m", "+", "3"}], ")"}]}], "+",
                                         "5"}], ")"}]}], "+", "1"}], ")"}]}], 
                            "-", "8"}], ")"}]}], "+", "2"}], ")"}]}], "+", 
                "4"}], ")"}], " ", 
            SubscriptBox["T", "f"]}], 
          RowBox[{
            SuperscriptBox["m", "3"], " ", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"m", "+", "1"}], ")"}], "3"]}]]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[88]=  (21:51:52 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "Check that all odd moments give the same for the two representations of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubsuperscriptBox["\[Gamma]", 
            RowBox[{"S", ",", "gg", " "}], 
            RowBox[{"(", "1", ")", " "}]], "."}], TraditionalForm]]]
}], "Text",
  CellTags->"AnomalousDimension"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Table", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"%", "-", "%%"}], "/.", 
          RowBox[{"OPEm", "\[Rule]", "ij"}]}], ",", 
        RowBox[{"{", 
          RowBox[{"ij", ",", "1", ",", "17", ",", "2"}], "}"}]}], 
      "]"}]], "Input",
  CellLabel->"In[89]:=  (21:51:52 on 5/16/01)",
  CellTags->"AnomalousDimension"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
        "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
          "0", ",", "0"}], "}"}], TraditionalForm]], "Output",
  CellLabel->"Out[89]=  (21:51:53 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Anti5", "ObjectName",
  CellTags->"Anti5"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"Anti5"],

Cell[TextData[{
  "Anti5[exp] anticommutes all ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox["\[Gamma]", "5"], TraditionalForm]]],
  "in exp to the right. Anti5[exp, n] anticommutes all ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox["\[Gamma]", 
          RowBox[{"5", " "}]], TraditionalForm]]],
  "n times to the right. Anti5[exp, -n] anticommutes all ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox["\[Gamma]", "5"], TraditionalForm]]],
  " n times to the left."
}], "Text",
  CellTags->"Anti5"],

Cell[TextData[{
  "The naive ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox["\[Gamma]", "5"], TraditionalForm]]],
  "scheme is used."
}], "Text",
  CellTags->"Anti5"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["DiracOrder",
    ButtonData:>"DiracOrder",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracOrder"],
  ", ",
  ButtonBox["DiracSimplify",
    ButtonData:>"DiracSimplify",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracSimplify"],
  ", ",
  ButtonBox["DiracTrick",
    ButtonData:>"DiracTrick",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracTrick"],
  "."
}], "Text",
  CellTags->"Anti5"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"Anti5"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"DiracMatrix", "[", 
        RowBox[{"5", ",", "\[Mu]"}], "]"}], " "}]], "Input",
  CellLabel->"In[90]:=  (21:51:53 on 5/16/01)",
  CellTags->"Anti5"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", "5"], 
        SuperscriptBox["\[Gamma]", "\[Mu]"]}], TraditionalForm]], "Output",
  CellLabel->"Out[90]=  (21:51:53 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Anti5", "[", "%", "]"}]], "Input",
  CellLabel->"In[91]:=  (21:51:53 on 5/16/01)",
  CellTags->"Anti5"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        RowBox[{
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], ".", 
          SuperscriptBox["\[Gamma]", "5"]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[91]=  (21:51:53 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Anti5", "[", 
      RowBox[{"%", ",", 
        RowBox[{"-", "1"}]}], "]"}]], "Input",
  CellLabel->"In[92]:=  (21:51:53 on 5/16/01)",
  CellTags->"Anti5"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", "5"], ".", 
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[92]=  (21:51:53 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracMatrix", "[", 
      RowBox[{
      "5", ",", "\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]", ",", 
        "\[Delta]"}], "]"}]], "Input",
  CellLabel->"In[93]:=  (21:51:53 on 5/16/01)",
  CellTags->"Anti5"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", "5"], 
        SuperscriptBox["\[Gamma]", "\[Alpha]"], 
        SuperscriptBox["\[Gamma]", "\[Beta]"], 
        SuperscriptBox["\[Gamma]", "\[Gamma]"], 
        SuperscriptBox["\[Gamma]", "\[Delta]"]}], TraditionalForm]], "Output",\

  CellLabel->"Out[93]=  (21:51:53 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Anti5", "[", 
      RowBox[{"%", ",", "2"}], "]"}]], "Input",
  CellLabel->"In[94]:=  (21:51:53 on 5/16/01)",
  CellTags->"Anti5"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Alpha]",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Beta]",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        SuperscriptBox["\[Gamma]", "5"], ".", 
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Gamma]",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Delta]",
              "TraditionalForm"],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[94]=  (21:51:53 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Anti5", "[", 
      RowBox[{"%%", ",", "Infinity"}], "]"}]], "Input",
  CellLabel->"In[95]:=  (21:51:53 on 5/16/01)",
  CellTags->"Anti5"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Alpha]",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Beta]",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Gamma]",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Delta]",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        SuperscriptBox["\[Gamma]", "5"]}], TraditionalForm]], "Output",
  CellLabel->"Out[95]=  (21:51:53 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Anti5", "[", 
      RowBox[{"%", ",", 
        RowBox[{"-", "Infinity"}]}], "]"}]], "Input",
  CellLabel->"In[96]:=  (21:51:53 on 5/16/01)",
  CellTags->"Anti5"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", "5"], ".", 
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Alpha]",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Beta]",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Gamma]",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Delta]",
              "TraditionalForm"],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[96]=  (21:51:53 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "In the naive ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox["\[Gamma]", "5"], TraditionalForm]]],
  "- scheme D-dimensional ",
  Cell[BoxData[
      FormBox["\[Gamma]", TraditionalForm]]],
  "-matrices anticommute with ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox["\[Gamma]", "5"], TraditionalForm]]],
  "."
}], "Text",
  CellTags->"Anti5"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GAD", "[", 
      RowBox[{"5", ",", "\[Mu]"}], "]"}]], "Input",
  CellLabel->"In[97]:=  (21:51:53 on 5/16/01)",
  CellTags->"Anti5"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", "5"], ".", 
        SuperscriptBox["\[Gamma]", "\[Mu]"]}], TraditionalForm]], "Output",
  CellLabel->"Out[97]=  (21:51:53 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Anti5", "[", "%", "]"}]], "Input",
  CellLabel->"In[98]:=  (21:51:53 on 5/16/01)",
  CellTags->"Anti5"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        RowBox[{
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], ".", 
          SuperscriptBox["\[Gamma]", "5"]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[98]=  (21:51:53 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["AntiCommutator", "ObjectName",
  CellTags->"AntiCommutator"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"AntiCommutator"],

Cell["\<\
AntiCommutator[x, y] = c defines the anti-commutator of the non commuting \
objects x and y.\
\>", "Text",
  CellTags->"AntiCommutator"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["Commutator",
    ButtonData:>"Commutator",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Commutator"],
  ", ",
  ButtonBox["CommutatorExplicit",
    ButtonData:>"CommutatorExplicit",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"CommutatorExplicit"],
  ", ",
  ButtonBox["DeclareNonCommutative",
    ButtonData:>"DeclareNonCommutative",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DeclareNonCommutative"],
  ", ",
  ButtonBox["DotSimplify",
    ButtonData:>"DotSimplify",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DotSimplify"],
  "."
}], "Text",
  CellTags->"AntiCommutator"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"AntiCommutator"],

Cell[TextData[{
  "This declares ",
  StyleBox["a",
    FontFamily->"Courier"],
  " and ",
  StyleBox["b",
    FontFamily->"Courier"],
  " as noncommutative variables."
}], "Text",
  CellTags->"AntiCommutator"],

Cell[BoxData[
    RowBox[{"DeclareNonCommutative", "[", 
      RowBox[{"a", ",", "b"}], "]"}]], "Input",
  CellLabel->"In[99]:=  (21:51:53 on 5/16/01)",
  CellTags->"AntiCommutator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"AntiCommutator", "[", 
      RowBox[{"a", ",", "b"}], "]"}]], "Input",
  CellLabel->"In[100]:=  (21:51:53 on 5/16/01)",
  CellTags->"AntiCommutator"],

Cell[BoxData[
    FormBox[
      RowBox[{
      "{", "\[NoBreak]", "a", "\[NoBreak]", ",", "\[NoBreak]", 
        "\[MediumSpace]", "\[NoBreak]", "b", "\[NoBreak]", "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[100]=  (21:51:53 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"CommutatorExplicit", "[", "%", "]"}]], "Input",
  CellLabel->"In[101]:=  (21:51:53 on 5/16/01)",
  CellTags->"AntiCommutator"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"a", ".", "b"}], "+", 
        RowBox[{"b", ".", "a"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[101]=  (21:51:53 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"CommutatorExplicit", "[", 
      RowBox[{"AntiCommutator", "[", 
        RowBox[{
          RowBox[{"a", "+", "b"}], ",", 
          RowBox[{
            RowBox[{"a", "-", 
              RowBox[{"2", "b"}]}], " "}]}], "]"}], "]"}]], "Input",
  CellLabel->"In[102]:=  (21:51:53 on 5/16/01)",
  CellTags->"AntiCommutator"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{"a", "-", 
              RowBox[{"2", " ", "b"}]}], ")"}], ".", 
          RowBox[{"(", 
            RowBox[{"a", "+", "b"}], ")"}]}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"a", "+", "b"}], ")"}], ".", 
          RowBox[{"(", 
            RowBox[{"a", "-", 
              RowBox[{"2", " ", "b"}]}], ")"}]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[102]=  (21:51:53 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DotSimplify", "[", 
      RowBox[{"AntiCommutator", "[", 
        RowBox[{
          RowBox[{"a", "+", "b"}], ",", 
          RowBox[{
            RowBox[{"a", "-", 
              RowBox[{"2", "b"}]}], " "}]}], "]"}], "]"}]], "Input",
  CellLabel->"In[103]:=  (21:51:53 on 5/16/01)",
  CellTags->"AntiCommutator"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"2", " ", 
          SuperscriptBox["a", "2"]}], "-", 
        RowBox[{"4", " ", 
          SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"a", ".", "b"}], "-", 
        RowBox[{"b", ".", "a"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[103]=  (21:51:53 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{"DeclareNonCommutative", "[", 
      RowBox[{"c", ",", "d", ",", 
        OverscriptBox["c", "~"], ",", 
        OverscriptBox["d", "~"]}], "]"}]], "Input",
  CellLabel->"In[104]:=  (21:51:53 on 5/16/01)",
  CellTags->"AntiCommutator"],

Cell["Defining {c,d} = z results in replacements of c.d by z-d.c.", "Text",
  CellTags->"AntiCommutator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"AntiCommutator", "[", 
        RowBox[{"c", ",", "d"}], "]"}], " ", "=", " ", "z"}]], "Input",
  CellLabel->"In[105]:=  (21:51:54 on 5/16/01)",
  CellTags->"AntiCommutator"],

Cell[BoxData[
    FormBox["z", TraditionalForm]], "Output",
  CellLabel->"Out[105]=  (21:51:54 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DotSimplify", "[", " ", 
      RowBox[{"d", " ", ".", " ", "c", " ", ".", " ", "d"}], " ", 
      "]"}]], "Input",
  CellLabel->"In[106]:=  (21:51:54 on 5/16/01)",
  CellTags->"AntiCommutator"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"d", " ", "z"}], "-", 
        RowBox[{
          SuperscriptBox["d", "2"], ".", "c"}]}], TraditionalForm]], "Output",\

  CellLabel->"Out[106]=  (21:51:54 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"AntiCommutator", "[", 
        RowBox[{
          OverscriptBox["d", "~"], ",", 
          OverscriptBox["c", "~"]}], "]"}], " ", "=", " ", 
      OverscriptBox["z", "~"]}]], "Input",
  CellLabel->"In[107]:=  (21:51:54 on 5/16/01)",
  CellTags->"AntiCommutator"],

Cell[BoxData[
    FormBox[
      OverscriptBox["z", "~"], TraditionalForm]], "Output",
  CellLabel->"Out[107]=  (21:51:54 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DotSimplify", "[", " ", 
      RowBox[{
        OverscriptBox["d", "~"], " ", ".", " ", 
        OverscriptBox["c", "~"], " ", ".", " ", 
        OverscriptBox["d", "~"]}], " ", "]"}]], "Input",
  CellLabel->"In[108]:=  (21:51:54 on 5/16/01)",
  CellTags->"AntiCommutator"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          OverscriptBox["d", "~"], " ", 
          OverscriptBox["z", "~"]}], "-", 
        RowBox[{
          OverscriptBox["c", "~"], ".", 
          SuperscriptBox[
            OverscriptBox["d", "~"], "2"]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[108]=  (21:51:54 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{"UnDeclareNonCommutative", "[", 
      RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", 
        OverscriptBox["c", "~"], ",", 
        OverscriptBox["d", "~"]}], "]"}]], "Input",
  CellLabel->"In[109]:=  (21:51:54 on 5/16/01)",
  CellTags->"AntiCommutator"],

Cell[BoxData[
    RowBox[{"Unset", "[", 
      RowBox[{"AntiCommutator", "[", 
        RowBox[{"c", ",", "d"}], "]"}], "]"}]], "Input",
  CellLabel->"In[110]:=  (21:51:54 on 5/16/01)",
  CellTags->"AntiCommutator"],

Cell[BoxData[
    RowBox[{"Unset", "[", 
      RowBox[{"AntiCommutator", "[", 
        RowBox[{
          OverscriptBox["d", "~"], ",", 
          OverscriptBox["c", "~"]}], "]"}], "]"}]], "Input",
  CellLabel->"In[111]:=  (21:51:54 on 5/16/01)",
  CellTags->"AntiCommutator"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["AntiQuarkField", "ObjectName",
  CellTags->"AntiQuarkField"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"AntiQuarkField"],

Cell["\<\
AntiQuarkField is the name of a fermionic field. AntiQuarkField is just a \
name with no functional properties. Only typeset rules are attached.\
\>", "Text",
  CellTags->"AntiQuarkField"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["QuantumField",
    ButtonData:>"QuantumField",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"QuantumField"],
  ", ",
  ButtonBox["QuarkField",
    ButtonData:>"QuarkField",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"QuarkField"],
  "."
}], "Text",
  CellTags->"AntiQuarkField"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"AntiQuarkField"],

Cell[CellGroupData[{

Cell[BoxData["AntiQuarkField"], "Input",
  CellLabel->"In[112]:=  (21:51:54 on 5/16/01)",
  CellTags->"AntiQuarkField"],

Cell[BoxData[
    FormBox[
      OverscriptBox["\[Psi]", "_"], TraditionalForm]], "Output",
  CellLabel->"Out[112]=  (21:51:54 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["AntiSymmetrize", "ObjectName",
  CellTags->"AntiSymmetrize"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"AntiSymmetrize"],

Cell["\<\
AntiSymmetrize[expr, {a1, a2, ...}] antisymmetrizes expr with respect to the \
variables a1,a2, ... \
\>", "Text",
  CellTags->"AntiSymmetrize"],

Cell[TextData[{
  "See also: ",
  ButtonBox["Symmetrize",
    ButtonData:>"Symmetrize",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Symmetrize"],
  "."
}], "Text",
  CellTags->"AntiSymmetrize"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"AntiSymmetrize"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"AntiSymmetrize", "[", 
      RowBox[{
        RowBox[{"f", "[", 
          RowBox[{"a", ",", "b"}], "]"}], ",", 
        RowBox[{"{", 
          RowBox[{"a", ",", "b"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[113]:=  (21:51:54 on 5/16/01)",
  CellTags->"AntiSymmetrize"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"f", "(", 
              RowBox[{"a", ",", "b"}], ")"}], "-", 
            RowBox[{"f", "(", 
              RowBox[{"b", ",", "a"}], ")"}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[113]=  (21:51:54 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"AntiSymmetrize", "[", 
      RowBox[{
        RowBox[{"f", "[", 
          RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", 
        RowBox[{"{", 
          RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[114]:=  (21:51:54 on 5/16/01)",
  CellTags->"AntiSymmetrize"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox["1", "6"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"f", "(", 
              RowBox[{"x", ",", "y", ",", "z"}], ")"}], "-", 
            RowBox[{"f", "(", 
              RowBox[{"x", ",", "z", ",", "y"}], ")"}], "-", 
            RowBox[{"f", "(", 
              RowBox[{"y", ",", "x", ",", "z"}], ")"}], "+", 
            RowBox[{"f", "(", 
              RowBox[{"y", ",", "z", ",", "x"}], ")"}], "+", 
            RowBox[{"f", "(", 
              RowBox[{"z", ",", "x", ",", "y"}], ")"}], "-", 
            RowBox[{"f", "(", 
              RowBox[{"z", ",", "y", ",", "x"}], ")"}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[114]=  (21:51:54 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Apart1", "ObjectName",
  CellTags->"Apart1"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"Apart1"],

Cell["\<\
Apart1[expr, x] is equivalent to Apart[expr, x], but it is faster than Apart \
if explicit complex numbers (I's) are in exp.\
\>", "Text",
  CellTags->"Apart1"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["Apart2",
    ButtonData:>"Apart2",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Apart2"],
  ", ",
  ButtonBox["Apart3",
    ButtonData:>"Apart3",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Apart3"],
  "."
}], "Text",
  CellTags->"Apart1"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"Apart1"],

Cell[BoxData[
    RowBox[{
      RowBox[{"t", "=", 
        RowBox[{
          RowBox[{
            RowBox[{"1", "/", "4"}], "*", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"1", "-", "x"}], ")"}], "^", "4"}], "*", "x", "*", 
            RowBox[{"(", 
              RowBox[{"21", "+", 
                RowBox[{"13", "*", "x"}], "+", 
                RowBox[{"3", "*", 
                  RowBox[{"x", "^", "2"}]}]}], ")"}]}], "-", 
          RowBox[{
            RowBox[{"1", "/", "24"}], "*", "11", "*", "I", "*", "Pi", "*", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"1", "-", "x"}], ")"}], "^", "4"}], "*", "x", "*", 
            RowBox[{"(", 
              RowBox[{"21", "+", 
                RowBox[{"13", "*", "x"}], "+", 
                RowBox[{"3", "*", 
                  RowBox[{"x", "^", "2"}]}]}], ")"}]}], "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"1", "-", "x"}], ")"}], "^", "4"}], "*", 
                RowBox[{"x", "^", "2"}], "*", 
                RowBox[{"(", 
                  RowBox[{"21", "+", 
                    RowBox[{"13", "*", "x"}], "+", 
                    RowBox[{"3", "*", 
                      RowBox[{"x", "^", "2"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
              RowBox[{"36", "*", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "4"}]}], 
              ")"}]}], "-", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"I", "*", "Pi", "*", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"1", "-", "x"}], ")"}], "^", "4"}], "*", 
                RowBox[{"x", "^", "2"}], "*", 
                RowBox[{"(", 
                  RowBox[{"21", "+", 
                    RowBox[{"13", "*", "x"}], "+", 
                    RowBox[{"3", "*", 
                      RowBox[{"x", "^", "2"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
              RowBox[{"12", "*", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "4"}]}], 
              ")"}]}], "-", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"7", "*", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"1", "-", "x"}], ")"}], "^", "4"}], "*", 
                RowBox[{"x", "^", "3"}], "*", 
                RowBox[{"(", 
                  RowBox[{"21", "+", 
                    RowBox[{"13", "*", "x"}], "+", 
                    RowBox[{"3", "*", 
                      RowBox[{"x", "^", "2"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
              RowBox[{"48", "*", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "4"}]}], 
              ")"}]}], "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"3", "*", "I", "*", "Pi", "*", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"1", "-", "x"}], ")"}], "^", "4"}], "*", 
                RowBox[{"x", "^", "3"}], "*", 
                RowBox[{"(", 
                  RowBox[{"21", "+", 
                    RowBox[{"13", "*", "x"}], "+", 
                    RowBox[{"3", "*", 
                      RowBox[{"x", "^", "2"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
              RowBox[{"8", "*", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "4"}]}], 
              ")"}]}], "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"11", "*", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"1", "-", "x"}], ")"}], "^", "4"}], "*", 
                RowBox[{"x", "^", "4"}], "*", 
                RowBox[{"(", 
                  RowBox[{"21", "+", 
                    RowBox[{"13", "*", "x"}], "+", 
                    RowBox[{"3", "*", 
                      RowBox[{"x", "^", "2"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
              RowBox[{"24", "*", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "4"}]}], 
              ")"}]}], "-", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"3", "*", "I", "*", "Pi", "*", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"1", "-", "x"}], ")"}], "^", "4"}], "*", 
                RowBox[{"x", "^", "4"}], "*", 
                RowBox[{"(", 
                  RowBox[{"21", "+", 
                    RowBox[{"13", "*", "x"}], "+", 
                    RowBox[{"3", "*", 
                      RowBox[{"x", "^", "2"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
              RowBox[{"4", "*", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "4"}]}], 
              ")"}]}], "-", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"49", "*", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"1", "-", "x"}], ")"}], "^", "4"}], "*", 
                RowBox[{"x", "^", "5"}], "*", 
                RowBox[{"(", 
                  RowBox[{"21", "+", 
                    RowBox[{"13", "*", "x"}], "+", 
                    RowBox[{"3", "*", 
                      RowBox[{"x", "^", "2"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
              RowBox[{"144", "*", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "4"}]}], 
              ")"}]}], "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"11", "*", "I", "*", "Pi", "*", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"1", "-", "x"}], ")"}], "^", "4"}], "*", 
                RowBox[{"x", "^", "5"}], "*", 
                RowBox[{"(", 
                  RowBox[{"21", "+", 
                    RowBox[{"13", "*", "x"}], "+", 
                    RowBox[{"3", "*", 
                      RowBox[{"x", "^", "2"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
              RowBox[{"24", "*", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "4"}]}], 
              ")"}]}], "+", 
          RowBox[{
            RowBox[{"1", "/", "4"}], "*", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"1", "-", "x"}], ")"}], "^", "4"}], "*", "x", "*", 
            RowBox[{"(", 
              RowBox[{"21", "+", 
                RowBox[{"13", "*", "x"}], "+", 
                RowBox[{"3", "*", 
                  RowBox[{"x", "^", "2"}]}]}], ")"}], "*", "Zeta2"}], "+", 
          RowBox[{
            RowBox[{"11", "/", "24"}], "*", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"1", "-", "x"}], ")"}], "^", "4"}], "*", "x", "*", 
            RowBox[{"(", 
              RowBox[{"21", "+", 
                RowBox[{"13", "*", "x"}], "+", 
                RowBox[{"3", "*", 
                  RowBox[{"x", "^", "2"}]}]}], ")"}], "*", 
            RowBox[{"Log", "[", "x", "]"}]}], "+", 
          RowBox[{
            RowBox[{"1", "/", "4"}], "*", "I", "*", "Pi", "*", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"1", "-", "x"}], ")"}], "^", "4"}], "*", "x", "*", 
            RowBox[{"(", 
              RowBox[{"21", "+", 
                RowBox[{"13", "*", "x"}], "+", 
                RowBox[{"3", "*", 
                  RowBox[{"x", "^", "2"}]}]}], ")"}], "*", 
            RowBox[{"Log", "[", "x", "]"}]}], "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"1", "-", "x"}], ")"}], "^", "4"}], "*", 
                RowBox[{"x", "^", "2"}], "*", 
                RowBox[{"(", 
                  RowBox[{"21", "+", 
                    RowBox[{"13", "*", "x"}], "+", 
                    RowBox[{"3", "*", 
                      RowBox[{"x", "^", "2"}]}]}], ")"}], "*", 
                RowBox[{"Log", "[", "x", "]"}]}], ")"}], "/", 
            RowBox[{"(", 
              RowBox[{"12", "*", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "4"}]}], 
              ")"}]}], "-", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"3", "*", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"1", "-", "x"}], ")"}], "^", "4"}], "*", 
                RowBox[{"x", "^", "3"}], "*", 
                RowBox[{"(", 
                  RowBox[{"21", "+", 
                    RowBox[{"13", "*", "x"}], "+", 
                    RowBox[{"3", "*", 
                      RowBox[{"x", "^", "2"}]}]}], ")"}], "*", 
                RowBox[{"Log", "[", "x", "]"}]}], ")"}], "/", 
            RowBox[{"(", 
              RowBox[{"8", "*", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "4"}]}], 
              ")"}]}], "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"3", "*", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"1", "-", "x"}], ")"}], "^", "4"}], "*", 
                RowBox[{"x", "^", "4"}], "*", 
                RowBox[{"(", 
                  RowBox[{"21", "+", 
                    RowBox[{"13", "*", "x"}], "+", 
                    RowBox[{"3", "*", 
                      RowBox[{"x", "^", "2"}]}]}], ")"}], "*", 
                RowBox[{"Log", "[", "x", "]"}]}], ")"}], "/", 
            RowBox[{"(", 
              RowBox[{"4", "*", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "4"}]}], 
              ")"}]}]}]}], ";"}]], "Input",
  CellLabel->"In[115]:=  (21:51:54 on 5/16/01)",
  CellTags->"Apart1"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Timing", "[", 
      RowBox[{
        RowBox[{"a1", "=", 
          RowBox[{"Apart1", "[", 
            RowBox[{"t", ",", "x"}], "]"}]}], ";"}], "]"}]], "Input",
  CellLabel->"In[116]:=  (21:51:54 on 5/16/01)",
  CellTags->"Apart1"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"0.29999999999999716`", " ", "Second"}], ",", "Null"}], 
        "}"}], TraditionalForm]], "Output",
  CellLabel->"Out[116]=  (21:51:54 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Timing", "[", 
      RowBox[{
        RowBox[{"a2", "=", 
          RowBox[{"Apart", "[", 
            RowBox[{"t", ",", "x"}], "]"}]}], ";"}], "]"}]], "Input",
  CellLabel->"In[117]:=  (21:51:54 on 5/16/01)",
  CellTags->"Apart1"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"1.6329999999999956`", " ", "Second"}], ",", "Null"}], 
        "}"}], TraditionalForm]], "Output",
  CellLabel->"Out[117]=  (21:51:56 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"a1", "-", "a2"}], "//", "Expand"}]], "Input",
  CellLabel->"In[118]:=  (21:51:58 on 5/16/01)",
  CellTags->"Apart1"],

Cell[BoxData[
    FormBox["0", TraditionalForm]], "Output",
  CellLabel->"Out[118]=  (21:51:58 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{"Clear", "[", 
      RowBox[{"t", ",", "a1", ",", "a2"}], "]"}]], "Input",
  CellLabel->"In[119]:=  (21:51:58 on 5/16/01)",
  CellTags->"Apart1"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Apart2", "ObjectName",
  CellTags->"Apart2"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"Apart2"],

Cell["\<\
Apart2[expr] partial fractions FeynAmpDenominators (and FAD's).\
\>", "Text",
  CellTags->"Apart2"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["FAD",
    ButtonData:>"FAD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FAD"],
  ", ",
  ButtonBox["FeynAmpDenominator",
    ButtonData:>"FeynAmpDenominator",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FeynAmpDenominator"],
  "."
}], "Text",
  CellTags->"Apart2"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"Apart2"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FAD", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"q", ",", "m"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"q", ",", "M"}], "}"}], ",", 
        RowBox[{"q", "-", "p"}]}], "]"}]], "Input",
  CellLabel->"In[120]:=  (21:51:58 on 5/16/01)",
  CellTags->"Apart2"],

Cell[BoxData[
    FormBox[
      FractionBox["1", 
        RowBox[{
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"q", "-", "p"}], ")"}], "2"], 
                "\[InvisibleSpace]", "\<\"]\"\>"}],
              SequenceForm[ "[", 
                Power[ 
                  Plus[ 
                    Times[ -1, p], q], 2], "]"],
              Editable->False], ")"}], " ", 
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
                SuperscriptBox["q", "2"], "\[InvisibleSpace]", "\<\"-\"\>", 
                "\[InvisibleSpace]", 
                SuperscriptBox["m", "2"], "\[InvisibleSpace]", "\<\"]\"\>"}],
              SequenceForm[ "[", 
                Power[ q, 2], "-", 
                Power[ m, 2], "]"],
              Editable->False], ")"}], " ", 
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
                SuperscriptBox["q", "2"], "\[InvisibleSpace]", "\<\"-\"\>", 
                "\[InvisibleSpace]", 
                SuperscriptBox["M", "2"], "\[InvisibleSpace]", "\<\"]\"\>"}],
              SequenceForm[ "[", 
                Power[ q, 2], "-", 
                Power[ M, 2], "]"],
              Editable->False], ")"}]}]], TraditionalForm]], "Output",
  CellLabel->"Out[120]=  (21:51:58 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Apart2", "[", "%", "]"}]], "Input",
  CellLabel->"In[121]:=  (21:51:58 on 5/16/01)",
  CellTags->"Apart2"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{
          FractionBox["1", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox["q", "2"], "-", 
                  SuperscriptBox["m", "2"]}], ")"}], ".", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"q", "-", "p"}], ")"}], "2"]}]], "-", 
          FractionBox["1", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox["q", "2"], "-", 
                  SuperscriptBox["M", "2"]}], ")"}], ".", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"q", "-", "p"}], ")"}], "2"]}]]}], 
        RowBox[{
          SuperscriptBox["m", "2"], "-", 
          SuperscriptBox["M", "2"]}]], TraditionalForm]], "Output",
  CellLabel->"Out[121]=  (21:51:59 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StandardForm", "[", 
      RowBox[{"FCE", "[", "%", "]"}], "]"}]], "Input",
  CellLabel->"In[122]:=  (21:51:59 on 5/16/01)",
  CellTags->"Apart2"],

Cell[BoxData[
    FractionBox[
      RowBox[{
        RowBox[{"FAD", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"q", ",", "m"}], "}"}], ",", 
            RowBox[{
              RowBox[{"-", "p"}], "+", "q"}]}], "]"}], "-", 
        RowBox[{"FAD", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"q", ",", "M"}], "}"}], ",", 
            RowBox[{
              RowBox[{"-", "p"}], "+", "q"}]}], "]"}]}], 
      RowBox[{
        SuperscriptBox["m", "2"], "-", 
        SuperscriptBox["M", "2"]}]]], "Output",
  CellLabel->"Out[122]//StandardForm=  (21:51:59 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Apart3", "ObjectName",
  CellTags->"Apart3"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"Apart3"],

Cell["\<\
Apart3[expr, x] is equivalent to Map2[Factor2, Collect2[Apart1[expr,x],x]].\
\>", "Text",
  CellTags->"Apart3"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["Apart1",
    ButtonData:>"Apart1",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Apart1"],
  "."
}], "Text",
  CellTags->"Apart3"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"Apart3"],

Cell[BoxData[
    RowBox[{
      RowBox[{"t", "=", 
        RowBox[{
          RowBox[{
            RowBox[{"1", "/", "4"}], " ", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"1", "-", "x"}], ")"}], "^", "4"}], " ", "x", " ", 
            RowBox[{"(", 
              RowBox[{"21", "+", 
                RowBox[{"13", " ", "x"}], "+", 
                RowBox[{"3", " ", 
                  RowBox[{"x", "^", "2"}]}]}], ")"}]}], "-", 
          RowBox[{
            RowBox[{"11", "/", "24"}], " ", "I", " ", "\[Pi]", " ", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"1", "-", "x"}], ")"}], "^", "4"}], " ", "x", " ", 
            RowBox[{"(", 
              RowBox[{"21", "+", 
                RowBox[{"13", " ", "x"}], "+", 
                RowBox[{"3", " ", 
                  RowBox[{"x", "^", "2"}]}]}], ")"}]}], "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"1", "-", "x"}], ")"}], "^", "4"}], " ", 
                RowBox[{"x", "^", "2"}], " ", 
                RowBox[{"(", 
                  RowBox[{"21", "+", 
                    RowBox[{"13", " ", "x"}], "+", 
                    RowBox[{"3", " ", 
                      RowBox[{"x", "^", "2"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
              RowBox[{"36", " ", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "4"}]}], 
              ")"}]}], "-", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"I", " ", "\[Pi]", " ", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"1", "-", "x"}], ")"}], "^", "4"}], " ", 
                RowBox[{"x", "^", "2"}], " ", 
                RowBox[{"(", 
                  RowBox[{"21", "+", 
                    RowBox[{"13", " ", "x"}], "+", 
                    RowBox[{"3", " ", 
                      RowBox[{"x", "^", "2"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
              RowBox[{"12", " ", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "4"}]}], 
              ")"}]}], "-", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"7", " ", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"1", "-", "x"}], ")"}], "^", "4"}], " ", 
                RowBox[{"x", "^", "3"}], " ", 
                RowBox[{"(", 
                  RowBox[{"21", "+", 
                    RowBox[{"13", " ", "x"}], "+", 
                    RowBox[{"3", " ", 
                      RowBox[{"x", "^", "2"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
              RowBox[{"48", " ", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "4"}]}], 
              ")"}]}], "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"3", " ", "I", " ", "\[Pi]", " ", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"1", "-", "x"}], ")"}], "^", "4"}], " ", 
                RowBox[{"x", "^", "3"}], " ", 
                RowBox[{"(", 
                  RowBox[{"21", "+", 
                    RowBox[{"13", " ", "x"}], "+", 
                    RowBox[{"3", " ", 
                      RowBox[{"x", "^", "2"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
              RowBox[{"8", " ", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "4"}]}], 
              ")"}]}], "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"11", " ", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"1", "-", "x"}], ")"}], "^", "4"}], " ", 
                RowBox[{"x", "^", "4"}], " ", 
                RowBox[{"(", 
                  RowBox[{"21", "+", 
                    RowBox[{"13", " ", "x"}], "+", 
                    RowBox[{"3", " ", 
                      RowBox[{"x", "^", "2"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
              RowBox[{"24", " ", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "4"}]}], 
              ")"}]}], "-", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"3", " ", "I", " ", "\[Pi]", " ", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"1", "-", "x"}], ")"}], "^", "4"}], " ", 
                RowBox[{"x", "^", "4"}], " ", 
                RowBox[{"(", 
                  RowBox[{"21", "+", 
                    RowBox[{"13", " ", "x"}], "+", 
                    RowBox[{"3", " ", 
                      RowBox[{"x", "^", "2"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
              RowBox[{"4", " ", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "4"}]}], 
              ")"}]}], "-", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"49", " ", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"1", "-", "x"}], ")"}], "^", "4"}], " ", 
                RowBox[{"x", "^", "5"}], " ", 
                RowBox[{"(", 
                  RowBox[{"21", "+", 
                    RowBox[{"13", " ", "x"}], "+", 
                    RowBox[{"3", " ", 
                      RowBox[{"x", "^", "2"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
              RowBox[{"144", " ", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "4"}]}], 
              ")"}]}], "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"11", " ", "I", " ", "\[Pi]", " ", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"1", "-", "x"}], ")"}], "^", "4"}], " ", 
                RowBox[{"x", "^", "5"}], " ", 
                RowBox[{"(", 
                  RowBox[{"21", "+", 
                    RowBox[{"13", " ", "x"}], "+", 
                    RowBox[{"3", " ", 
                      RowBox[{"x", "^", "2"}]}]}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
              RowBox[{"24", " ", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "4"}]}], 
              ")"}]}], "+", 
          RowBox[{
            RowBox[{"1", "/", "4"}], " ", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"1", "-", "x"}], ")"}], "^", "4"}], " ", "x", " ", 
            RowBox[{"(", 
              RowBox[{"21", "+", 
                RowBox[{"13", " ", "x"}], "+", 
                RowBox[{"3", " ", 
                  RowBox[{"x", "^", "2"}]}]}], ")"}], " ", "Zeta2"}], "+", 
          RowBox[{
            RowBox[{"11", "/", "24"}], " ", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"1", "-", "x"}], ")"}], "^", "4"}], " ", "x", " ", 
            RowBox[{"(", 
              RowBox[{"21", "+", 
                RowBox[{"13", " ", "x"}], "+", 
                RowBox[{"3", " ", 
                  RowBox[{"x", "^", "2"}]}]}], ")"}], " ", 
            RowBox[{"Log", "[", "x", "]"}]}], "+", 
          RowBox[{
            RowBox[{"1", "/", "4"}], " ", "I", " ", "\[Pi]", " ", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"1", "-", "x"}], ")"}], "^", "4"}], " ", "x", " ", 
            RowBox[{"(", 
              RowBox[{"21", "+", 
                RowBox[{"13", " ", "x"}], "+", 
                RowBox[{"3", " ", 
                  RowBox[{"x", "^", "2"}]}]}], ")"}], " ", 
            RowBox[{"Log", "[", "x", "]"}]}], "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"1", "-", "x"}], ")"}], "^", "4"}], " ", 
                RowBox[{"x", "^", "2"}], " ", 
                RowBox[{"(", 
                  RowBox[{"21", "+", 
                    RowBox[{"13", " ", "x"}], "+", 
                    RowBox[{"3", " ", 
                      RowBox[{"x", "^", "2"}]}]}], ")"}], " ", 
                RowBox[{"Log", "[", "x", "]"}]}], ")"}], "/", 
            RowBox[{"(", 
              RowBox[{"12", " ", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "4"}]}], 
              ")"}]}], "-", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"3", " ", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"1", "-", "x"}], ")"}], "^", "4"}], " ", 
                RowBox[{"x", "^", "3"}], " ", 
                RowBox[{"(", 
                  RowBox[{"21", "+", 
                    RowBox[{"13", " ", "x"}], "+", 
                    RowBox[{"3", " ", 
                      RowBox[{"x", "^", "2"}]}]}], ")"}], " ", 
                RowBox[{"Log", "[", "x", "]"}]}], ")"}], "/", 
            RowBox[{"(", 
              RowBox[{"8", " ", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "4"}]}], 
              ")"}]}], "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"3", " ", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"1", "-", "x"}], ")"}], "^", "4"}], " ", 
                RowBox[{"x", "^", "4"}], " ", 
                RowBox[{"(", 
                  RowBox[{"21", "+", 
                    RowBox[{"13", " ", "x"}], "+", 
                    RowBox[{"3", " ", 
                      RowBox[{"x", "^", "2"}]}]}], ")"}], " ", 
                RowBox[{"Log", "[", "x", "]"}]}], ")"}], "/", 
            RowBox[{"(", 
              RowBox[{"4", " ", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "4"}]}], 
              ")"}]}]}]}], ";"}]], "Input",
  CellLabel->"In[123]:=  (21:51:59 on 5/16/01)",
  CellTags->"Apart3"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Timing", "[", 
      RowBox[{
        RowBox[{"a1", "=", 
          RowBox[{"Apart3", "[", 
            RowBox[{"t", ",", "x"}], "]"}]}], ";"}], "]"}]], "Input",
  CellLabel->"In[124]:=  (21:51:59 on 5/16/01)",
  CellTags->"Apart3"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"0.47099999999999653`", " ", "Second"}], ",", "Null"}], 
        "}"}], TraditionalForm]], "Output",
  CellLabel->"Out[124]=  (21:52:00 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Timing", "[", 
      RowBox[{
        RowBox[{"a2", "=", 
          RowBox[{"Apart", "[", 
            RowBox[{"t", ",", "x"}], "]"}]}], ";"}], "]"}]], "Input",
  CellLabel->"In[125]:=  (21:52:00 on 5/16/01)",
  CellTags->"Apart3"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"1.631999999999998`", " ", "Second"}], ",", "Null"}], "}"}],
       TraditionalForm]], "Output",
  CellLabel->"Out[125]=  (21:52:02 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"a1", "-", "a2"}], "//", "Expand"}]], "Input",
  CellLabel->"In[126]:=  (21:52:02 on 5/16/01)",
  CellTags->"Apart3"],

Cell[BoxData[
    FormBox["0", TraditionalForm]], "Output",
  CellLabel->"Out[126]=  (21:52:02 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{"Clear", "[", 
      RowBox[{"t", ",", "a1", ",", "a2"}], "]"}]], "Input",
  CellLabel->"In[127]:=  (21:52:02 on 5/16/01)",
  CellTags->"Apart3"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["B00", "ObjectName",
  CellTags->"B00"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"B00"],

Cell["\<\
B00[pp, ma^2,mb^2] is the Passarino-Veltman B00-function, i.e., the \
coefficient function of the metric tensor. All arguments are scalars and have \
dimension mass^2.\
\>", "Text",
  CellTags->"B00"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "B00", "]"}]], "Input",
  CellLabel->"In[128]:=  (21:52:02 on 5/16/01)",
  CellTags->"B00"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"BReduce", "\[Rule]", "True"}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[128]=  (21:52:02 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["B0",
    ButtonData:>"B0",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"B0"],
  ", ",
  ButtonBox["B1",
    ButtonData:>"B1",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"B1"],
  ", ",
  ButtonBox["PaVe",
    ButtonData:>"PaVe",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"PaVe"],
  "."
}], "Text",
  CellTags->"B00"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"B00"],

Cell[TextData[{
  "Remember that SP[p] is a short hand input for ScalarProduct[p,p], i.e., ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox["p", "2"], TraditionalForm]]],
  "."
}], "Text",
  CellTags->"B00"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SP", "[", "p", "]"}]], "Input",
  CellLabel->"In[129]:=  (21:52:02 on 5/16/01)",
  CellTags->"B00"],

Cell[BoxData[
    FormBox[
      SuperscriptBox[
        FormBox["p",
          "TraditionalForm"], "2"], TraditionalForm]], "Output",
  CellLabel->"Out[129]=  (21:52:02 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"B00", "[", 
      RowBox[{
        RowBox[{"SP", "[", "p", "]"}], ",", 
        SuperscriptBox["m", "2"], ",", 
        SuperscriptBox["M", "2"]}], "]"}]], "Input",
  CellLabel->"In[130]:=  (21:52:02 on 5/16/01)",
  CellTags->"B00"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{
            SubscriptBox["B", "0"], "(", 
            FormBox[
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"],
              "TraditionalForm"], ",", 
            SuperscriptBox["m", "2"], ",", 
            SuperscriptBox["M", "2"], ")"}], " ", 
          SuperscriptBox["m", "2"]}], "+", 
        RowBox[{
          FractionBox["1", "18"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"3", " ", 
                SuperscriptBox["m", "2"]}], "+", 
              RowBox[{"3", " ", 
                SuperscriptBox["M", "2"]}], "-", 
              FormBox[
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"],
                "TraditionalForm"]}], ")"}]}], "+", 
        RowBox[{
          FractionBox["1", "6"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{
                  SubscriptBox["B", "0"], "(", "0", ",", 
                  SuperscriptBox["M", "2"], ",", 
                  SuperscriptBox["M", "2"], ")"}], " ", 
                SuperscriptBox["M", "2"]}], "+", 
              SuperscriptBox["M", "2"], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    FractionBox[
                      RowBox[{
                        RowBox[{"(", 
                          RowBox[{
                            SuperscriptBox["M", "2"], "-", 
                            SuperscriptBox["m", "2"]}], ")"}], " ", 
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              SubscriptBox["B", "0"], "(", 
                              FormBox[
                                SuperscriptBox[
                                  FormBox["p",
                                    "TraditionalForm"], "2"],
                                "TraditionalForm"], ",", 
                              SuperscriptBox["m", "2"], ",", 
                              SuperscriptBox["M", "2"], ")"}], "-", 
                            RowBox[{
                              SubscriptBox["B", "0"], "(", "0", ",", 
                              SuperscriptBox["m", "2"], ",", 
                              SuperscriptBox["M", "2"], ")"}]}], ")"}]}], 
                      RowBox[{"2", " ", 
                        FormBox[
                          SuperscriptBox[
                            FormBox["p",
                              "TraditionalForm"], "2"],
                          "TraditionalForm"]}]], "-", 
                    RowBox[{
                      FractionBox["1", "2"], " ", 
                      RowBox[{
                        SubscriptBox["B", "0"], "(", 
                        FormBox[
                          SuperscriptBox[
                            FormBox["p",
                              "TraditionalForm"], "2"],
                          "TraditionalForm"], ",", 
                        SuperscriptBox["m", "2"], ",", 
                        SuperscriptBox["M", "2"], ")"}]}]}], ")"}], " ", 
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox["m", "2"], "-", 
                    SuperscriptBox["M", "2"], "+", 
                    FormBox[
                      SuperscriptBox[
                        FormBox["p",
                          "TraditionalForm"], "2"],
                      "TraditionalForm"]}], ")"}]}]}], ")"}]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[130]=  (21:52:02 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"B00", "[", 
      RowBox[{
        RowBox[{"SP", "[", "p", "]"}], ",", 
        SuperscriptBox["m", "2"], ",", 
        SuperscriptBox["m", "2"]}], "]"}]], "Input",
  CellLabel->"In[131]:=  (21:52:02 on 5/16/01)",
  CellTags->"B00"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{
            SubscriptBox["B", "0"], "(", 
            FormBox[
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"],
              "TraditionalForm"], ",", 
            SuperscriptBox["m", "2"], ",", 
            SuperscriptBox["m", "2"], ")"}], " ", 
          SuperscriptBox["m", "2"]}], "+", 
        RowBox[{
          FractionBox["1", "18"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"6", " ", 
                SuperscriptBox["m", "2"]}], "-", 
              FormBox[
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"],
                "TraditionalForm"]}], ")"}]}], "+", 
        RowBox[{
          FractionBox["1", "6"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{
                  SubscriptBox["B", "0"], "(", "0", ",", 
                  SuperscriptBox["m", "2"], ",", 
                  SuperscriptBox["m", "2"], ")"}], " ", 
                SuperscriptBox["m", "2"]}], "+", 
              SuperscriptBox["m", "2"], "-", 
              RowBox[{
                FractionBox["1", "2"], " ", 
                RowBox[{
                  SubscriptBox["B", "0"], "(", 
                  FormBox[
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"],
                    "TraditionalForm"], ",", 
                  SuperscriptBox["m", "2"], ",", 
                  SuperscriptBox["m", "2"], ")"}], " ", 
                FormBox[
                  SuperscriptBox[
                    FormBox["p",
                      "TraditionalForm"], "2"],
                  "TraditionalForm"]}]}], ")"}]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[131]=  (21:52:03 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"B00", "[", 
      RowBox[{
        RowBox[{"SP", "[", "p", "]"}], ",", 
        SuperscriptBox["m", "2"], ",", 
        SuperscriptBox["M", "2"], ",", 
        RowBox[{"BReduce", "\[Rule]", "False"}]}], "]"}]], "Input",
  CellLabel->"In[132]:=  (21:52:03 on 5/16/01)",
  CellTags->"B00"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          SubscriptBox["\<\"B\"\>", "\<\"00\"\>"],
          "TraditionalForm"], "\[NoBreak]", "(", "\[NoBreak]", 
        FormBox[
          FormBox[
            SuperscriptBox[
              FormBox["p",
                "TraditionalForm"], "2"],
            "TraditionalForm"],
          "TraditionalForm"], "\[NoBreak]", 
        RowBox[{",", " "}], "\[NoBreak]", 
        FormBox[
          SuperscriptBox["m", "2"],
          "TraditionalForm"], "\[NoBreak]", 
        RowBox[{",", " "}], "\[NoBreak]", 
        FormBox[
          SuperscriptBox["M", "2"],
          "TraditionalForm"], "\[NoBreak]", ")"}], TraditionalForm]], "Output",\

  CellLabel->"Out[132]=  (21:52:03 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"B00", "[", 
      RowBox[{"0", ",", 
        SuperscriptBox["m", "2"], ",", 
        SuperscriptBox["m", "2"]}], "]"}]], "Input",
  CellLabel->"In[133]:=  (21:52:03 on 5/16/01)",
  CellTags->"B00"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{
            SubscriptBox["B", "0"], "(", "0", ",", 
            SuperscriptBox["m", "2"], ",", 
            SuperscriptBox["m", "2"], ")"}], " ", 
          SuperscriptBox["m", "2"]}], "+", 
        FractionBox[
          SuperscriptBox["m", "2"], "3"], "+", 
        RowBox[{
          FractionBox["1", "6"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{
                  SubscriptBox["B", "0"], "(", "0", ",", 
                  SuperscriptBox["m", "2"], ",", 
                  SuperscriptBox["m", "2"], ")"}], " ", 
                SuperscriptBox["m", "2"]}], "+", 
              SuperscriptBox["m", "2"]}], ")"}]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[133]=  (21:52:03 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"B00", "[", 
      RowBox[{
        RowBox[{"SmallVariable", "[", 
          SuperscriptBox["M", "2"], "]"}], ",", 
        SuperscriptBox["m", "2"], ",", 
        SuperscriptBox["m", "2"]}], "]"}]], "Input",
  CellLabel->"In[134]:=  (21:52:03 on 5/16/01)",
  CellTags->"B00"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{
            SubscriptBox["B", "0"], "(", 
            SuperscriptBox["M", "2"], ",", 
            SuperscriptBox["m", "2"], ",", 
            SuperscriptBox["m", "2"], ")"}], " ", 
          SuperscriptBox["m", "2"]}], "+", 
        FractionBox[
          SuperscriptBox["m", "2"], "3"], "+", 
        RowBox[{
          FractionBox["1", "6"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{
                  SubscriptBox["B", "0"], "(", "0", ",", 
                  SuperscriptBox["m", "2"], ",", 
                  SuperscriptBox["m", "2"], ")"}], " ", 
                SuperscriptBox["m", "2"]}], "+", 
              SuperscriptBox["m", "2"]}], ")"}]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[134]=  (21:52:03 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["B0", "ObjectName",
  CellTags->"B0"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"B0"],

Cell["\<\
B0[pp, ma^2, mb^2] is the Passarino - Veltman two-point integral B0. All \
arguments are scalars and have dimension mass^2. If the option BReduce is set \
to True certain B0's are reduced to A0's. Setting the option B0Unique to True \
simplifies B0[a,0,a] and B0[0,0,a].\
\>", "Text",
  CellTags->"B0"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "B0", "]"}]], "Input",
  CellLabel->"In[135]:=  (21:52:03 on 5/16/01)",
  CellTags->"B0"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"BReduce", "\[Rule]", "False"}], ",", 
          RowBox[{"B0Unique", "\[Rule]", "False"}], ",", 
          RowBox[{"B0Real", "\[Rule]", "False"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[135]=  (21:52:03 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["B1",
    ButtonData:>"B1",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"B1"],
  ", ",
  ButtonBox["B00",
    ButtonData:>"B00",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"B00"],
  ", ",
  ButtonBox["B11",
    ButtonData:>"B11",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"B11"],
  ", ",
  ButtonBox["PaVe",
    ButtonData:>"PaVe",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"PaVe"],
  "."
}], "Text",
  CellTags->"B0"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"B0"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"B0", "[", 
      RowBox[{
        RowBox[{"SP", "[", 
          RowBox[{"p", ",", "p"}], "]"}], ",", 
        SuperscriptBox["m", "2"], ",", 
        SuperscriptBox["m", "2"]}], "]"}]], "Input",
  CellLabel->"In[136]:=  (21:52:03 on 5/16/01)",
  CellTags->"B0"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["B", "0"], "(", 
        FormBox[
          SuperscriptBox[
            FormBox["p",
              "TraditionalForm"], "2"],
          "TraditionalForm"], ",", 
        SuperscriptBox["m", "2"], ",", 
        SuperscriptBox["m", "2"], ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[136]=  (21:52:03 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      RowBox[{"SetOptions", "[", 
        RowBox[{"B0", ",", 
          RowBox[{"B0Unique", "\[Rule]", "True"}], ",", 
          RowBox[{"B0Real", "\[Rule]", "True"}]}], "]"}], ";"}]], "Input",
  CellLabel->"In[137]:=  (21:52:03 on 5/16/01)",
  CellTags->"B0"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"B0", "[", 
      RowBox[{"0", ",", "0", ",", 
        SuperscriptBox["m", "2"]}], "]"}]], "Input",
  CellLabel->"In[138]:=  (21:52:03 on 5/16/01)",
  CellTags->"B0"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["B", "0"], "(", "0", ",", 
          SuperscriptBox["m", "2"], ",", 
          SuperscriptBox["m", "2"], ")"}], "+", "1"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[138]=  (21:52:03 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"B0", "[", 
      RowBox[{
        SuperscriptBox["m", "2"], ",", "0", ",", 
        SuperscriptBox["m", "2"]}], "]"}]], "Input",
  CellLabel->"In[139]:=  (21:52:04 on 5/16/01)",
  CellTags->"B0"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["B", "0"], "(", "0", ",", 
          SuperscriptBox["m", "2"], ",", 
          SuperscriptBox["m", "2"], ")"}], "+", "2"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[139]=  (21:52:04 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"B0", "[", 
      RowBox[{"0", ",", 
        RowBox[{"m", "^", "2"}], ",", 
        RowBox[{"m", "^", "2"}]}], "]"}]], "Input",
  CellLabel->"In[140]:=  (21:52:04 on 5/16/01)",
  CellTags->"B0"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["B", "0"], "(", "0", ",", 
        SuperscriptBox["m", "2"], ",", 
        SuperscriptBox["m", "2"], ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[140]=  (21:52:04 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["B11", "ObjectName",
  CellTags->"B11"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"B11"],

Cell[TextData[{
  "B11[pp, ma^2, mb^2] is the Passarino - Veltman ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["B", "11"], TraditionalForm]]],
  "-function, i.e., the coefficient function of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox["p", "\[Mu]"], " ", 
          SuperscriptBox["p", "\[Nu]"]}], TraditionalForm]]],
  ". All arguments are scalars and have dimension mass",
  Cell[BoxData[
      FormBox[
        SuperscriptBox["\[Null]", "2"], TraditionalForm]]],
  "."
}], "Text",
  CellTags->"B11"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "B11", "]"}]], "Input",
  CellLabel->"In[141]:=  (21:52:04 on 5/16/01)",
  CellTags->"B11"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"BReduce", "\[Rule]", "True"}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[141]=  (21:52:04 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["B0",
    ButtonData:>"B0",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"B0"],
  ", ",
  ButtonBox["B00",
    ButtonData:>"B00",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"B00"],
  ", ",
  ButtonBox["B1",
    ButtonData:>"B1",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"B1"],
  ", ",
  ButtonBox["PaVe",
    ButtonData:>"PaVe",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"PaVe"],
  "."
}], "Text",
  CellTags->"B11"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"B11"],

Cell[TextData[{
  "Remember that SP[p] is a short hand input for ScalarProduct[p,p], i.e. ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox["p", "2"], "."}], TraditionalForm]]]
}], "Text",
  CellTags->"B11"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SP", "[", "p", "]"}]], "Input",
  CellLabel->"In[142]:=  (21:52:04 on 5/16/01)",
  CellTags->"B11"],

Cell[BoxData[
    FormBox[
      SuperscriptBox[
        FormBox["p",
          "TraditionalForm"], "2"], TraditionalForm]], "Output",
  CellLabel->"Out[142]=  (21:52:04 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"B11", "[", 
      RowBox[{
        RowBox[{"SP", "[", "p", "]"}], ",", 
        SuperscriptBox["m", "2"], ",", 
        SuperscriptBox["M", "2"]}], "]"}]], "Input",
  CellLabel->"In[143]:=  (21:52:04 on 5/16/01)",
  CellTags->"B11"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox["1", 
          RowBox[{"3", " ", 
            FormBox[
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"],
              "TraditionalForm"]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                RowBox[{
                  SubscriptBox["B", "0"], "(", 
                  FormBox[
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"],
                    "TraditionalForm"], ",", 
                  SuperscriptBox["m", "2"], ",", 
                  SuperscriptBox["M", "2"], ")"}]}], " ", 
              SuperscriptBox["m", "2"]}], "+", 
            SuperscriptBox["M", "2"], "+", 
            RowBox[{
              SuperscriptBox["M", "2"], " ", 
              RowBox[{
                SubscriptBox["B", "0"], "(", "0", ",", 
                SuperscriptBox["M", "2"], ",", 
                SuperscriptBox["M", "2"], ")"}]}], "+", 
            RowBox[{
              FractionBox["1", "6"], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"-", "3"}], " ", 
                    SuperscriptBox["m", "2"]}], "-", 
                  RowBox[{"3", " ", 
                    SuperscriptBox["M", "2"]}], "+", 
                  FormBox[
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"],
                    "TraditionalForm"]}], ")"}]}], "-", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                RowBox[{
                  FractionBox[
                    RowBox[{
                      RowBox[{"(", 
                        RowBox[{
                          SuperscriptBox["M", "2"], "-", 
                          SuperscriptBox["m", "2"]}], ")"}], " ", 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            SubscriptBox["B", "0"], "(", 
                            FormBox[
                              SuperscriptBox[
                                FormBox["p",
                                  "TraditionalForm"], "2"],
                              "TraditionalForm"], ",", 
                            SuperscriptBox["m", "2"], ",", 
                            SuperscriptBox["M", "2"], ")"}], "-", 
                          RowBox[{
                            SubscriptBox["B", "0"], "(", "0", ",", 
                            SuperscriptBox["m", "2"], ",", 
                            SuperscriptBox["M", "2"], ")"}]}], ")"}]}], 
                    RowBox[{"2", " ", 
                      FormBox[
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"],
                        "TraditionalForm"]}]], "-", 
                  RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{
                      SubscriptBox["B", "0"], "(", 
                      FormBox[
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"],
                        "TraditionalForm"], ",", 
                      SuperscriptBox["m", "2"], ",", 
                      SuperscriptBox["M", "2"], ")"}]}]}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox["m", "2"], "-", 
                  SuperscriptBox["M", "2"], "+", 
                  FormBox[
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"],
                    "TraditionalForm"]}], ")"}]}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[143]=  (21:52:04 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"B11", "[", 
      RowBox[{
        RowBox[{"SP", "[", "p", "]"}], ",", 
        SuperscriptBox["m", "2"], ",", 
        SuperscriptBox["m", "2"]}], "]"}]], "Input",
  CellLabel->"In[144]:=  (21:52:04 on 5/16/01)",
  CellTags->"B11"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{
              SubscriptBox["B", "0"], "(", "0", ",", 
              SuperscriptBox["m", "2"], ",", 
              SuperscriptBox["m", "2"], ")"}], " ", 
            SuperscriptBox["m", "2"]}], "+", 
          SuperscriptBox["m", "2"], "+", 
          RowBox[{
            FractionBox["1", "6"], " ", 
            RowBox[{"(", 
              RowBox[{
                FormBox[
                  SuperscriptBox[
                    FormBox["p",
                      "TraditionalForm"], "2"],
                  "TraditionalForm"], "-", 
                RowBox[{"6", " ", 
                  SuperscriptBox["m", "2"]}]}], ")"}]}], "+", 
          RowBox[{
            RowBox[{
              SubscriptBox["B", "0"], "(", 
              FormBox[
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"],
                "TraditionalForm"], ",", 
              SuperscriptBox["m", "2"], ",", 
              SuperscriptBox["m", "2"], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                FormBox[
                  SuperscriptBox[
                    FormBox["p",
                      "TraditionalForm"], "2"],
                  "TraditionalForm"], "-", 
                SuperscriptBox["m", "2"]}], ")"}]}]}], 
        RowBox[{"3", " ", 
          FormBox[
            SuperscriptBox[
              FormBox["p",
                "TraditionalForm"], "2"],
            "TraditionalForm"]}]], TraditionalForm]], "Output",
  CellLabel->"Out[144]=  (21:52:05 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SetOptions", "[", 
      RowBox[{"B11", ",", 
        RowBox[{"BReduce", "\[Rule]", "False"}]}], "]"}]], "Input",
  CellLabel->"In[145]:=  (21:52:05 on 5/16/01)",
  CellTags->"B11"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"BReduce", "\[Rule]", "False"}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[145]=  (21:52:05 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"B11", "[", 
      RowBox[{
        RowBox[{"SP", "[", "p", "]"}], ",", 
        SuperscriptBox["m", "2"], ",", 
        SuperscriptBox["M", "2"]}], "]"}]], "Input",
  CellLabel->"In[146]:=  (21:52:05 on 5/16/01)",
  CellTags->"B11"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          SubscriptBox["\<\"B\"\>", "\<\"11\"\>"],
          "TraditionalForm"], "\[NoBreak]", "(", "\[NoBreak]", 
        FormBox[
          FormBox[
            SuperscriptBox[
              FormBox["p",
                "TraditionalForm"], "2"],
            "TraditionalForm"],
          "TraditionalForm"], "\[NoBreak]", 
        RowBox[{",", " "}], "\[NoBreak]", 
        FormBox[
          SuperscriptBox["m", "2"],
          "TraditionalForm"], "\[NoBreak]", 
        RowBox[{",", " "}], "\[NoBreak]", 
        FormBox[
          SuperscriptBox["M", "2"],
          "TraditionalForm"], "\[NoBreak]", ")"}], TraditionalForm]], "Output",\

  CellLabel->"Out[146]=  (21:52:05 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SetOptions", "[", 
      RowBox[{"B11", ",", 
        RowBox[{"BReduce", "\[Rule]", "True"}]}], "]"}]], "Input",
  CellLabel->"In[147]:=  (21:52:05 on 5/16/01)",
  CellTags->"B11"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"BReduce", "\[Rule]", "True"}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[147]=  (21:52:05 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"B11", "[", 
      RowBox[{"0", ",", 
        SuperscriptBox["m", "2"], ",", 
        SuperscriptBox["m", "2"]}], "]"}]], "Input",
  CellLabel->"In[148]:=  (21:52:05 on 5/16/01)",
  CellTags->"B11"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox["1", "3"], " ", 
        RowBox[{
          SubscriptBox["B", "0"], "(", "0", ",", 
          SuperscriptBox["m", "2"], ",", 
          SuperscriptBox["m", "2"], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[148]=  (21:52:05 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"B11", "[", 
      RowBox[{
        RowBox[{"SmallVariable", "[", 
          SuperscriptBox["M", "2"], "]"}], ",", 
        SuperscriptBox["m", "2"], ",", 
        SuperscriptBox["m", "2"]}], "]"}]], "Input",
  CellLabel->"In[149]:=  (21:52:05 on 5/16/01)",
  CellTags->"B11"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox["1", "3"], " ", 
        RowBox[{
          SubscriptBox["B", "0"], "(", 
          SuperscriptBox["M", "2"], ",", 
          SuperscriptBox["m", "2"], ",", 
          SuperscriptBox["m", "2"], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[149]=  (21:52:05 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["B1", "ObjectName",
  CellTags->"B1"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"B1"],

Cell[TextData[{
  "B1[pp, ma^2, mb^2] the Passarino - Veltman ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["B", "1"], TraditionalForm]]],
  "-function. All arguments are scalars and have dimension mass^2."
}], "Text",
  CellTags->"B1"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "B1", "]"}]], "Input",
  CellLabel->"In[150]:=  (21:52:05 on 5/16/01)",
  CellTags->"B1"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"BReduce", "\[Rule]", "True"}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[150]=  (21:52:05 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["B0",
    ButtonData:>"B0",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"B0"],
  ", ",
  ButtonBox["B00",
    ButtonData:>"B00",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"B00"],
  ", ",
  ButtonBox["B11",
    ButtonData:>"B11",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"B11"],
  ", ",
  ButtonBox["PaVe",
    ButtonData:>"PaVe",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"PaVe"],
  ", ",
  ButtonBox["PaVeReduce",
    ButtonData:>"PaVeReduce",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"PaVeReduce"],
  "."
}], "Text",
  CellTags->"B1"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"B1"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"B1", "[", 
      RowBox[{
        RowBox[{"SP", "[", "p", "]"}], ",", 
        SuperscriptBox["m", "2"], ",", 
        SuperscriptBox["M", "2"]}], "]"}]], "Input",
  CellLabel->"In[151]:=  (21:52:05 on 5/16/01)",
  CellTags->"B1"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox["M", "2"], "-", 
                SuperscriptBox["m", "2"]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  SubscriptBox["B", "0"], "(", 
                  FormBox[
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"],
                    "TraditionalForm"], ",", 
                  SuperscriptBox["m", "2"], ",", 
                  SuperscriptBox["M", "2"], ")"}], "-", 
                RowBox[{
                  SubscriptBox["B", "0"], "(", "0", ",", 
                  SuperscriptBox["m", "2"], ",", 
                  SuperscriptBox["M", "2"], ")"}]}], ")"}]}], 
          RowBox[{"2", " ", 
            FormBox[
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"],
              "TraditionalForm"]}]], "-", 
        RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{
            SubscriptBox["B", "0"], "(", 
            FormBox[
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"],
              "TraditionalForm"], ",", 
            SuperscriptBox["m", "2"], ",", 
            SuperscriptBox["M", "2"], ")"}]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[151]=  (21:52:05 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"B1", "[", 
      RowBox[{
        RowBox[{"SP", "[", "p", "]"}], ",", 
        SuperscriptBox["m", "2"], ",", 
        SuperscriptBox["M", "2"], ",", 
        RowBox[{"BReduce", "\[Rule]", "False"}]}], "]"}]], "Input",
  CellLabel->"In[152]:=  (21:52:05 on 5/16/01)",
  CellTags->"B1"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["B", "1"], "(", 
        FormBox[
          SuperscriptBox[
            FormBox["p",
              "TraditionalForm"], "2"],
          "TraditionalForm"], ",", 
        SuperscriptBox["m", "2"], ",", 
        SuperscriptBox["M", "2"], ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[152]=  (21:52:05 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      RowBox[{"SetOptions", "[", 
        RowBox[{"B1", ",", 
          RowBox[{"BReduce", "\[Rule]", "True"}]}], "]"}], ";"}]], "Input",
  CellLabel->"In[153]:=  (21:52:05 on 5/16/01)",
  CellTags->"B1"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"B1", "[", 
      RowBox[{
        RowBox[{"SP", "[", "p", "]"}], ",", 
        SuperscriptBox["m", "2"], ",", 
        SuperscriptBox["m", "2"]}], "]"}]], "Input",
  CellLabel->"In[154]:=  (21:52:05 on 5/16/01)",
  CellTags->"B1"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          FractionBox["1", "2"]}], " ", 
        RowBox[{
          SubscriptBox["B", "0"], "(", 
          FormBox[
            SuperscriptBox[
              FormBox["p",
                "TraditionalForm"], "2"],
            "TraditionalForm"], ",", 
          SuperscriptBox["m", "2"], ",", 
          SuperscriptBox["m", "2"], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[154]=  (21:52:05 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"B1", "[", 
      RowBox[{
        SuperscriptBox["m", "2"], ",", 
        SuperscriptBox["m", "2"], ",", "0"}], "]"}]], "Input",
  CellLabel->"In[155]:=  (21:52:06 on 5/16/01)",
  CellTags->"B1"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{
                  SubscriptBox["B", "0"], "(", "0", ",", 
                  SuperscriptBox["m", "2"], ",", 
                  SuperscriptBox["m", "2"], ")"}]}], "-", "2"}], ")"}]}], "-",
         
        FractionBox["1", "2"]}], TraditionalForm]], "Output",
  CellLabel->"Out[155]=  (21:52:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"B1", "[", 
      RowBox[{"0", ",", "0", ",", 
        SuperscriptBox["m", "2"]}], "]"}]], "Input",
  CellLabel->"In[156]:=  (21:52:06 on 5/16/01)",
  CellTags->"B1"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{
                  SubscriptBox["B", "0"], "(", "0", ",", 
                  SuperscriptBox["m", "2"], ",", 
                  SuperscriptBox["m", "2"], ")"}]}], "-", "1"}], ")"}]}], "+",
         
        FractionBox["1", "4"]}], TraditionalForm]], "Output",
  CellLabel->"Out[156]=  (21:52:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"B1", "[", 
      RowBox[{"pp", ",", 
        RowBox[{"SmallVariable", "[", 
          SubsuperscriptBox["m", "e", "2"], "]"}], ",", 
        SubsuperscriptBox["m", "2", "2"]}], "]"}]], "Input",
  CellLabel->"In[157]:=  (21:52:06 on 5/16/01)",
  CellTags->"B1"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  SubscriptBox["B", "0"], "(", "pp", ",", 
                  SubsuperscriptBox["m", "e", "2"], ",", 
                  SubsuperscriptBox["m", "2", "2"], ")"}], "-", 
                RowBox[{
                  SubscriptBox["B", "0"], "(", "0", ",", 
                  SubsuperscriptBox["m", "e", "2"], ",", 
                  SubsuperscriptBox["m", "2", "2"], ")"}]}], ")"}], " ", 
            SubsuperscriptBox["m", "2", "2"]}], 
          RowBox[{"2", " ", "pp"}]], "-", 
        RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{
            SubscriptBox["B", "0"], "(", "pp", ",", 
            SubsuperscriptBox["m", "e", "2"], ",", 
            SubsuperscriptBox["m", "2", "2"], ")"}]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[157]=  (21:52:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"B1", "[", 
      RowBox[{
        RowBox[{"SmallVariable", "[", 
          SubsuperscriptBox["m", "e", "2"], "]"}], ",", 
        RowBox[{"SmallVariable", "[", 
          SubsuperscriptBox["m", "e", "2"], "]"}], ",", "0"}], "]"}]], "Input",\

  CellLabel->"In[158]:=  (21:52:06 on 5/16/01)",
  CellTags->"B1"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{
                  SubscriptBox["B", "0"], "(", "0", ",", 
                  SubsuperscriptBox["m", "e", "2"], ",", 
                  SubsuperscriptBox["m", "e", "2"], ")"}]}], "-", "2"}], 
            ")"}]}], "-", 
        FractionBox["1", "2"]}], TraditionalForm]], "Output",
  CellLabel->"Out[158]=  (21:52:06 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["BackgroundGluonVertex", "ObjectName",
  CellTags->"BackgroundGluonVertex"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"BackgroundGluonVertex"],

Cell[TextData[{
  "BackgroundGluonVertex[{p,mu,a}, {q,nu,b}, {k,la,c}] or \
BackgroundGluonVertex[ p,mu,a , q,nu,b , k,la,c ] yields the 3-gluon vertex \
in the background field gauge, where the first set of arguments corresponds \
to the external background field. BackgroundGluonVertex[{p,mu,a}, {q,nu,b}, \
{k,la,c}, {s,si,d}] or BackgroundGluonVertex[{mu,a}, {nu,b}, {la,c}, {",
  "si",
  ",d}] or BackgroundGluonVertex[p,mu,a , q,nu,b , k,la,c , s,si,d] or \
BackgroundGluonVertex[ mu,a , nu,b , la,c , si,d ] yields the 4-gluon vertex, \
with {p,mu,a} and {k,la,c} denoting the external background fields. The \
gauge, dimension and the name of the coupling constant are determined by the \
options Gauge, Dimension and CouplingConstant. The Feynman rules are taken \
from L.Abbot ",
  StyleBox["NPB ",
    FontWeight->"Bold"],
  "185 (1981), 189-203; except that all momenta are incoming. Note that \
Abbots coupling constant convention is consistent with the default setting of \
GluonVertex."
}], "Text",
  CellTags->"BackgroundGluonVertex"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "BackgroundGluonVertex", "]"}]], "Input",
  CellLabel->"In[159]:=  (21:52:06 on 5/16/01)",
  CellTags->"BackgroundGluonVertex"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
          RowBox[{"CouplingConstant", "\[Rule]", 
            SubscriptBox["g", "s"]}], ",", 
          RowBox[{"Gauge", "\[Rule]", "1"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[159]=  (21:52:06 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["GluonVertex",
    ButtonData:>"GluonVertex",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"GluonVertex"],
  "."
}], "Text",
  CellTags->"BackgroundGluonVertex"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"BackgroundGluonVertex"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"BackgroundGluonVertex", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"q", ",", "\[Nu]", ",", "b"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"k", ",", "\[Lambda]", ",", "c"}], "}"}]}], "]"}]], "Input",\

  CellLabel->"In[160]:=  (21:52:06 on 5/16/01)",
  CellTags->"BackgroundGluonVertex"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["g", "s"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{
                        RowBox[{"-", 
                          FormBox[
                            TagBox[
                              StyleBox["\<\"k\"\>",
                                FontSlant->"Italic"],
                              (StyleForm[ #, FontSlant -> "Italic"]&)],
                            "TraditionalForm"]}], "+", "p", "-", "q"}],
                      "TraditionalForm"], ")"}], 
                  FormBox[
                    FormBox["\[Lambda]",
                      "TraditionalForm"],
                    "TraditionalForm"]], ")"}], " ", 
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}], "+", 
            RowBox[{
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Lambda]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              RowBox[{"(", 
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{"q", "-", 
                        FormBox[
                          TagBox[
                            StyleBox["\<\"k\"\>",
                              FontSlant->"Italic"],
                            (StyleForm[ #, FontSlant -> "Italic"]&)],
                          "TraditionalForm"]}],
                      "TraditionalForm"], ")"}], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], ")"}]}], "+", 
            RowBox[{
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Lambda]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              RowBox[{"(", 
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{
                        FormBox[
                          TagBox[
                            StyleBox["\<\"k\"\>",
                              FontSlant->"Italic"],
                            (StyleForm[ #, FontSlant -> "Italic"]&)],
                          "TraditionalForm"], "-", "p", "+", "q"}],
                      "TraditionalForm"], ")"}], 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], ")"}]}]}], ")"}], " ", 
        SubscriptBox["f", 
          RowBox[{
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["c",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[160]=  (21:52:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"BackgroundGluonVertex", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"q", ",", "\[Nu]", ",", "b"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"k", ",", "\[Lambda]", ",", "c"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"s", ",", "\[Sigma]", ",", "d"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[161]:=  (21:52:06 on 5/16/01)",
  CellTags->"BackgroundGluonVertex"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        SubsuperscriptBox["g", "s", "2"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Lambda]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Sigma]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}], "-", 
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Lambda]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Sigma]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}], "-", 
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Lambda]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Sigma]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}]}], ")"}], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["a",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["d",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["u6",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["b",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["c",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["u6",
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Lambda]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Sigma]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}], "-", 
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Lambda]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Sigma]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}]}], ")"}], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["a",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["c",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["u6",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["b",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["d",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["u6",
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Lambda]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Sigma]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}], "-", 
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Lambda]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Sigma]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}], "+", 
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Lambda]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Sigma]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}]}], ")"}], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["a",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["b",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["u6",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["c",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["d",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["u6",
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[161]=  (21:52:07 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"BackgroundGluonVertex", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"q", ",", "\[Nu]", ",", "b"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"k", ",", "\[Lambda]", ",", "c"}], "}"}], ",", 
        RowBox[{"Gauge", "\[Rule]", "\[Alpha]"}]}], "]"}]], "Input",
  CellLabel->"In[162]:=  (21:52:07 on 5/16/01)",
  CellTags->"BackgroundGluonVertex"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["g", "s"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{
                        RowBox[{"(", 
                          RowBox[{"p", "-", "q"}], ")"}], "-", 
                        FractionBox[
                          FormBox[
                            TagBox[
                              StyleBox["\<\"k\"\>",
                                FontSlant->"Italic"],
                              (StyleForm[ #, FontSlant -> "Italic"]&)],
                            "TraditionalForm"], "\[Alpha]"]}],
                      "TraditionalForm"], ")"}], 
                  FormBox[
                    FormBox["\[Lambda]",
                      "TraditionalForm"],
                    "TraditionalForm"]], ")"}], " ", 
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}], "+", 
            RowBox[{
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Lambda]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              RowBox[{"(", 
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{"q", "-", 
                        FormBox[
                          TagBox[
                            StyleBox["\<\"k\"\>",
                              FontSlant->"Italic"],
                            (StyleForm[ #, FontSlant -> "Italic"]&)],
                          "TraditionalForm"]}],
                      "TraditionalForm"], ")"}], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], ")"}]}], "+", 
            RowBox[{
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Lambda]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              RowBox[{"(", 
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{
                        RowBox[{"(", 
                          RowBox[{
                            FormBox[
                              TagBox[
                                StyleBox["\<\"k\"\>",
                                  FontSlant->"Italic"],
                                (StyleForm[ #, FontSlant -> "Italic"]&)],
                              "TraditionalForm"], "-", "p"}], ")"}], "+", 
                        FractionBox["q", "\[Alpha]"]}],
                      "TraditionalForm"], ")"}], 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], ")"}]}]}], ")"}], " ", 
        SubscriptBox["f", 
          RowBox[{
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["c",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[162]=  (21:52:07 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"BackgroundGluonVertex", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"q", ",", "\[Nu]", ",", "b"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"k", ",", "\[Lambda]", ",", "c"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"s", ",", "\[Sigma]", ",", "d"}], "}"}], ",", 
        RowBox[{"Gauge", "\[Rule]", "\[Alpha]"}]}], "]"}]], "Input",
  CellLabel->"In[163]:=  (21:52:07 on 5/16/01)",
  CellTags->"BackgroundGluonVertex"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        SubsuperscriptBox["g", "s", "2"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Lambda]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Sigma]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}], "-", 
                  FractionBox[
                    RowBox[{
                      SuperscriptBox["g", 
                        RowBox[{
                          FormBox[
                            FormBox["\[Lambda]",
                              "TraditionalForm"],
                            "TraditionalForm"], "\[NoBreak]", 
                          FormBox[
                            FormBox["\[Nu]",
                              "TraditionalForm"],
                            "TraditionalForm"]}]], " ", 
                      SuperscriptBox["g", 
                        RowBox[{
                          FormBox[
                            FormBox["\[Mu]",
                              "TraditionalForm"],
                            "TraditionalForm"], "\[NoBreak]", 
                          FormBox[
                            FormBox["\[Sigma]",
                              "TraditionalForm"],
                            "TraditionalForm"]}]]}], "\[Alpha]"], "-", 
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Lambda]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Sigma]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}]}], ")"}], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["a",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["d",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["u7",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["b",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["c",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["u7",
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Lambda]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Sigma]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}], "-", 
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Lambda]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Sigma]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}]}], ")"}], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["a",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["c",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["u7",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["b",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["d",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["u7",
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  FractionBox[
                    RowBox[{
                      SuperscriptBox["g", 
                        RowBox[{
                          FormBox[
                            FormBox["\[Lambda]",
                              "TraditionalForm"],
                            "TraditionalForm"], "\[NoBreak]", 
                          FormBox[
                            FormBox["\[Sigma]",
                              "TraditionalForm"],
                            "TraditionalForm"]}]], " ", 
                      SuperscriptBox["g", 
                        RowBox[{
                          FormBox[
                            FormBox["\[Mu]",
                              "TraditionalForm"],
                            "TraditionalForm"], "\[NoBreak]", 
                          FormBox[
                            FormBox["\[Nu]",
                              "TraditionalForm"],
                            "TraditionalForm"]}]]}], "\[Alpha]"], "-", 
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Lambda]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Sigma]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}], "+", 
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Lambda]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Sigma]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}]}], ")"}], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["a",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["b",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["u7",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["c",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["d",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["u7",
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[163]=  (21:52:07 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["C0", "ObjectName",
  CellTags->"C0"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"C0"],

Cell[TextData[{
  "C0[p10, p12, p20, m1^2, m2^2, m3^2] is the scalar Passarino - Veltman ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["C", "0"], TraditionalForm]]],
  "function. The convention for the arguments is that if the denominator of \
the integrand has the form ([q^2-m1^2] [(q+p1)^2-m2^2] [(q+p2)^2-m3^2]), the \
first three arguments of C0 are the scalar products p10 = p1^2, p12 = \
(p1-p2).(p1-p2), p20 = p2^2."
}], "Text",
  CellTags->"C0"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["B0",
    ButtonData:>"B0",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"B0"],
  ", ",
  ButtonBox["D0",
    ButtonData:>"D0",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"D0"],
  ", ",
  ButtonBox["PaVe",
    ButtonData:>"PaVe",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"PaVe"],
  ", ",
  ButtonBox["PaVeOrder",
    ButtonData:>"PaVeOrder",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"PaVeOrder"],
  "."
}], "Text",
  CellTags->"C0"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"C0"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"C0", "[", 
      RowBox[{
      "a", ",", "b", ",", "c", ",", " ", "m12", ",", "m22", ",", "m32"}], 
      "]"}]], "Input",
  CellLabel->"In[164]:=  (21:52:07 on 5/16/01)",
  CellTags->"C0"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          SubscriptBox["\<\"C\"\>", "\<\"0\"\>"],
          "TraditionalForm"], "\[NoBreak]", "(", "\[NoBreak]", "a", 
        "\[NoBreak]", ",", "\[NoBreak]", "b", "\[NoBreak]", ",", "\[NoBreak]",
         "c", "\[NoBreak]", ",", "\[NoBreak]", "m12", "\[NoBreak]", ",", 
        "\[NoBreak]", "m22", "\[NoBreak]", ",", "\[NoBreak]", "m32", 
        "\[NoBreak]", ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[164]=  (21:52:07 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"C0", "[", 
        RowBox[{"b", ",", "a", ",", "c", ",", "m32", ",", "m22", ",", "m12"}],
         "]"}], "//", "PaVeOrder"}]], "Input",
  CellLabel->"In[165]:=  (21:52:07 on 5/16/01)",
  CellTags->"C0"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          SubscriptBox["\<\"C\"\>", "\<\"0\"\>"],
          "TraditionalForm"], "\[NoBreak]", "(", "\[NoBreak]", "a", 
        "\[NoBreak]", ",", "\[NoBreak]", "b", "\[NoBreak]", ",", "\[NoBreak]",
         "c", "\[NoBreak]", ",", "\[NoBreak]", "m12", "\[NoBreak]", ",", 
        "\[NoBreak]", "m22", "\[NoBreak]", ",", "\[NoBreak]", "m32", 
        "\[NoBreak]", ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[165]=  (21:52:07 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"PaVeOrder", "[", 
      RowBox[{
        RowBox[{"C0", "[", 
          RowBox[{
          "b", ",", "a", ",", "c", ",", "m32", ",", "m22", ",", "m12"}], 
          "]"}], ",", 
        RowBox[{"PaVeOrderList", "->", 
          RowBox[{"{", 
            RowBox[{"c", ",", "a"}], "}"}]}]}], "]"}]], "Input",
  CellLabel->"In[166]:=  (21:52:07 on 5/16/01)",
  CellTags->"C0"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          SubscriptBox["\<\"C\"\>", "\<\"0\"\>"],
          "TraditionalForm"], "\[NoBreak]", "(", "\[NoBreak]", "b", 
        "\[NoBreak]", ",", "\[NoBreak]", "c", "\[NoBreak]", ",", "\[NoBreak]",
         "a", "\[NoBreak]", ",", "\[NoBreak]", "m22", "\[NoBreak]", ",", 
        "\[NoBreak]", "m32", "\[NoBreak]", ",", "\[NoBreak]", "m12", 
        "\[NoBreak]", ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[166]=  (21:52:07 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Calc", "ObjectName",
  CellTags->"Calc"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"Calc"],

Cell["\<\
Calc[exp] performs several basic simplifications. Calc[exp] is the same as \
DotSimplify[DiracSimplify[Contract[DiracSimplify[Explicit[ \
SUNSimplify[Trick[exp], Explicit->False] ]]]]]\
\>", "Text",
  CellTags->"Calc"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["DiracSimplify",
    ButtonData:>"DiracSimplify",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracSimplify"],
  ", ",
  ButtonBox["DiracTrick",
    ButtonData:>"DiracTrick",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracTrick"],
  ", ",
  ButtonBox["Trick",
    ButtonData:>"Trick",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Trick"],
  "."
}], "Text",
  CellTags->"Calc"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData["Examples"], "Subsubsection",
  CellTags->"Calc"],

Cell[TextData[{
  "This calculates ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox["\[Gamma]", "\[Mu]"], 
          SubscriptBox["\[Gamma]", "\[Mu]"]}], TraditionalForm]]],
  " in 4 dimensions and ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["g", "\[Nu]", "\[Nu]"], TraditionalForm]]],
  " in D dimensions."
}], "Text",
  CellTags->"Calc"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Calc", "[", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"GA", "[", 
            RowBox[{"\[Mu]", ",", "\[Mu]"}], "]"}], ",", " ", 
          RowBox[{"MTD", "[", 
            RowBox[{"\[Nu]", ",", "\[Nu]"}], "]"}]}], "}"}], "]"}]], "Input",
  CellLabel->"In[167]:=  (21:52:07 on 5/16/01)",
  CellTags->"Calc"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"4", ",", "D"}], "}"}], TraditionalForm]], "Output",
  CellLabel->"Out[167]=  (21:52:08 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "This simplifies ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox["f", "abc"], " ", 
          RowBox[{
            SubscriptBox["f", "abe"], "."}]}], TraditionalForm]]]
}], "Text",
  CellTags->"Calc"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Calc", "[", 
      RowBox[{
        RowBox[{"SUNF", "[", 
          RowBox[{"a", ",", "b", ",", "c"}], "]"}], " ", 
        RowBox[{"SUNF", "[", 
          RowBox[{"a", ",", "b", ",", "e"}], "]"}]}], "]"}]], "Input",
  CellLabel->"In[168]:=  (21:52:08 on 5/16/01)",
  CellTags->"Calc"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["C", "A"], " ", 
        SubscriptBox["\[Delta]", 
          RowBox[{
            FormBox[
              FormBox["c",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["e",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[168]=  (21:52:08 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"FV", "[", 
        RowBox[{
          RowBox[{"p", "+", "r"}], ",", "\[Mu]"}], "]"}], " ", 
      RowBox[{"MT", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], " ", 
      RowBox[{"FV", "[", 
        RowBox[{
          RowBox[{"q", "-", "p"}], ",", "\[Nu]"}], "]"}]}]], "Input",
  CellLabel->"In[169]:=  (21:52:08 on 5/16/01)",
  CellTags->"Calc"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"(", 
          SuperscriptBox[
            RowBox[{"(", 
              FormBox[
                RowBox[{"q", "-", "p"}],
                "TraditionalForm"], ")"}], "\[Nu]"], ")"}], " ", 
        RowBox[{"(", 
          SuperscriptBox[
            RowBox[{"(", 
              FormBox[
                RowBox[{"p", "+", "r"}],
                "TraditionalForm"], ")"}], "\[Mu]"], ")"}], " ", 
        SuperscriptBox["g", 
          RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[169]=  (21:52:08 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Calc", "[", "%", "]"}]], "Input",
  CellLabel->"In[170]:=  (21:52:08 on 5/16/01)",
  CellTags->"Calc"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          SuperscriptBox[
            FormBox["p",
              "TraditionalForm"], "2"]}], "+", 
        RowBox[{
          FormBox["p",
            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
          FormBox["q",
            "TraditionalForm"]}], "-", 
        RowBox[{
          FormBox["p",
            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
          FormBox["r",
            "TraditionalForm"]}], "+", 
        RowBox[{
          FormBox["q",
            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
          FormBox["r",
            "TraditionalForm"]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[170]=  (21:52:08 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GluonVertex", "[", 
      RowBox[{"p", ",", "1", ",", "q", ",", "2", ",", 
        RowBox[{
          RowBox[{"-", "p"}], "-", "q"}], ",", "3"}], "]"}]], "Input",
  CellLabel->"In[171]:=  (21:52:08 on 5/16/01)",
  CellTags->"Calc"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["g", "s"], " ", 
        RowBox[{
          SuperscriptBox["V", 
            RowBox[{
              FormBox[
                FormBox["li1",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["li2",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["li3",
                  "TraditionalForm"],
                "TraditionalForm"]}]], "(", 
          RowBox[{
            FormBox["p",
              "TraditionalForm"], "\[NoBreak]", 
            RowBox[{",", " "}], "\[NoBreak]", 
            FormBox["q",
              "TraditionalForm"], "\[NoBreak]", 
            RowBox[{",", " "}], "\[NoBreak]", 
            FormBox[
              RowBox[{
                RowBox[{"-", "p"}], "-", "q"}],
              "TraditionalForm"]}], ")"}], " ", 
        SubscriptBox["f", 
          RowBox[{
            FormBox[
              FormBox["ci1",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["ci2",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["ci3",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[171]=  (21:52:08 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Calc", "[", 
      RowBox[{
        RowBox[{"%", " ", 
          RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "li1"}], "]"}]}], " ", 
        RowBox[{"FVD", "[", 
          RowBox[{"q", ",", "li2"}], "]"}], " ", 
        RowBox[{"FVD", "[", 
          RowBox[{
            RowBox[{
              RowBox[{"-", "p"}], "-", "q"}], ",", "li3"}], "]"}]}], 
      "]"}]], "Input",
  CellLabel->"In[172]:=  (21:52:08 on 5/16/01)",
  CellTags->"Calc"],

Cell[BoxData[
    FormBox["0", TraditionalForm]], "Output",
  CellLabel->"Out[172]=  (21:52:09 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["CA", "ObjectName",
  CellTags->"CA"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"CA"],

Cell["CA is one of the Casimir operators of SU(N) (CA = N).", "Text",
  CellTags->"CA"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["CF",
    ButtonData:>"CF",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"CF"],
  ", ",
  ButtonBox["SUNSimplify",
    ButtonData:>"SUNSimplify",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SUNSimplify"],
  "."
}], "Text",
  CellTags->"CA"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"CA"],

Cell[CellGroupData[{

Cell[BoxData["CA"], "Input",
  CellLabel->"In[173]:=  (21:52:09 on 5/16/01)",
  CellTags->"CA"],

Cell[BoxData[
    FormBox[
      SubscriptBox["C", "A"], TraditionalForm]], "Output",
  CellLabel->"Out[173]=  (21:52:09 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNSimplify", "[", 
      RowBox[{"CA", ",", 
        RowBox[{"SUNNToCACF", "\[Rule]", "False"}]}], "]"}]], "Input",
  CellLabel->"In[174]:=  (21:52:09 on 5/16/01)",
  CellTags->"CA"],

Cell[BoxData[
    FormBox["N", TraditionalForm]], "Output",
  CellLabel->"Out[174]=  (21:52:09 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData["SUNN"], "Input",
  CellLabel->"In[175]:=  (21:52:09 on 5/16/01)",
  CellTags->"CA"],

Cell[BoxData[
    FormBox["N", TraditionalForm]], "Output",
  CellLabel->"Out[175]=  (21:52:09 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Cases2", "ObjectName",
  CellTags->"Cases2"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"Cases2"],

Cell["\<\
Cases2[expr, f] returns a list of all objects in expr with head f. \
Cases2[expr,f] is equivalent to Cases2[{expr},f[___],Infinity]//Union. \
Cases2[expr, f, g, ...] or Cases2[expr, {f,g, ...}] is equivalent to \
Cases[{expr},f[___] | g[___] ...] .\
\>", "Text",
  CellTags->"Cases2"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData["Examples"], "Subsubsection",
  CellTags->"Cases2"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Cases2", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"f", "[", "a", "]"}], "+", 
          SuperscriptBox[
            RowBox[{"f", "[", "b", "]"}], "2"], "+", 
          RowBox[{"f", "[", 
            RowBox[{"c", ",", "d"}], "]"}]}], ",", "f"}], "]"}]], "Input",
  CellLabel->"In[176]:=  (21:52:09 on 5/16/01)",
  CellTags->"Cases2"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"f", "(", "a", ")"}], ",", 
          RowBox[{"f", "(", "b", ")"}], ",", 
          RowBox[{"f", "(", 
            RowBox[{"c", ",", "d"}], ")"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[176]=  (21:52:09 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Cases2", "[", 
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{"Sin", "[", "x", "]"}], " ", 
            RowBox[{"Sin", "[", 
              RowBox[{"y", "-", "z"}], "]"}]}], "+", 
          RowBox[{"g", "[", "y", "]"}]}], ",", "Sin", ",", "g"}], 
      "]"}]], "Input",
  CellLabel->"In[177]:=  (21:52:09 on 5/16/01)",
  CellTags->"Cases2"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"g", "(", "y", ")"}], ",", 
          RowBox[{"sin", "(", "x", ")"}], ",", 
          RowBox[{"sin", "(", 
            RowBox[{"y", "-", "z"}], ")"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[177]=  (21:52:09 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Cases2", "[", 
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{"Sin", "[", "x", "]"}], " ", 
            RowBox[{"Sin", "[", 
              RowBox[{"y", "-", "z"}], "]"}]}], "+", 
          RowBox[{"g", "[", "x", "]"}], "+", 
          RowBox[{"g", "[", 
            RowBox[{"a", ",", "b", ",", "c"}], "]"}]}], ",", 
        RowBox[{"{", 
          RowBox[{"Sin", ",", "g"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[178]:=  (21:52:09 on 5/16/01)",
  CellTags->"Cases2"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"g", "(", "x", ")"}], ",", 
          RowBox[{"g", "(", 
            RowBox[{"a", ",", "b", ",", "c"}], ")"}], ",", 
          RowBox[{"sin", "(", "x", ")"}], ",", 
          RowBox[{"sin", "(", 
            RowBox[{"y", "-", "z"}], ")"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[178]=  (21:52:09 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Cases2", "[", 
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{"DiracSlash", "[", "p", "]"}], ".", 
            RowBox[{"DiracSlash", "[", "q", "]"}]}], "+", 
          RowBox[{"ScalarProduct", "[", 
            RowBox[{"p", ",", "p"}], "]"}]}], ",", "Dot"}], "]"}]], "Input",
  CellLabel->"In[179]:=  (21:52:09 on 5/16/01)",
  CellTags->"Cases2"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              FormBox["\<\"\[Gamma]\"\>",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox["p",
                "TraditionalForm"]}], ")"}], ".", 
          RowBox[{"(", 
            RowBox[{
              FormBox["\<\"\[Gamma]\"\>",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox["q",
                "TraditionalForm"]}], ")"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[179]=  (21:52:09 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["CF", "ObjectName",
  CellTags->"CF"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"CF"],

Cell["\<\
CF is one of the Casimir operators of SU(N) (CF = (N^2-1)/(2 N)).\
\>", "Text",
  CellTags->"CF"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["CA",
    ButtonData:>"CA",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"CA"],
  ", ",
  ButtonBox["SUNSimplify",
    ButtonData:>"SUNSimplify",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SUNSimplify"],
  "."
}], "Text",
  CellTags->"CF"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"CF"],

Cell[CellGroupData[{

Cell[BoxData["CF"], "Input",
  CellLabel->"In[180]:=  (21:52:09 on 5/16/01)",
  CellTags->"CF"],

Cell[BoxData[
    FormBox[
      SubscriptBox["C", "F"], TraditionalForm]], "Output",
  CellLabel->"Out[180]=  (21:52:09 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNSimplify", "[", 
      RowBox[{"CF", ",", " ", 
        RowBox[{"SUNNToCACF", " ", "->", " ", "False"}]}], "]"}]], "Input",
  CellLabel->"In[181]:=  (21:52:10 on 5/16/01)",
  CellTags->"CF"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{
          SuperscriptBox["N", "2"], "-", "1"}], 
        RowBox[{"2", " ", "N"}]], TraditionalForm]], "Output",
  CellLabel->"Out[181]=  (21:52:10 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData["SUNN"], "Input",
  CellLabel->"In[182]:=  (21:52:10 on 5/16/01)",
  CellTags->"CF"],

Cell[BoxData[
    FormBox["N", TraditionalForm]], "Output",
  CellLabel->"Out[182]=  (21:52:10 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNSimplify", "[", 
      RowBox[{"CF", ",", " ", 
        RowBox[{"SUNNToCACF", " ", "->", "True"}]}], "]"}]], "Input",
  CellLabel->"In[183]:=  (21:52:10 on 5/16/01)",
  CellTags->"CF"],

Cell[BoxData[
    FormBox[
      SubscriptBox["C", "F"], TraditionalForm]], "Output",
  CellLabel->"Out[183]=  (21:52:10 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["ChangeDimension", "ObjectName",
  CellTags->"ChangeDimension"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"ChangeDimension"],

Cell["\<\
ChangeDimension[exp, dim] changes all LorentzIndex and Momenta in exp to \
dimension dim (and also Levi-Civita-tensors, Dirac slashes and Dirac \
matrices).\
\>", "Text",
  CellTags->"ChangeDimension"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["LorentzIndex",
    ButtonData:>"LorentzIndex",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"LorentzIndex"],
  ", ",
  ButtonBox["Momentum",
    ButtonData:>"Momentum",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Momentum"],
  ", ",
  ButtonBox["DiracGamma",
    ButtonData:>"DiracGamma",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracGamma"],
  ", ",
  ButtonBox["Eps",
    ButtonData:>"Eps",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Eps"],
  "."
}], "Text",
  CellTags->"ChangeDimension"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"ChangeDimension"],

Cell["\<\
Remember that LorentzIndex[mu, 4] is simplified to LorentzIndex[mu] and \
Momentum[p, 4] to Momentum[p]. Thus the fullowing objects are defined in four \
dimensions.\
\>", "Text",
  CellTags->"ChangeDimension"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", " ", 
        RowBox[{"Momentum", "[", "p", "]"}]}], "}"}]], "Input",
  CellLabel->"In[184]:=  (21:52:10 on 5/16/01)",
  CellTags->"ChangeDimension"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          FormBox["\[Mu]",
            "TraditionalForm"], ",", "p"}], "}"}], TraditionalForm]], "Output",\

  CellLabel->"Out[184]=  (21:52:10 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ChangeDimension", "[", 
      RowBox[{"%", ",", " ", "D"}], "]"}]], "Input",
  CellLabel->"In[185]:=  (21:52:10 on 5/16/01)",
  CellTags->"ChangeDimension"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          FormBox["\[Mu]",
            "TraditionalForm"], ",", "p"}], "}"}], TraditionalForm]], "Output",\

  CellLabel->"Out[185]=  (21:52:10 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "StandardForm"}]], "Input",
  CellLabel->"In[186]:=  (21:52:10 on 5/16/01)",
  CellTags->"ChangeDimension"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"LorentzIndex", "[", 
          RowBox[{"\[Mu]", ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
          RowBox[{"p", ",", "D"}], "]"}]}], "}"}]], "Output",
  CellLabel->"Out[186]//StandardForm=  (21:52:10 on 5/16/01)"]
}, Closed]],

Cell["\<\
This changes all non-4-dimensional objects to 4-dimensional ones.\
\>", "Text",
  CellTags->"ChangeDimension"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"ChangeDimension", "[", 
        RowBox[{"%%", ",", " ", "4"}], "]"}], " ", "//", " ", 
      "StandardForm"}]], "Input",
  CellLabel->"In[187]:=  (21:52:10 on 5/16/01)",
  CellTags->"ChangeDimension"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
        RowBox[{"Momentum", "[", "p", "]"}]}], "}"}]], "Output",
  CellLabel->"Out[187]//StandardForm=  (21:52:10 on 5/16/01)"]
}, Closed]],

Cell["Consider the following list of 4- and D-dimensional object.", "Text",
  CellTags->"ChangeDimension"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{"GA", "[", 
            RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], " ", 
          RowBox[{"MT", "[", 
            RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}]}], ",", " ", 
        RowBox[{
          RowBox[{"GAD", "[", 
            RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], " ", 
          RowBox[{"MTD", "[", 
            RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], " ", 
          RowBox[{"f", "[", "D", "]"}]}]}], "}"}]], "Input",
  CellLabel->"In[188]:=  (21:52:10 on 5/16/01)",
  CellTags->"ChangeDimension"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{
            RowBox[{
              SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
              SuperscriptBox["\[Gamma]", "\[Nu]"]}], " ", 
            SuperscriptBox["g", 
              RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]]}], ",", 
          RowBox[{
            RowBox[{
              SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
              SuperscriptBox["\[Gamma]", "\[Nu]"]}], " ", 
            RowBox[{"f", "(", "D", ")"}], " ", 
            SuperscriptBox["g", 
              RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]]}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[188]=  (21:52:10 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracTrick", "[", 
      RowBox[{"Contract", "[", "%", "]"}], "]"}]], "Input",
  CellLabel->"In[189]:=  (21:52:10 on 5/16/01)",
  CellTags->"ChangeDimension"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"4", ",", 
          RowBox[{"D", " ", 
            RowBox[{"f", "(", "D", ")"}]}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[189]=  (21:52:10 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracTrick", "[", 
      RowBox[{"Contract", "[", 
        RowBox[{"ChangeDimension", "[", 
          RowBox[{"%%", ",", "n"}], "]"}], "]"}], "]"}]], "Input",
  CellLabel->"In[190]:=  (21:52:10 on 5/16/01)",
  CellTags->"ChangeDimension"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"n", ",", 
          RowBox[{"n", " ", 
            RowBox[{"f", "(", "D", ")"}]}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[190]=  (21:52:10 on 5/16/01)"]
}, Closed]],

Cell["\<\
Any explicit occurence of D (like in f(D)) is not replaced by \
ChangeDimension.\
\>", "Text",
  CellTags->"ChangeDimension"],

Cell[BoxData[
    RowBox[{
      RowBox[{"SetOptions", "[", 
        RowBox[{"LeviCivita", ",", 
          RowBox[{"Dimension", "\[Rule]", "D"}]}], "]"}], ";"}]], "Input",
  CellLabel->"In[191]:=  (21:52:10 on 5/16/01)",
  CellTags->"ChangeDimension"],

Cell["\<\
The option Dimension of Eps must be changed too, since with the default \
setting Dimension->4 the arguments of Eps are automatically changed to 4 \
dimensions.\
\>", "Text",
  CellTags->"ChangeDimension"],

Cell[BoxData[
    RowBox[{
      RowBox[{"SetOptions", "[", 
        RowBox[{"Eps", ",", 
          RowBox[{"Dimension", "\[Rule]", "D"}]}], "]"}], ";"}]], "Input",
  CellLabel->"In[192]:=  (21:52:10 on 5/16/01)",
  CellTags->"ChangeDimension"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"a1", " ", "=", " ", 
      RowBox[{"LeviCivita", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Sigma]"}], 
        "]"}]}]], "Input",
  CellLabel->"In[193]:=  (21:52:11 on 5/16/01)",
  CellTags->"ChangeDimension"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["\[Epsilon]", 
        RowBox[{
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", 
          FormBox[
            FormBox["\[Nu]",
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", 
          FormBox[
            FormBox["\[Rho]",
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", 
          FormBox[
            FormBox["\[Sigma]",
              "TraditionalForm"],
            "TraditionalForm"]}]], TraditionalForm]], "Output",
  CellLabel->"Out[193]=  (21:52:11 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"a2", " ", "=", " ", 
      RowBox[{"ChangeDimension", "[", 
        RowBox[{"a1", ",", "4"}], "]"}]}]], "Input",
  CellLabel->"In[194]:=  (21:52:11 on 5/16/01)",
  CellTags->"ChangeDimension"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["\[Epsilon]", 
        RowBox[{
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", 
          FormBox[
            FormBox["\[Nu]",
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", 
          FormBox[
            FormBox["\[Rho]",
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", 
          FormBox[
            FormBox["\[Sigma]",
              "TraditionalForm"],
            "TraditionalForm"]}]], TraditionalForm]], "Output",
  CellLabel->"Out[194]=  (21:52:11 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Factor2", "[", 
      RowBox[{"Contract", "[", 
        SuperscriptBox["a1", "2"], "]"}], "]"}]], "Input",
  CellLabel->"In[195]:=  (21:52:11 on 5/16/01)",
  CellTags->"ChangeDimension"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"(", 
          RowBox[{"1", "-", "D"}], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{"2", "-", "D"}], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{"3", "-", "D"}], ")"}], " ", "D"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[195]=  (21:52:11 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Contract", "[", 
      SuperscriptBox["a2", "2"], "]"}]], "Input",
  CellLabel->"In[196]:=  (21:52:11 on 5/16/01)",
  CellTags->"ChangeDimension"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", "24"}], TraditionalForm]], "Output",
  CellLabel->"Out[196]=  (21:52:11 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      RowBox[{"SetOptions", "[", 
        RowBox[{"Eps", ",", 
          RowBox[{"Dimension", "\[Rule]", "4"}]}], "]"}], ";"}]], "Input",
  CellLabel->"In[197]:=  (21:52:11 on 5/16/01)",
  CellTags->"ChangeDimension"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Clear", "[", 
        RowBox[{"a1", ",", "a2"}], "]"}], ";"}]], "Input",
  CellLabel->"In[198]:=  (21:52:11 on 5/16/01)",
  CellTags->"ChangeDimension"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["ChargeConjugationMatrixInv", "ObjectName",
  CellTags->"ChargeConjugationMatrixInv"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"ChargeConjugationMatrixInv"],

Cell["\<\
ChargeConjugationMatrixInv is the inverse of ChargeConjugationMatrix. It is \
substituted immediately by -ChargeConjugationMatrix.\
\>", "Text",
  CellTags->"ChargeConjugationMatrixInv"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["ChargeConjugationMatrix",
    ButtonData:>"ChargeConjugationMatrix",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"ChargeConjugationMatrix"],
  "."
}], "Text",
  CellTags->"ChargeConjugationMatrixInv"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"ChargeConjugationMatrixInv"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ChargeConjugationMatrix", ".", 
      RowBox[{"DiracMatrix", "[", "\[Mu]", "]"}], ".", 
      "ChargeConjugationMatrixInv"}]], "Input",
  CellLabel->"In[199]:=  (21:52:11 on 5/16/01)",
  CellTags->"ChargeConjugationMatrixInv"],

Cell[BoxData[
    FormBox[
      RowBox[{"C", ".", 
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        RowBox[{"(", 
          RowBox[{"-", "C"}], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[199]=  (21:52:11 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Calc", "[", "%", "]"}]], "Input",
  CellLabel->"In[200]:=  (21:52:11 on 5/16/01)",
  CellTags->"ChargeConjugationMatrixInv"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        SubsuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"], "T"]}], TraditionalForm]], "Output",
  CellLabel->"Out[200]=  (21:52:11 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ChargeConjugationMatrix", ".", 
      RowBox[{"DiracGamma", "[", "5", "]"}], ".", 
      "ChargeConjugationMatrixInv"}]], "Input",
  CellLabel->"In[201]:=  (21:52:11 on 5/16/01)",
  CellTags->"ChargeConjugationMatrixInv"],

Cell[BoxData[
    FormBox[
      RowBox[{"C", ".", 
        SuperscriptBox["\[Gamma]", "5"], ".", 
        RowBox[{"(", 
          RowBox[{"-", "C"}], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[201]=  (21:52:11 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Calc", "[", "%", "]"}]], "Input",
  CellLabel->"In[202]:=  (21:52:12 on 5/16/01)",
  CellTags->"ChargeConjugationMatrixInv"],

Cell[BoxData[
    FormBox[
      SubsuperscriptBox["\[Gamma]", 
        FormBox["5",
          "TraditionalForm"], "T"], TraditionalForm]], "Output",
  CellLabel->"Out[202]=  (21:52:12 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
    "ChargeConjugationMatrix", ".", "ChargeConjugationMatrixInv"}]], "Input",
  CellLabel->"In[203]:=  (21:52:12 on 5/16/01)",
  CellTags->"ChargeConjugationMatrixInv"],

Cell[BoxData[
    FormBox[
      RowBox[{"C", ".", 
        RowBox[{"(", 
          RowBox[{"-", "C"}], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[203]=  (21:52:12 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "Calc"}]], "Input",
  CellLabel->"In[204]:=  (21:52:12 on 5/16/01)",
  CellTags->"ChargeConjugationMatrixInv"],

Cell[BoxData[
    FormBox["1", TraditionalForm]], "Output",
  CellLabel->"Out[204]=  (21:52:12 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ChargeConjugationMatrixInv", "^", "2"}]], "Input",
  CellLabel->"In[205]:=  (21:52:12 on 5/16/01)",
  CellTags->"ChargeConjugationMatrixInv"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", "1"}], TraditionalForm]], "Output",
  CellLabel->"Out[205]=  (21:52:12 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["ChargeConjugationMatrix", "ObjectName",
  CellTags->"ChargeConjugationMatrix"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"ChargeConjugationMatrix"],

Cell[TextData[{
  "ChargeConjugationMatrix denotes the charge conjugation matrix ",
  StyleBox["C",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"ChargeConjugationMatrix"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["ChargeConjugationMatrixInv",
    ButtonData:>"ChargeConjugationMatrixInv",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"ChargeConjugationMatrixInv"],
  "."
}], "Text",
  CellTags->"ChargeConjugationMatrix"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"ChargeConjugationMatrix"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ChargeConjugationMatrix", ".", 
      RowBox[{"DiracMatrix", "[", "\[Mu]", "]"}], ".", 
      "ChargeConjugationMatrixInv"}]], "Input",
  CellLabel->"In[206]:=  (21:52:13 on 5/16/01)",
  CellTags->"ChargeConjugationMatrix"],

Cell[BoxData[
    FormBox[
      RowBox[{"C", ".", 
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        RowBox[{"(", 
          RowBox[{"-", "C"}], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[206]=  (21:52:13 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Calc", "[", "%", "]"}]], "Input",
  CellLabel->"In[207]:=  (21:52:13 on 5/16/01)",
  CellTags->"ChargeConjugationMatrix"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        SubsuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"], "T"]}], TraditionalForm]], "Output",
  CellLabel->"Out[207]=  (21:52:13 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ChargeConjugationMatrix", ".", 
      RowBox[{"DiracGamma", "[", "5", "]"}], ".", 
      "ChargeConjugationMatrixInv"}]], "Input",
  CellLabel->"In[208]:=  (21:52:13 on 5/16/01)",
  CellTags->"ChargeConjugationMatrix"],

Cell[BoxData[
    FormBox[
      RowBox[{"C", ".", 
        SuperscriptBox["\[Gamma]", "5"], ".", 
        RowBox[{"(", 
          RowBox[{"-", "C"}], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[208]=  (21:52:13 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Calc", "[", "%", "]"}]], "Input",
  CellLabel->"In[209]:=  (21:52:13 on 5/16/01)",
  CellTags->"ChargeConjugationMatrix"],

Cell[BoxData[
    FormBox[
      SubsuperscriptBox["\[Gamma]", 
        FormBox["5",
          "TraditionalForm"], "T"], TraditionalForm]], "Output",
  CellLabel->"Out[209]=  (21:52:13 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ChargeConjugationMatrix", "^", "2"}]], "Input",
  CellLabel->"In[210]:=  (21:52:14 on 5/16/01)",
  CellTags->"ChargeConjugationMatrix"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", "1"}], TraditionalForm]], "Output",
  CellLabel->"Out[210]=  (21:52:14 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["ChiralityProjector", "ObjectName",
  CellTags->"ChiralityProjector"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"ChiralityProjector"],

Cell[TextData[{
  "ChiralityProjector[+1] denotes ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"1", "/", "2"}], 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox["\[Gamma]", "5"]}], ")"}]}], TraditionalForm]]],
  ". ChiralityProjector[-1] denotes ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"1", "/", "2"}], 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox["\[Gamma]", "5"]}], ")"}]}], TraditionalForm]]],
  "."
}], "Text",
  CellTags->"ChiralityProjector"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["DiracGamma",
    ButtonData:>"DiracGamma",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracGamma"],
  ", ",
  ButtonBox["DiracMatrix",
    ButtonData:>"DiracMatrix",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracMatrix"],
  ", ",
  ButtonBox["FCI",
    ButtonData:>"FCI",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FCI"],
  "."
}], "Text",
  CellTags->"ChiralityProjector"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"ChiralityProjector"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"ChiralityProjector", "[", 
          RowBox[{"+", "1"}], "]"}], ",", 
        RowBox[{"ChiralityProjector", "[", 
          RowBox[{"-", "1"}], "]"}]}], "}"}]], "Input",
  CellLabel->"In[211]:=  (21:52:14 on 5/16/01)",
  CellTags->"ChiralityProjector"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          SuperscriptBox["\[Gamma]", "6"], ",", 
          SuperscriptBox["\[Gamma]", "7"]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[211]=  (21:52:14 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FCI", "[", "%", "]"}]], "Input",
  CellLabel->"In[212]:=  (21:52:14 on 5/16/01)",
  CellTags->"ChiralityProjector"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          SuperscriptBox["\[Gamma]", "6"], ",", 
          SuperscriptBox["\[Gamma]", "7"]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[212]=  (21:52:14 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracSimplify", "[", 
      RowBox[{"%", ",", 
        RowBox[{"DiracSubstitute67", "\[Rule]", "True"}]}], "]"}]], "Input",
  CellLabel->"In[213]:=  (21:52:15 on 5/16/01)",
  CellTags->"ChiralityProjector"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{
            FractionBox[
              SuperscriptBox["\[Gamma]", "5"], "2"], "+", 
            FractionBox["1", "2"]}], ",", 
          RowBox[{
            FractionBox["1", "2"], "-", 
            FractionBox[
              SuperscriptBox["\[Gamma]", "5"], "2"]}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[213]=  (21:52:15 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Chisholm", "ObjectName",
  CellTags->"Chisholm"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"Chisholm"],

Cell["\<\
Chisholm[x] substitutes products of three Dirac matrices or slashes by the \
Chisholm identity.\
\>", "Text",
  CellTags->"Chisholm"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["EpsChisholm",
    ButtonData:>"EpsChisholm",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"EpsChisholm"],
  "."
}], "Text",
  CellTags->"Chisholm"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"Chisholm"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Chisholm", "[", 
      RowBox[{"GA", "[", 
        RowBox[{"\[Alpha]", ",", "\[Beta]", ",", "\[Mu]", ",", "\[Nu]"}], 
        "]"}], "]"}]], "Input",
  CellLabel->"In[214]:=  (21:52:15 on 5/16/01)",
  CellTags->"Chisholm"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", 
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["$MU$42",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", "5"]}], " ", 
          SuperscriptBox["\[Epsilon]", 
            RowBox[{
              FormBox[
                FormBox["\[Alpha]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Beta]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["$MU$42",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "+", 
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Alpha]", "\[NoBreak]", "\[Beta]"}]]}], "-", 
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Beta]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Alpha]", "\[NoBreak]", "\[Mu]"}]]}], "+", 
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Alpha]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Beta]", "\[NoBreak]", "\[Mu]"}]]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[214]=  (21:52:16 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t1", "=", 
      RowBox[{"DiracMatrix", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]"}], "]"}]}]], "Input",
  CellLabel->"In[215]:=  (21:52:16 on 5/16/01)",
  CellTags->"Chisholm"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", "\[Mu]"], 
        SuperscriptBox["\[Gamma]", "\[Nu]"], 
        SuperscriptBox["\[Gamma]", "\[Rho]"]}], TraditionalForm]], "Output",
  CellLabel->"Out[215]=  (21:52:16 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t2", " ", "=", 
      RowBox[{"Chisholm", "[", "t1", "]"}]}]], "Input",
  CellLabel->"In[216]:=  (21:52:16 on 5/16/01)",
  CellTags->"Chisholm"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["$MU$43",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", "5"]}], " ", 
          SuperscriptBox["\[Epsilon]", 
            RowBox[{
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Rho]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["$MU$43",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "+", 
        RowBox[{
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox["\[Rho]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]]}], "-", 
        RowBox[{
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Rho]"}]]}], "+", 
        RowBox[{
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Nu]", "\[NoBreak]", "\[Rho]"}]]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[216]=  (21:52:17 on 5/16/01)"]
}, Closed]],

Cell["The $MU$ variables are unique indices.", "Text",
  CellTags->"Chisholm"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Calc", "[", 
      RowBox[{"t1", ".", "t1"}], "]"}]], "Input",
  CellLabel->"In[217]:=  (21:52:17 on 5/16/01)",
  CellTags->"Chisholm"],

Cell[BoxData[
    FormBox["16", TraditionalForm]], "Output",
  CellLabel->"Out[217]=  (21:52:17 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t3", " ", "=", 
      RowBox[{"Chisholm", "[", "t1", "]"}]}]], "Input",
  CellLabel->"In[218]:=  (21:52:17 on 5/16/01)",
  CellTags->"Chisholm"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["$MU$44",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", "5"]}], " ", 
          SuperscriptBox["\[Epsilon]", 
            RowBox[{
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Rho]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["$MU$44",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "+", 
        RowBox[{
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox["\[Rho]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]]}], "-", 
        RowBox[{
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Rho]"}]]}], "+", 
        RowBox[{
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Nu]", "\[NoBreak]", "\[Rho]"}]]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[218]=  (21:52:18 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Calc", "[", 
      RowBox[{"t2", ".", "t3"}], "]"}]], "Input",
  CellLabel->"In[219]:=  (21:52:18 on 5/16/01)",
  CellTags->"Chisholm"],

Cell[BoxData[
    FormBox["16", TraditionalForm]], "Output",
  CellLabel->"Out[219]=  (21:52:19 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t4", "=", 
      RowBox[{"DiracSlash", "[", 
        RowBox[{"a", ",", "b", ",", "c"}], "]"}]}]], "Input",
  CellLabel->"In[220]:=  (21:52:19 on 5/16/01)",
  CellTags->"Chisholm"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            FormBox["\<\"\[Gamma]\"\>",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["a",
              "TraditionalForm"]}], ")"}], ".", 
        RowBox[{"(", 
          RowBox[{
            FormBox["\<\"\[Gamma]\"\>",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["b",
              "TraditionalForm"]}], ")"}], ".", 
        RowBox[{"(", 
          RowBox[{
            FormBox["\<\"\[Gamma]\"\>",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["c",
              "TraditionalForm"]}], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[220]=  (21:52:19 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Chisholm", "[", "t4", "]"}]], "Input",
  CellLabel->"In[221]:=  (21:52:19 on 5/16/01)",
  CellTags->"Chisholm"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", 
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["$MU$45",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", "5"]}], " ", 
          SuperscriptBox["\[Epsilon]", 
            RowBox[{
              FormBox[
                FormBox["$MU$45",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox["a",
                "TraditionalForm"], "\[NoBreak]", 
              FormBox["b",
                "TraditionalForm"], "\[NoBreak]", 
              FormBox["c",
                "TraditionalForm"]}]]}], "+", 
        RowBox[{
          RowBox[{
            FormBox["\<\"\[Gamma]\"\>",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["c",
              "TraditionalForm"]}], " ", 
          RowBox[{
            FormBox["a",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["b",
              "TraditionalForm"]}]}], "-", 
        RowBox[{
          RowBox[{
            FormBox["\<\"\[Gamma]\"\>",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["b",
              "TraditionalForm"]}], " ", 
          RowBox[{
            FormBox["a",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["c",
              "TraditionalForm"]}]}], "+", 
        RowBox[{
          RowBox[{
            FormBox["\<\"\[Gamma]\"\>",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["a",
              "TraditionalForm"]}], " ", 
          RowBox[{
            FormBox["b",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["c",
              "TraditionalForm"]}]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[221]=  (21:52:20 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"a1", "=", 
      RowBox[{"GA", "[", 
        RowBox[{
        "\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Sigma]", ",", "\[Tau]", 
          ",", "\[Kappa]"}], "]"}]}]], "Input",
  CellLabel->"In[222]:=  (21:52:20 on 5/16/01)",
  CellTags->"Chisholm"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
        SuperscriptBox["\[Gamma]", "\[Nu]"], ".", 
        SuperscriptBox["\[Gamma]", "\[Rho]"], ".", 
        SuperscriptBox["\[Gamma]", "\[Sigma]"], ".", 
        SuperscriptBox["\[Gamma]", "\[Tau]"], ".", 
        SuperscriptBox["\[Gamma]", "\[Kappa]"]}], TraditionalForm]], "Output",\

  CellLabel->"Out[222]=  (21:52:20 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"a2", " ", "=", 
      RowBox[{"Chisholm", "[", "a1", "]"}]}]], "Input",
  CellLabel->"In[223]:=  (21:52:20 on 5/16/01)",
  CellTags->"Chisholm"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", 
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Tau]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Kappa]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", "5"]}], " ", 
          SuperscriptBox["\[Epsilon]", 
            RowBox[{
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Rho]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Kappa]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", "5"]}], " ", 
          SuperscriptBox["\[Epsilon]", 
            RowBox[{
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Rho]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Tau]",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "-", 
        RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["$MU$48",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Kappa]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", "5"]}], " ", 
          SuperscriptBox["\[Epsilon]", 
            RowBox[{
              FormBox[
                FormBox["\[Rho]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Tau]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["$MU$48",
                  "TraditionalForm"],
                "TraditionalForm"]}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]]}], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["$MU$49",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Kappa]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", "5"]}], " ", 
          SuperscriptBox["\[Epsilon]", 
            RowBox[{
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Tau]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["$MU$49",
                  "TraditionalForm"],
                "TraditionalForm"]}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Rho]"}]]}], "-", 
        RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["$MU$50",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Kappa]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", "5"]}], " ", 
          SuperscriptBox["\[Epsilon]", 
            RowBox[{
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Tau]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["$MU$50",
                  "TraditionalForm"],
                "TraditionalForm"]}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Nu]", "\[NoBreak]", "\[Rho]"}]]}], "+", 
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Tau]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Kappa]",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Sigma]"}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Nu]", "\[NoBreak]", "\[Rho]"}]]}], "-", 
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Kappa]",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Tau]"}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Nu]", "\[NoBreak]", "\[Rho]"}]]}], "-", 
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Tau]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Kappa]",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Rho]"}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Nu]", "\[NoBreak]", "\[Sigma]"}]]}], "+", 
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Rho]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Kappa]",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Tau]"}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Nu]", "\[NoBreak]", "\[Sigma]"}]]}], "+", 
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Kappa]",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Rho]"}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Nu]", "\[NoBreak]", "\[Tau]"}]]}], "-", 
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Rho]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Kappa]",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Sigma]"}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Nu]", "\[NoBreak]", "\[Tau]"}]]}], "+", 
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Tau]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Kappa]",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Rho]", "\[NoBreak]", "\[Sigma]"}]]}], "-", 
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Kappa]",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Tau]"}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Rho]", "\[NoBreak]", "\[Sigma]"}]]}], "+", 
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Kappa]",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Nu]", "\[NoBreak]", "\[Tau]"}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Rho]", "\[NoBreak]", "\[Sigma]"}]]}], "-", 
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Kappa]",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Rho]", "\[NoBreak]", "\[Tau]"}]]}], "+", 
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Kappa]",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Sigma]"}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Rho]", "\[NoBreak]", "\[Tau]"}]]}], "-", 
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Kappa]",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Nu]", "\[NoBreak]", "\[Sigma]"}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Rho]", "\[NoBreak]", "\[Tau]"}]]}], "-", 
        RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["$MU$46",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Kappa]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", "5"]}], " ", 
          SuperscriptBox["\[Epsilon]", 
            RowBox[{
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Rho]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["$MU$46",
                  "TraditionalForm"],
                "TraditionalForm"]}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Sigma]", "\[NoBreak]", "\[Tau]"}]]}], "+", 
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Rho]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Kappa]",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Sigma]", "\[NoBreak]", "\[Tau]"}]]}], "-", 
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Kappa]",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Rho]"}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Sigma]", "\[NoBreak]", "\[Tau]"}]]}], "+", 
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Kappa]",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Nu]", "\[NoBreak]", "\[Rho]"}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Sigma]", "\[NoBreak]", "\[Tau]"}]]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[223]=  (21:52:23 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"a3", " ", "=", 
      RowBox[{"Chisholm", "[", "a1", "]"}]}]], "Input",
  CellLabel->"In[224]:=  (21:52:23 on 5/16/01)",
  CellTags->"Chisholm"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", 
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Tau]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Kappa]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", "5"]}], " ", 
          SuperscriptBox["\[Epsilon]", 
            RowBox[{
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Rho]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Kappa]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", "5"]}], " ", 
          SuperscriptBox["\[Epsilon]", 
            RowBox[{
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Rho]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Tau]",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "-", 
        RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["$MU$53",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Kappa]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", "5"]}], " ", 
          SuperscriptBox["\[Epsilon]", 
            RowBox[{
              FormBox[
                FormBox["\[Rho]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Tau]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["$MU$53",
                  "TraditionalForm"],
                "TraditionalForm"]}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]]}], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["$MU$54",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Kappa]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", "5"]}], " ", 
          SuperscriptBox["\[Epsilon]", 
            RowBox[{
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Tau]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["$MU$54",
                  "TraditionalForm"],
                "TraditionalForm"]}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Rho]"}]]}], "-", 
        RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["$MU$55",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Kappa]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", "5"]}], " ", 
          SuperscriptBox["\[Epsilon]", 
            RowBox[{
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Tau]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["$MU$55",
                  "TraditionalForm"],
                "TraditionalForm"]}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Nu]", "\[NoBreak]", "\[Rho]"}]]}], "+", 
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Tau]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Kappa]",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Sigma]"}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Nu]", "\[NoBreak]", "\[Rho]"}]]}], "-", 
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Kappa]",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Tau]"}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Nu]", "\[NoBreak]", "\[Rho]"}]]}], "-", 
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Tau]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Kappa]",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Rho]"}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Nu]", "\[NoBreak]", "\[Sigma]"}]]}], "+", 
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Rho]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Kappa]",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Tau]"}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Nu]", "\[NoBreak]", "\[Sigma]"}]]}], "+", 
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Kappa]",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Rho]"}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Nu]", "\[NoBreak]", "\[Tau]"}]]}], "-", 
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Rho]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Kappa]",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Sigma]"}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Nu]", "\[NoBreak]", "\[Tau]"}]]}], "+", 
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Tau]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Kappa]",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Rho]", "\[NoBreak]", "\[Sigma]"}]]}], "-", 
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Kappa]",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Tau]"}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Rho]", "\[NoBreak]", "\[Sigma]"}]]}], "+", 
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Kappa]",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Nu]", "\[NoBreak]", "\[Tau]"}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Rho]", "\[NoBreak]", "\[Sigma]"}]]}], "-", 
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Kappa]",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Rho]", "\[NoBreak]", "\[Tau]"}]]}], "+", 
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Kappa]",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Sigma]"}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Rho]", "\[NoBreak]", "\[Tau]"}]]}], "-", 
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Kappa]",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Nu]", "\[NoBreak]", "\[Sigma]"}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Rho]", "\[NoBreak]", "\[Tau]"}]]}], "-", 
        RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["$MU$51",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Kappa]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", "5"]}], " ", 
          SuperscriptBox["\[Epsilon]", 
            RowBox[{
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Rho]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["$MU$51",
                  "TraditionalForm"],
                "TraditionalForm"]}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Sigma]", "\[NoBreak]", "\[Tau]"}]]}], "+", 
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Rho]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Kappa]",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Sigma]", "\[NoBreak]", "\[Tau]"}]]}], "-", 
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Kappa]",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Rho]"}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Sigma]", "\[NoBreak]", "\[Tau]"}]]}], "+", 
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Kappa]",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Nu]", "\[NoBreak]", "\[Rho]"}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Sigma]", "\[NoBreak]", "\[Tau]"}]]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[224]=  (21:52:26 on 5/16/01)"]
}, Closed]],

Cell["Check that both a1.a1 and a2.a3 give the same.", "Text",
  CellTags->"Chisholm"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Calc", "[", 
      RowBox[{"a1", ".", "a1"}], "]"}]], "Input",
  CellLabel->"In[225]:=  (21:52:26 on 5/16/01)",
  CellTags->"Chisholm"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", "2048"}], TraditionalForm]], "Output",
  CellLabel->"Out[225]=  (21:52:26 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Calc", "[", 
      RowBox[{"a2", ".", "a3"}], "]"}]], "Input",
  CellLabel->"In[226]:=  (21:52:26 on 5/16/01)",
  CellTags->"Chisholm"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", "2048"}], TraditionalForm]], "Output",
  CellLabel->"Out[226]=  (21:52:35 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{"Clear", "[", 
      RowBox[{
      "t1", ",", "t2", ",", "t3", ",", "t4", ",", "a1", ",", "a2", ",", 
        "a3"}], "]"}]], "Input",
  CellLabel->"In[227]:=  (21:52:35 on 5/16/01)",
  CellTags->"Chisholm"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["ClearScalarProducts", "ObjectName",
  CellTags->"ClearScalarProducts"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"ClearScalarProducts"],

Cell["\<\
ClearScalarProducts removes all user-performed specific settings for \
ScalarProduct's.\
\>", "Text",
  CellTags->"ClearScalarProducts"],

Cell[TextData[{
  "See also: ",
  ButtonBox["ScalarProduct",
    ButtonData:>"ScalarProduct",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"ScalarProduct"],
  ", ",
  ButtonBox["Pair",
    ButtonData:>"Pair",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Pair"],
  ", ",
  ButtonBox["SP",
    ButtonData:>"SP",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SP"],
  ", ",
  ButtonBox["SPD",
    ButtonData:>"SPD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SPD"],
  "."
}], "Text",
  CellTags->"ClearScalarProducts"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"ClearScalarProducts"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"ScalarProduct", "[", 
        RowBox[{"p", ",", "p"}], "]"}], "=", 
      RowBox[{"m", "^", "2"}]}]], "Input",
  CellLabel->"In[228]:=  (21:52:35 on 5/16/01)",
  CellTags->"ClearScalarProducts"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["m", "2"], TraditionalForm]], "Output",
  CellLabel->"Out[228]=  (21:52:35 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Pair", "[", 
      RowBox[{
        RowBox[{"Momentum", "[", "p", "]"}], ",", 
        RowBox[{"Momentum", "[", "p", "]"}]}], "]"}]], "Input",
  CellLabel->"In[229]:=  (21:52:35 on 5/16/01)",
  CellTags->"ClearScalarProducts"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["m", "2"], TraditionalForm]], "Output",
  CellLabel->"Out[229]=  (21:52:35 on 5/16/01)"]
}, Closed]],

Cell[BoxData["ClearScalarProducts"], "Input",
  CellLabel->"In[230]:=  (21:52:35 on 5/16/01)",
  CellTags->"ClearScalarProducts"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Pair", "[", 
      RowBox[{
        RowBox[{"Momentum", "[", "p", "]"}], ",", 
        RowBox[{"Momentum", "[", "p", "]"}]}], "]"}]], "Input",
  CellLabel->"In[231]:=  (21:52:35 on 5/16/01)",
  CellTags->"ClearScalarProducts"],

Cell[BoxData[
    FormBox[
      SuperscriptBox[
        FormBox["p",
          "TraditionalForm"], "2"], TraditionalForm]], "Output",
  CellLabel->"Out[231]=  (21:52:35 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ScalarProduct", "[", 
      RowBox[{"p", ",", "p"}], "]"}]], "Input",
  CellLabel->"In[232]:=  (21:52:35 on 5/16/01)",
  CellTags->"ClearScalarProducts"],

Cell[BoxData[
    FormBox[
      SuperscriptBox[
        FormBox["p",
          "TraditionalForm"], "2"], TraditionalForm]], "Output",
  CellLabel->"Out[232]=  (21:52:35 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Collect2", "ObjectName",
  CellTags->"Collect2"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"Collect2"],

Cell["\<\
Collect2[expr, x] collects together terms which are not free of any \
occurrence of x. Collect2[expr, {x1, x2, ...}] (or also Collect2[expr, x1, \
x2, ...]) collects together terms which are not free of any occurrence of x1, \
x2, .... The coefficients are put over a common denominator. If expr is \
expanded before collecting depends on the option Factoring, which may be set \
to Factor, Factor2, or any other function, which is applied to the \
coefficients. If expr is already expanded with respect to x (x1,x2, ...), the \
option Expanding can be set to False.\
\>", "Text",
  CellTags->"Collect2"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "Collect2", "]"}]], "Input",
  CellLabel->"In[233]:=  (21:52:35 on 5/16/01)",
  CellTags->"Collect2"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"Denominator", "\[Rule]", "False"}], ",", 
          RowBox[{"Dot", "\[Rule]", "False"}], ",", 
          RowBox[{"Expanding", "\[Rule]", "True"}], ",", 
          RowBox[{"Factoring", "\[Rule]", "Factor2"}], ",", 
          RowBox[{"IsolateNames", "\[Rule]", "False"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[233]=  (21:52:35 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["Isolate",
    ButtonData:>"Isolate",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Isolate"],
  "."
}], "Text",
  CellTags->"Collect2"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"Collect2"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Collect2", "[", 
      RowBox[{
        RowBox[{"t1", "=", 
          RowBox[{"a", "+", 
            RowBox[{"r", " ", "a"}], "+", 
            RowBox[{
              SuperscriptBox["k", "2"], " ", 
              RowBox[{"f", "[", "a", "]"}]}], "-", 
            RowBox[{"k", " ", 
              RowBox[{"f", "[", "a", "]"}]}], "+", 
            FractionBox["x", "2"], "-", 
            FractionBox["y", "w"]}]}], ",", "a"}], "]"}]], "Input",
  CellLabel->"In[234]:=  (21:52:35 on 5/16/01)",
  CellTags->"Collect2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"a", " ", 
          RowBox[{"(", 
            RowBox[{"r", "+", "1"}], ")"}]}], "+", 
        FractionBox[
          RowBox[{
            RowBox[{"w", " ", "x"}], "-", 
            RowBox[{"2", " ", "y"}]}], 
          RowBox[{"2", " ", "w"}]], "-", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "-", 
              FormBox[
                TagBox[
                  StyleBox["\<\"k\"\>",
                    FontSlant->"Italic"],
                  (StyleForm[ #, FontSlant -> "Italic"]&)],
                "TraditionalForm"]}], ")"}], " ", 
          FormBox[
            TagBox[
              StyleBox["\<\"k\"\>",
                FontSlant->"Italic"],
              (StyleForm[ #, FontSlant -> "Italic"]&)],
            "TraditionalForm"], " ", 
          RowBox[{"f", "(", "a", ")"}]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[234]=  (21:52:35 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Collect2", "[", 
      RowBox[{"t1", ",", "a", ",", 
        RowBox[{"Factoring", "->", "False"}]}], "]"}]], "Input",
  CellLabel->"In[235]:=  (21:52:35 on 5/16/01)",
  CellTags->"Collect2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"a", " ", 
          RowBox[{"(", 
            RowBox[{"r", "+", "1"}], ")"}]}], "+", 
        FractionBox["x", "2"], "-", 
        FractionBox["y", "w"], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"], "2"], "-", 
              FormBox[
                TagBox[
                  StyleBox["\<\"k\"\>",
                    FontSlant->"Italic"],
                  (StyleForm[ #, FontSlant -> "Italic"]&)],
                "TraditionalForm"]}], ")"}], " ", 
          RowBox[{"f", "(", "a", ")"}]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[235]=  (21:52:35 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Collect2", "[", 
      RowBox[{"t1", ",", "a", ",", 
        RowBox[{"Factoring", "->", "Factor"}]}], "]"}]], "Input",
  CellLabel->"In[236]:=  (21:52:35 on 5/16/01)",
  CellTags->"Collect2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"a", " ", 
          RowBox[{"(", 
            RowBox[{"r", "+", "1"}], ")"}]}], "+", 
        FractionBox[
          RowBox[{
            RowBox[{"w", " ", "x"}], "-", 
            RowBox[{"2", " ", "y"}]}], 
          RowBox[{"2", " ", "w"}]], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              FormBox[
                TagBox[
                  StyleBox["\<\"k\"\>",
                    FontSlant->"Italic"],
                  (StyleForm[ #, FontSlant -> "Italic"]&)],
                "TraditionalForm"], "-", "1"}], ")"}], " ", 
          FormBox[
            TagBox[
              StyleBox["\<\"k\"\>",
                FontSlant->"Italic"],
              (StyleForm[ #, FontSlant -> "Italic"]&)],
            "TraditionalForm"], " ", 
          RowBox[{"f", "(", "a", ")"}]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[236]=  (21:52:35 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Collect2", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"2", " ", "a", " ", 
            RowBox[{"(", 
              RowBox[{"b", "-", "a"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"h", "-", "1"}], ")"}]}], "-", 
          RowBox[{
            SuperscriptBox["b", "2"], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"e", " ", "a"}], "-", "c"}], ")"}]}], "+", 
          SuperscriptBox["b", "2"]}], ",", 
        RowBox[{"{", 
          RowBox[{"a", ",", "b"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[237]:=  (21:52:35 on 5/16/01)",
  CellTags->"Collect2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"2", " ", 
          RowBox[{"(", 
            RowBox[{"1", "-", "h"}], ")"}], " ", 
          SuperscriptBox["a", "2"]}], "-", 
        RowBox[{
          SuperscriptBox["b", "2"], " ", "e", " ", "a"}], "-", 
        RowBox[{"2", " ", "b", " ", 
          RowBox[{"(", 
            RowBox[{"1", "-", "h"}], ")"}], " ", "a"}], "+", 
        RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
            RowBox[{"c", "+", "1"}], ")"}]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[237]=  (21:52:35 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Collect2", "[", 
      RowBox[{
        RowBox[{"Expand", "[", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"a", "-", "b", "-", "c", "-", "d"}], ")"}], "5"], "]"}],
         ",", "a", ",", 
        RowBox[{"IsolateNames", "\[Rule]", "L"}]}], "]"}]], "Input",
  CellLabel->"In[238]:=  (21:52:35 on 5/16/01)",
  CellTags->"Collect2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["a", "5"], "-", 
        RowBox[{"5", " ", 
          TagBox[
            RowBox[{"L", "(", "1", ")"}],
            HoldForm], " ", 
          SuperscriptBox["a", "4"]}], "+", 
        RowBox[{"10", " ", 
          SuperscriptBox[
            TagBox[
              RowBox[{"L", "(", "1", ")"}],
              HoldForm], "2"], " ", 
          SuperscriptBox["a", "3"]}], "-", 
        RowBox[{"10", " ", 
          SuperscriptBox[
            TagBox[
              RowBox[{"L", "(", "1", ")"}],
              HoldForm], "3"], " ", 
          SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"5", " ", 
          SuperscriptBox[
            TagBox[
              RowBox[{"L", "(", "1", ")"}],
              HoldForm], "4"], " ", "a"}], "-", 
        SuperscriptBox[
          TagBox[
            RowBox[{"L", "(", "1", ")"}],
            HoldForm], "5"]}], TraditionalForm]], "Output",
  CellLabel->"Out[238]=  (21:52:35 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ReleaseHold", "[", "%", "]"}]], "Input",
  CellLabel->"In[239]:=  (21:52:35 on 5/16/01)",
  CellTags->"Collect2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["a", "5"], "-", 
        RowBox[{"5", " ", 
          RowBox[{"(", 
            RowBox[{"b", "+", "c", "+", "d"}], ")"}], " ", 
          SuperscriptBox["a", "4"]}], "+", 
        RowBox[{"10", " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"b", "+", "c", "+", "d"}], ")"}], "2"], " ", 
          SuperscriptBox["a", "3"]}], "-", 
        RowBox[{"10", " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"b", "+", "c", "+", "d"}], ")"}], "3"], " ", 
          SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"5", " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"b", "+", "c", "+", "d"}], ")"}], "4"], " ", "a"}], "-",
         
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{"b", "+", "c", "+", "d"}], ")"}], "5"]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[239]=  (21:52:35 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{"Clear", "[", 
      RowBox[{"t1", ",", "L"}], "]"}]], "Input",
  CellLabel->"In[240]:=  (21:52:35 on 5/16/01)",
  CellTags->"Collect2"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Collect2", "[", 
      RowBox[{
        RowBox[{"Expand", "[", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"a", "-", "b", "-", "c"}], ")"}], "3"], "]"}], ",", "a",
         ",", 
        RowBox[{"Factoring", "\[Rule]", "fun"}]}], "]"}]], "Input",
  CellLabel->"In[241]:=  (21:52:35 on 5/16/01)",
  CellTags->"Collect2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"fun", "(", "1", ")"}], " ", 
          SuperscriptBox["a", "3"]}], "+", 
        RowBox[{
          RowBox[{"fun", "(", 
            RowBox[{
              RowBox[{
                RowBox[{"-", "3"}], " ", "b"}], "-", 
              RowBox[{"3", " ", "c"}]}], ")"}], " ", 
          SuperscriptBox["a", "2"]}], "+", 
        RowBox[{
          RowBox[{"fun", "(", 
            RowBox[{
              RowBox[{"3", " ", 
                SuperscriptBox["b", "2"]}], "+", 
              RowBox[{"6", " ", "c", " ", "b"}], "+", 
              RowBox[{"3", " ", 
                SuperscriptBox["c", "2"]}]}], ")"}], " ", "a"}], "+", 
        RowBox[{"fun", "(", 
          RowBox[{
            RowBox[{"-", 
              SuperscriptBox["b", "3"]}], "-", 
            RowBox[{"3", " ", "c", " ", 
              SuperscriptBox["b", "2"]}], "-", 
            RowBox[{"3", " ", 
              SuperscriptBox["c", "2"], " ", "b"}], "-", 
            SuperscriptBox["c", "3"]}], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[241]=  (21:52:35 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", " ", "/.", " ", 
      RowBox[{"fun", "->", "FactorTerms"}]}]], "Input",
  CellLabel->"In[242]:=  (21:52:36 on 5/16/01)",
  CellTags->"Collect2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{"3", " ", 
          RowBox[{"(", 
            RowBox[{"b", "+", "c"}], ")"}], " ", 
          SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"3", " ", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox["b", "2"], "+", 
              RowBox[{"2", " ", "c", " ", "b"}], "+", 
              SuperscriptBox["c", "2"]}], ")"}], " ", "a"}], "-", 
        SuperscriptBox["b", "3"], "-", 
        SuperscriptBox["c", "3"], "-", 
        RowBox[{"3", " ", "b", " ", 
          SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
          SuperscriptBox["b", "2"], " ", "c"}]}], TraditionalForm]], "Output",\

  CellLabel->"Out[242]=  (21:52:36 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Combine", "ObjectName",
  CellTags->"Combine"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"Combine"],

Cell["\<\
Combine[expr]puts terms in a sum over a common denominator,and cancels \
factors in the result. Combine is similar to Together, but accepts the option \
Expanding and works usually better than Together for polynomials involving \
rationals with sums in the denominator.\
\>", "Text",
  CellTags->"Combine"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "Combine", "]"}]], "Input",
  CellLabel->"In[243]:=  (21:52:36 on 5/16/01)",
  CellTags->"Combine"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"Expanding", "\[Rule]", "False"}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[243]=  (21:52:36 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["Factor2",
    ButtonData:>"Factor2",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Factor2"],
  "."
}], "Text",
  CellTags->"Combine"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"Combine"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Combine", "[", 
      RowBox[{
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"a", "-", "b"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"c", "-", "d"}], ")"}]}], "e"], "+", "g"}], 
      "]"}]], "Input",
  CellLabel->"In[244]:=  (21:52:36 on 5/16/01)",
  CellTags->"Combine"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"(", 
              RowBox[{"a", "-", "b"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"c", "-", "d"}], ")"}]}], "+", 
          RowBox[{"e", " ", "g"}]}], "e"], TraditionalForm]], "Output",
  CellLabel->"Out[244]=  (21:52:36 on 5/16/01)"]
}, Closed]],

Cell["\<\
Here the result from Together where the numerator is automatically \
expanded.\
\>", "Text",
  CellTags->"Combine"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Together", "[", 
      RowBox[{
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"a", "-", "b"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"c", "-", "d"}], ")"}]}], "e"], "+", "g"}], 
      "]"}]], "Input",
  CellLabel->"In[245]:=  (21:52:36 on 5/16/01)",
  CellTags->"Combine"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{
          RowBox[{"a", " ", "c"}], "-", 
          RowBox[{"b", " ", "c"}], "-", 
          RowBox[{"a", " ", "d"}], "+", 
          RowBox[{"b", " ", "d"}], "+", 
          RowBox[{"e", " ", "g"}]}], "e"], TraditionalForm]], "Output",
  CellLabel->"Out[245]=  (21:52:36 on 5/16/01)"]
}, Closed]],

Cell["\<\
If the option Expanding is set to True, the result of Combine is the same as \
Together, but uses a slightly different algorithm.\
\>", "Text",
  CellTags->"Combine"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Combine", "[", 
      RowBox[{
        RowBox[{
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{"a", "-", "b"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{"c", "-", "d"}], ")"}]}], "e"], "+", "g"}], ",", 
        RowBox[{"Expanding", "\[Rule]", "True"}]}], "]"}]], "Input",
  CellLabel->"In[246]:=  (21:52:36 on 5/16/01)",
  CellTags->"Combine"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{
          RowBox[{"a", " ", "c"}], "-", 
          RowBox[{"b", " ", "c"}], "-", 
          RowBox[{"a", " ", "d"}], "+", 
          RowBox[{"b", " ", "d"}], "+", 
          RowBox[{"e", " ", "g"}]}], "e"], TraditionalForm]], "Output",
  CellLabel->"Out[246]=  (21:52:36 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["CommutatorExplicit", "ObjectName",
  CellTags->"CommutatorExplicit"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"CommutatorExplicit"],

Cell["\<\
CommutatorExplicit[exp] substitutes any Commutator and AntiCommutator in exp \
by their definitions.\
\>", "Text",
  CellTags->"CommutatorExplicit"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["Calc",
    ButtonData:>"Calc",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Calc"],
  ", ",
  ButtonBox["DotSimplify",
    ButtonData:>"DotSimplify",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DotSimplify"],
  "."
}], "Text",
  CellTags->"CommutatorExplicit"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"CommutatorExplicit"],

Cell[BoxData[
    RowBox[{"DeclareNonCommutative", "[", 
      RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}]], "Input",
  CellLabel->"In[247]:=  (21:52:36 on 5/16/01)",
  CellTags->"CommutatorExplicit"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Commutator", "[", 
      RowBox[{"a", ",", "b"}], "]"}]], "Input",
  CellLabel->"In[248]:=  (21:52:36 on 5/16/01)",
  CellTags->"CommutatorExplicit"],

Cell[BoxData[
    FormBox[
      RowBox[{
      "[", "\[NoBreak]", "a", "\[NoBreak]", ",", "b", "\[NoBreak]", "]"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[248]=  (21:52:36 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"CommutatorExplicit", "[", "%", "]"}]], "Input",
  CellLabel->"In[249]:=  (21:52:36 on 5/16/01)",
  CellTags->"CommutatorExplicit"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"a", ".", "b"}], "-", 
        RowBox[{"b", ".", "a"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[249]=  (21:52:36 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"AntiCommutator", "[", 
      RowBox[{
        RowBox[{"a", "-", "c"}], ",", 
        RowBox[{"b", "-", "d"}]}], "]"}]], "Input",
  CellLabel->"In[250]:=  (21:52:36 on 5/16/01)",
  CellTags->"CommutatorExplicit"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", "\[NoBreak]", 
        FormBox[
          RowBox[{"a", "-", "c"}],
          "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
        "\[MediumSpace]", "\[NoBreak]", 
        FormBox[
          RowBox[{"b", "-", "d"}],
          "TraditionalForm"], "\[NoBreak]", "}"}], TraditionalForm]], "Output",\

  CellLabel->"Out[250]=  (21:52:36 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"CommutatorExplicit", "[", "%", "]"}]], "Input",
  CellLabel->"In[251]:=  (21:52:36 on 5/16/01)",
  CellTags->"CommutatorExplicit"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{"a", "-", "c"}], ")"}], ".", 
          RowBox[{"(", 
            RowBox[{"b", "-", "d"}], ")"}]}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"b", "-", "d"}], ")"}], ".", 
          RowBox[{"(", 
            RowBox[{"a", "-", "c"}], ")"}]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[251]=  (21:52:36 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"CommutatorExplicit", "[", "%%", "]"}], "//", 
      "DotSimplify"}]], "Input",
  CellLabel->"In[252]:=  (21:52:36 on 5/16/01)",
  CellTags->"CommutatorExplicit"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"a", ".", "b"}], "-", 
        RowBox[{"a", ".", "d"}], "+", 
        RowBox[{"b", ".", "a"}], "-", 
        RowBox[{"b", ".", "c"}], "-", 
        RowBox[{"c", ".", "b"}], "+", 
        RowBox[{"c", ".", "d"}], "-", 
        RowBox[{"d", ".", "a"}], "+", 
        RowBox[{"d", ".", "c"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[252]=  (21:52:36 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{"UnDeclareNonCommutative", "[", 
      RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}]], "Input",
  CellLabel->"In[253]:=  (21:52:36 on 5/16/01)",
  CellTags->"CommutatorExplicit"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Commutator", "ObjectName",
  CellTags->"Commutator"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"Commutator"],

Cell["\<\
Commutator[x, y] = c defines the commutator between the non-commuting objects \
x and y. \
\>", "Text",
  CellTags->"Commutator"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["AntiCommutator",
    ButtonData:>"AntiCommutator",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"AntiCommutator"],
  ", ",
  ButtonBox["CommutatorExplicit",
    ButtonData:>"CommutatorExplicit",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"CommutatorExplicit"],
  ", ",
  ButtonBox["DeclareNonCommutative",
    ButtonData:>"DeclareNonCommutative",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DeclareNonCommutative"],
  ", ",
  ButtonBox["DotSimplify",
    ButtonData:>"DotSimplify",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DotSimplify"],
  "."
}], "Text",
  CellTags->"Commutator"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"Commutator"],

Cell[BoxData[
    RowBox[{"DeclareNonCommutative", "[", 
      RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}]], "Input",
  CellLabel->"In[254]:=  (21:52:36 on 5/16/01)",
  CellTags->"Commutator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Commutator", "[", 
      RowBox[{"a", ",", "b"}], "]"}]], "Input",
  CellLabel->"In[255]:=  (21:52:36 on 5/16/01)",
  CellTags->"Commutator"],

Cell[BoxData[
    FormBox[
      RowBox[{
      "[", "\[NoBreak]", "a", "\[NoBreak]", ",", "b", "\[NoBreak]", "]"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[255]=  (21:52:36 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"CommutatorExplicit", "[", "%", "]"}]], "Input",
  CellLabel->"In[256]:=  (21:52:36 on 5/16/01)",
  CellTags->"Commutator"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"a", ".", "b"}], "-", 
        RowBox[{"b", ".", "a"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[256]=  (21:52:37 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"DotSimplify", "[", 
        RowBox[{"Commutator", "[", 
          RowBox[{
            RowBox[{"a", "+", "b"}], ",", 
            RowBox[{"c", "+", "d"}]}], "]"}], "]"}], " "}]], "Input",
  CellLabel->"In[257]:=  (21:52:37 on 5/16/01)",
  CellTags->"Commutator"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"a", ".", "c"}], "+", 
        RowBox[{"a", ".", "d"}], "+", 
        RowBox[{"b", ".", "c"}], "+", 
        RowBox[{"b", ".", "d"}], "-", 
        RowBox[{"c", ".", "a"}], "-", 
        RowBox[{"c", ".", "b"}], "-", 
        RowBox[{"d", ".", "a"}], "-", 
        RowBox[{"d", ".", "b"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[257]=  (21:52:37 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{"UnDeclareNonCommutative", "[", 
      RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}]], "Input",
  CellLabel->"In[258]:=  (21:52:37 on 5/16/01)",
  CellTags->"Commutator"],

Cell["Verify the Jacobi identity.", "Text",
  CellTags->"Commutator"],

Cell[BoxData[
    RowBox[{
      RowBox[{"\[Chi]", "=", "Commutator"}], ";", " ", 
      RowBox[{"DeclareNonCommutative", "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}], ";"}]], "Input",
  CellLabel->"In[259]:=  (21:52:37 on 5/16/01)",
  CellTags->"Commutator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"\[Chi]", "[", 
        RowBox[{"x", ",", 
          RowBox[{"\[Chi]", "[", 
            RowBox[{"y", ",", "z"}], "]"}]}], "]"}], "+", 
      RowBox[{"\[Chi]", "[", 
        RowBox[{"y", ",", 
          RowBox[{"\[Chi]", "[", 
            RowBox[{"z", ",", "x"}], "]"}]}], "]"}], "+", 
      RowBox[{"\[Chi]", "[", 
        RowBox[{"z", ",", 
          RowBox[{"\[Chi]", "[", 
            RowBox[{"x", ",", "y"}], "]"}]}], "]"}]}]], "Input",
  CellLabel->"In[260]:=  (21:52:37 on 5/16/01)",
  CellTags->"Commutator"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"[", "\[NoBreak]", "x", "\[NoBreak]", ",", 
          FormBox[
            RowBox[{
            "[", "\[NoBreak]", "y", "\[NoBreak]", ",", "z", "\[NoBreak]", 
              "]"}],
            "TraditionalForm"], "\[NoBreak]", "]"}], "+", 
        RowBox[{"[", "\[NoBreak]", "y", "\[NoBreak]", ",", 
          FormBox[
            RowBox[{
            "[", "\[NoBreak]", "z", "\[NoBreak]", ",", "x", "\[NoBreak]", 
              "]"}],
            "TraditionalForm"], "\[NoBreak]", "]"}], "+", 
        RowBox[{"[", "\[NoBreak]", "z", "\[NoBreak]", ",", 
          FormBox[
            RowBox[{
            "[", "\[NoBreak]", "x", "\[NoBreak]", ",", "y", "\[NoBreak]", 
              "]"}],
            "TraditionalForm"], "\[NoBreak]", "]"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[260]=  (21:52:37 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DotSimplify", "[", "%", "]"}]], "Input",
  CellLabel->"In[261]:=  (21:52:37 on 5/16/01)",
  CellTags->"Commutator"],

Cell[BoxData[
    FormBox["0", TraditionalForm]], "Output",
  CellLabel->"Out[261]=  (21:52:37 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{"Clear", "[", "\[Chi]", "]"}]], "Input",
  CellLabel->"In[262]:=  (21:52:37 on 5/16/01)",
  CellTags->"Commutator"],

Cell[BoxData[
    RowBox[{"UnDeclareNonCommutative", "[", 
      RowBox[{"x", ",", "y", ",", "z"}], "]"}]], "Input",
  CellLabel->"In[263]:=  (21:52:37 on 5/16/01)",
  CellTags->"Commutator"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["ComplexConjugate", "ObjectName",
  CellTags->"ComplexConjugate"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"ComplexConjugate"],

Cell["\<\
ComplexConjugate[expr] complex conjugates expr. It operates on fermion lines, \
i.e., products of Spinor[..] .DiracMatrix[..] . Spinor[..], and changes all \
occuring LorentzIndex[mu] into LorentzIndex[ComplexIndex[mu]]. For taking the \
spin sum (i.e. constructing the traces) use FermionSpinSum. WARNING: In expr \
should be NO explicit I's in denominators!\
\>", "Text",
  CellTags->"ComplexConjugate"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["ComplexIndex",
    ButtonData:>"ComplexIndex",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"ComplexIndex"],
  ", ",
  ButtonBox["FermionSpinSum",
    ButtonData:>"FermionSpinSum",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FermionSpinSum"],
  ", ",
  ButtonBox["LorentzIndex",
    ButtonData:>"LorentzIndex",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"LorentzIndex"],
  "."
}], "Text",
  CellTags->"ComplexConjugate"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"ComplexConjugate"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ComplexConjugate", "[", 
      RowBox[{"MetricTensor", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], "]"}]], "Input",
  CellLabel->"In[264]:=  (21:52:37 on 5/16/01)",
  CellTags->"ComplexConjugate"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["g", 
        RowBox[{
          FormBox[
            SuperscriptBox["\[Mu]", "*"],
            "TraditionalForm"], "\[NoBreak]", 
          FormBox[
            SuperscriptBox["\[Nu]", "*"],
            "TraditionalForm"]}]], TraditionalForm]], "Output",
  CellLabel->"Out[264]=  (21:52:38 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StandardForm", "[", "%", "]"}]], "Input",
  CellLabel->"In[265]:=  (21:52:38 on 5/16/01)",
  CellTags->"ComplexConjugate"],

Cell[BoxData[
    RowBox[{"Pair", "[", 
      RowBox[{
        RowBox[{"LorentzIndex", "[", 
          RowBox[{"ComplexIndex", "[", "\[Mu]", "]"}], "]"}], ",", 
        RowBox[{"LorentzIndex", "[", 
          RowBox[{"ComplexIndex", "[", "\[Nu]", "]"}], "]"}]}], 
      "]"}]], "Output",
  CellLabel->"Out[265]//StandardForm=  (21:52:38 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GA", "[", 
      RowBox[{"\[Mu]", ",", "\[Nu]", ",", "5"}], "]"}]], "Input",
  CellLabel->"In[266]:=  (21:52:38 on 5/16/01)",
  CellTags->"ComplexConjugate"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
        SuperscriptBox["\[Gamma]", "\[Nu]"], ".", 
        SuperscriptBox["\[Gamma]", "5"]}], TraditionalForm]], "Output",
  CellLabel->"Out[266]=  (21:52:38 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ComplexConjugate", "[", "%", "]"}]], "Input",
  CellLabel->"In[267]:=  (21:52:38 on 5/16/01)",
  CellTags->"ComplexConjugate"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        RowBox[{
          SuperscriptBox["\[Gamma]", "5"], ".", 
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox[
                SuperscriptBox["\[Nu]", "*"],
                "TraditionalForm"],
              "TraditionalForm"]], ".", 
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox[
                SuperscriptBox["\[Mu]", "*"],
                "TraditionalForm"],
              "TraditionalForm"]]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[267]=  (21:52:38 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNTrace", "[", 
      RowBox[{"SUNT", "[", 
        RowBox[{"a", ",", "b", ",", "c"}], "]"}], "]"}]], "Input",
  CellLabel->"In[268]:=  (21:52:38 on 5/16/01)",
  CellTags->"ComplexConjugate"],

Cell[BoxData[
    FormBox[
      RowBox[{"tr", "\[NoBreak]", "(", "\[NoBreak]", 
        FormBox[
          RowBox[{
            SubscriptBox["T", 
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SubscriptBox["T", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SubscriptBox["T", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"]]}],
          "TraditionalForm"], "\[NoBreak]", ")"}], TraditionalForm]], "Output",\

  CellLabel->"Out[268]=  (21:52:39 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ComplexConjugate", "[", "%", "]"}]], "Input",
  CellLabel->"In[269]:=  (21:52:39 on 5/16/01)",
  CellTags->"ComplexConjugate"],

Cell[BoxData[
    FormBox[
      RowBox[{"tr", "\[NoBreak]", "(", "\[NoBreak]", 
        FormBox[
          RowBox[{
            SubscriptBox["T", 
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SubscriptBox["T", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SubscriptBox["T", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"]]}],
          "TraditionalForm"], "\[NoBreak]", ")"}], TraditionalForm]], "Output",\

  CellLabel->"Out[269]=  (21:52:39 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ComplexConjugate", "[", 
      RowBox[{"SUNF", "[", 
        RowBox[{"a", ",", "b", ",", "c"}], "]"}], "]"}]], "Input",
  CellLabel->"In[270]:=  (21:52:39 on 5/16/01)",
  CellTags->"ComplexConjugate"],

Cell[BoxData[
    FormBox[
      SubscriptBox["f", 
        RowBox[{
          FormBox[
            FormBox["a",
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", 
          FormBox[
            FormBox["b",
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", 
          FormBox[
            FormBox["c",
              "TraditionalForm"],
            "TraditionalForm"]}]], TraditionalForm]], "Output",
  CellLabel->"Out[270]=  (21:52:39 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StandardForm", "[", 
      RowBox[{"FCE", "[", 
        RowBox[{"ComplexConjugate", "[", 
          RowBox[{"MetricTensor", "[", 
            RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], "]"}], "]"}], 
      "]"}]], "Input",
  CellLabel->"In[271]:=  (21:52:39 on 5/16/01)",
  CellTags->"ComplexConjugate"],

Cell[BoxData[
    RowBox[{"MT", "[", 
      RowBox[{
        RowBox[{"ComplexIndex", "[", "\[Mu]", "]"}], ",", 
        RowBox[{"ComplexIndex", "[", "\[Nu]", "]"}]}], "]"}]], "Output",
  CellLabel->"Out[271]//StandardForm=  (21:52:39 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"SpinorUBar", "[", 
        RowBox[{"k1", ",", "m"}], "]"}], ".", 
      RowBox[{"GA", "[", "\[Lambda]", "]"}], ".", 
      RowBox[{"SpinorU", "[", 
        RowBox[{"p1", ",", "m"}], "]"}]}]], "Input",
  CellLabel->"In[272]:=  (21:52:39 on 5/16/01)",
  CellTags->"ComplexConjugate"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FormBox[
            OverscriptBox["\<\"u\"\>", "_"],
            "TraditionalForm"], "\[NoBreak]", "(", "\[NoBreak]", "k1", 
          "\[NoBreak]", ",", "\[NoBreak]", "m", "\[NoBreak]", ")"}], ".", 
        SuperscriptBox["\[Gamma]", "\[Lambda]"], ".", 
        RowBox[{
        "u", "\[NoBreak]", "(", "\[NoBreak]", "p1", "\[NoBreak]", ",", 
          "\[NoBreak]", "m", "\[NoBreak]", ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[272]=  (21:52:39 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ComplexConjugate", "[", "%", "]"}]], "Input",
  CellLabel->"In[273]:=  (21:52:39 on 5/16/01)",
  CellTags->"ComplexConjugate"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[CurlyPhi]", "\[NoBreak]", "(", "\[NoBreak]", 
          FormBox["p1",
            "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", "m", 
          "\[NoBreak]", ")"}], ".", 
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox[
              SuperscriptBox["\[Lambda]", "*"],
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        RowBox[{"\[CurlyPhi]", "\[NoBreak]", "(", "\[NoBreak]", 
          FormBox["k1",
            "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", "m", 
          "\[NoBreak]", ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[273]=  (21:52:39 on 5/16/01)"]
}, Closed]],

Cell["\<\
Notice that SpinorUBar and SpinorU are only input functions. Internally they \
are converted to Spinor objects.\
\>", "Text",
  CellTags->"ComplexConjugate"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["ComplexIndex", "ObjectName",
  CellTags->"ComplexIndex"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"ComplexIndex"],

Cell["\<\
ComplexIndex is the head of a \"complex conjugate index\", which is \
understood as just another index.\
\>", "Text",
  CellTags->"ComplexIndex"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["LorentzIndex",
    ButtonData:>"LorentzIndex",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"LorentzIndex"],
  "."
}], "Text",
  CellTags->"ComplexIndex"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"ComplexIndex"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}]], "Input",
  CellLabel->"In[274]:=  (21:52:39 on 5/16/01)",
  CellTags->"ComplexIndex"],

Cell[BoxData[
    FormBox["\[Mu]", TraditionalForm]], "Output",
  CellLabel->"Out[274]=  (21:52:40 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ComplexConjugate", "[", "%", "]"}]], "Input",
  CellLabel->"In[275]:=  (21:52:40 on 5/16/01)",
  CellTags->"ComplexIndex"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["\[Mu]", "*"], TraditionalForm]], "Output",
  CellLabel->"Out[275]=  (21:52:40 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "StandardForm"}]], "Input",
  CellLabel->"In[276]:=  (21:52:40 on 5/16/01)",
  CellTags->"ComplexIndex"],

Cell[BoxData[
    RowBox[{"LorentzIndex", "[", 
      RowBox[{"ComplexIndex", "[", "\[Mu]", "]"}], "]"}]], "Output",
  CellLabel->"Out[276]//StandardForm=  (21:52:40 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FourVector", "[", 
      RowBox[{"p", ",", "\[Mu]"}], "]"}]], "Input",
  CellLabel->"In[277]:=  (21:52:40 on 5/16/01)",
  CellTags->"ComplexIndex"],

Cell[BoxData[
    FormBox[
      SubscriptBox["p", "\[Mu]"], TraditionalForm]], "Output",
  CellLabel->"Out[277]=  (21:52:40 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ComplexConjugate", "[", "%", "]"}]], "Input",
  CellLabel->"In[278]:=  (21:52:40 on 5/16/01)",
  CellTags->"ComplexIndex"],

Cell[BoxData[
    FormBox[
      SuperscriptBox[
        FormBox["p",
          "TraditionalForm"], 
        FormBox[
          FormBox[
            SuperscriptBox["\[Mu]", "*"],
            "TraditionalForm"],
          "TraditionalForm"]], TraditionalForm]], "Output",
  CellLabel->"Out[278]=  (21:52:40 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "StandardForm"}]], "Input",
  CellLabel->"In[279]:=  (21:52:40 on 5/16/01)",
  CellTags->"ComplexIndex"],

Cell[BoxData[
    RowBox[{"Pair", "[", 
      RowBox[{
        RowBox[{"LorentzIndex", "[", 
          RowBox[{"ComplexIndex", "[", "\[Mu]", "]"}], "]"}], ",", 
        RowBox[{"Momentum", "[", "p", "]"}]}], "]"}]], "Output",
  CellLabel->"Out[279]//StandardForm=  (21:52:40 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ComplexConjugate", "[", "%", "]"}]], "Input",
  CellLabel->"In[280]:=  (21:52:40 on 5/16/01)",
  CellTags->"ComplexIndex"],

Cell[BoxData[
    FormBox[
      SuperscriptBox[
        FormBox["p",
          "TraditionalForm"], 
        FormBox[
          FormBox["\[Mu]",
            "TraditionalForm"],
          "TraditionalForm"]], TraditionalForm]], "Output",
  CellLabel->"Out[280]=  (21:52:40 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Contract", "ObjectName",
  CellTags->"Contract"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"Contract"],

Cell["\<\
Contract[expr] contracts pairs of Lorentz indices of metric tensors, \
four-vectors and (depending on the optionEpsContract) of Levi-Civita tensors \
in expr. For the contraction of Dirac matrices with each other use \
DiracSimplify. Contract[exp1, exp2] contracts (exp1*exp2), where exp1 and \
exp2 may be larger products of sums of metric tensors and 4-vectors. \
\>", "Text",
  CellTags->"Contract"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "Contract", "]"}]], "Input",
  CellLabel->"In[281]:=  (21:52:40 on 5/16/01)",
  CellTags->"Contract"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"Collecting", "\[Rule]", "True"}], ",", 
          RowBox[{"EpsContract", "\[Rule]", "True"}], ",", 
          RowBox[{"Expanding", "\[Rule]", "True"}], ",", 
          RowBox[{"Factoring", "\[Rule]", "False"}], ",", 
          RowBox[{"FeynCalcInternal", "\[Rule]", "False"}], ",", 
          RowBox[{"MomentumCombine", "\[Rule]", "False"}], ",", 
          RowBox[{"Rename", "\[Rule]", "False"}], ",", 
          RowBox[{"Schouten", "\[Rule]", "0"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[281]=  (21:52:41 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["Pair",
    ButtonData:>"Pair",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Pair"],
  ", ",
  ButtonBox["DiracSimplify",
    ButtonData:>"DiracSimplify",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracSimplify"],
  ", ",
  ButtonBox["MomentumCombine",
    ButtonData:>"MomentumCombine",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"MomentumCombine"],
  "."
}], "Text",
  CellTags->"Contract"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"Contract"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"MetricTensor", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], " ", 
      RowBox[{"FourVector", "[", 
        RowBox[{"p", ",", "\[Mu]"}], "]"}]}]], "Input",
  CellLabel->"In[282]:=  (21:52:41 on 5/16/01)",
  CellTags->"Contract"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["p", "\[Mu]"], " ", 
        SuperscriptBox["g", 
          RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[282]=  (21:52:41 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Contract", "[", "%", "]"}]], "Input",
  CellLabel->"In[283]:=  (21:52:41 on 5/16/01)",
  CellTags->"Contract"],

Cell[BoxData[
    FormBox[
      SuperscriptBox[
        FormBox["p",
          "TraditionalForm"], 
        FormBox[
          FormBox["\[Nu]",
            "TraditionalForm"],
          "TraditionalForm"]], TraditionalForm]], "Output",
  CellLabel->"Out[283]=  (21:52:41 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"FourVector", "[", 
        RowBox[{"p", ",", "\[Mu]"}], "]"}], 
      RowBox[{"DiracMatrix", "[", "\[Mu]", "]"}]}]], "Input",
  CellLabel->"In[284]:=  (21:52:41 on 5/16/01)",
  CellTags->"Contract"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]], " ", 
        SubscriptBox["p", "\[Mu]"]}], TraditionalForm]], "Output",
  CellLabel->"Out[284]=  (21:52:41 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Contract", "[", "%", "]"}]], "Input",
  CellLabel->"In[285]:=  (21:52:41 on 5/16/01)",
  CellTags->"Contract"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox["\<\"\[Gamma]\"\>",
          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
        FormBox["p",
          "TraditionalForm"]}], TraditionalForm]], "Output",
  CellLabel->"Out[285]=  (21:52:41 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"MetricTensor", "[", 
      RowBox[{"\[Mu]", ",", "\[Mu]"}], "]"}]], "Input",
  CellLabel->"In[286]:=  (21:52:41 on 5/16/01)",
  CellTags->"Contract"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["g", 
        RowBox[{"\[Mu]", "\[NoBreak]", "\[Mu]"}]], TraditionalForm]], "Output",\

  CellLabel->"Out[286]=  (21:52:41 on 5/16/01)"]
}, Closed]],

Cell["The default dimension for MetricTensor is 4.", "Text",
  CellTags->"Contract"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Contract", "[", "%", "]"}]], "Input",
  CellLabel->"In[287]:=  (21:52:41 on 5/16/01)",
  CellTags->"Contract"],

Cell[BoxData[
    FormBox["4", TraditionalForm]], "Output",
  CellLabel->"Out[287]=  (21:52:41 on 5/16/01)"]
}, Closed]],

Cell["\<\
A short way to enter D-dimensional metric tensors is given by MTD. The \".\" \
as multiplication operator is not necessary but just convenient for \
typesetting.\
\>", "Text",
  CellTags->"Contract"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"MTD", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], " ", ".", " ", 
      RowBox[{"MTD", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}]}]], "Input",
  CellLabel->"In[288]:=  (21:52:42 on 5/16/01)",
  CellTags->"Contract"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["g", 
          RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]], ".", 
        SuperscriptBox["g", 
          RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[288]=  (21:52:42 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Contract", "[", "%", "]"}]], "Input",
  CellLabel->"In[289]:=  (21:52:42 on 5/16/01)",
  CellTags->"Contract"],

Cell[BoxData[
    FormBox["D", TraditionalForm]], "Output",
  CellLabel->"Out[289]=  (21:52:42 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"MTD", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], " ", ".", " ", 
      RowBox[{"MTD", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}]}]], "Input",
  CellLabel->"In[290]:=  (21:52:42 on 5/16/01)",
  CellTags->"Contract"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["g", 
          RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]], ".", 
        SuperscriptBox["g", 
          RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[290]=  (21:52:42 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"FourVector", "[", 
        RowBox[{"p", ",", "\[Mu]"}], "]"}], " ", 
      RowBox[{"FourVector", "[", 
        RowBox[{"q", ",", "\[Mu]"}], "]"}]}]], "Input",
  CellLabel->"In[291]:=  (21:52:42 on 5/16/01)",
  CellTags->"Contract"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["p", "\[Mu]"], " ", 
        SubscriptBox["q", "\[Mu]"]}], TraditionalForm]], "Output",
  CellLabel->"Out[291]=  (21:52:42 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Contract", "[", "%", " ", "]"}]], "Input",
  CellLabel->"In[292]:=  (21:52:42 on 5/16/01)",
  CellTags->"Contract"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox["p",
          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
        FormBox["q",
          "TraditionalForm"]}], TraditionalForm]], "Output",
  CellLabel->"Out[292]=  (21:52:42 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"FourVector", "[", 
        RowBox[{
          RowBox[{"p", "-", "q"}], ",", "\[Mu]"}], "]"}], " ", 
      RowBox[{"FourVector", "[", 
        RowBox[{
          RowBox[{"a", "-", "b"}], ",", "\[Mu]"}], "]"}]}]], "Input",
  CellLabel->"In[293]:=  (21:52:42 on 5/16/01)",
  CellTags->"Contract"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox[
          RowBox[{"(", "\[NoBreak]", 
            FormBox[
              TagBox[
                RowBox[{"a", "-", "b"}],
                HoldForm],
              "TraditionalForm"], "\[NoBreak]", ")"}], "\[Mu]"], " ", 
        SubscriptBox[
          RowBox[{"(", "\[NoBreak]", 
            FormBox[
              TagBox[
                RowBox[{"p", "-", "q"}],
                HoldForm],
              "TraditionalForm"], "\[NoBreak]", ")"}], "\[Mu]"]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[293]=  (21:52:42 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Contract", "[", "%", "]"}]], "Input",
  CellLabel->"In[294]:=  (21:52:42 on 5/16/01)",
  CellTags->"Contract"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FormBox["a",
            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
          FormBox["p",
            "TraditionalForm"]}], "-", 
        RowBox[{
          FormBox["a",
            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
          FormBox["q",
            "TraditionalForm"]}], "-", 
        RowBox[{
          FormBox["b",
            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
          FormBox["p",
            "TraditionalForm"]}], "+", 
        RowBox[{
          FormBox["b",
            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
          FormBox["q",
            "TraditionalForm"]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[294]=  (21:52:42 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"LeviCivita", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]", ",", "\[Sigma]"}], 
        "]"}], " ", 
      RowBox[{"FourVector", "[", 
        RowBox[{"p", ",", "\[Sigma]"}], "]"}]}]], "Input",
  CellLabel->"In[295]:=  (21:52:42 on 5/16/01)",
  CellTags->"Contract"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Epsilon]", 
          RowBox[{
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["\[Alpha]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["\[Sigma]",
                "TraditionalForm"],
              "TraditionalForm"]}]], " ", 
        SubscriptBox["p", "\[Sigma]"]}], TraditionalForm]], "Output",
  CellLabel->"Out[295]=  (21:52:42 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Contract", "[", "%", "]"}]], "Input",
  CellLabel->"In[296]:=  (21:52:42 on 5/16/01)",
  CellTags->"Contract"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["\[Epsilon]", 
        RowBox[{
          FormBox[
            FormBox["\[Alpha]",
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", 
          FormBox[
            FormBox["\[Nu]",
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", 
          FormBox["p",
            "TraditionalForm"]}]], TraditionalForm]], "Output",
  CellLabel->"Out[296]=  (21:52:43 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"LeviCivita", "[", 
          RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]", ",", "\[Beta]"}], 
          "]"}], " ", 
        RowBox[{"LeviCivita", "[", 
          RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]", ",", "\[Sigma]"}], 
          "]"}]}], " "}]], "Input",
  CellLabel->"In[297]:=  (21:52:43 on 5/16/01)",
  CellTags->"Contract"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Epsilon]", 
          RowBox[{
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["\[Alpha]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["\[Beta]",
                "TraditionalForm"],
              "TraditionalForm"]}]], " ", 
        SuperscriptBox["\[Epsilon]", 
          RowBox[{
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["\[Alpha]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["\[Sigma]",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[297]=  (21:52:43 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Contract", "[", "%", "]"}]], "Input",
  CellLabel->"In[298]:=  (21:52:43 on 5/16/01)",
  CellTags->"Contract"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", "6"}], " ", 
        SuperscriptBox["g", 
          RowBox[{"\[Beta]", "\[NoBreak]", "\[Sigma]"}]]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[298]=  (21:52:43 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"SetOptions", "[", 
        RowBox[{"Eps", ",", 
          RowBox[{"Dimension", "\[Rule]", "D"}]}], "]"}], ";", 
      RowBox[{
        RowBox[{"LCD", "[", 
          RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]", ",", "\[Beta]"}], 
          "]"}], " ", 
        RowBox[{"LCD", "[", 
          RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]", ",", "\[Sigma]"}], 
          "]"}]}]}]], "Input",
  CellLabel->"In[299]:=  (21:52:43 on 5/16/01)",
  CellTags->"Contract"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Epsilon]", 
          RowBox[{
          "\[Mu]", "\[NoBreak]", "\[Nu]", "\[NoBreak]", "\[Alpha]", 
            "\[NoBreak]", "\[Beta]"}]], " ", 
        SuperscriptBox["\[Epsilon]", 
          RowBox[{
          "\[Mu]", "\[NoBreak]", "\[Nu]", "\[NoBreak]", "\[Alpha]", 
            "\[NoBreak]", "\[Sigma]"}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[299]=  (21:52:43 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Contract", "[", "%", "]"}], "//", "Factor2"}]], "Input",
  CellLabel->"In[300]:=  (21:52:43 on 5/16/01)",
  CellTags->"Contract"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"(", 
          RowBox[{"1", "-", "D"}], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{"2", "-", "D"}], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{"3", "-", "D"}], ")"}], " ", 
        SuperscriptBox["g", 
          RowBox[{
            FormBox[
              FormBox["\[Beta]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["\[Sigma]",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[300]=  (21:52:43 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      RowBox[{"SetOptions", "[", 
        RowBox[{"Eps", ",", 
          RowBox[{"Dimension", "\[Rule]", "4"}]}], "]"}], ";"}]], "Input",
  CellLabel->"In[301]:=  (21:52:43 on 5/16/01)",
  CellTags->"Contract"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Convolute", "ObjectName",
  CellTags->"Convolute"],

Cell["Description", "Text",
  CellTags->"Convolute"],

Cell[TextData[{
  "Convolute[f, g, x] convolutes f(x) and g(x), i.e., ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubsuperscriptBox["\[Integral]", "0", "1"], 
          RowBox[{
            SubscriptBox["dx", "1"], " ", 
            RowBox[{
              SubsuperscriptBox["\[Integral]", "0", "1"], 
              RowBox[{
                SubscriptBox["dx", "2"], " ", 
                RowBox[{"\[Delta]", "(", 
                  RowBox[{"x", " ", "-", " ", 
                    RowBox[{
                      SubscriptBox["x", "1"], " ", 
                      SubscriptBox["x", "2"]}]}], ")"}], " ", 
                RowBox[{"f", "(", 
                  SubscriptBox["x", "1"], ")"}], " ", 
                RowBox[{
                  RowBox[{"g", "(", 
                    SubscriptBox["x", "2"], ")"}], " ", "."}]}]}]}]}], 
        TraditionalForm]]],
  " Convolute[f, g] is equivalent to Convolute[f, g, x]. Convolute[exp, {x1, \
x2}] assumes that exp is polynomial in x1 and x2. Convolute uses \
table-look-up and does not do any integral calculations, only linear \
algebra."
}], "Text",
  CellTags->"Convolute"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "Convolute", "]"}]], "Input",
  CellLabel->"In[302]:=  (21:52:43 on 5/16/01)",
  CellTags->"Convolute"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"Bracket", "\[Rule]", 
            RowBox[{"{", 
              TagBox["\[CurlyEpsilon]",
                TraditionalForm], "}"}]}], ",", 
          RowBox[{"FinalSubstitutions", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{"PlusDistribution", "\[Rule]", "Identity"}], "}"}]}]}], 
        "}"}], TraditionalForm]], "Output",
  CellLabel->"Out[302]=  (21:52:43 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["PlusDistribution",
    ButtonData:>"PlusDistribution",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"PlusDistribution"],
  "."
}], "Text",
  CellTags->"Convolute"],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"Convolute"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Convolute", "[", 
      RowBox[{"1", ",", "1"}], "]"}]], "Input",
  CellLabel->"In[303]:=  (21:52:43 on 5/16/01)",
  CellTags->"Convolute"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        RowBox[{"log", "(", "x", ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[303]=  (21:52:44 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Convolute", "[", 
      RowBox[{"x", ",", "x"}], "]"}]], "Input",
  CellLabel->"In[304]:=  (21:52:44 on 5/16/01)",
  CellTags->"Convolute"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", "x"}], " ", 
        RowBox[{"log", "(", "x", ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[304]=  (21:52:44 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Convolute", "[", 
      RowBox[{"1", ",", "x"}], "]"}]], "Input",
  CellLabel->"In[305]:=  (21:52:44 on 5/16/01)",
  CellTags->"Convolute"],

Cell[BoxData[
    FormBox[
      RowBox[{"1", "-", "x"}], TraditionalForm]], "Output",
  CellLabel->"Out[305]=  (21:52:44 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Convolute", "[", 
      RowBox[{"1", ",", 
        FractionBox["1", 
          RowBox[{"1", "-", "x"}]]}], "]"}]], "Input",
  CellLabel->"In[306]:=  (21:52:44 on 5/16/01)",
  CellTags->"Convolute"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"log", "(", 
          RowBox[{"1", "-", "x"}], ")"}], "-", 
        RowBox[{"log", "(", "x", ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[306]=  (21:52:44 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Convolute", "[", 
      RowBox[{"1", ",", 
        RowBox[{"PlusDistribution", "[", 
          FractionBox["1", 
            RowBox[{"1", "-", "x"}]], "]"}]}], "]"}]], "Input",
  CellLabel->"In[307]:=  (21:52:44 on 5/16/01)",
  CellTags->"Convolute"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"log", "(", 
          RowBox[{"1", "-", "x"}], ")"}], "-", 
        RowBox[{"log", "(", "x", ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[307]=  (21:52:44 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Convolute", "[", 
      RowBox[{
        FractionBox["1", 
          RowBox[{"1", "-", "x"}]], ",", "x"}], "]"}]], "Input",
  CellLabel->"In[308]:=  (21:52:44 on 5/16/01)",
  CellTags->"Convolute"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"log", "(", 
            RowBox[{"1", "-", "x"}], ")"}], " ", "x"}], "-", 
        RowBox[{
          RowBox[{"log", "(", "x", ")"}], " ", "x"}], "-", "x", "+", "1"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[308]=  (21:52:44 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Convolute", "[", 
      RowBox[{
        FractionBox["1", 
          RowBox[{"1", "-", "x"}]], ",", 
        FractionBox["1", 
          RowBox[{"1", "-", "x"}]]}], "]"}]], "Input",
  CellLabel->"In[309]:=  (21:52:44 on 5/16/01)",
  CellTags->"Convolute"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"-", 
            RowBox[{"\[Zeta]", "(", "2", ")"}]}], " ", 
          RowBox[{"\[Delta]", "(", 
            FormBox[
              RowBox[{"1", "-", "x"}],
              "TraditionalForm"], ")"}]}], "+", 
        FractionBox[
          RowBox[{"2", " ", 
            RowBox[{"log", "(", 
              RowBox[{"1", "-", "x"}], ")"}]}], 
          RowBox[{"1", "-", "x"}]], "-", 
        FractionBox[
          RowBox[{"log", "(", "x", ")"}], 
          RowBox[{"1", "-", "x"}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[309]=  (21:52:45 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Convolute", "[", 
      RowBox[{"1", ",", 
        RowBox[{"Log", "[", 
          RowBox[{"1", "-", "x"}], "]"}]}], "]"}]], "Input",
  CellLabel->"In[310]:=  (21:52:45 on 5/16/01)",
  CellTags->"Convolute"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"-", 
            RowBox[{"log", "(", 
              RowBox[{"1", "-", "x"}], ")"}]}], " ", 
          RowBox[{"log", "(", "x", ")"}]}], "-", 
        RowBox[{
          SubscriptBox["Li", "2"], "(", 
          RowBox[{"1", "-", "x"}], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[310]=  (21:52:45 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Convolute", "[", 
      RowBox[{"1", ",", 
        RowBox[{"x", " ", 
          RowBox[{"Log", "[", 
            RowBox[{"1", "-", "x"}], "]"}]}]}], "]"}]], "Input",
  CellLabel->"In[311]:=  (21:52:45 on 5/16/01)",
  CellTags->"Convolute"],

Cell[BoxData[
    FormBox[
      RowBox[{"x", "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "-", "x"}], ")"}], " ", 
          RowBox[{"log", "(", 
            RowBox[{"1", "-", "x"}], ")"}]}], "-", "1"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[311]=  (21:52:45 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Convolute", "[", 
      RowBox[{
        FractionBox["1", 
          RowBox[{"1", "-", "x"}]], ",", 
        RowBox[{"Log", "[", 
          RowBox[{"1", "-", "x"}], "]"}]}], "]"}]], "Input",
  CellLabel->"In[312]:=  (21:52:45 on 5/16/01)",
  CellTags->"Convolute"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SuperscriptBox["log", "2"], "(", 
          RowBox[{"1", "-", "x"}], ")"}], "-", 
        RowBox[{
          RowBox[{"log", "(", "x", ")"}], " ", 
          RowBox[{"log", "(", 
            RowBox[{"1", "-", "x"}], ")"}]}], "-", 
        RowBox[{"\[Zeta]", "(", "2", ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[312]=  (21:52:45 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Convolute", "[", 
      RowBox[{
        FractionBox["1", 
          RowBox[{"1", "-", "x"}]], ",", 
        RowBox[{"x", " ", 
          RowBox[{"Log", "[", 
            RowBox[{"1", "-", "x"}], "]"}]}]}], "]"}]], "Input",
  CellLabel->"In[313]:=  (21:52:45 on 5/16/01)",
  CellTags->"Convolute"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"x", " ", 
          RowBox[{
            SuperscriptBox["log", "2"], "(", 
            RowBox[{"1", "-", "x"}], ")"}]}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "-", "x"}], ")"}], " ", 
          RowBox[{"log", "(", 
            RowBox[{"1", "-", "x"}], ")"}]}], "-", 
        RowBox[{"x", " ", 
          RowBox[{"log", "(", "x", ")"}], " ", 
          RowBox[{"log", "(", 
            RowBox[{"1", "-", "x"}], ")"}]}], "+", "x", "-", 
        RowBox[{"x", " ", 
          RowBox[{"\[Zeta]", "(", "2", ")"}]}], "-", "1"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[313]=  (21:52:45 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Convolute", "[", 
      RowBox[{
        FractionBox[
          RowBox[{"Log", "[", 
            RowBox[{"1", "-", "x"}], "]"}], 
          RowBox[{"1", "-", "x"}]], ",", "x"}], "]"}]], "Input",
  CellLabel->"In[314]:=  (21:52:45 on 5/16/01)",
  CellTags->"Convolute"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox["1", "2"], " ", "x", " ", 
          RowBox[{
            SuperscriptBox["log", "2"], "(", 
            RowBox[{"1", "-", "x"}], ")"}]}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "-", "x"}], ")"}], " ", 
          RowBox[{"log", "(", 
            RowBox[{"1", "-", "x"}], ")"}]}], "-", 
        RowBox[{"x", " ", 
          RowBox[{"log", "(", "x", ")"}], " ", 
          RowBox[{"log", "(", 
            RowBox[{"1", "-", "x"}], ")"}]}], "+", 
        RowBox[{"x", " ", 
          RowBox[{"log", "(", "x", ")"}]}], "-", 
        RowBox[{"x", " ", 
          RowBox[{
            SubscriptBox["Li", "2"], "(", 
            RowBox[{"1", "-", "x"}], ")"}]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[314]=  (21:52:45 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Convolute", "[", 
      RowBox[{"1", ",", 
        RowBox[{"x", " ", 
          RowBox[{"Log", "[", "x", "]"}]}]}], "]"}]], "Input",
  CellLabel->"In[315]:=  (21:52:45 on 5/16/01)",
  CellTags->"Convolute"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"-", 
            RowBox[{"log", "(", "x", ")"}]}], " ", "x"}], "+", "x", "-", 
        "1"}], TraditionalForm]], "Output",
  CellLabel->"Out[315]=  (21:52:45 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Convolute", "[", 
      RowBox[{
        RowBox[{"Log", "[", 
          RowBox[{"1", "-", "x"}], "]"}], ",", "x"}], "]"}]], "Input",
  CellLabel->"In[316]:=  (21:52:45 on 5/16/01)",
  CellTags->"Convolute"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "-", "x"}], ")"}], " ", 
          RowBox[{"log", "(", 
            RowBox[{"1", "-", "x"}], ")"}]}], "+", 
        RowBox[{"x", " ", 
          RowBox[{"log", "(", "x", ")"}]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[316]=  (21:52:45 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Convolute", "[", 
      RowBox[{
        FractionBox["1", 
          RowBox[{"1", "-", "x"}]], ",", 
        FractionBox[
          RowBox[{"Log", "[", "x", "]"}], 
          RowBox[{"1", "-", "x"}]]}], "]"}]], "Input",
  CellLabel->"In[317]:=  (21:52:45 on 5/16/01)",
  CellTags->"Convolute"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{
            RowBox[{"log", "(", 
              RowBox[{"1", "-", "x"}], ")"}], " ", 
            RowBox[{"log", "(", "x", ")"}]}], 
          RowBox[{"1", "-", "x"}]], "-", 
        FractionBox[
          RowBox[{
            SuperscriptBox["log", "2"], "(", "x", ")"}], 
          RowBox[{"2", " ", 
            RowBox[{"(", 
              RowBox[{"1", "-", "x"}], ")"}]}]]}], TraditionalForm]], "Output",\

  CellLabel->"Out[317]=  (21:52:45 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Convolute", "[", 
      RowBox[{"1", ",", 
        RowBox[{"Log", "[", "x", "]"}]}], "]"}]], "Input",
  CellLabel->"In[318]:=  (21:52:45 on 5/16/01)",
  CellTags->"Convolute"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          FractionBox["1", "2"]}], " ", 
        RowBox[{
          SuperscriptBox["log", "2"], "(", "x", ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[318]=  (21:52:45 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Convolute", "[", 
      RowBox[{"x", ",", " ", 
        RowBox[{"x", " ", 
          RowBox[{"Log", "[", "x", "]"}]}]}], "]"}]], "Input",
  CellLabel->"In[319]:=  (21:52:45 on 5/16/01)",
  CellTags->"Convolute"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          FractionBox["1", "2"]}], " ", "x", " ", 
        RowBox[{
          SuperscriptBox["log", "2"], "(", "x", ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[319]=  (21:52:45 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Convolute", "[", 
      RowBox[{
        FractionBox["1", 
          RowBox[{"1", "-", "x"}]], ",", 
        RowBox[{"Log", "[", "x", "]"}]}], "]"}]], "Input",
  CellLabel->"In[320]:=  (21:52:45 on 5/16/01)",
  CellTags->"Convolute"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"-", 
            FractionBox["1", "2"]}], " ", 
          RowBox[{
            SuperscriptBox["log", "2"], "(", "x", ")"}]}], "+", 
        RowBox[{
          RowBox[{"log", "(", 
            RowBox[{"1", "-", "x"}], ")"}], " ", 
          RowBox[{"log", "(", "x", ")"}]}], "+", 
        RowBox[{
          SubscriptBox["Li", "2"], "(", 
          RowBox[{"1", "-", "x"}], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[320]=  (21:52:45 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Convolute", "[", 
      RowBox[{"1", ",", 
        FractionBox[
          RowBox[{"Log", "[", "x", "]"}], 
          RowBox[{"1", "-", "x"}]]}], "]"}]], "Input",
  CellLabel->"In[321]:=  (21:52:45 on 5/16/01)",
  CellTags->"Convolute"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"-", 
            FractionBox["1", "2"]}], " ", 
          RowBox[{
            SuperscriptBox["log", "2"], "(", "x", ")"}]}], "-", 
        RowBox[{
          SubscriptBox["Li", "2"], "(", 
          RowBox[{"1", "-", "x"}], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[321]=  (21:52:45 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Convolute", "[", 
      RowBox[{
        FractionBox["1", 
          RowBox[{"1", "-", "x"}]], ",", 
        RowBox[{"x", " ", 
          RowBox[{"Log", "[", "x", "]"}]}]}], "]"}]], "Input",
  CellLabel->"In[322]:=  (21:52:46 on 5/16/01)",
  CellTags->"Convolute"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"-", 
            FractionBox["1", "2"]}], " ", "x", " ", 
          RowBox[{
            SuperscriptBox["log", "2"], "(", "x", ")"}]}], "-", 
        RowBox[{"x", " ", 
          RowBox[{"log", "(", "x", ")"}]}], "+", 
        RowBox[{"x", " ", 
          RowBox[{"log", "(", 
            RowBox[{"1", "-", "x"}], ")"}], " ", 
          RowBox[{"log", "(", "x", ")"}]}], "+", "x", "+", 
        RowBox[{"x", " ", 
          RowBox[{
            SubscriptBox["Li", "2"], "(", 
            RowBox[{"1", "-", "x"}], ")"}]}], "-", "1"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[322]=  (21:52:46 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Convolute", "[", 
      RowBox[{
        FractionBox[
          RowBox[{"Log", "[", "x", "]"}], 
          RowBox[{"1", "-", "x"}]], ",", "x"}], "]"}]], "Input",
  CellLabel->"In[323]:=  (21:52:46 on 5/16/01)",
  CellTags->"Convolute"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"-", 
            FractionBox["1", "2"]}], " ", "x", " ", 
          RowBox[{
            SuperscriptBox["log", "2"], "(", "x", ")"}]}], "+", 
        RowBox[{"log", "(", "x", ")"}], "-", "x", "-", 
        RowBox[{"x", " ", 
          RowBox[{
            SubscriptBox["Li", "2"], "(", 
            RowBox[{"1", "-", "x"}], ")"}]}], "+", "1"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[323]=  (21:52:46 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Convolute", "[", 
      RowBox[{"1", ",", 
        RowBox[{"x", " ", 
          RowBox[{"Log", "[", "x", "]"}]}]}], "]"}]], "Input",
  CellLabel->"In[324]:=  (21:52:46 on 5/16/01)",
  CellTags->"Convolute"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"-", 
            RowBox[{"log", "(", "x", ")"}]}], " ", "x"}], "+", "x", "-", 
        "1"}], TraditionalForm]], "Output",
  CellLabel->"Out[324]=  (21:52:46 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Convolute", "[", 
      RowBox[{
        RowBox[{"Log", "[", "x", "]"}], ",", "x"}], "]"}]], "Input",
  CellLabel->"In[325]:=  (21:52:46 on 5/16/01)",
  CellTags->"Convolute"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", "x"}], "+", 
        RowBox[{"log", "(", "x", ")"}], "+", "1"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[325]=  (21:52:46 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Convolute", "[", 
      RowBox[{
        FractionBox["1", 
          RowBox[{"1", "-", "x"}]], ",", 
        FractionBox[
          RowBox[{"Log", "[", 
            RowBox[{"1", "-", "x"}], "]"}], 
          RowBox[{"1", "-", "x"}]]}], "]"}]], "Input",
  CellLabel->"In[326]:=  (21:52:46 on 5/16/01)",
  CellTags->"Convolute"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{"3", " ", 
            RowBox[{
              SuperscriptBox["log", "2"], "(", 
              RowBox[{"1", "-", "x"}], ")"}]}], 
          RowBox[{"2", " ", 
            RowBox[{"(", 
              RowBox[{"1", "-", "x"}], ")"}]}]], "-", 
        FractionBox[
          RowBox[{
            RowBox[{"log", "(", "x", ")"}], " ", 
            RowBox[{"log", "(", 
              RowBox[{"1", "-", "x"}], ")"}]}], 
          RowBox[{"1", "-", "x"}]], "-", 
        FractionBox[
          RowBox[{"\[Zeta]", "(", "2", ")"}], 
          RowBox[{"1", "-", "x"}]], "+", 
        RowBox[{
          RowBox[{"\[Delta]", "(", 
            FormBox[
              RowBox[{"1", "-", "x"}],
              "TraditionalForm"], ")"}], " ", 
          TagBox[
            RowBox[{"\[Zeta]", "(", 
              TagBox["3",
                (Editable -> True)], ")"}],
            InterpretTemplate[ Zeta[ #]&]]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[326]=  (21:52:46 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["CovariantD", "ObjectName",
  CellTags->"CovariantD"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"CovariantD"],

Cell["\<\
CovariantD[mu, a, b] is the covariant derivative for a bosonic field. \
CovariantD[mu] is the covariant derivative for a fermionic field. \
CovariantD[OPEDelta, a, b] is a short form for \
CovariantD[mu,a,b]*FourVector[OPEDelta, mu]. CovariantD[{OPEDelta, a, b}, \
{n}] yields the product of m operators., where n is an integer. \
CovariantD[OPEDelta, a, b, {m, n}] gives the expanded form of \
CovariantD[OPEDelta, a, b]^m up to order g^n for the gluon, where n is an \
integer and g the couplingconstant indicated by the setting of the option \
CouplingConstant. CovariantD[OPEDelta, {m, n}] gives the expanded form of \
CovariantD[OPEDelta]^m up to order g^n of the fermionic field.\
\>", "Text",
  CellTags->"CovariantD"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "CovariantD", "]"}]], "Input",
  CellLabel->"In[327]:=  (21:52:46 on 5/16/01)",
  CellTags->"CovariantD"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"CouplingConstant", "\[Rule]", 
            SubscriptBox["g", "s"]}], ",", 
          RowBox[{"DummyIndex", "\[Rule]", "Automatic"}], ",", 
          RowBox[{"Explicit", "\[Rule]", "False"}], ",", 
          RowBox[{"PartialD", "\[Rule]", "RightPartialD"}], ",", 
          RowBox[{"QuantumField", "\[Rule]", "A"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[327]=  (21:52:46 on 5/16/01)"]
}, Closed]],

Cell["\<\
 Possible settings of PartialD are: LeftPartialD, LeftRigthPartialD, \
RightPartialD. The default setting of QuantumField is GaugeField.\
\>", "Text",
  CellTags->"CovariantD"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["LeftPartialD",
    ButtonData:>"LeftPartialD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"LeftPartialD"],
  ", ",
  ButtonBox["LeftRightPartialD",
    ButtonData:>"LeftRightPartialD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"LeftRightPartialD"],
  ", ",
  ButtonBox["RightPartialD",
    ButtonData:>"RightPartialD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"RightPartialD"],
  "."
}], "Text",
  CellTags->"CovariantD"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"CovariantD"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"CovariantD", "[", "\[Mu]", "]"}]], "Input",
  CellLabel->"In[328]:=  (21:52:46 on 5/16/01)",
  CellTags->"CovariantD"],

Cell[BoxData[
    FormBox[
      SubscriptBox["D", "\[Mu]"], TraditionalForm]], "Output",
  CellLabel->"Out[328]=  (21:52:46 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"CovariantD", "[", 
      RowBox[{"\[Mu]", ",", "a", ",", "b"}], "]"}]], "Input",
  CellLabel->"In[329]:=  (21:52:46 on 5/16/01)",
  CellTags->"CovariantD"],

Cell[BoxData[
    FormBox[
      SubsuperscriptBox["D", "\[Mu]", 
        RowBox[{"a", "\[NoBreak]", "b"}]], TraditionalForm]], "Output",
  CellLabel->"Out[329]=  (21:52:46 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"CovariantD", "[", 
      RowBox[{"\[Mu]", ",", 
        RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]], "Input",
  CellLabel->"In[330]:=  (21:52:46 on 5/16/01)",
  CellTags->"CovariantD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox[
          OverscriptBox["\[PartialD]", "\[RightArrow]"], 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]], "-", 
        RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["g", "s"], " ", 
          RowBox[{
            SubscriptBox["T", 
              FormBox[
                FormBox[
                  InterpretationBox[
                    SubscriptBox["c", "1"],
                    Subscripted[ 
                      c[ 1]],
                    Editable->False],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SubsuperscriptBox[
              FormBox["A",
                "TraditionalForm"], 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox[
                  InterpretationBox[
                    SubscriptBox["c", "1"],
                    Subscripted[ 
                      c[ 1]],
                    Editable->False],
                  "TraditionalForm"],
                "TraditionalForm"]]}]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[330]=  (21:52:46 on 5/16/01)"]
}, Closed]],

Cell["\<\
The first argument of CovariantD is intepreted as type LorentzIndex, except \
for OPEDelta, which is type Momentum.\
\>", "Text",
  CellTags->"CovariantD"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"CovariantD", "[", "OPEDelta", "]"}]], "Input",
  CellLabel->"In[331]:=  (21:52:46 on 5/16/01)",
  CellTags->"CovariantD"],

Cell[BoxData[
    FormBox[
      SubscriptBox["D", 
        FormBox["\[CapitalDelta]",
          "TraditionalForm"]], TraditionalForm]], "Output",
  CellLabel->"Out[331]=  (21:52:46 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"CovariantD", "[", 
      RowBox[{"OPEDelta", ",", "a", ",", "b"}], "]"}]], "Input",
  CellLabel->"In[332]:=  (21:52:46 on 5/16/01)",
  CellTags->"CovariantD"],

Cell[BoxData[
    FormBox[
      SubsuperscriptBox["D", 
        FormBox["\[CapitalDelta]",
          "TraditionalForm"], 
        RowBox[{"a", "\[NoBreak]", "b"}]], TraditionalForm]], "Output",
  CellLabel->"Out[332]=  (21:52:46 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"CovariantD", "[", 
      RowBox[{"OPEDelta", ",", "a", ",", "b", ",", 
        RowBox[{"Explicit", "->", "True"}]}], "]"}]], "Input",
  CellLabel->"In[333]:=  (21:52:46 on 5/16/01)",
  CellTags->"CovariantD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox[
            OverscriptBox["\[PartialD]", "\[RightArrow]"], 
            FormBox["\[CapitalDelta]",
              "TraditionalForm"]], " ", 
          SubscriptBox["\[Delta]", 
            RowBox[{"a", "\[NoBreak]", "b"}]]}], "-", 
        RowBox[{
          SubscriptBox["g", "s"], " ", 
          SubsuperscriptBox[
            FormBox["A",
              "TraditionalForm"], 
            FormBox["\[CapitalDelta]",
              "TraditionalForm"], 
            FormBox[
              FormBox[
                InterpretationBox[
                  SubscriptBox["c", "2"],
                  Subscripted[ 
                    c[ 2]],
                  Editable->False],
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubscriptBox["f", 
            RowBox[{"a", "\[NoBreak]", "b", "\[NoBreak]", 
              FormBox[
                InterpretationBox[
                  SubscriptBox["c", "2"],
                  Subscripted[ 
                    c[ 2]],
                  Editable->False],
                "TraditionalForm"]}]]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[333]=  (21:52:46 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"CovariantD", "[", 
      RowBox[{"OPEDelta", ",", 
        RowBox[{"Explicit", "->", "True"}]}], "]"}]], "Input",
  CellLabel->"In[334]:=  (21:52:46 on 5/16/01)",
  CellTags->"CovariantD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox[
          OverscriptBox["\[PartialD]", "\[RightArrow]"], 
          FormBox["\[CapitalDelta]",
            "TraditionalForm"]], "-", 
        RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["g", "s"], " ", 
          RowBox[{
            SubscriptBox["T", 
              FormBox[
                FormBox[
                  InterpretationBox[
                    SubscriptBox["c", "3"],
                    Subscripted[ 
                      c[ 3]],
                    Editable->False],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SubsuperscriptBox[
              FormBox["A",
                "TraditionalForm"], 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"], 
              FormBox[
                FormBox[
                  InterpretationBox[
                    SubscriptBox["c", "3"],
                    Subscripted[ 
                      c[ 3]],
                    Editable->False],
                  "TraditionalForm"],
                "TraditionalForm"]]}]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[334]=  (21:52:46 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"CovariantD", "[", 
      RowBox[{"OPEDelta", ",", "a", ",", "b", ",", 
        RowBox[{"{", "2", "}"}]}], "]"}]], "Input",
  CellLabel->"In[335]:=  (21:52:46 on 5/16/01)",
  CellTags->"CovariantD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SubscriptBox[
                OverscriptBox["\[PartialD]", "\[RightArrow]"], 
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"]], " ", 
              SubscriptBox["\[Delta]", 
                RowBox[{"a", "\[NoBreak]", "c8"}]]}], "-", 
            RowBox[{
              SubscriptBox["g", "s"], " ", 
              SubsuperscriptBox[
                FormBox["A",
                  "TraditionalForm"], 
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["e1",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SubscriptBox["f", 
                RowBox[{"a", "\[NoBreak]", "c8", "\[NoBreak]", "e1"}]]}]}], 
          ")"}], ".", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SubscriptBox[
                OverscriptBox["\[PartialD]", "\[RightArrow]"], 
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"]], " ", 
              SubscriptBox["\[Delta]", 
                RowBox[{"b", "\[NoBreak]", "c8"}]]}], "-", 
            RowBox[{
              SubscriptBox["g", "s"], " ", 
              SubsuperscriptBox[
                FormBox["A",
                  "TraditionalForm"], 
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["e2",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SubscriptBox["f", 
                RowBox[{"c8", "\[NoBreak]", "b", "\[NoBreak]", "e2"}]]}]}], 
          ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[335]=  (21:52:46 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "This gives",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{"m", " ", "times", " ", 
            SubscriptBox[
              OverscriptBox["\[PartialD]", "\[RightArrow]"], 
              "\[CapitalDelta]"]}], ",", " "}], TraditionalForm]]],
  "the partial derivative ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          OverscriptBox["\[PartialD]", "\[RightArrow]"], 
          RowBox[{"\[Mu]", " "}]], TraditionalForm]]],
  "contracted with ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox["\[CapitalDelta]", "\[Mu]"], "."}], 
        TraditionalForm]]]
}], "Text",
  CellTags->"CovariantD"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"CovariantD", "[", 
      RowBox[{"OPEDelta", ",", "a", ",", "b", ",", 
        RowBox[{"{", 
          RowBox[{"OPEm", ",", "0"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[336]:=  (21:52:46 on 5/16/01)",
  CellTags->"CovariantD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox[
          RowBox[{"(", 
            SubscriptBox[
              OverscriptBox["\[PartialD]", "\[RightArrow]"], 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"]], ")"}], "m"], " ", 
        SubscriptBox["\[Delta]", 
          RowBox[{
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[336]=  (21:52:46 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "The expansion up to first order in the coupling constant ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox["g", "s"], " ", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"the", "sum", "is", "the", "FeynCalc", "OPESum"}], 
              ")"}], "."}]}], TraditionalForm]]]
}], "Text",
  CellTags->"CovariantD"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"CovariantD", "[", 
      RowBox[{"OPEDelta", ",", "a", ",", "b", ",", 
        RowBox[{"{", 
          RowBox[{"OPEm", ",", "1"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[337]:=  (21:52:46 on 5/16/01)",
  CellTags->"CovariantD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              SubscriptBox[
                OverscriptBox["\[PartialD]", "\[RightArrow]"], 
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"]], ")"}], "m"], " ", 
          SubscriptBox["\[Delta]", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "-", 
        RowBox[{
          SubscriptBox["g", "s"], " ", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", 
                  RowBox[{"i", "=", "0"}], 
                  RowBox[{"m", "-", "1"}]], 
                RowBox[{
                  RowBox[{
                    SuperscriptBox[
                      RowBox[{"(", 
                        SubscriptBox[
                          OverscriptBox["\[PartialD]", "\[RightArrow]"], 
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"]], ")"}], "i"], ".", 
                    SubsuperscriptBox[
                      FormBox["A",
                        "TraditionalForm"], 
                      FormBox["\[CapitalDelta]",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox[
                          InterpretationBox[
                            SubscriptBox["c", "1"],
                            Subscripted[ 
                              c[ 1]],
                            Editable->False],
                          "TraditionalForm"],
                        "TraditionalForm"]], ".", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        SubscriptBox[
                          OverscriptBox["\[PartialD]", "\[RightArrow]"], 
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"]], ")"}], 
                      RowBox[{
                        RowBox[{"-", "i"}], "+", "m", "-", "1"}]]}], " ", 
                  SubscriptBox["f", 
                    RowBox[{
                      FormBox[
                        FormBox["a",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["b",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox[
                          InterpretationBox[
                            SubscriptBox["c", "1"],
                            Subscripted[ 
                              c[ 1]],
                            Editable->False],
                          "TraditionalForm"],
                        "TraditionalForm"]}]]}]}],
              HoldForm],
            "TraditionalForm"]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[337]=  (21:52:47 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "The expansion up to second order in the ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox["g", "s"], "."}], TraditionalForm]]]
}], "Text",
  CellTags->"CovariantD"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"CovariantD", "[", 
      RowBox[{"OPEDelta", ",", "a", ",", "b", ",", 
        RowBox[{"{", 
          RowBox[{"OPEm", ",", "2"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[338]:=  (21:52:47 on 5/16/01)",
  CellTags->"CovariantD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["\[Delta]", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]}]], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              SubscriptBox[
                OverscriptBox["\[PartialD]", "\[RightArrow]"], 
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"]], ")"}], "m"]}], "-", 
        RowBox[{
          SubsuperscriptBox["g", "s", "2"], " ", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", 
                  RowBox[{"j", "=", "0"}], 
                  RowBox[{"m", "-", "2"}]], 
                FormBox[
                  TagBox[
                    RowBox[{
                      UnderoverscriptBox["\[Sum]", 
                        RowBox[{"i", "=", "0"}], "j"], 
                      RowBox[{
                        RowBox[{
                          SuperscriptBox[
                            RowBox[{"(", 
                              SubscriptBox[
                                OverscriptBox["\[PartialD]", "\[RightArrow]"],
                                 
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"]], ")"}], "i"], ".", 
                          SubsuperscriptBox[
                            FormBox["A",
                              "TraditionalForm"], 
                            FormBox["\[CapitalDelta]",
                              "TraditionalForm"], 
                            FormBox[
                              FormBox[
                                InterpretationBox[
                                  SubscriptBox["c", "1"],
                                  Subscripted[ 
                                    c[ 1]],
                                  Editable->False],
                                "TraditionalForm"],
                              "TraditionalForm"]], ".", 
                          SuperscriptBox[
                            RowBox[{"(", 
                              SubscriptBox[
                                OverscriptBox["\[PartialD]", "\[RightArrow]"],
                                 
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"]], ")"}], 
                            RowBox[{"j", "-", "i"}]], ".", 
                          SubsuperscriptBox[
                            FormBox["A",
                              "TraditionalForm"], 
                            FormBox["\[CapitalDelta]",
                              "TraditionalForm"], 
                            FormBox[
                              FormBox[
                                InterpretationBox[
                                  SubscriptBox["c", "2"],
                                  Subscripted[ 
                                    c[ 2]],
                                  Editable->False],
                                "TraditionalForm"],
                              "TraditionalForm"]], ".", 
                          SuperscriptBox[
                            RowBox[{"(", 
                              SubscriptBox[
                                OverscriptBox["\[PartialD]", "\[RightArrow]"],
                                 
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"]], ")"}], 
                            RowBox[{
                              RowBox[{"-", "j"}], "+", "m", "-", "2"}]]}], 
                        " ", 
                        SubscriptBox["f", 
                          RowBox[{
                            FormBox[
                              FormBox["a",
                                "TraditionalForm"],
                              "TraditionalForm"], "\[NoBreak]", 
                            FormBox[
                              FormBox[
                                InterpretationBox[
                                  SubscriptBox["c", "1"],
                                  Subscripted[ 
                                    c[ 1]],
                                  Editable->False],
                                "TraditionalForm"],
                              "TraditionalForm"], "\[NoBreak]", 
                            FormBox[
                              FormBox[
                                InterpretationBox[
                                  SubscriptBox["e", "1"],
                                  Subscripted[ 
                                    e[ 1]],
                                  Editable->False],
                                "TraditionalForm"],
                              "TraditionalForm"]}]], " ", 
                        SubscriptBox["f", 
                          RowBox[{
                            FormBox[
                              FormBox["b",
                                "TraditionalForm"],
                              "TraditionalForm"], "\[NoBreak]", 
                            FormBox[
                              FormBox[
                                InterpretationBox[
                                  SubscriptBox["c", "2"],
                                  Subscripted[ 
                                    c[ 2]],
                                  Editable->False],
                                "TraditionalForm"],
                              "TraditionalForm"], "\[NoBreak]", 
                            FormBox[
                              FormBox[
                                InterpretationBox[
                                  SubscriptBox["e", "1"],
                                  Subscripted[ 
                                    e[ 1]],
                                  Editable->False],
                                "TraditionalForm"],
                              "TraditionalForm"]}]]}]}],
                    HoldForm],
                  "TraditionalForm"]}],
              HoldForm],
            "TraditionalForm"]}], "-", 
        RowBox[{
          SubscriptBox["g", "s"], " ", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", 
                  RowBox[{"i", "=", "0"}], 
                  RowBox[{"m", "-", "1"}]], 
                RowBox[{
                  RowBox[{
                    SuperscriptBox[
                      RowBox[{"(", 
                        SubscriptBox[
                          OverscriptBox["\[PartialD]", "\[RightArrow]"], 
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"]], ")"}], "i"], ".", 
                    SubsuperscriptBox[
                      FormBox["A",
                        "TraditionalForm"], 
                      FormBox["\[CapitalDelta]",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox[
                          InterpretationBox[
                            SubscriptBox["c", "1"],
                            Subscripted[ 
                              c[ 1]],
                            Editable->False],
                          "TraditionalForm"],
                        "TraditionalForm"]], ".", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        SubscriptBox[
                          OverscriptBox["\[PartialD]", "\[RightArrow]"], 
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"]], ")"}], 
                      RowBox[{
                        RowBox[{"-", "i"}], "+", "m", "-", "1"}]]}], " ", 
                  SubscriptBox["f", 
                    RowBox[{
                      FormBox[
                        FormBox["a",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["b",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox[
                          InterpretationBox[
                            SubscriptBox["c", "1"],
                            Subscripted[ 
                              c[ 1]],
                            Editable->False],
                          "TraditionalForm"],
                        "TraditionalForm"]}]]}]}],
              HoldForm],
            "TraditionalForm"]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[338]=  (21:52:47 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    SuperscriptBox[
      RowBox[{"CovariantD", "[", 
        RowBox[{"OPEDelta", ",", "a", ",", "b"}], "]"}], "OPEm"]], "Input",
  CellLabel->"In[339]:=  (21:52:47 on 5/16/01)",
  CellTags->"CovariantD"],

Cell[BoxData[
    FormBox[
      SuperscriptBox[
        RowBox[{"(", 
          SubsuperscriptBox["D", 
            FormBox["\[CapitalDelta]",
              "TraditionalForm"], 
            RowBox[{"a", "\[NoBreak]", "b"}]], ")"}], "m"], 
      TraditionalForm]], "Output",
  CellLabel->"Out[339]=  (21:52:47 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"CovariantD", "[", 
      RowBox[{"OPEDelta", ",", 
        RowBox[{"{", 
          RowBox[{"OPEm", ",", "2"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[340]:=  (21:52:47 on 5/16/01)",
  CellTags->"CovariantD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox[
          RowBox[{"(", 
            SubscriptBox[
              OverscriptBox["\[PartialD]", "\[RightArrow]"], 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"]], ")"}], "m"], "-", 
        RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["g", "s"], " ", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", 
                  RowBox[{"i", "=", "0"}], 
                  RowBox[{"m", "-", "1"}]], 
                RowBox[{
                  SubscriptBox["T", 
                    FormBox[
                      FormBox[
                        InterpretationBox[
                          SubscriptBox["c", "1"],
                          Subscripted[ 
                            c[ 1]],
                          Editable->False],
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      SubscriptBox[
                        OverscriptBox["\[PartialD]", "\[RightArrow]"], 
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"]], ")"}], "i"], ".", 
                  SubsuperscriptBox[
                    FormBox["A",
                      "TraditionalForm"], 
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox[
                        InterpretationBox[
                          SubscriptBox["c", "1"],
                          Subscripted[ 
                            c[ 1]],
                          Editable->False],
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      SubscriptBox[
                        OverscriptBox["\[PartialD]", "\[RightArrow]"], 
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"]], ")"}], 
                    RowBox[{
                      RowBox[{"-", "i"}], "+", "m", "-", "1"}]]}]}],
              HoldForm],
            "TraditionalForm"]}], "-", 
        RowBox[{
          SubsuperscriptBox["g", "s", "2"], " ", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", 
                  RowBox[{"j", "=", "0"}], 
                  RowBox[{"m", "-", "2"}]], 
                FormBox[
                  TagBox[
                    RowBox[{
                      UnderoverscriptBox["\[Sum]", 
                        RowBox[{"i", "=", "0"}], "j"], 
                      RowBox[{
                        SubscriptBox["T", 
                          FormBox[
                            FormBox[
                              InterpretationBox[
                                SubscriptBox["c", "1"],
                                Subscripted[ 
                                  c[ 1]],
                                Editable->False],
                              "TraditionalForm"],
                            "TraditionalForm"]], ".", 
                        SubscriptBox["T", 
                          FormBox[
                            FormBox[
                              InterpretationBox[
                                SubscriptBox["c", "2"],
                                Subscripted[ 
                                  c[ 2]],
                                Editable->False],
                              "TraditionalForm"],
                            "TraditionalForm"]], ".", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            SubscriptBox[
                              OverscriptBox["\[PartialD]", "\[RightArrow]"], 
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"]], ")"}], "i"], ".", 
                        SubsuperscriptBox[
                          FormBox["A",
                            "TraditionalForm"], 
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], 
                          FormBox[
                            FormBox[
                              InterpretationBox[
                                SubscriptBox["c", "1"],
                                Subscripted[ 
                                  c[ 1]],
                                Editable->False],
                              "TraditionalForm"],
                            "TraditionalForm"]], ".", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            SubscriptBox[
                              OverscriptBox["\[PartialD]", "\[RightArrow]"], 
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"]], ")"}], 
                          RowBox[{"j", "-", "i"}]], ".", 
                        SubsuperscriptBox[
                          FormBox["A",
                            "TraditionalForm"], 
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], 
                          FormBox[
                            FormBox[
                              InterpretationBox[
                                SubscriptBox["c", "2"],
                                Subscripted[ 
                                  c[ 2]],
                                Editable->False],
                              "TraditionalForm"],
                            "TraditionalForm"]], ".", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            SubscriptBox[
                              OverscriptBox["\[PartialD]", "\[RightArrow]"], 
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"]], ")"}], 
                          RowBox[{
                            RowBox[{"-", "j"}], "+", "m", "-", "2"}]]}]}],
                    HoldForm],
                  "TraditionalForm"]}],
              HoldForm],
            "TraditionalForm"]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[340]=  (21:52:47 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"CovariantD", "[", 
        RowBox[{"OPEDelta", ",", 
          RowBox[{"Explicit", "->", "True"}]}], "]"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[341]:=  (21:52:47 on 5/16/01)",
  CellTags->"CovariantD"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", "Gstrong", " ", 
        RowBox[{
          RowBox[{"SUNT", "[", 
            RowBox[{"SUNIndex", "[", 
              InterpretationBox[
                SubscriptBox["c", "4"],
                Subscripted[ 
                  c[ 4]],
                Editable->False], "]"}], "]"}], ".", 
          RowBox[{"QuantumField", "[", 
            RowBox[{"GaugeField", ",", 
              RowBox[{"Momentum", "[", "OPEDelta", "]"}], ",", 
              RowBox[{"SUNIndex", "[", 
                InterpretationBox[
                  SubscriptBox["c", "4"],
                  Subscripted[ 
                    c[ 4]],
                  Editable->False], "]"}]}], "]"}]}]}], "+", 
      RowBox[{"RightPartialD", "[", 
        RowBox[{"Momentum", "[", "OPEDelta", "]"}], "]"}]}]], "Output",
  CellLabel->"Out[341]//StandardForm=  (21:52:47 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"CovariantD", "[", 
        RowBox[{"\[Mu]", ",", "a", ",", "b", ",", 
          RowBox[{"Explicit", "->", "True"}]}], "]"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[342]:=  (21:52:48 on 5/16/01)",
  CellTags->"CovariantD"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"RightPartialD", "[", 
          RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], "]"}], " ", 
        RowBox[{"SUNDelta", "[", 
          RowBox[{"a", ",", "b"}], "]"}]}], "-", 
      RowBox[{"Gstrong", " ", 
        RowBox[{"QuantumField", "[", 
          RowBox[{"GaugeField", ",", 
            RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
            RowBox[{"SUNIndex", "[", 
              InterpretationBox[
                SubscriptBox["c", "5"],
                Subscripted[ 
                  c[ 5]],
                Editable->False], "]"}]}], "]"}], " ", 
        RowBox[{"SUNF", "[", 
          RowBox[{"a", ",", "b", ",", 
            InterpretationBox[
              SubscriptBox["c", "5"],
              Subscripted[ 
                c[ 5]],
              Editable->False]}], "]"}]}]}]], "Output",
  CellLabel->"Out[342]//StandardForm=  (21:52:48 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["D0", "ObjectName",
  CellTags->"D0"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"D0"],

Cell[TextData[{
  "D0[ p10, p12, p23, p30, p20, p13, m1^2, m2^2, m3^2, m4^2 ] is the \
Passarino-Veltman ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["D", "0"], TraditionalForm]]],
  " function. The convention for the arguments is that if the denominator of \
the integrand has the form ([q^2-m1^2] [(q+p1)^2-m2^2] [(q+p2)^2-m3^2] \
[(q+p3)^2-m4^2] ), the first six arguments of D0 are the scalar products p10 \
= p1^2, p12 = (p1-p2)^2, p23 = (p2-p3)^2, p30 = p3^2, p20 = p2^2, p13 = \
(p1-p3)^2."
}], "Text",
  CellTags->"D0"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["B0",
    ButtonData:>"B0",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"B0"],
  ", ",
  ButtonBox["C0",
    ButtonData:>"C0",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"C0"],
  ", ",
  ButtonBox["PaVe",
    ButtonData:>"PaVe",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"PaVe"],
  ", ",
  ButtonBox["PaVeOrder",
    ButtonData:>"PaVeOrder",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"PaVeOrder"],
  "."
}], "Text",
  CellTags->"D0"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"D0"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"D0", "[", 
      RowBox[{
      "p10", ",", "p12", ",", "p23", ",", "p30", ",", "p20", ",", "p13", ",", 
        
        RowBox[{"m1", "^", "2"}], ",", 
        RowBox[{"m2", "^", "2"}], ",", 
        RowBox[{"m3", "^", "2"}], ",", 
        RowBox[{"m4", "^", "2"}]}], "]"}]], "Input",
  CellLabel->"In[343]:=  (21:52:48 on 5/16/01)",
  CellTags->"D0"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          SubscriptBox["\<\"D\"\>", "\<\"0\"\>"],
          "TraditionalForm"], "\[NoBreak]", "(", "\[NoBreak]", 
        FormBox[
          SubscriptBox[
            StyleBox["\<\"p\"\>",
              FontSlant->"Italic"], "10"],
          "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
        FormBox[
          SubscriptBox[
            StyleBox["\<\"p\"\>",
              FontSlant->"Italic"], "12"],
          "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", "p23", 
        "\[NoBreak]", ",", "\[NoBreak]", "p30", "\[NoBreak]", ",", 
        "\[NoBreak]", "p20", "\[NoBreak]", ",", "\[NoBreak]", "p13", 
        "\[NoBreak]", ",", "\[NoBreak]", 
        FormBox[
          SuperscriptBox["m1", "2"],
          "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
        FormBox[
          SuperscriptBox["m2", "2"],
          "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
        FormBox[
          SuperscriptBox["m3", "2"],
          "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
        FormBox[
          SuperscriptBox["m4", "2"],
          "TraditionalForm"], "\[NoBreak]", ")"}], TraditionalForm]], "Output",\

  CellLabel->"Out[343]=  (21:52:48 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"PaVeOrder", "[", 
      RowBox[{
        RowBox[{"D0", "[", 
          RowBox[{
          "p10", ",", "p12", ",", "p23", ",", "p30", ",", "p20", ",", "p13", 
            ",", 
            RowBox[{"m1", "^", "2"}], ",", 
            RowBox[{"m2", "^", "2"}], ",", 
            RowBox[{"m3", "^", "2"}], ",", 
            RowBox[{"m4", "^", "2"}]}], "]"}], ",", 
        RowBox[{"PaVeOrderList", "->", 
          RowBox[{"{", 
            RowBox[{"p13", ",", "p20"}], "}"}]}]}], "]"}]], "Input",
  CellLabel->"In[344]:=  (21:52:48 on 5/16/01)",
  CellTags->"D0"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          SubscriptBox["\<\"D\"\>", "\<\"0\"\>"],
          "TraditionalForm"], "\[NoBreak]", "(", "\[NoBreak]", 
        FormBox[
          SubscriptBox[
            StyleBox["\<\"p\"\>",
              FontSlant->"Italic"], "10"],
          "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", "p30", 
        "\[NoBreak]", ",", "\[NoBreak]", "p23", "\[NoBreak]", ",", 
        "\[NoBreak]", 
        FormBox[
          SubscriptBox[
            StyleBox["\<\"p\"\>",
              FontSlant->"Italic"], "12"],
          "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", "p13", 
        "\[NoBreak]", ",", "\[NoBreak]", "p20", "\[NoBreak]", ",", 
        "\[NoBreak]", 
        FormBox[
          SuperscriptBox["m2", "2"],
          "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
        FormBox[
          SuperscriptBox["m1", "2"],
          "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
        FormBox[
          SuperscriptBox["m4", "2"],
          "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
        FormBox[
          SuperscriptBox["m3", "2"],
          "TraditionalForm"], "\[NoBreak]", ")"}], TraditionalForm]], "Output",\

  CellLabel->"Out[344]=  (21:52:48 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"PaVeOrder", "[", "%", "]"}]], "Input",
  CellLabel->"In[345]:=  (21:52:48 on 5/16/01)",
  CellTags->"D0"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          SubscriptBox["\<\"D\"\>", "\<\"0\"\>"],
          "TraditionalForm"], "\[NoBreak]", "(", "\[NoBreak]", 
        FormBox[
          SubscriptBox[
            StyleBox["\<\"p\"\>",
              FontSlant->"Italic"], "10"],
          "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
        FormBox[
          SubscriptBox[
            StyleBox["\<\"p\"\>",
              FontSlant->"Italic"], "12"],
          "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", "p23", 
        "\[NoBreak]", ",", "\[NoBreak]", "p30", "\[NoBreak]", ",", 
        "\[NoBreak]", "p20", "\[NoBreak]", ",", "\[NoBreak]", "p13", 
        "\[NoBreak]", ",", "\[NoBreak]", 
        FormBox[
          SuperscriptBox["m1", "2"],
          "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
        FormBox[
          SuperscriptBox["m2", "2"],
          "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
        FormBox[
          SuperscriptBox["m3", "2"],
          "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
        FormBox[
          SuperscriptBox["m4", "2"],
          "TraditionalForm"], "\[NoBreak]", ")"}], TraditionalForm]], "Output",\

  CellLabel->"Out[345]=  (21:52:48 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["DataType", "ObjectName",
  CellTags->"DataType"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"DataType"],

Cell["\<\
DataType[exp, type] = True defines the object exp to have data-type type. \
DataType[exp1, exp2, ..., type] defines the objects exp1, exp2, ...to have \
data-type type. The default setting is DataType[__, _] := False. To assign a \
certain data-type, do, e.g., DataType[x, PositiveInteger] = True.\
\>", "Text",
  CellTags->"DataType"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["DeclareNonCommutative",
    ButtonData:>"DeclareNonCommutative",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DeclareNonCommutative"],
  "."
}], "Text",
  CellTags->"DataType"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"DataType"],

Cell["NonCommutative is just a data-type.", "Text",
  CellTags->"DataType"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"DataType", "[", 
          RowBox[{"f", ",", "g", ",", " ", "NonCommutative"}], "]"}], " ", 
        "=", " ", "True"}], ";"}]], "Input",
  CellLabel->"In[346]:=  (21:52:48 on 5/16/01)",
  CellTags->"DataType"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t", "=", 
      RowBox[{
        RowBox[{"f", ".", "g"}], "-", 
        RowBox[{"g", ".", 
          RowBox[{"(", 
            RowBox[{"2", "a"}], ")"}], ".", "f"}]}]}]], "Input",
  CellLabel->"In[347]:=  (21:52:48 on 5/16/01)",
  CellTags->"DataType"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"f", ".", "g"}], "-", 
        RowBox[{"g", ".", 
          RowBox[{"(", 
            RowBox[{"2", " ", "a"}], ")"}], ".", "f"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[347]=  (21:52:49 on 5/16/01)"]
}, Closed]],

Cell["\<\
Since \"f \"and \"g\" have DataType NonCommutative the function DotSimplify \
extracts only \"a\" out of the noncommutative product.\
\>", "Text",
  CellTags->"DataType"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DotSimplify", "[", "t", "]"}]], "Input",
  CellLabel->"In[348]:=  (21:52:49 on 5/16/01)",
  CellTags->"DataType"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"f", ".", "g"}], "-", 
        RowBox[{"2", " ", "a", " ", 
          RowBox[{"g", ".", "f"}]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[348]=  (21:52:49 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"DataType", "[", 
          RowBox[{"m", ",", "odd"}], "]"}], "=", 
        RowBox[{
          RowBox[{"DataType", "[", 
            RowBox[{"a", ",", "even"}], "]"}], "=", "True"}]}], 
      ";"}]], "Input",
  CellLabel->"In[349]:=  (21:52:49 on 5/16/01)",
  CellTags->"DataType"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"ptest1", "[", "x_", "]"}], ":=", 
        RowBox[{"x", "/.", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"-", "1"}], ")"}], "n_"], "/;", 
              RowBox[{"DataType", "[", 
                RowBox[{"n", ",", "odd"}], "]"}]}], "\[RuleDelayed]", 
            RowBox[{"-", "1"}]}]}]}], ";"}]], "Input",
  CellLabel->"In[350]:=  (21:52:49 on 5/16/01)",
  CellTags->"DataType"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"ptest2", "[", "x_", "]"}], ":=", 
        RowBox[{"x", "/.", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"-", "1"}], ")"}], "n_"], "/;", 
              RowBox[{"DataType", "[", 
                RowBox[{"n", ",", "even"}], "]"}]}], "\[RuleDelayed]", 
            "1"}]}]}], ";"}]], "Input",
  CellLabel->"In[351]:=  (21:52:49 on 5/16/01)",
  CellTags->"DataType"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t", "=", 
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "^", "m"}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "^", "a"}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "^", "z"}]}]}]], "Input",
  CellLabel->"In[352]:=  (21:52:49 on 5/16/01)",
  CellTags->"DataType"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "a"], "+", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "m"], "+", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "z"]}], TraditionalForm]], "Output",
  CellLabel->"Out[352]=  (21:52:49 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ptest1", "[", "t", "]"}]], "Input",
  CellLabel->"In[353]:=  (21:52:49 on 5/16/01)",
  CellTags->"DataType"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "a"], "+", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "z"]}], TraditionalForm]], "Output",
  CellLabel->"Out[353]=  (21:52:49 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ptest2", "[", "%", "]"}]], "Input",
  CellLabel->"In[354]:=  (21:52:49 on 5/16/01)",
  CellTags->"DataType"],

Cell[BoxData[
    FormBox[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "z"], TraditionalForm]], "Output",
  CellLabel->"Out[354]=  (21:52:49 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      RowBox[{"Clear", "[", 
        RowBox[{"ptest1", ",", "ptest2", ",", "t", ",", "a", ",", "m"}], 
        "]"}], ";"}]], "Input",
  CellLabel->"In[355]:=  (21:52:50 on 5/16/01)",
  CellTags->"DataType"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"DataType", "[", 
          RowBox[{"m", ",", "ganzeZahl"}], "]"}], "=", "True"}], 
      ";"}]], "Input",
  CellLabel->"In[356]:=  (21:52:50 on 5/16/01)",
  CellTags->"DataType"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"f", "[", "x_", "]"}], ":=", 
        RowBox[{"x", "/.", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"-", "1"}], ")"}], "^", "p_"}], "/;", 
                RowBox[{"DataType", "[", 
                  RowBox[{"p", ",", "ganzeZahl"}], "]"}]}], ":>", "1"}], 
            "}"}]}]}], ";"}]], "Input",
  CellLabel->"In[357]:=  (21:52:50 on 5/16/01)",
  CellTags->"DataType"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"test", "=", 
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "^", "m"}], "+", 
        RowBox[{
          RowBox[{
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "^", "n"}], " ", "x"}]}]}]], "Input",\

  CellLabel->"In[358]:=  (21:52:50 on 5/16/01)",
  CellTags->"DataType"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "n"], " ", "x"}], "+", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "m"]}], TraditionalForm]], "Output",
  CellLabel->"Out[358]=  (21:52:50 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"f", "[", "test", "]"}]], "Input",
  CellLabel->"In[359]:=  (21:52:50 on 5/16/01)",
  CellTags->"DataType"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "n"], " ", "x"}], "+", "1"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[359]=  (21:52:50 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      RowBox[{"Clear", "[", 
        RowBox[{"f", ",", "test"}], "]"}], ";"}]], "Input",
  CellLabel->"In[360]:=  (21:52:50 on 5/16/01)",
  CellTags->"DataType"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"DataType", "[", 
          RowBox[{"f", ",", "g", ",", " ", "NonCommutative"}], "]"}], " ", 
        "=", " ", "False"}], ";"}]], "Input",
  CellLabel->"In[361]:=  (21:52:50 on 5/16/01)",
  CellTags->"DataType"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"DataType", "[", 
          RowBox[{"m", ",", "odd"}], "]"}], "=", 
        RowBox[{
          RowBox[{"DataType", "[", 
            RowBox[{"a", ",", "even"}], "]"}], "=", "False"}]}], 
      ";"}]], "Input",
  CellLabel->"In[362]:=  (21:52:50 on 5/16/01)",
  CellTags->"DataType"],

Cell["\<\
Certain FeynCalc objects have DataType PositiveInteger set to True.\
\>", "Text",
  CellTags->"DataType"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DataType", "[", 
      RowBox[{"OPEm", ",", "PositiveInteger"}], "]"}]], "Input",
  CellLabel->"In[363]:=  (21:52:50 on 5/16/01)",
  CellTags->"DataType"],

Cell[BoxData[
    FormBox["True", TraditionalForm]], "Output",
  CellLabel->"Out[363]=  (21:52:51 on 5/16/01)"]
}, Closed]],

Cell["PowerSimplify uses the DataType information.", "Text",
  CellTags->"DataType"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"PowerSimplify", "[", " ", 
      RowBox[{
        RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "^", 
        RowBox[{"(", 
          RowBox[{"2", "OPEm"}], ")"}]}], "]"}]], "Input",
  CellLabel->"In[364]:=  (21:52:51 on 5/16/01)",
  CellTags->"DataType"],

Cell[BoxData[
    FormBox["1", TraditionalForm]], "Output",
  CellLabel->"Out[364]=  (21:52:51 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"PowerSimplify", "[", " ", 
      RowBox[{
        RowBox[{"(", 
          RowBox[{"-", " ", 
            RowBox[{"SO", "[", "q", "]"}]}], ")"}], "^", "OPEm"}], 
      "]"}]], "Input",
  CellLabel->"In[365]:=  (21:52:51 on 5/16/01)",
  CellTags->"DataType"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "m"], " ", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              FormBox["\<\"\[CapitalDelta]\"\>",
                "TraditionalForm"], 
              FormBox["\<\"\[CenterDot]\"\>",
                "TraditionalForm"], 
              FormBox["q",
                "TraditionalForm"]}], ")"}], "m"]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[365]=  (21:52:51 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["DeclareNonCommutative", "ObjectName",
  CellTags->"DeclareNonCommutative"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"DeclareNonCommutative"],

Cell["\<\
DeclareNonCommutative[a, b, ...] declares a,b, ... to be non-commutative, \
i.e., DataType[a,b, ..., NonCommutative] is set to True.\
\>", "Text",
  CellTags->"DeclareNonCommutative"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["DataType",
    ButtonData:>"DataType",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DataType"],
  ", ",
  ButtonBox["UnDeclareNonCommutative",
    ButtonData:>"UnDeclareNonCommutative",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"UnDeclareNonCommutative"],
  "."
}], "Text",
  CellTags->"DeclareNonCommutative"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"DeclareNonCommutative"],

Cell[BoxData[
    RowBox[{"DeclareNonCommutative", "[", "x", "]"}]], "Input",
  CellLabel->"In[366]:=  (21:52:51 on 5/16/01)",
  CellTags->"DeclareNonCommutative"],

Cell["\<\
As a side effect of DeclareNonCommutative x is declared to be of data type \
NonCommutative.\
\>", "Text",
  CellTags->"DeclareNonCommutative"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DataType", "[", 
      RowBox[{"x", ",", "NonCommutative"}], "]"}]], "Input",
  CellLabel->"In[367]:=  (21:52:51 on 5/16/01)",
  CellTags->"DeclareNonCommutative"],

Cell[BoxData[
    FormBox["True", TraditionalForm]], "Output",
  CellLabel->"Out[367]=  (21:52:51 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{"DeclareNonCommutative", "[", 
      RowBox[{"y", ",", "z"}], "]"}]], "Input",
  CellLabel->"In[368]:=  (21:52:51 on 5/16/01)",
  CellTags->"DeclareNonCommutative"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DataType", "[", 
      RowBox[{"a", ",", "x", ",", "y", ",", "z", ",", "NonCommutative"}], 
      "]"}]], "Input",
  CellLabel->"In[369]:=  (21:52:51 on 5/16/01)",
  CellTags->"DeclareNonCommutative"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"False", ",", "True", ",", "True", ",", "True"}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[369]=  (21:52:51 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{"UnDeclareNonCommutative", "[", 
      RowBox[{"x", ",", "y", ",", "z"}], "]"}]], "Input",
  CellLabel->"In[370]:=  (21:52:51 on 5/16/01)",
  CellTags->"DeclareNonCommutative"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DataType", "[", 
      RowBox[{"a", ",", "x", ",", "y", ",", "z", ",", "NonCommutative"}], 
      "]"}]], "Input",
  CellLabel->"In[371]:=  (21:52:52 on 5/16/01)",
  CellTags->"DeclareNonCommutative"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"False", ",", "False", ",", "False", ",", "False"}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[371]=  (21:52:52 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["DeltaFunction", "ObjectName",
  CellTags->"DeltaFunction"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"DeltaFunction"],

Cell[TextData[{
  " DeltaFunction[x] is the Dirac delta-function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Delta]", "(", "x", ")"}], TraditionalForm]]],
  "."
}], "Text",
  CellTags->"DeltaFunction"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["Convolute",
    ButtonData:>"Convolute",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Convolute"],
  ", ",
  ButtonBox["DeltaFunctionPrime",
    ButtonData:>"DeltaFunctionPrime",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DeltaFunctionPrime"],
  ", ",
  ButtonBox["Integrate2",
    ButtonData:>"Integrate2",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Integrate2"],
  ", ",
  ButtonBox["SimplifyDeltaFunction",
    ButtonData:>"SimplifyDeltaFunction",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SimplifyDeltaFunction"],
  "."
}], "Text",
  CellTags->"DeltaFunction"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"DeltaFunction"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DeltaFunction", "[", 
      RowBox[{"1", "-", "x"}], "]"}]], "Input",
  CellLabel->"In[372]:=  (21:52:52 on 5/16/01)",
  CellTags->"DeltaFunction"],

Cell[BoxData[
    FormBox[
      RowBox[{"\[Delta]", "(", 
        FormBox[
          RowBox[{"1", "-", "x"}],
          "TraditionalForm"], ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[372]=  (21:52:52 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Integrate2", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"DeltaFunction", "[", 
            RowBox[{"1", "-", "x"}], "]"}], " ", 
          RowBox[{"f", "[", "x", "]"}]}], ",", 
        RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[373]:=  (21:52:52 on 5/16/01)",
  CellTags->"DeltaFunction"],

Cell[BoxData[
    FormBox[
      RowBox[{"f", "(", "1", ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[373]=  (21:52:52 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Integrate2", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"DeltaFunction", "[", "x", "]"}], " ", 
          RowBox[{"f", "[", "x", "]"}]}], ",", 
        RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[374]:=  (21:52:52 on 5/16/01)",
  CellTags->"DeltaFunction"],

Cell[BoxData[
    FormBox[
      RowBox[{"f", "(", "0", ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[374]=  (21:52:52 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Integrate2", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"DeltaFunction", "[", 
            RowBox[{"1", "-", "x"}], "]"}], " ", 
          RowBox[{"f", "[", "x", "]"}]}], ",", 
        RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[375]:=  (21:52:52 on 5/16/01)",
  CellTags->"DeltaFunction"],

Cell[BoxData[
    FormBox[
      RowBox[{"f", "(", "1", ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[375]=  (21:52:52 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Convolute", "[", 
      RowBox[{
        RowBox[{"DeltaFunction", "[", 
          RowBox[{"1", "-", "x"}], "]"}], ",", "x"}], "]"}]], "Input",
  CellLabel->"In[376]:=  (21:52:52 on 5/16/01)",
  CellTags->"DeltaFunction"],

Cell[BoxData[
    FormBox["x", TraditionalForm]], "Output",
  CellLabel->"Out[376]=  (21:52:52 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["DeltaFunctionPrime", "ObjectName",
  CellTags->"DeltaFunctionPrime"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"DeltaFunctionPrime"],

Cell[TextData[{
  " DeltaFunctionPrime[1-x] is the derivative of the Dirac ",
  Cell[BoxData[
      FormBox["\[Delta]", TraditionalForm]]],
  " function."
}], "Text",
  CellTags->"DeltaFunctionPrime"],

Cell[TextData[{
  "See also: ",
  ButtonBox["Convolute",
    ButtonData:>"Convolute",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Convolute"],
  ", ",
  ButtonBox["DeltaFunction",
    ButtonData:>"DeltaFunction",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DeltaFunction"],
  ", ",
  ButtonBox["Integrate2",
    ButtonData:>"Integrate2",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Integrate2"],
  ", ",
  ButtonBox["SimplifyDeltaFunction",
    ButtonData:>"SimplifyDeltaFunction",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SimplifyDeltaFunction"],
  "."
}], "Text",
  CellTags->"DeltaFunctionPrime"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"DeltaFunctionPrime"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DeltaFunctionPrime", "[", 
      RowBox[{"1", "-", "x"}], "]"}]], "Input",
  CellLabel->"In[377]:=  (21:52:52 on 5/16/01)",
  CellTags->"DeltaFunctionPrime"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Delta]", "\[Prime]"], "(", 
        FormBox[
          RowBox[{"1", "-", "x"}],
          "TraditionalForm"], ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[377]=  (21:52:52 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Integrate2", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"DeltaFunctionPrime", "[", 
            RowBox[{"1", "-", "x"}], "]"}], " ", 
          RowBox[{"f", "[", "x", "]"}]}], ",", 
        RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[378]:=  (21:52:52 on 5/16/01)",
  CellTags->"DeltaFunctionPrime"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["f", "\[Prime]",
          MultilineFunction->None], "(", "1", ")"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[378]=  (21:52:53 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Integrate2", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"DeltaFunctionPrime", "[", 
            RowBox[{"1", "-", "x"}], "]"}], " ", 
          SuperscriptBox["x", "2"]}], ",", 
        RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[379]:=  (21:52:53 on 5/16/01)",
  CellTags->"DeltaFunctionPrime"],

Cell[BoxData[
    FormBox["2", TraditionalForm]], "Output",
  CellLabel->"Out[379]=  (21:52:53 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Dimension", "ObjectName",
  CellTags->"Dimension"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"Dimension"],

Cell["\<\
Dimension is an option of several functions and denotes the space-time \
dimension. Possible settings are: 4, n, d, D, ... ,the variable does not \
matter, but it should have Head Symbol.\
\>", "Text",
  CellTags->"Dimension"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "MetricTensor", "]"}]], "Input",
  CellLabel->"In[380]:=  (21:52:53 on 5/16/01)",
  CellTags->"Dimension"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"Dimension", "\[Rule]", "4"}], ",", 
          RowBox[{"FeynCalcInternal", "\[Rule]", "True"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[380]=  (21:52:53 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"MetricTensor", "[", 
          RowBox[{"m", ",", "n", ",", 
            RowBox[{"Dimension", "\[Rule]", "d"}]}], "]"}], 
        RowBox[{"DiracMatrix", "[", 
          RowBox[{"\[Alpha]", ",", 
            RowBox[{"Dimension", "\[Rule]", "d"}]}], "]"}]}], "//", 
      "FCI"}]], "Input",
  CellLabel->"In[381]:=  (21:52:53 on 5/16/01)",
  CellTags->"Dimension"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Alpha]",
              "TraditionalForm"],
            "TraditionalForm"]], " ", 
        SuperscriptBox["g", 
          RowBox[{
            FormBox[
              FormBox["m",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["n",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[381]=  (21:52:53 on 5/16/01)"]
}, Closed]],

Cell["\<\
The dimension of the indices is not shown by default but can be inspected \
easily.\
\>", "Text",
  CellTags->"Dimension"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"MetricTensor", "[", 
          RowBox[{"m", ",", "n", ",", 
            RowBox[{"Dimension", "\[Rule]", "d"}]}], "]"}], 
        RowBox[{"DiracMatrix", "[", 
          RowBox[{"\[Alpha]", ",", 
            RowBox[{"Dimension", "\[Rule]", "d"}]}], "]"}]}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[382]:=  (21:52:53 on 5/16/01)",
  CellTags->"Dimension"],

Cell[BoxData[
    RowBox[{
      RowBox[{"DiracGamma", "[", 
        RowBox[{
          RowBox[{"LorentzIndex", "[", 
            RowBox[{"\[Alpha]", ",", "d"}], "]"}], ",", "d"}], "]"}], " ", 
      RowBox[{"Pair", "[", 
        RowBox[{
          RowBox[{"LorentzIndex", "[", 
            RowBox[{"m", ",", "d"}], "]"}], ",", 
          RowBox[{"LorentzIndex", "[", 
            RowBox[{"n", ",", "d"}], "]"}]}], "]"}]}]], "Output",
  CellLabel->"Out[382]//StandardForm=  (21:52:53 on 5/16/01)"]
}, Closed]],

Cell["\<\
Setting the global variable $LorentzIndices to True will display the \
dimension (if different from 4) as a subscript.\
\>", "Text",
  CellTags->"Dimension"],

Cell[BoxData[
    RowBox[{
      RowBox[{"$LorentzIndices", "=", "True"}], ";"}]], "Input",
  CellLabel->"In[383]:=  (21:52:53 on 5/16/01)",
  CellTags->"Dimension"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"MetricTensor", "[", 
        RowBox[{"\[Alpha]", ",", "\[Beta]", ",", 
          RowBox[{"Dimension", "\[Rule]", "n"}]}], "]"}], 
      RowBox[{"DiracMatrix", "[", 
        RowBox[{"\[Alpha]", ",", 
          RowBox[{"Dimension", "\[Rule]", "n"}]}], "]"}]}]], "Input",
  CellLabel->"In[384]:=  (21:52:53 on 5/16/01)",
  CellTags->"Dimension"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", 
          FormBox[
            SubscriptBox[
              FormBox["\[Alpha]",
                "TraditionalForm"], 
              FormBox["n",
                "TraditionalForm"]],
            "TraditionalForm"]], " ", 
        SuperscriptBox["g", 
          RowBox[{
            FormBox[
              SubscriptBox[
                FormBox["\[Alpha]",
                  "TraditionalForm"], 
                FormBox["n",
                  "TraditionalForm"]],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              SubscriptBox[
                FormBox["\[Beta]",
                  "TraditionalForm"], 
                FormBox["n",
                  "TraditionalForm"]],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[384]=  (21:52:53 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "StandardForm"}]], "Input",
  CellLabel->"In[385]:=  (21:52:53 on 5/16/01)",
  CellTags->"Dimension"],

Cell[BoxData[
    RowBox[{
      RowBox[{"DiracGamma", "[", 
        RowBox[{
          RowBox[{"LorentzIndex", "[", 
            RowBox[{"\[Alpha]", ",", "n"}], "]"}], ",", "n"}], "]"}], " ", 
      RowBox[{"Pair", "[", 
        RowBox[{
          RowBox[{"LorentzIndex", "[", 
            RowBox[{"\[Alpha]", ",", "n"}], "]"}], ",", 
          RowBox[{"LorentzIndex", "[", 
            RowBox[{"\[Beta]", ",", "n"}], "]"}]}], "]"}]}]], "Output",
  CellLabel->"Out[385]//StandardForm=  (21:52:53 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      RowBox[{"$LorentzIndices", "=", "False"}], ";"}]], "Input",
  CellLabel->"In[386]:=  (21:52:53 on 5/16/01)",
  CellTags->"Dimension"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["DiracGammaCombine", "ObjectName",
  CellTags->"DiracGammaCombine"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"DiracGammaCombine"],

Cell["\<\
DiracGammaCombine[exp] is (nearly) the inverse operation to DiracGammaExpand.\
\
\>", "Text",
  CellTags->"DiracGammaCombine"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["DiracGamma",
    ButtonData:>"DiracGamma",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracGamma"],
  ", ",
  ButtonBox["DiracGammaExpand",
    ButtonData:>"DiracGammaExpand",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracGammaExpand"],
  ", ",
  ButtonBox["DiracMatrix",
    ButtonData:>"DiracMatrix",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracMatrix"],
  ", ",
  ButtonBox["DiracSimplify",
    ButtonData:>"DiracSimplify",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracSimplify"],
  ", ",
  ButtonBox["DiracSlash",
    ButtonData:>"DiracSlash",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracSlash"],
  ", ",
  ButtonBox["DiracTrick",
    ButtonData:>"DiracTrick",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracTrick"],
  "."
}], "Text",
  CellTags->"DiracGammaCombine"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"DiracGammaCombine"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracGammaCombine", "[", 
      RowBox[{
        RowBox[{"GS", "[", "p", "]"}], " ", "+", " ", 
        RowBox[{"GS", "[", "q", "]"}]}], "]"}]], "Input",
  CellLabel->"In[387]:=  (21:52:53 on 5/16/01)",
  CellTags->"DiracGammaCombine"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox["\<\"\[Gamma]\"\>",
          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "(",
         "\[NoBreak]", 
        FormBox[
          RowBox[{"p", "+", "q"}],
          "TraditionalForm"], "\[NoBreak]", ")"}], TraditionalForm]], "Output",\

  CellLabel->"Out[387]=  (21:52:54 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StandardForm", "[", "%", "]"}]], "Input",
  CellLabel->"In[388]:=  (21:52:54 on 5/16/01)",
  CellTags->"DiracGammaCombine"],

Cell[BoxData[
    RowBox[{"DiracGamma", "[", 
      RowBox[{"Momentum", "[", 
        RowBox[{"p", "+", "q"}], "]"}], "]"}]], "Output",
  CellLabel->"Out[388]//StandardForm=  (21:52:54 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracGammaCombine", "[", 
      RowBox[{
        RowBox[{"2", " ", 
          RowBox[{"GS", "[", "p", "]"}]}], " ", "-", " ", 
        RowBox[{"2", " ", 
          RowBox[{"GS", "[", "q", "]"}]}]}], "]"}]], "Input",
  CellLabel->"In[389]:=  (21:52:54 on 5/16/01)",
  CellTags->"DiracGammaCombine"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox["\<\"\[Gamma]\"\>",
          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "(",
         "\[NoBreak]", 
        FormBox[
          RowBox[{
            RowBox[{"2", " ", "p"}], "-", 
            RowBox[{"2", " ", "q"}]}],
          "TraditionalForm"], "\[NoBreak]", ")"}], TraditionalForm]], "Output",\

  CellLabel->"Out[389]=  (21:52:54 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StandardForm", "[", "%", "]"}]], "Input",
  CellLabel->"In[390]:=  (21:52:54 on 5/16/01)",
  CellTags->"DiracGammaCombine"],

Cell[BoxData[
    RowBox[{"DiracGamma", "[", 
      RowBox[{"Momentum", "[", 
        RowBox[{
          RowBox[{"2", " ", "p"}], "-", 
          RowBox[{"2", " ", "q"}]}], "]"}], "]"}]], "Output",
  CellLabel->"Out[390]//StandardForm=  (21:52:54 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracGammaExpand", "[", "%%", "]"}]], "Input",
  CellLabel->"In[391]:=  (21:52:54 on 5/16/01)",
  CellTags->"DiracGammaCombine"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"2", " ", 
          RowBox[{
            FormBox["\<\"\[Gamma]\"\>",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["p",
              "TraditionalForm"]}]}], "-", 
        RowBox[{"2", " ", 
          RowBox[{
            FormBox["\<\"\[Gamma]\"\>",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["q",
              "TraditionalForm"]}]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[391]=  (21:52:54 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["DiracGammaExpand", "ObjectName",
  CellTags->"DiracGammaExpand"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"DiracGammaExpand"],

Cell["\<\
DiracGammaExpand[exp] expands all DiracGamma[Momentum[a+b+..]] in exp into \
(DiracGamma[Momentum[a]] + DiracGamma[Momentum[b]] + ...).\
\>", "Text",
  CellTags->"DiracGammaExpand"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["DiracGamma",
    ButtonData:>"DiracGamma",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracGamma"],
  ", ",
  ButtonBox["DiracGammaCombine",
    ButtonData:>"DiracGammaCombine",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracGammaCombine"],
  ", ",
  ButtonBox["DiracMatrix",
    ButtonData:>"DiracMatrix",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracMatrix"],
  ", ",
  ButtonBox["DiracSimplify",
    ButtonData:>"DiracSimplify",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracSimplify"],
  ", ",
  ButtonBox["DiracSlash",
    ButtonData:>"DiracSlash",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracSlash"],
  ", ",
  ButtonBox["DiracTrick",
    ButtonData:>"DiracTrick",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracTrick"],
  "."
}], "Text",
  CellTags->"DiracGammaExpand"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"DiracGammaExpand"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t", "=", 
      RowBox[{
        RowBox[{"DiracGamma", "[", 
          RowBox[{"Momentum", "[", "q", "]"}], "]"}], " ", ".", " ", 
        RowBox[{"DiracGamma", "[", 
          RowBox[{"Momentum", "[", 
            RowBox[{"p", "-", "q"}], "]"}], "]"}]}]}]], "Input",
  CellLabel->"In[392]:=  (21:52:54 on 5/16/01)",
  CellTags->"DiracGammaExpand"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            FormBox["\<\"\[Gamma]\"\>",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["q",
              "TraditionalForm"]}], ")"}], ".", 
        RowBox[{"(", 
          RowBox[{
            FormBox["\<\"\[Gamma]\"\>",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            "(", "\[NoBreak]", 
            FormBox[
              RowBox[{"p", "-", "q"}],
              "TraditionalForm"], "\[NoBreak]", ")"}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[392]=  (21:52:54 on 5/16/01)"]
}, Closed]],

Cell["\<\
Momentum is the head of p-q, i.e., it is treated as one four-momentum.\
\>", "Text",
  CellTags->"DiracGammaExpand"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StandardForm", "[", "t", "]"}]], "Input",
  CellLabel->"In[393]:=  (21:52:54 on 5/16/01)",
  CellTags->"DiracGammaExpand"],

Cell[BoxData[
    RowBox[{
      RowBox[{"DiracGamma", "[", 
        RowBox[{"Momentum", "[", "q", "]"}], "]"}], ".", 
      RowBox[{"DiracGamma", "[", 
        RowBox[{"Momentum", "[", 
          RowBox[{"p", "-", "q"}], "]"}], "]"}]}]], "Output",
  CellLabel->"Out[393]//StandardForm=  (21:52:54 on 5/16/01)"]
}, Closed]],

Cell["With DiracGammaExpand the Momentum[p-q] gets expanded.", "Text",
  CellTags->"DiracGammaExpand"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracGammaExpand", "[", "t", "]"}]], "Input",
  CellLabel->"In[394]:=  (21:52:54 on 5/16/01)",
  CellTags->"DiracGammaExpand"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            FormBox["\<\"\[Gamma]\"\>",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["q",
              "TraditionalForm"]}], ")"}], ".", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              FormBox["\<\"\[Gamma]\"\>",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox["p",
                "TraditionalForm"]}], "-", 
            RowBox[{
              FormBox["\<\"\[Gamma]\"\>",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox["q",
                "TraditionalForm"]}]}], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[394]=  (21:52:54 on 5/16/01)"]
}, Closed]],

Cell["The inverse operation is DiracGammaCombine.", "Text",
  CellTags->"DiracGammaExpand"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StandardForm", "[", 
      RowBox[{"DiracGammaCombine", "[", 
        RowBox[{"DiracGammaExpand", "[", "t", "]"}], "]"}], "]"}]], "Input",
  CellLabel->"In[395]:=  (21:52:54 on 5/16/01)",
  CellTags->"DiracGammaExpand"],

Cell[BoxData[
    RowBox[{
      RowBox[{"DiracGamma", "[", 
        RowBox[{"Momentum", "[", "q", "]"}], "]"}], ".", 
      RowBox[{"DiracGamma", "[", 
        RowBox[{"Momentum", "[", 
          RowBox[{"p", "-", "q"}], "]"}], "]"}]}]], "Output",
  CellLabel->"Out[395]//StandardForm=  (21:52:54 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StandardForm", "[", 
      RowBox[{"DiracGammaExpand", "[", "t", "]"}], "]"}]], "Input",
  CellLabel->"In[396]:=  (21:52:54 on 5/16/01)",
  CellTags->"DiracGammaExpand"],

Cell[BoxData[
    RowBox[{
      RowBox[{"DiracGamma", "[", 
        RowBox[{"Momentum", "[", "q", "]"}], "]"}], ".", 
      RowBox[{"(", 
        RowBox[{
          RowBox[{"DiracGamma", "[", 
            RowBox[{"Momentum", "[", "p", "]"}], "]"}], "-", 
          RowBox[{"DiracGamma", "[", 
            RowBox[{"Momentum", "[", "q", "]"}], "]"}]}], ")"}]}]], "Output",
  CellLabel->"Out[396]//StandardForm=  (21:52:54 on 5/16/01)"]
}, Closed]],

Cell["In order to do non-commutative expansion use DiracSimplify.", "Text",
  CellTags->"DiracGammaExpand"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracSimplify", "[", "t", "]"}]], "Input",
  CellLabel->"In[397]:=  (21:52:54 on 5/16/01)",
  CellTags->"DiracGammaExpand"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              FormBox["\<\"\[Gamma]\"\>",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox["q",
                "TraditionalForm"]}], ")"}], ".", 
          RowBox[{"(", 
            RowBox[{
              FormBox["\<\"\[Gamma]\"\>",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox["p",
                "TraditionalForm"]}], ")"}]}], "-", 
        SuperscriptBox[
          FormBox["q",
            "TraditionalForm"], "2"]}], TraditionalForm]], "Output",
  CellLabel->"Out[397]=  (21:52:54 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{"Clear", "[", "t", "]"}]], "Input",
  CellLabel->"In[398]:=  (21:52:54 on 5/16/01)",
  CellTags->"DiracGammaExpand"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["DiracGamma", "ObjectName",
  CellTags->"DiracGamma"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"DiracGamma"],

Cell[TextData[{
  "DiracGamma[x, dim] is the head of all Dirac matrices and slashes (in the \
internal representation). Use DiracMatrix (or GA, GAD) and DiracSlash (or GS, \
GSD) for manual (short) input. DiracGamma[x, 4] simplifies to DiracGamma[x]. \
DiracGamma[5] is ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox["\[Gamma]", "5"], TraditionalForm]]],
  ". DiracGamma[6] is ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox["\[Gamma]", "5"]}], ")"}], "/", "2."}], 
        TraditionalForm]]],
  " DiracGamma[7] is ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "-", 
              SuperscriptBox["\[Gamma]", "5"]}], ")"}], "/", "2."}], 
        TraditionalForm]]]
}], "Text",
  CellTags->"DiracGamma"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["DiracGammaExpand",
    ButtonData:>"DiracGammaExpand",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracGammaExpand"],
  ", ",
  ButtonBox["DiracMatrix",
    ButtonData:>"DiracMatrix",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracMatrix"],
  ", ",
  ButtonBox["DiracSimplify",
    ButtonData:>"DiracSimplify",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracSimplify"],
  ", ",
  ButtonBox["DiracSlash",
    ButtonData:>"DiracSlash",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracSlash"],
  ", ",
  ButtonBox["DiracTrick",
    ButtonData:>"DiracTrick",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracTrick"],
  "."
}], "Text",
  CellTags->"DiracGamma"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"DiracGamma"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracGamma", "[", "5", "]"}]], "Input",
  CellLabel->"In[399]:=  (21:52:54 on 5/16/01)",
  CellTags->"DiracGamma"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["\[Gamma]", "5"], TraditionalForm]], "Output",
  CellLabel->"Out[399]=  (21:52:54 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracGamma", "[", 
      RowBox[{"LorentzIndex", "[", "\[Alpha]", "]"}], "]"}]], "Input",
  CellLabel->"In[400]:=  (21:52:54 on 5/16/01)",
  CellTags->"DiracGamma"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["\[Gamma]", 
        FormBox[
          FormBox["\[Alpha]",
            "TraditionalForm"],
          "TraditionalForm"]], TraditionalForm]], "Output",
  CellLabel->"Out[400]=  (21:52:54 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "A Dirac-slash, i.e., ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox["\[Gamma]", "\[Mu]"], 
          SubscriptBox["q", "\[Mu]"]}], TraditionalForm]]],
  ", is displayed as ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Gamma]", "\[CenterDot]", "q"}], TraditionalForm]]],
  "."
}], "Text",
  CellTags->"DiracGamma"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"DiracGamma", "[", 
        RowBox[{"Momentum", "[", "q", "]"}], "]"}], " "}]], "Input",
  CellLabel->"In[401]:=  (21:52:54 on 5/16/01)",
  CellTags->"DiracGamma"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox["\<\"\[Gamma]\"\>",
          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
        FormBox["q",
          "TraditionalForm"]}], TraditionalForm]], "Output",
  CellLabel->"Out[401]=  (21:52:54 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"DiracGamma", "[", 
        RowBox[{"Momentum", "[", "q", "]"}], "]"}], " ", ".", " ", 
      RowBox[{"DiracGamma", "[", 
        RowBox[{"Momentum", "[", 
          RowBox[{"p", "-", "q"}], "]"}], "]"}]}]], "Input",
  CellLabel->"In[402]:=  (21:52:54 on 5/16/01)",
  CellTags->"DiracGamma"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            FormBox["\<\"\[Gamma]\"\>",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["q",
              "TraditionalForm"]}], ")"}], ".", 
        RowBox[{"(", 
          RowBox[{
            FormBox["\<\"\[Gamma]\"\>",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            "(", "\[NoBreak]", 
            FormBox[
              RowBox[{"p", "-", "q"}],
              "TraditionalForm"], "\[NoBreak]", ")"}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[402]=  (21:52:54 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"DiracGamma", "[", 
        RowBox[{
          RowBox[{"Momentum", "[", 
            RowBox[{"q", ",", "D"}], "]"}], ",", "D"}], "]"}], " "}]], "Input",\

  CellLabel->"In[403]:=  (21:52:54 on 5/16/01)",
  CellTags->"DiracGamma"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox["\<\"\[Gamma]\"\>",
          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
        FormBox["q",
          "TraditionalForm"]}], TraditionalForm]], "Output",
  CellLabel->"Out[403]=  (21:52:54 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"a1", "=", 
      RowBox[{
        RowBox[{"GS", "[", 
          RowBox[{"p", "-", "q"}], "]"}], ".", 
        RowBox[{"GS", "[", "p", "]"}]}]}]], "Input",
  CellLabel->"In[404]:=  (21:52:54 on 5/16/01)",
  CellTags->"DiracGamma"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
          "\[Gamma]", "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "(", 
            "\[NoBreak]", 
            FormBox[
              RowBox[{"p", "-", "q"}],
              "TraditionalForm"], "\[NoBreak]", ")"}], ")"}], ".", 
        RowBox[{"(", 
          RowBox[{
          "\[Gamma]", "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "p"}], 
          ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[404]=  (21:52:54 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"a2", "=", 
      RowBox[{"DiracGammaExpand", "[", "a1", "]"}]}]], "Input",
  CellLabel->"In[405]:=  (21:52:54 on 5/16/01)",
  CellTags->"DiracGamma"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              FormBox["\<\"\[Gamma]\"\>",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox["p",
                "TraditionalForm"]}], "-", 
            RowBox[{
              FormBox["\<\"\[Gamma]\"\>",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox["q",
                "TraditionalForm"]}]}], ")"}], ".", 
        RowBox[{"(", 
          RowBox[{
            FormBox["\<\"\[Gamma]\"\>",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["p",
              "TraditionalForm"]}], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[405]=  (21:52:54 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"a3", "=", 
      RowBox[{
        RowBox[{"GAD", "[", "\[Mu]", "]"}], ".", 
        RowBox[{"GSD", "[", 
          RowBox[{"p", "-", "q"}], "]"}], ".", 
        RowBox[{"GSD", "[", "q", "]"}], ".", 
        RowBox[{"GAD", "[", "\[Mu]", "]"}]}]}]], "Input",
  CellLabel->"In[406]:=  (21:52:55 on 5/16/01)",
  CellTags->"DiracGamma"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
        RowBox[{"(", 
          RowBox[{
          "\[Gamma]", "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "(", 
            "\[NoBreak]", 
            FormBox[
              RowBox[{"p", "-", "q"}],
              "TraditionalForm"], "\[NoBreak]", ")"}], ")"}], ".", 
        RowBox[{"(", 
          RowBox[{
          "\[Gamma]", "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "q"}], 
          ")"}], ".", 
        SuperscriptBox["\[Gamma]", "\[Mu]"]}], TraditionalForm]], "Output",
  CellLabel->"Out[406]=  (21:52:55 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"a4", "=", 
      RowBox[{"DiracTrick", "[", "a3", "]"}]}]], "Input",
  CellLabel->"In[407]:=  (21:52:55 on 5/16/01)",
  CellTags->"DiracGamma"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{"D", "-", "4"}], ")"}], " ", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                FormBox["\<\"\[Gamma]\"\>",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", "(", "\[NoBreak]", 
                FormBox[
                  RowBox[{"p", "-", "q"}],
                  "TraditionalForm"], "\[NoBreak]", ")"}], ")"}], ".", 
            RowBox[{"(", 
              RowBox[{
                FormBox["\<\"\[Gamma]\"\>",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}], ")"}]}]}], "+", 
        RowBox[{"4", " ", 
          RowBox[{"(", "\[NoBreak]", 
            FormBox[
              RowBox[{"p", "-", "q"}],
              "TraditionalForm"], "\[NoBreak]", ")", "\[NoBreak]", 
            "\[CenterDot]", "\[NoBreak]", 
            FormBox["q",
              "TraditionalForm"]}]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[407]=  (21:52:55 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"a5", "=", 
      RowBox[{"DiracSimplify", "[", "a4", "]"}]}]], "Input",
  CellLabel->"In[408]:=  (21:52:55 on 5/16/01)",
  CellTags->"DiracGamma"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"D", " ", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                FormBox["\<\"\[Gamma]\"\>",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["p",
                  "TraditionalForm"]}], ")"}], ".", 
            RowBox[{"(", 
              RowBox[{
                FormBox["\<\"\[Gamma]\"\>",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}], ")"}]}]}], "-", 
        RowBox[{"4", " ", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                FormBox["\<\"\[Gamma]\"\>",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["p",
                  "TraditionalForm"]}], ")"}], ".", 
            RowBox[{"(", 
              RowBox[{
                FormBox["\<\"\[Gamma]\"\>",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}], ")"}]}]}], "+", 
        RowBox[{"4", " ", 
          RowBox[{
            FormBox["p",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["q",
              "TraditionalForm"]}]}], "-", 
        RowBox[{"D", " ", 
          SuperscriptBox[
            FormBox["q",
              "TraditionalForm"], "2"]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[408]=  (21:52:55 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{"Clear", "[", 
      RowBox[{"a1", ",", "a2", ",", "a3", ",", "a4", ",", "a5"}], 
      "]"}]], "Input",
  CellLabel->"In[409]:=  (21:52:55 on 5/16/01)",
  CellTags->"DiracGamma"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["DiracGammaT", "ObjectName",
  CellTags->"DiracGammaT"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"DiracGammaT"],

Cell["\<\
DiracGammaT[x] denotes the transpose of DiracGamma[x]. \
Transpose[DiracGammaT[x]] gives DiracGamma[x]. Note that x must have Head \
LorentzIndex or Momentum.\
\>", "Text",
  CellTags->"DiracGammaT"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["DiracGamma",
    ButtonData:>"DiracGamma",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracGamma"],
  "."
}], "Text",
  CellTags->"DiracGammaT"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"DiracGammaT"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracGammaT", "[", 
      RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], "]"}]], "Input",
  CellLabel->"In[410]:=  (21:52:55 on 5/16/01)",
  CellTags->"DiracGammaT"],

Cell[BoxData[
    FormBox[
      SubsuperscriptBox["\[Gamma]", 
        FormBox[
          FormBox["\[Mu]",
            "TraditionalForm"],
          "TraditionalForm"], "T"], TraditionalForm]], "Output",
  CellLabel->"Out[410]=  (21:52:55 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Transpose", "[", "%", "]"}]], "Input",
  CellLabel->"In[411]:=  (21:52:55 on 5/16/01)",
  CellTags->"DiracGammaT"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["\[Gamma]", 
        FormBox[
          FormBox["\[Mu]",
            "TraditionalForm"],
          "TraditionalForm"]], TraditionalForm]], "Output",
  CellLabel->"Out[411]=  (21:52:55 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"GS", "[", "p", "]"}], "//", "FCI"}], "//", 
      "Transpose"}]], "Input",
  CellLabel->"In[412]:=  (21:52:56 on 5/16/01)",
  CellTags->"DiracGammaT"],

Cell[BoxData[
    FormBox[
      SuperscriptBox[
        RowBox[{
        "(", "\[NoBreak]", "\[Gamma]", "\[NoBreak]", "\[CenterDot]", 
          "\[NoBreak]", 
          FormBox["p",
            "TraditionalForm"], "\[NoBreak]", ")"}], "T"], 
      TraditionalForm]], "Output",
  CellLabel->"Out[412]=  (21:52:56 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["DiracMatrix", "ObjectName",
  CellTags->"DiracMatrix"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"DiracMatrix"],

Cell[TextData[{
  "DiracMatrix[",
  Cell[BoxData[
      FormBox["\[Mu]", TraditionalForm]]],
  "] denotes a Dirac gamma matrix with Lorentz index ",
  Cell[BoxData[
      FormBox["\[Mu]", TraditionalForm]]],
  ". DiracMatrix[",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[Mu]", ",", "\[Nu]", ","}], " "}], TraditionalForm]]],
  "...] is a product of ",
  Cell[BoxData[
      FormBox["\[Gamma]", TraditionalForm]]],
  " matrices with Lorentz indices ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Mu]", ",", " ", "\[Nu]", ",", " ", "..."}], 
        TraditionalForm]]],
  " DiracMatrix[5] is ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox["\[Gamma]", "5"], TraditionalForm]]],
  ". DiracMatrix[6] is ",
  Cell[BoxData[
      FormBox[
        RowBox[{"1", "/", "2"}], TraditionalForm]]],
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            RowBox[{"+", " ", 
              SuperscriptBox["\[Gamma]", "5"]}], "/", "2"}]}], 
        TraditionalForm]]],
  ". DiracMatrix[7] is",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", "1", "/", "2"}], TraditionalForm]]],
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            RowBox[{"-", " ", 
              SuperscriptBox["\[Gamma]", "5"]}], "/", "2"}]}], 
        TraditionalForm]]],
  "."
}], "Text",
  CellTags->"DiracMatrix"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["DiracGammaExpand",
    ButtonData:>"DiracGammaExpand",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracGammaExpand"],
  ", ",
  ButtonBox["DiracGamma",
    ButtonData:>"DiracGamma",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracGamma"],
  ", ",
  ButtonBox["DiracSimplify",
    ButtonData:>"DiracSimplify",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracSimplify"],
  ", ",
  ButtonBox["DiracSlash",
    ButtonData:>"DiracSlash",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracSlash"],
  ", ",
  ButtonBox["DiracTrick",
    ButtonData:>"DiracTrick",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracTrick"],
  ", ",
  ButtonBox["GA",
    ButtonData:>"GA",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"GA"],
  ", ",
  ButtonBox["GAD",
    ButtonData:>"GAD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"GAD"],
  ", ",
  ButtonBox["GS",
    ButtonData:>"GS",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"GS"],
  ", ",
  ButtonBox["GSD",
    ButtonData:>"GSD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"GSD"],
  "."
}], "Text",
  CellTags->"DiracMatrix"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"DiracMatrix"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracMatrix", "[", "\[Mu]", "]"}]], "Input",
  CellLabel->"In[413]:=  (21:52:56 on 5/16/01)",
  CellTags->"DiracMatrix"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["\[Gamma]", 
        FormBox[
          FormBox["\[Mu]",
            "TraditionalForm"],
          "TraditionalForm"]], TraditionalForm]], "Output",
  CellLabel->"Out[413]=  (21:52:56 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "This is how to enter the non-commutative product of two ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], 
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"]]}], TraditionalForm]]],
  ". The ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Dot \".\" is used as non-commutative multiplication operator."
}], "Text",
  CellTags->"DiracMatrix"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"DiracMatrix", "[", "\[Mu]", "]"}], ".", 
      RowBox[{"DiracMatrix", "[", "\[Nu]", "]"}]}]], "Input",
  CellLabel->"In[414]:=  (21:52:56 on 5/16/01)",
  CellTags->"DiracMatrix"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Nu]",
              "TraditionalForm"],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[414]=  (21:52:56 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"DiracMatrix", "[", "\[Alpha]", "]"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[415]:=  (21:52:56 on 5/16/01)",
  CellTags->"DiracMatrix"],

Cell[BoxData[
    RowBox[{"DiracGamma", "[", 
      RowBox[{"LorentzIndex", "[", "\[Alpha]", "]"}], "]"}]], "Output",
  CellLabel->"Out[415]//StandardForm=  (21:52:56 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"DiracMatrix", "[", "\[Mu]", "]"}], "//", "FCE"}]], "Input",
  CellLabel->"In[416]:=  (21:52:56 on 5/16/01)",
  CellTags->"DiracMatrix"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["\[Gamma]", "\[Mu]"], TraditionalForm]], "Output",
  CellLabel->"Out[416]=  (21:52:56 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "StandardForm"}]], "Input",
  CellLabel->"In[417]:=  (21:52:56 on 5/16/01)",
  CellTags->"DiracMatrix"],

Cell[BoxData[
    RowBox[{"GA", "[", "\[Mu]", "]"}]], "Output",
  CellLabel->"Out[417]//StandardForm=  (21:52:56 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GAD", "[", "\[Mu]", "]"}]], "Input",
  CellLabel->"In[418]:=  (21:52:56 on 5/16/01)",
  CellTags->"DiracMatrix"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["\[Gamma]", "\[Mu]"], TraditionalForm]], "Output",
  CellLabel->"Out[418]=  (21:52:56 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"%", "//", "FCI"}], "//", "StandardForm"}]], "Input",
  CellLabel->"In[419]:=  (21:52:56 on 5/16/01)",
  CellTags->"DiracMatrix"],

Cell[BoxData[
    RowBox[{"DiracGamma", "[", 
      RowBox[{
        RowBox[{"LorentzIndex", "[", 
          RowBox[{"\[Mu]", ",", "D"}], "]"}], ",", "D"}], "]"}]], "Output",
  CellLabel->"Out[419]//StandardForm=  (21:52:56 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GA", "[", 
      RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]"}], "]"}]], "Input",
  CellLabel->"In[420]:=  (21:52:57 on 5/16/01)",
  CellTags->"DiracMatrix"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
        SuperscriptBox["\[Gamma]", "\[Nu]"], ".", 
        SuperscriptBox["\[Gamma]", "\[Rho]"]}], TraditionalForm]], "Output",
  CellLabel->"Out[420]=  (21:52:57 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"GA", "[", 
        RowBox[{"a", " ", ".", " ", "b"}], "]"}], "//", "FCI"}]], "Input",
  CellLabel->"In[421]:=  (21:52:57 on 5/16/01)",
  CellTags->"DiracMatrix"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["a",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["b",
              "TraditionalForm"],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[421]=  (21:52:57 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "StandardForm"}]], "Input",
  CellLabel->"In[422]:=  (21:52:57 on 5/16/01)",
  CellTags->"DiracMatrix"],

Cell[BoxData[
    RowBox[{
      RowBox[{"DiracGamma", "[", 
        RowBox[{"LorentzIndex", "[", "a", "]"}], "]"}], ".", 
      RowBox[{"DiracGamma", "[", 
        RowBox[{"LorentzIndex", "[", "b", "]"}], "]"}]}]], "Output",
  CellLabel->"Out[422]//StandardForm=  (21:52:57 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["DiracOrder", "ObjectName",
  CellTags->"DiracOrder"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"DiracOrder"],

Cell["\<\
DiracOrder[expr] orders the Dirac matrices in expr alphabetically. \
DiracOrder[expr,orderlist] orders the Dirac matrices in expr according to \
orderlist.\
\>", "Text",
  CellTags->"DiracOrder"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["DiracSimplify",
    ButtonData:>"DiracSimplify",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracSimplify"],
  ", ",
  ButtonBox["DiracTrick",
    ButtonData:>"DiracTrick",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracTrick"],
  "."
}], "Text",
  CellTags->"DiracOrder"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"DiracOrder"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t1", " ", "=", " ", 
      RowBox[{"GA", "[", 
        RowBox[{"\[Beta]", ",", "\[Alpha]"}], "]"}]}]], "Input",
  CellLabel->"In[423]:=  (21:52:57 on 5/16/01)",
  CellTags->"DiracOrder"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", "\[Beta]"], ".", 
        SuperscriptBox["\[Gamma]", "\[Alpha]"]}], TraditionalForm]], "Output",\

  CellLabel->"Out[423]=  (21:52:57 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracOrder", "[", "t1", "]"}]], "Input",
  CellLabel->"In[424]:=  (21:52:57 on 5/16/01)",
  CellTags->"DiracOrder"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"2", " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Alpha]", "\[NoBreak]", "\[Beta]"}]]}], "-", 
        RowBox[{
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox["\[Alpha]",
                "TraditionalForm"],
              "TraditionalForm"]], ".", 
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox["\[Beta]",
                "TraditionalForm"],
              "TraditionalForm"]]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[424]=  (21:52:57 on 5/16/01)"]
}, Closed]],

Cell["This is a string of Dirac matrices in D dimensions. ", "Text",
  CellTags->"DiracOrder"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t2", "=", 
      RowBox[{"GAD", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Mu]"}], "]"}]}]], "Input",
  CellLabel->"In[425]:=  (21:52:57 on 5/16/01)",
  CellTags->"DiracOrder"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
        SuperscriptBox["\[Gamma]", "\[Nu]"], ".", 
        SuperscriptBox["\[Gamma]", "\[Mu]"]}], TraditionalForm]], "Output",
  CellLabel->"Out[425]=  (21:52:57 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracOrder", "[", "t1", "]"}]], "Input",
  CellLabel->"In[426]:=  (21:52:57 on 5/16/01)",
  CellTags->"DiracOrder"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"2", " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Alpha]", "\[NoBreak]", "\[Beta]"}]]}], "-", 
        RowBox[{
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox["\[Alpha]",
                "TraditionalForm"],
              "TraditionalForm"]], ".", 
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox["\[Beta]",
                "TraditionalForm"],
              "TraditionalForm"]]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[426]=  (21:52:57 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t3", "=", 
      RowBox[{"GA", "[", 
        RowBox[{"5", ",", "\[Mu]", ",", "\[Nu]"}], "]"}]}]], "Input",
  CellLabel->"In[427]:=  (21:52:57 on 5/16/01)",
  CellTags->"DiracOrder"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", "5"], ".", 
        SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
        SuperscriptBox["\[Gamma]", "\[Nu]"]}], TraditionalForm]], "Output",
  CellLabel->"Out[427]=  (21:52:57 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "By default ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox["\[Gamma]", "5"], " "}], TraditionalForm]]],
  "is moved to the right."
}], "Text",
  CellTags->"DiracOrder"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracOrder", "[", "t3", "]"}]], "Input",
  CellLabel->"In[428]:=  (21:52:58 on 5/16/01)",
  CellTags->"DiracOrder"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Nu]",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        SuperscriptBox["\[Gamma]", "5"]}], TraditionalForm]], "Output",
  CellLabel->"Out[428]=  (21:52:58 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t4", "=", 
      RowBox[{"GA", "[", 
        RowBox[{"6", ",", "\[Mu]", ",", "7"}], "]"}]}]], "Input",
  CellLabel->"In[429]:=  (21:52:58 on 5/16/01)",
  CellTags->"DiracOrder"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", "6"], ".", 
        SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
        SuperscriptBox["\[Gamma]", "7"]}], TraditionalForm]], "Output",
  CellLabel->"Out[429]=  (21:52:58 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracOrder", "[", "t4", "]"}]], "Input",
  CellLabel->"In[430]:=  (21:52:58 on 5/16/01)",
  CellTags->"DiracOrder"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        SuperscriptBox["\[Gamma]", "7"]}], TraditionalForm]], "Output",
  CellLabel->"Out[430]=  (21:52:58 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t5", "=", 
      RowBox[{"GA", "[", 
        RowBox[{"\[Alpha]", ",", "\[Beta]", ",", "\[Delta]"}], 
        "]"}]}]], "Input",
  CellLabel->"In[431]:=  (21:52:58 on 5/16/01)",
  CellTags->"DiracOrder"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", "\[Alpha]"], ".", 
        SuperscriptBox["\[Gamma]", "\[Beta]"], ".", 
        SuperscriptBox["\[Gamma]", "\[Delta]"]}], TraditionalForm]], "Output",\

  CellLabel->"Out[431]=  (21:52:58 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "This orders the ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox["\[Gamma]", "\[Alpha]"], 
          SuperscriptBox["\[Gamma]", "\[Beta]"], 
          SuperscriptBox["\[Gamma]", "\[Delta]"]}], TraditionalForm]]],
  " in reverse order."
}], "Text",
  CellTags->"DiracOrder"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracOrder", "[", 
      RowBox[{"t5", ",", 
        RowBox[{"{", 
          RowBox[{"\[Delta]", ",", "\[Beta]", ",", "\[Alpha]"}], "}"}]}], 
      "]"}]], "Input",
  CellLabel->"In[432]:=  (21:52:58 on 5/16/01)",
  CellTags->"DiracOrder"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Delta]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Beta]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Alpha]",
                  "TraditionalForm"],
                "TraditionalForm"]]}]}], "+", 
        RowBox[{"2", " ", 
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox["\[Delta]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Alpha]", "\[NoBreak]", "\[Beta]"}]]}], "-", 
        RowBox[{"2", " ", 
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox["\[Beta]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Alpha]", "\[NoBreak]", "\[Delta]"}]]}], "+", 
        RowBox[{"2", " ", 
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox["\[Alpha]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Beta]", "\[NoBreak]", "\[Delta]"}]]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[432]=  (21:52:58 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracOrder", "[", "%", "]"}]], "Input",
  CellLabel->"In[433]:=  (21:52:58 on 5/16/01)",
  CellTags->"DiracOrder"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Alpha]",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Beta]",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Delta]",
              "TraditionalForm"],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[433]=  (21:52:58 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      RowBox[{"Clear", "[", 
        RowBox[{"t1", ",", "t2", ",", "t3", ",", "t4", ",", "t5"}], "]"}], 
      ";"}]], "Input",
  CellLabel->"In[434]:=  (21:52:58 on 5/16/01)",
  CellTags->"DiracOrder"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["DiracReduce", "ObjectName",
  CellTags->"DiracReduce"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"DiracReduce"],

Cell["\<\
DiracReduce[exp] reduces all four-dimensional Dirac matrices in exp to the \
standard basis (S,P,V,A,T) using the Chisholm identity (see Chisholm). In the \
result the basic Dirac structures are wrapped with a head DiracBasis. I.e., S \
corresponds to DiracBasis[1], P : DiracBasis[DiracMatrix[5]], V: \
DiracBasis[DiracMatrix[mu]], A: DiracBasis[DiracMatrix[mu, 5]], T: \
DiracBasis[DiracSigma[DiracMatrix[mu, nu]]]. By default DiracBasis is \
substituted to Identity. Notice that the result of DiracReduce is given in \
the FeynCalcExternal - way, i.e.,evtl. you may have to use FeynCalcInternal \
on the result.\
\>", "Text",
  CellTags->"DiracReduce"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "DiracReduce", "]"}]], "Input",
  CellLabel->"In[435]:=  (21:52:59 on 5/16/01)",
  CellTags->"DiracReduce"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"Factoring", "\[Rule]", "False"}], ",", 
          RowBox[{"FinalSubstitutions", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{"DiracBasis", "\[Rule]", "Identity"}], "}"}]}]}], "}"}],
       TraditionalForm]], "Output",
  CellLabel->"Out[435]=  (21:52:59 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["DiracSimplify",
    ButtonData:>"DiracSimplify",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracSimplify"],
  "."
}], "Text",
  CellTags->"DiracReduce"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"DiracReduce"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t1", " ", "=", " ", 
      RowBox[{"GA", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}]}]], "Input",
  CellLabel->"In[436]:=  (21:52:59 on 5/16/01)",
  CellTags->"DiracReduce"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
        SuperscriptBox["\[Gamma]", "\[Nu]"]}], TraditionalForm]], "Output",
  CellLabel->"Out[436]=  (21:52:59 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracReduce", "[", "t1", "]"}]], "Input",
  CellLabel->"In[437]:=  (21:52:59 on 5/16/01)",
  CellTags->"DiracReduce"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["g", 
          RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]], "-", 
        RowBox[{"\[ImaginaryI]", " ", 
          SuperscriptBox["\[Sigma]", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[437]=  (21:52:59 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t2", "=", 
      RowBox[{"DiracMatrix", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]"}], "]"}]}]], "Input",
  CellLabel->"In[438]:=  (21:52:59 on 5/16/01)",
  CellTags->"DiracReduce"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", "\[Mu]"], 
        SuperscriptBox["\[Gamma]", "\[Nu]"], 
        SuperscriptBox["\[Gamma]", "\[Rho]"]}], TraditionalForm]], "Output",
  CellLabel->"Out[438]=  (21:52:59 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracReduce", "[", "t2", "]"}]], "Input",
  CellLabel->"In[439]:=  (21:52:59 on 5/16/01)",
  CellTags->"DiracReduce"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              RowBox[{"$MU", "\[InvisibleApplication]", 
                RowBox[{"(", "1", ")"}]}]], ".", 
            SuperscriptBox["\[Gamma]", "5"]}], " ", 
          SuperscriptBox["\[Epsilon]", 
            RowBox[{
            "\[Mu]", "\[NoBreak]", "\[Nu]", "\[NoBreak]", "\[Rho]", 
              "\[NoBreak]", 
              FormBox[
                RowBox[{"$MU", "\[InvisibleApplication]", 
                  RowBox[{"(", "1", ")"}]}],
                "TraditionalForm"]}]]}], "+", 
        RowBox[{
          SuperscriptBox["\[Gamma]", "\[Rho]"], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]]}], "-", 
        RowBox[{
          SuperscriptBox["\[Gamma]", "\[Nu]"], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Rho]"}]]}], "+", 
        RowBox[{
          SuperscriptBox["\[Gamma]", "\[Mu]"], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Nu]", "\[NoBreak]", "\[Rho]"}]]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[439]=  (21:53:00 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t3", "=", 
      RowBox[{"DiracMatrix", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Sigma]"}], 
        "]"}]}]], "Input",
  CellLabel->"In[440]:=  (21:53:00 on 5/16/01)",
  CellTags->"DiracReduce"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", "\[Mu]"], 
        SuperscriptBox["\[Gamma]", "\[Nu]"], 
        SuperscriptBox["\[Gamma]", "\[Rho]"], 
        SuperscriptBox["\[Gamma]", "\[Sigma]"]}], TraditionalForm]], "Output",\

  CellLabel->"Out[440]=  (21:53:00 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t4", "=", 
      RowBox[{"DiracReduce", "[", "t3", "]"}]}]], "Input",
  CellLabel->"In[441]:=  (21:53:00 on 5/16/01)",
  CellTags->"DiracReduce"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", 
          SuperscriptBox["\[Gamma]", "5"], " ", 
          SuperscriptBox["\[Epsilon]", 
            RowBox[{
            "\[Mu]", "\[NoBreak]", "\[Nu]", "\[NoBreak]", "\[Rho]", 
              "\[NoBreak]", "\[Sigma]"}]]}], "-", 
        RowBox[{"\[ImaginaryI]", " ", 
          SuperscriptBox["\[Sigma]", 
            RowBox[{"\[Rho]", "\[NoBreak]", "\[Sigma]"}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]]}], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
          SuperscriptBox["\[Sigma]", 
            RowBox[{"\[Nu]", "\[NoBreak]", "\[Sigma]"}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Rho]"}]]}], "-", 
        RowBox[{"\[ImaginaryI]", " ", 
          SuperscriptBox["\[Sigma]", 
            RowBox[{"\[Nu]", "\[NoBreak]", "\[Rho]"}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Sigma]"}]]}], "-", 
        RowBox[{"\[ImaginaryI]", " ", 
          SuperscriptBox["\[Sigma]", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Sigma]"}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Nu]", "\[NoBreak]", "\[Rho]"}]]}], "+", 
        RowBox[{
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Sigma]"}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Nu]", "\[NoBreak]", "\[Rho]"}]]}], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
          SuperscriptBox["\[Sigma]", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Rho]"}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Nu]", "\[NoBreak]", "\[Sigma]"}]]}], "-", 
        RowBox[{
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Rho]"}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Nu]", "\[NoBreak]", "\[Sigma]"}]]}], "-", 
        RowBox[{"\[ImaginaryI]", " ", 
          SuperscriptBox["\[Sigma]", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Rho]", "\[NoBreak]", "\[Sigma]"}]]}], "+", 
        RowBox[{
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Rho]", "\[NoBreak]", "\[Sigma]"}]]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[441]=  (21:53:02 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t5", " ", "=", 
      RowBox[{"Calc", "[", 
        RowBox[{"DiracSimplify", "[", 
          RowBox[{"DiracSigmaExplicit", "[", 
            RowBox[{"t4", ".", "t4"}], "]"}], "]"}], "]"}]}]], "Input",
  CellLabel->"In[442]:=  (21:53:03 on 5/16/01)",
  CellTags->"DiracReduce"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", "128"}], TraditionalForm]], "Output",
  CellLabel->"Out[442]=  (21:53:04 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Calc", "[", 
      RowBox[{"t4", ".", "t4"}], "]"}]], "Input",
  CellLabel->"In[443]:=  (21:53:05 on 5/16/01)",
  CellTags->"DiracReduce"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", "128"}], TraditionalForm]], "Output",
  CellLabel->"Out[443]=  (21:53:05 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{"Clear", "[", 
      RowBox[{"t1", ",", "t2", ",", "t3", ",", "t4"}], "]"}]], "Input",
  CellLabel->"In[444]:=  (21:53:05 on 5/16/01)",
  CellTags->"DiracReduce"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["DiracSigmaExplicit", "ObjectName",
  CellTags->"DiracSigmaExplicit"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"DiracSigmaExplicit"],

Cell["\<\
DiracSigmaExplicit[exp] inserts in exp for all DiracSigma its definition. \
DiracSigmaExplict is also an option of DiracSimplify.\
\>", "Text",
  CellTags->"DiracSigmaExplicit"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["DiracSigma",
    ButtonData:>"DiracSigma",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracSigma"],
  "."
}], "Text",
  CellTags->"DiracSigmaExplicit"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"DiracSigmaExplicit"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracSigma", "[", 
      RowBox[{
        RowBox[{"GA", "[", "\[Alpha]", "]"}], ",", 
        RowBox[{"GA", "[", "\[Beta]", "]"}]}], "]"}]], "Input",
  CellLabel->"In[445]:=  (21:53:06 on 5/16/01)",
  CellTags->"DiracSigmaExplicit"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["\[Sigma]", 
        RowBox[{"\[Alpha]", "\[NoBreak]", "\[Beta]"}]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[445]=  (21:53:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracSigmaExplicit", "[", "%", "]"}]], "Input",
  CellLabel->"In[446]:=  (21:53:06 on 5/16/01)",
  CellTags->"DiracSigmaExplicit"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox["\[Gamma]", 
                FormBox[
                  FormBox["\[Alpha]",
                    "TraditionalForm"],
                  "TraditionalForm"]], ".", 
              SuperscriptBox["\[Gamma]", 
                FormBox[
                  FormBox["\[Beta]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], "-", 
            RowBox[{
              SuperscriptBox["\[Gamma]", 
                FormBox[
                  FormBox["\[Beta]",
                    "TraditionalForm"],
                  "TraditionalForm"]], ".", 
              SuperscriptBox["\[Gamma]", 
                FormBox[
                  FormBox["\[Alpha]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[446]=  (21:53:06 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["DiracSigma", "ObjectName",
  CellTags->"DiracSigma"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"DiracSigma"],

Cell["\<\
DiracSigma[a, b] stands for i/2*(a . b - b . a) in 4 dimensions. a and b must \
have Head DiracGamma, DiracMatrix or DiracSlash. Only antisymmetry is \
implemented.\
\>", "Text",
  CellTags->"DiracSigma"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["DiracSigmaExplicit",
    ButtonData:>"DiracSigmaExplicit",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracSigmaExplicit"],
  "."
}], "Text",
  CellTags->"DiracSigma"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"DiracSigma"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t1", "=", 
      RowBox[{"DiracSigma", "[", 
        RowBox[{
          RowBox[{"GA", "[", "\[Alpha]", "]"}], ",", 
          RowBox[{"GA", "[", "\[Beta]", "]"}]}], "]"}]}]], "Input",
  CellLabel->"In[447]:=  (21:53:06 on 5/16/01)",
  CellTags->"DiracSigma"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["\[Sigma]", 
        RowBox[{"\[Alpha]", "\[NoBreak]", "\[Beta]"}]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[447]=  (21:53:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracSigmaExplicit", "[", "t1", "]"}]], "Input",
  CellLabel->"In[448]:=  (21:53:06 on 5/16/01)",
  CellTags->"DiracSigma"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox["\[Gamma]", 
                FormBox[
                  FormBox["\[Alpha]",
                    "TraditionalForm"],
                  "TraditionalForm"]], ".", 
              SuperscriptBox["\[Gamma]", 
                FormBox[
                  FormBox["\[Beta]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], "-", 
            RowBox[{
              SuperscriptBox["\[Gamma]", 
                FormBox[
                  FormBox["\[Beta]",
                    "TraditionalForm"],
                  "TraditionalForm"]], ".", 
              SuperscriptBox["\[Gamma]", 
                FormBox[
                  FormBox["\[Alpha]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[448]=  (21:53:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t2", "=", 
      RowBox[{"DiracSigma", "[", 
        RowBox[{
          RowBox[{"GA", "[", "\[Beta]", "]"}], ",", 
          RowBox[{"GA", "[", "\[Alpha]", "]"}]}], "]"}]}]], "Input",
  CellLabel->"In[449]:=  (21:53:06 on 5/16/01)",
  CellTags->"DiracSigma"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        SuperscriptBox["\[Sigma]", 
          RowBox[{"\[Alpha]", "\[NoBreak]", "\[Beta]"}]]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[449]=  (21:53:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t3", "=", 
      RowBox[{"DiracSigma", "[", 
        RowBox[{
          RowBox[{"GS", "[", "p", "]"}], ",", 
          RowBox[{"GS", "[", "q", "]"}]}], "]"}]}]], "Input",
  CellLabel->"In[450]:=  (21:53:06 on 5/16/01)",
  CellTags->"DiracSigma"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["\[Sigma]", 
        RowBox[{"p", "\[NoBreak]", "q"}]], TraditionalForm]], "Output",
  CellLabel->"Out[450]=  (21:53:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracSigmaExplicit", "[", "t3", "]"}]], "Input",
  CellLabel->"In[451]:=  (21:53:07 on 5/16/01)",
  CellTags->"DiracSigma"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  FormBox["\<\"\[Gamma]\"\>",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["p",
                    "TraditionalForm"]}], ")"}], ".", 
              RowBox[{"(", 
                RowBox[{
                  FormBox["\<\"\[Gamma]\"\>",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  FormBox["\<\"\[Gamma]\"\>",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}], ")"}], ".", 
              RowBox[{"(", 
                RowBox[{
                  FormBox["\<\"\[Gamma]\"\>",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["p",
                    "TraditionalForm"]}], ")"}]}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[451]=  (21:53:07 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{"Clear", "[", 
      RowBox[{"t1", ",", "t2", ",", "t3"}], "]"}]], "Input",
  CellLabel->"In[452]:=  (21:53:07 on 5/16/01)",
  CellTags->"DiracSigma"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["DiracSimplify", "ObjectName",
  CellTags->"DiracSimplify"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"DiracSimplify"],

Cell["\<\
DiracSimplify[expr] simplifies products of Dirac matrices in expr and expands \
non-commutative products. Double Lorentz indices and four vectors are \
contracted. The Dirac equation is applied. All DiracMatrix[5], DiracMatrix[6] \
and DiracMatrix[7] are moved to the right. The order of the other Dirac \
matrices is not changed.\
\>", "Text",
  CellTags->"DiracSimplify"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "DiracSimplify", "]"}]], "Input",
  CellLabel->"In[453]:=  (21:53:07 on 5/16/01)",
  CellTags->"DiracSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"DiracCanonical", "\[Rule]", "False"}], ",", 
          RowBox[{"DiracSigmaExplicit", "\[Rule]", "True"}], ",", 
          RowBox[{"DiracSimpCombine", "\[Rule]", "False"}], ",", 
          RowBox[{"DiracSubstitute67", "\[Rule]", "False"}], ",", 
          RowBox[{"Expanding", "\[Rule]", "True"}], ",", 
          RowBox[{"Factoring", "\[Rule]", "False"}], ",", 
          RowBox[{"FeynCalcInternal", "\[Rule]", "False"}], ",", 
          RowBox[{"InsideDiracTrace", "\[Rule]", "False"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[453]=  (21:53:07 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["Calc",
    ButtonData:>"Calc",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Calc"],
  ", ",
  ButtonBox["DiracGammaExpand",
    ButtonData:>"DiracGammaExpand",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracGammaExpand"],
  ", ",
  ButtonBox["DiracTrick",
    ButtonData:>"DiracTrick",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracTrick"],
  "."
}], "Text",
  CellTags->"DiracSimplify"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"DiracSimplify"],

Cell["This is a string of Dirac matrices in four dimensions. ", "Text",
  CellTags->"DiracSimplify"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t1", "=", 
      RowBox[{"GA", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Mu]"}], "]"}]}]], "Input",
  CellLabel->"In[454]:=  (21:53:07 on 5/16/01)",
  CellTags->"DiracSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
        SuperscriptBox["\[Gamma]", "\[Nu]"], ".", 
        SuperscriptBox["\[Gamma]", "\[Mu]"]}], TraditionalForm]], "Output",
  CellLabel->"Out[454]=  (21:53:07 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracSimplify", "[", "t1", "]"}]], "Input",
  CellLabel->"In[455]:=  (21:53:07 on 5/16/01)",
  CellTags->"DiracSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", "2"}], " ", 
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Nu]",
              "TraditionalForm"],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[455]=  (21:53:07 on 5/16/01)"]
}, Closed]],

Cell["This is a string of Dirac matrices in D dimensions. ", "Text",
  CellTags->"DiracSimplify"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t2", "=", 
      RowBox[{"GAD", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Mu]"}], "]"}]}]], "Input",
  CellLabel->"In[456]:=  (21:53:07 on 5/16/01)",
  CellTags->"DiracSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
        SuperscriptBox["\[Gamma]", "\[Nu]"], ".", 
        SuperscriptBox["\[Gamma]", "\[Mu]"]}], TraditionalForm]], "Output",
  CellLabel->"Out[456]=  (21:53:07 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracSimplify", "[", "t1", "]"}]], "Input",
  CellLabel->"In[457]:=  (21:53:07 on 5/16/01)",
  CellTags->"DiracSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", "2"}], " ", 
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Nu]",
              "TraditionalForm"],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[457]=  (21:53:07 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t3", "=", 
      RowBox[{"GA", "[", 
        RowBox[{"5", ",", "\[Mu]", ",", "\[Nu]"}], "]"}]}]], "Input",
  CellLabel->"In[458]:=  (21:53:07 on 5/16/01)",
  CellTags->"DiracSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", "5"], ".", 
        SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
        SuperscriptBox["\[Gamma]", "\[Nu]"]}], TraditionalForm]], "Output",
  CellLabel->"Out[458]=  (21:53:07 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "By default ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox["\[Gamma]", "5"], TraditionalForm]]],
  "is moved to the right."
}], "Text",
  CellTags->"DiracSimplify"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracSimplify", "[", "t3", "]"}]], "Input",
  CellLabel->"In[459]:=  (21:53:07 on 5/16/01)",
  CellTags->"DiracSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Nu]",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        SuperscriptBox["\[Gamma]", "5"]}], TraditionalForm]], "Output",
  CellLabel->"Out[459]=  (21:53:07 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t4", "=", 
      RowBox[{"GA", "[", 
        RowBox[{"6", ",", "\[Mu]", ",", "7"}], "]"}]}]], "Input",
  CellLabel->"In[460]:=  (21:53:07 on 5/16/01)",
  CellTags->"DiracSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", "6"], ".", 
        SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
        SuperscriptBox["\[Gamma]", "7"]}], TraditionalForm]], "Output",
  CellLabel->"Out[460]=  (21:53:07 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracSimplify", "[", "t4", "]"}]], "Input",
  CellLabel->"In[461]:=  (21:53:08 on 5/16/01)",
  CellTags->"DiracSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        SuperscriptBox["\[Gamma]", "7"]}], TraditionalForm]], "Output",
  CellLabel->"Out[461]=  (21:53:08 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t5", "=", 
      RowBox[{
        RowBox[{"GS", "[", 
          RowBox[{"a", "+", "b"}], "]"}], " ", ".", " ", 
        RowBox[{"GS", "[", "p", "]"}], ".", 
        RowBox[{"GS", "[", "p", "]"}], ".", 
        RowBox[{"GS", "[", 
          RowBox[{"c", "+", "d"}], "]"}]}]}]], "Input",
  CellLabel->"In[462]:=  (21:53:08 on 5/16/01)",
  CellTags->"DiracSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
          "\[Gamma]", "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "(", 
            "\[NoBreak]", 
            FormBox[
              RowBox[{"a", "+", "b"}],
              "TraditionalForm"], "\[NoBreak]", ")"}], ")"}], ".", 
        RowBox[{"(", 
          RowBox[{
          "\[Gamma]", "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "p"}], 
          ")"}], ".", 
        RowBox[{"(", 
          RowBox[{
          "\[Gamma]", "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "p"}], 
          ")"}], ".", 
        RowBox[{"(", 
          RowBox[{
          "\[Gamma]", "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "(", 
            "\[NoBreak]", 
            FormBox[
              RowBox[{"c", "+", "d"}],
              "TraditionalForm"], "\[NoBreak]", ")"}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[462]=  (21:53:08 on 5/16/01)"]
}, Closed]],

Cell["\<\
Contrary to DiracTrick DiracSimplify does non-commutative expansion.\
\>", "Text",
  CellTags->"DiracSimplify"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracSimplify", "[", "t5", "]"}]], "Input",
  CellLabel->"In[463]:=  (21:53:08 on 5/16/01)",
  CellTags->"DiracSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                FormBox["\<\"\[Gamma]\"\>",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["a",
                  "TraditionalForm"]}], ")"}], ".", 
            RowBox[{"(", 
              RowBox[{
                FormBox["\<\"\[Gamma]\"\>",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["c",
                  "TraditionalForm"]}], ")"}]}], " ", 
          SuperscriptBox[
            FormBox["p",
              "TraditionalForm"], "2"]}], "+", 
        RowBox[{
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                FormBox["\<\"\[Gamma]\"\>",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["a",
                  "TraditionalForm"]}], ")"}], ".", 
            RowBox[{"(", 
              RowBox[{
                FormBox["\<\"\[Gamma]\"\>",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["d",
                  "TraditionalForm"]}], ")"}]}], " ", 
          SuperscriptBox[
            FormBox["p",
              "TraditionalForm"], "2"]}], "+", 
        RowBox[{
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                FormBox["\<\"\[Gamma]\"\>",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["b",
                  "TraditionalForm"]}], ")"}], ".", 
            RowBox[{"(", 
              RowBox[{
                FormBox["\<\"\[Gamma]\"\>",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["c",
                  "TraditionalForm"]}], ")"}]}], " ", 
          SuperscriptBox[
            FormBox["p",
              "TraditionalForm"], "2"]}], "+", 
        RowBox[{
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                FormBox["\<\"\[Gamma]\"\>",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["b",
                  "TraditionalForm"]}], ")"}], ".", 
            RowBox[{"(", 
              RowBox[{
                FormBox["\<\"\[Gamma]\"\>",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["d",
                  "TraditionalForm"]}], ")"}]}], " ", 
          SuperscriptBox[
            FormBox["p",
              "TraditionalForm"], "2"]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[463]=  (21:53:08 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracTrick", "[", "t5", "]"}]], "Input",
  CellLabel->"In[464]:=  (21:53:08 on 5/16/01)",
  CellTags->"DiracSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              FormBox["\<\"\[Gamma]\"\>",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", "(", "\[NoBreak]", 
              FormBox[
                RowBox[{"a", "+", "b"}],
                "TraditionalForm"], "\[NoBreak]", ")"}], ")"}], ".", 
          RowBox[{"(", 
            RowBox[{
              FormBox["\<\"\[Gamma]\"\>",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", "(", "\[NoBreak]", 
              FormBox[
                RowBox[{"c", "+", "d"}],
                "TraditionalForm"], "\[NoBreak]", ")"}], ")"}]}], " ", 
        SuperscriptBox[
          FormBox["p",
            "TraditionalForm"], "2"]}], TraditionalForm]], "Output",
  CellLabel->"Out[464]=  (21:53:08 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t6", " ", "=", " ", 
      RowBox[{
        RowBox[{"SpinorVBar", "[", "p", "]"}], " ", ".", " ", 
        RowBox[{"GS", "[", "p", "]"}], " ", ".", " ", 
        RowBox[{"SpinorUBar", "[", "q", "]"}]}]}]], "Input",
  CellLabel->"In[465]:=  (21:53:08 on 5/16/01)",
  CellTags->"DiracSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FormBox[
            OverscriptBox["\<\"v\"\>", "_"],
            "TraditionalForm"], "\[NoBreak]", "(", "\[NoBreak]", "p", 
          "\[NoBreak]", ")"}], ".", 
        RowBox[{"(", 
          RowBox[{
          "\[Gamma]", "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "p"}], 
          ")"}], ".", 
        RowBox[{
          FormBox[
            OverscriptBox["\<\"u\"\>", "_"],
            "TraditionalForm"], "\[NoBreak]", "(", "\[NoBreak]", "q", 
          "\[NoBreak]", ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[465]=  (21:53:08 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracSimplify", "[", "t6", "]"}]], "Input",
  CellLabel->"In[466]:=  (21:53:08 on 5/16/01)",
  CellTags->"DiracSimplify"],

Cell[BoxData[
    FormBox["0", TraditionalForm]], "Output",
  CellLabel->"Out[466]=  (21:53:08 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GAD", "@@", 
      RowBox[{"Join", "[", 
        RowBox[{
          RowBox[{"{", "\[Mu]", "}"}], ",", 
          RowBox[{"Table", "[", 
            RowBox[{
              SubscriptBox["\[Nu]", "i"], ",", 
              RowBox[{"{", 
                RowBox[{"i", ",", "6"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", "\[Mu]", "}"}]}], "]"}]}]], "Input",
  CellLabel->"In[467]:=  (21:53:08 on 5/16/01)",
  CellTags->"DiracSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
        SuperscriptBox["\[Gamma]", 
          SubscriptBox["\[Nu]", "1"]], ".", 
        SuperscriptBox["\[Gamma]", 
          SubscriptBox["\[Nu]", "2"]], ".", 
        SuperscriptBox["\[Gamma]", 
          SubscriptBox["\[Nu]", "3"]], ".", 
        SuperscriptBox["\[Gamma]", 
          SubscriptBox["\[Nu]", "4"]], ".", 
        SuperscriptBox["\[Gamma]", 
          SubscriptBox["\[Nu]", "5"]], ".", 
        SuperscriptBox["\[Gamma]", 
          SubscriptBox["\[Nu]", "6"]], ".", 
        SuperscriptBox["\[Gamma]", "\[Mu]"]}], TraditionalForm]], "Output",
  CellLabel->"Out[467]=  (21:53:08 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracSimplify", "[", "%", "]"}]], "Input",
  CellLabel->"In[468]:=  (21:53:08 on 5/16/01)",
  CellTags->"DiracSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"D", " ", 
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "1"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "2"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "3"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "4"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "5"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "6"],
                  "TraditionalForm"],
                "TraditionalForm"]]}]}], "-", 
        RowBox[{"12", " ", 
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "1"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "2"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "3"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "4"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "5"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "6"],
                  "TraditionalForm"],
                "TraditionalForm"]]}]}], "+", 
        RowBox[{"4", " ", 
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "3"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "4"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "5"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "6"],
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "1"],
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "2"],
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "-", 
        RowBox[{"4", " ", 
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "2"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "4"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "5"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "6"],
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "1"],
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "3"],
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "+", 
        RowBox[{"4", " ", 
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "2"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "3"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "5"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "6"],
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "1"],
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "4"],
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "-", 
        RowBox[{"4", " ", 
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "2"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "3"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "4"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "6"],
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "1"],
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "5"],
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "+", 
        RowBox[{"4", " ", 
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "2"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "3"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "4"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "5"],
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "1"],
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "6"],
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "+", 
        RowBox[{"4", " ", 
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "1"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "4"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "5"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "6"],
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "2"],
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "3"],
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "-", 
        RowBox[{"4", " ", 
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "1"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "3"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "5"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "6"],
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "2"],
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "4"],
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "+", 
        RowBox[{"4", " ", 
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "1"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "3"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "4"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "6"],
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "2"],
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "5"],
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "-", 
        RowBox[{"4", " ", 
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "1"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "3"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "4"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "5"],
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "2"],
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "6"],
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "+", 
        RowBox[{"4", " ", 
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "1"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "2"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "5"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "6"],
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "3"],
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "4"],
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "-", 
        RowBox[{"4", " ", 
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "1"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "2"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "4"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "6"],
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "3"],
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "5"],
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "+", 
        RowBox[{"4", " ", 
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "1"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "2"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "4"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "5"],
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "3"],
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "6"],
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "+", 
        RowBox[{"4", " ", 
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "1"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "2"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "3"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "6"],
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "4"],
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "5"],
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "-", 
        RowBox[{"4", " ", 
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "1"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "2"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "3"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "5"],
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "4"],
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "6"],
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "+", 
        RowBox[{"4", " ", 
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "1"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "2"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "3"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "4"],
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "5"],
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "6"],
                  "TraditionalForm"],
                "TraditionalForm"]}]]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[468]=  (21:53:10 on 5/16/01)"]
}, Closed]],

Cell["\<\
 With the option DiracCanonical an alphabetic ordering is done.\
\>", "Text",
  CellTags->"DiracSimplify"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracSimplify", "[", 
      RowBox[{
        RowBox[{"GA", "[", 
          RowBox[{"\[Nu]", ",", "\[Mu]"}], "]"}], ",", 
        RowBox[{"DiracCanonical", "\[Rule]", "True"}]}], "]"}]], "Input",
  CellLabel->"In[469]:=  (21:53:10 on 5/16/01)",
  CellTags->"DiracSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"2", " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]]}], "-", 
        RowBox[{
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], ".", 
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"]]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[469]=  (21:53:10 on 5/16/01)"]
}, Closed]],

Cell["\<\
Setting InsideDiracTrace\[Rule]True assumes that a trace is still to be taken \
later on.\
\>", "Text",
  CellTags->"DiracSimplify"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracSimplify", "[", 
      RowBox[{
        RowBox[{"GA", "[", 
          RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Sigma]"}], 
          "]"}], ",", 
        RowBox[{"InsideDiracTrace", "\[Rule]", "True"}]}], "]"}]], "Input",
  CellLabel->"In[470]:=  (21:53:10 on 5/16/01)",
  CellTags->"DiracSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Sigma]"}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Nu]", "\[NoBreak]", "\[Rho]"}]]}], "-", 
        RowBox[{
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Rho]"}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Nu]", "\[NoBreak]", "\[Sigma]"}]]}], "+", 
        RowBox[{
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Rho]", "\[NoBreak]", "\[Sigma]"}]]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[470]=  (21:53:10 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracSimplify", "[", 
      RowBox[{
        RowBox[{"GA", "[", 
          RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]"}], "]"}], ",", 
        RowBox[{"InsideDiracTrace", "\[Rule]", "True"}]}], "]"}]], "Input",
  CellLabel->"In[471]:=  (21:53:10 on 5/16/01)",
  CellTags->"DiracSimplify"],

Cell[BoxData[
    FormBox["0", TraditionalForm]], "Output",
  CellLabel->"Out[471]=  (21:53:10 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{"Clear", "[", 
      RowBox[{"t1", ",", "t2", ",", "t3", ",", "t4", ",", "t5", ",", "t6"}], 
      "]"}]], "Input",
  CellLabel->"In[472]:=  (21:53:10 on 5/16/01)",
  CellTags->"DiracSimplify"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["DiracSimplify2", "ObjectName",
  CellTags->"DiracSimplify2"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"DiracSimplify2"],

Cell[TextData[{
  "DiracSimplify2[exp] simplifies the Dirac structure but leaves any ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox["\[Gamma]", "5"], TraditionalForm]]],
  " untouched."
}], "Text",
  CellTags->"DiracSimplify2"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["DiracSimplify",
    ButtonData:>"DiracSimplify",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracSimplify"],
  "."
}], "Text",
  CellTags->"DiracSimplify2"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"DiracSimplify2"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GAD", "[", 
      RowBox[{
      "\[Mu]", ",", "\[Nu]", ",", "\[Mu]", ",", "5", ",", "\[Alpha]", ",", 
        "\[Beta]", ",", "\[Alpha]"}], "]"}]], "Input",
  CellLabel->"In[473]:=  (21:53:10 on 5/16/01)",
  CellTags->"DiracSimplify2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
        SuperscriptBox["\[Gamma]", "\[Nu]"], ".", 
        SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
        SuperscriptBox["\[Gamma]", "5"], ".", 
        SuperscriptBox["\[Gamma]", "\[Alpha]"], ".", 
        SuperscriptBox["\[Gamma]", "\[Beta]"], ".", 
        SuperscriptBox["\[Gamma]", "\[Alpha]"]}], TraditionalForm]], "Output",\

  CellLabel->"Out[473]=  (21:53:10 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracSimplify2", "[", "%", "]"}]], "Input",
  CellLabel->"In[474]:=  (21:53:10 on 5/16/01)",
  CellTags->"DiracSimplify2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Nu]",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        SuperscriptBox["\[Gamma]", "5"], ".", 
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Alpha]",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Beta]",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Alpha]",
              "TraditionalForm"],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[474]=  (21:53:10 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["DiracSlash", "ObjectName",
  CellTags->"DiracSlash"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"DiracSlash"],

Cell[TextData[{
  "DiracSlash[p] is the contraction ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SuperscriptBox["p", "\[Mu]"], 
            SubscriptBox["\[Gamma]", "\[Mu]"]}], " "}], TraditionalForm]]],
  "(FourVector[p, ",
  Cell[BoxData[
      FormBox["\[Mu]", TraditionalForm]]],
  "] DiracMatrix[",
  Cell[BoxData[
      FormBox["\[Mu]", TraditionalForm]]],
  "]). Products of those can be entered in the form DiracSlash[p1, p2, ...]."
}], "Text",
  CellTags->"DiracSlash"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "DiracSlash", "]"}]], "Input",
  CellLabel->"In[475]:=  (21:53:10 on 5/16/01)",
  CellTags->"DiracSlash"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"Dimension", "\[Rule]", "4"}], ",", 
          RowBox[{"FeynCalcInternal", "\[Rule]", "True"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[475]=  (21:53:10 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["DiracGammaExpand",
    ButtonData:>"DiracGammaExpand",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracGammaExpand"],
  ", ",
  ButtonBox["DiracGamma",
    ButtonData:>"DiracGamma",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracGamma"],
  ", ",
  ButtonBox["DiracMatrix",
    ButtonData:>"DiracMatrix",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracMatrix"],
  ", ",
  ButtonBox["DiracSimplify",
    ButtonData:>"DiracSimplify",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracSimplify"],
  ", ",
  ButtonBox["DiracTrick",
    ButtonData:>"DiracTrick",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracTrick"],
  ", ",
  ButtonBox["GS",
    ButtonData:>"GS",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"GS"],
  ", ",
  ButtonBox["GSD",
    ButtonData:>"GSD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"GSD"],
  "."
}], "Text",
  CellTags->"DiracSlash"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"DiracSlash"],

Cell[TextData[{
  "This is q-slash, i.e., ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox["\[Gamma]", "\[Mu]"], 
          RowBox[{
            SubscriptBox["q", "\[Mu]"], "."}]}], TraditionalForm]]]
}], "Text",
  CellTags->"DiracSlash"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracSlash", "[", "q", "]"}]], "Input",
  CellLabel->"In[476]:=  (21:53:10 on 5/16/01)",
  CellTags->"DiracSlash"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox["\<\"\[Gamma]\"\>",
          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
        FormBox["q",
          "TraditionalForm"]}], TraditionalForm]], "Output",
  CellLabel->"Out[476]=  (21:53:10 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"DiracSlash", "[", "p", "]"}], ".", 
      RowBox[{"DiracSlash", "[", "q", "]"}]}]], "Input",
  CellLabel->"In[477]:=  (21:53:10 on 5/16/01)",
  CellTags->"DiracSlash"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            FormBox["\<\"\[Gamma]\"\>",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["p",
              "TraditionalForm"]}], ")"}], ".", 
        RowBox[{"(", 
          RowBox[{
            FormBox["\<\"\[Gamma]\"\>",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["q",
              "TraditionalForm"]}], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[477]=  (21:53:10 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracSlash", "[", 
      RowBox[{"p", ",", "q"}], "]"}]], "Input",
  CellLabel->"In[478]:=  (21:53:10 on 5/16/01)",
  CellTags->"DiracSlash"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            FormBox["\<\"\[Gamma]\"\>",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["p",
              "TraditionalForm"]}], ")"}], ".", 
        RowBox[{"(", 
          RowBox[{
            FormBox["\<\"\[Gamma]\"\>",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["q",
              "TraditionalForm"]}], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[478]=  (21:53:10 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GS", "[", "p", "]"}]], "Input",
  CellLabel->"In[479]:=  (21:53:10 on 5/16/01)",
  CellTags->"DiracSlash"],

Cell[BoxData[
    FormBox[
      RowBox[{"\[Gamma]", "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "p"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[479]=  (21:53:10 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"DiracSlash", "[", "q", "]"}], "//", "StandardForm"}]], "Input",\

  CellLabel->"In[480]:=  (21:53:10 on 5/16/01)",
  CellTags->"DiracSlash"],

Cell[BoxData[
    RowBox[{"DiracGamma", "[", 
      RowBox[{"Momentum", "[", "q", "]"}], "]"}]], "Output",
  CellLabel->"Out[480]//StandardForm=  (21:53:10 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"DiracSlash", "[", 
        RowBox[{"q", ",", 
          RowBox[{"Dimension", "->", "n"}]}], "]"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[481]:=  (21:53:11 on 5/16/01)",
  CellTags->"DiracSlash"],

Cell[BoxData[
    RowBox[{"DiracGamma", "[", 
      RowBox[{
        RowBox[{"Momentum", "[", 
          RowBox[{"q", ",", "n"}], "]"}], ",", "n"}], "]"}]], "Output",
  CellLabel->"Out[481]//StandardForm=  (21:53:11 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["DiracTrace", "ObjectName",
  CellTags->"DiracTrace"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"DiracTrace"],

Cell["\<\
DiracTrace[expr] is the head of Dirac Traces. Whether the trace is evaluated \
depends on the option DiracTraceEvaluate. Direct trace evaluation is \
performed by Tr. The argument expr may be a product of Dirac matrices or \
slashes separated by the Mathematica Dot \".\".\
\>", "Text",
  CellTags->"DiracTrace"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "DiracTrace", "]"}]], "Input",
  CellLabel->"In[482]:=  (21:53:11 on 5/16/01)",
  CellTags->"DiracTrace"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"EpsContract", "\[Rule]", "False"}], ",", 
          RowBox[{"Factoring", "\[Rule]", "False"}], ",", 
          RowBox[{"FeynCalcExternal", "\[Rule]", "False"}], ",", 
          RowBox[{"Mandelstam", "\[Rule]", 
            RowBox[{"{", "}"}]}], ",", 
          RowBox[{"PairCollect", "\[Rule]", "True"}], ",", 
          RowBox[{"DiracTraceEvaluate", "\[Rule]", "False"}], ",", 
          RowBox[{"Schouten", "\[Rule]", "0"}], ",", 
          RowBox[{"LeviCivitaSign", "\[Rule]", 
            RowBox[{"-", "1"}]}]}], "}"}], TraditionalForm]], "Output",
  CellLabel->"Out[482]=  (21:53:11 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "For comments regarding ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox["\[Gamma]", "5"], TraditionalForm]]],
  "schemes see the notes for ",
  ButtonBox["Tr",
    ButtonData:>"Tr",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Tr"],
  "."
}], "Text",
  CellTags->"DiracTrace"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["Tr",
    ButtonData:>"Tr",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Tr"],
  "."
}], "Text",
  CellTags->"DiracTrace"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"DiracTrace"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracTrace", "[", 
      RowBox[{"GA", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], "]"}]], "Input",
  CellLabel->"In[483]:=  (21:53:11 on 5/16/01)",
  CellTags->"DiracTrace"],

Cell[BoxData[
    FormBox[
      RowBox[{"tr", "(", 
        FormBox[
          RowBox[{
            SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
            SuperscriptBox["\[Gamma]", "\[Nu]"]}],
          "TraditionalForm"], ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[483]=  (21:53:11 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracTrace", "[", 
      RowBox[{"GA", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Sigma]"}], 
        "]"}], "]"}]], "Input",
  CellLabel->"In[484]:=  (21:53:11 on 5/16/01)",
  CellTags->"DiracTrace"],

Cell[BoxData[
    FormBox[
      RowBox[{"tr", "(", 
        FormBox[
          RowBox[{
            SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
            SuperscriptBox["\[Gamma]", "\[Nu]"], ".", 
            SuperscriptBox["\[Gamma]", "\[Rho]"], ".", 
            SuperscriptBox["\[Gamma]", "\[Sigma]"]}],
          "TraditionalForm"], ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[484]=  (21:53:11 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", " ", "/.", " ", 
      RowBox[{"DiracTrace", "\[Rule]", "Tr"}]}]], "Input",
  CellLabel->"In[485]:=  (21:53:11 on 5/16/01)",
  CellTags->"DiracTrace"],

Cell[BoxData[
    FormBox[
      RowBox[{"4", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox["g", 
                RowBox[{"\[Mu]", "\[NoBreak]", "\[Sigma]"}]], " ", 
              SuperscriptBox["g", 
                RowBox[{"\[Nu]", "\[NoBreak]", "\[Rho]"}]]}], "-", 
            RowBox[{
              SuperscriptBox["g", 
                RowBox[{"\[Mu]", "\[NoBreak]", "\[Rho]"}]], " ", 
              SuperscriptBox["g", 
                RowBox[{"\[Nu]", "\[NoBreak]", "\[Sigma]"}]]}], "+", 
            RowBox[{
              SuperscriptBox["g", 
                RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]], " ", 
              SuperscriptBox["g", 
                RowBox[{"\[Rho]", "\[NoBreak]", "\[Sigma]"}]]}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[485]=  (21:53:11 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracTrace", "[", 
      RowBox[{
        RowBox[{"GA", "[", 
          RowBox[{
          "\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Sigma]", ",", "5"}], 
          "]"}], ",", 
        RowBox[{"DiracTraceEvaluate", "\[Rule]", "True"}]}], "]"}]], "Input",
  CellLabel->"In[486]:=  (21:53:11 on 5/16/01)",
  CellTags->"DiracTrace"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", "4"}], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[Epsilon]", 
          RowBox[{
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["\[Rho]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["\[Sigma]",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[486]=  (21:53:11 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracTrace", "[", 
      RowBox[{
        RowBox[{"GA", "[", 
          RowBox[{
          "\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Sigma]", ",", 
            "\[Delta]", ",", "\[Tau]", ",", "5"}], "]"}], ",", 
        RowBox[{"DiracTraceEvaluate", "\[Rule]", "True"}]}], "]"}]], "Input",
  CellLabel->"In[487]:=  (21:53:11 on 5/16/01)",
  CellTags->"DiracTrace"],

Cell[BoxData[
    FormBox[
      RowBox[{"4", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"\[ImaginaryI]", " ", 
              SuperscriptBox["\[Epsilon]", 
                RowBox[{
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Tau]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox["g", 
                RowBox[{"\[Delta]", "\[NoBreak]", "\[Mu]"}]]}], "-", 
            RowBox[{"\[ImaginaryI]", " ", 
              SuperscriptBox["\[Epsilon]", 
                RowBox[{
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Tau]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox["g", 
                RowBox[{"\[Delta]", "\[NoBreak]", "\[Nu]"}]]}], "+", 
            RowBox[{"\[ImaginaryI]", " ", 
              SuperscriptBox["\[Epsilon]", 
                RowBox[{
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Tau]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox["g", 
                RowBox[{"\[Delta]", "\[NoBreak]", "\[Rho]"}]]}], "-", 
            RowBox[{"\[ImaginaryI]", " ", 
              SuperscriptBox["\[Epsilon]", 
                RowBox[{
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Tau]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox["g", 
                RowBox[{"\[Delta]", "\[NoBreak]", "\[Sigma]"}]]}], "-", 
            RowBox[{"\[ImaginaryI]", " ", 
              SuperscriptBox["\[Epsilon]", 
                RowBox[{
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox["g", 
                RowBox[{"\[Delta]", "\[NoBreak]", "\[Tau]"}]]}], "-", 
            RowBox[{"\[ImaginaryI]", " ", 
              SuperscriptBox["\[Epsilon]", 
                RowBox[{
                  FormBox[
                    FormBox["\[Delta]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Tau]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox["g", 
                RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]]}], "+", 
            RowBox[{"\[ImaginaryI]", " ", 
              SuperscriptBox["\[Epsilon]", 
                RowBox[{
                  FormBox[
                    FormBox["\[Delta]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Tau]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox["g", 
                RowBox[{"\[Mu]", "\[NoBreak]", "\[Rho]"}]]}], "-", 
            RowBox[{"\[ImaginaryI]", " ", 
              SuperscriptBox["\[Epsilon]", 
                RowBox[{
                  FormBox[
                    FormBox["\[Delta]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Tau]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox["g", 
                RowBox[{"\[Mu]", "\[NoBreak]", "\[Sigma]"}]]}], "+", 
            RowBox[{"\[ImaginaryI]", " ", 
              SuperscriptBox["\[Epsilon]", 
                RowBox[{
                  FormBox[
                    FormBox["\[Delta]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox["g", 
                RowBox[{"\[Mu]", "\[NoBreak]", "\[Tau]"}]]}], "-", 
            RowBox[{"\[ImaginaryI]", " ", 
              SuperscriptBox["\[Epsilon]", 
                RowBox[{
                  FormBox[
                    FormBox["\[Delta]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Tau]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox["g", 
                RowBox[{"\[Nu]", "\[NoBreak]", "\[Rho]"}]]}], "+", 
            RowBox[{"\[ImaginaryI]", " ", 
              SuperscriptBox["\[Epsilon]", 
                RowBox[{
                  FormBox[
                    FormBox["\[Delta]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Tau]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox["g", 
                RowBox[{"\[Nu]", "\[NoBreak]", "\[Sigma]"}]]}], "-", 
            RowBox[{"\[ImaginaryI]", " ", 
              SuperscriptBox["\[Epsilon]", 
                RowBox[{
                  FormBox[
                    FormBox["\[Delta]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox["g", 
                RowBox[{"\[Nu]", "\[NoBreak]", "\[Tau]"}]]}], "-", 
            RowBox[{"\[ImaginaryI]", " ", 
              SuperscriptBox["\[Epsilon]", 
                RowBox[{
                  FormBox[
                    FormBox["\[Delta]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Tau]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox["g", 
                RowBox[{"\[Rho]", "\[NoBreak]", "\[Sigma]"}]]}], "+", 
            RowBox[{"\[ImaginaryI]", " ", 
              SuperscriptBox["\[Epsilon]", 
                RowBox[{
                  FormBox[
                    FormBox["\[Delta]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox["g", 
                RowBox[{"\[Rho]", "\[NoBreak]", "\[Tau]"}]]}], "-", 
            RowBox[{"\[ImaginaryI]", " ", 
              SuperscriptBox["\[Epsilon]", 
                RowBox[{
                  FormBox[
                    FormBox["\[Delta]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox["g", 
                RowBox[{"\[Sigma]", "\[NoBreak]", "\[Tau]"}]]}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[487]=  (21:53:11 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracTrace", "[", 
      RowBox[{"GS", "[", 
        RowBox[{"p", ",", "q", ",", "r", ",", "s"}], "]"}], "]"}]], "Input",
  CellLabel->"In[488]:=  (21:53:11 on 5/16/01)",
  CellTags->"DiracTrace"],

Cell[BoxData[
    FormBox[
      RowBox[{"tr", "(", 
        FormBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
              "\[Gamma]", "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "p"}], 
              ")"}], ".", 
            RowBox[{"(", 
              RowBox[{
              "\[Gamma]", "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "q"}], 
              ")"}], ".", 
            RowBox[{"(", 
              RowBox[{
              "\[Gamma]", "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "r"}], 
              ")"}], ".", 
            RowBox[{"(", 
              RowBox[{
              "\[Gamma]", "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "s"}], 
              ")"}]}],
          "TraditionalForm"], ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[488]=  (21:53:11 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracTrace", "[", 
      RowBox[{
        RowBox[{"GA", "[", 
          RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], ",", 
        RowBox[{"DiracTraceEvaluate", "\[Rule]", "True"}], ",", 
        RowBox[{"FCE", "\[Rule]", "True"}]}], "]"}]], "Input",
  CellLabel->"In[489]:=  (21:53:11 on 5/16/01)",
  CellTags->"DiracTrace"],

Cell[BoxData[
    FormBox[
      RowBox[{"4", " ", 
        SuperscriptBox["g", 
          RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[489]=  (21:53:11 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "StandardForm"}]], "Input",
  CellLabel->"In[490]:=  (21:53:11 on 5/16/01)",
  CellTags->"DiracTrace"],

Cell[BoxData[
    RowBox[{"4", " ", 
      RowBox[{"MT", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}]}]], "Output",
  CellLabel->"Out[490]//StandardForm=  (21:53:11 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["DiracTrick", "ObjectName",
  CellTags->"DiracTrick"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"DiracTrick"],

Cell["\<\
DiracTrick[exp] contracts gamma matrices with each other and performs several \
simplifications, but no expansion, use Calc or DiracSimplify for \
non-commutative expansion.\
\>", "Text",
  CellTags->"DiracTrick"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "DiracTrick", "]"}]], "Input",
  CellLabel->"In[491]:=  (21:53:11 on 5/16/01)",
  CellTags->"DiracTrick"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"Expanding", "\[Rule]", "False"}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[491]=  (21:53:11 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["Calc",
    ButtonData:>"Calc",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Calc"],
  ", ",
  ButtonBox["DiracGammaExpand",
    ButtonData:>"DiracGammaExpand",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracGammaExpand"],
  ", ",
  ButtonBox["DiracSimplify",
    ButtonData:>"DiracSimplify",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracSimplify"],
  "."
}], "Text",
  CellTags->"DiracTrick"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"DiracTrick"],

Cell["This is a string of Dirac matrices in four dimensions. ", "Text",
  CellTags->"DiracTrick"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t1", "=", 
      RowBox[{"GA", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Mu]"}], "]"}]}]], "Input",
  CellLabel->"In[492]:=  (21:53:11 on 5/16/01)",
  CellTags->"DiracTrick"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
        SuperscriptBox["\[Gamma]", "\[Nu]"], ".", 
        SuperscriptBox["\[Gamma]", "\[Mu]"]}], TraditionalForm]], "Output",
  CellLabel->"Out[492]=  (21:53:11 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracTrick", "[", "t1", "]"}]], "Input",
  CellLabel->"In[493]:=  (21:53:11 on 5/16/01)",
  CellTags->"DiracTrick"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", "2"}], " ", 
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Nu]",
              "TraditionalForm"],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[493]=  (21:53:11 on 5/16/01)"]
}, Closed]],

Cell["This is a string of Dirac matrices in D dimensions. ", "Text",
  CellTags->"DiracTrick"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t2", "=", 
      RowBox[{"GAD", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Mu]"}], "]"}]}]], "Input",
  CellLabel->"In[494]:=  (21:53:12 on 5/16/01)",
  CellTags->"DiracTrick"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
        SuperscriptBox["\[Gamma]", "\[Nu]"], ".", 
        SuperscriptBox["\[Gamma]", "\[Mu]"]}], TraditionalForm]], "Output",
  CellLabel->"Out[494]=  (21:53:12 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracTrick", "[", "t2", "]"}]], "Input",
  CellLabel->"In[495]:=  (21:53:12 on 5/16/01)",
  CellTags->"DiracTrick"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"(", 
          RowBox[{"2", "-", "D"}], ")"}], " ", 
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Nu]",
              "TraditionalForm"],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[495]=  (21:53:12 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t3", "=", 
      RowBox[{"GA", "[", 
        RowBox[{"5", ",", "\[Mu]", ",", "\[Nu]"}], "]"}]}]], "Input",
  CellLabel->"In[496]:=  (21:53:12 on 5/16/01)",
  CellTags->"DiracTrick"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", "5"], ".", 
        SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
        SuperscriptBox["\[Gamma]", "\[Nu]"]}], TraditionalForm]], "Output",
  CellLabel->"Out[496]=  (21:53:12 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "By default ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox["\[Gamma]", "5"], TraditionalForm]]],
  "is moved to the right."
}], "Text",
  CellTags->"DiracTrick"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracTrick", "[", "t3", "]"}]], "Input",
  CellLabel->"In[497]:=  (21:53:12 on 5/16/01)",
  CellTags->"DiracTrick"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Nu]",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        SuperscriptBox["\[Gamma]", "5"]}], TraditionalForm]], "Output",
  CellLabel->"Out[497]=  (21:53:12 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t4", "=", 
      RowBox[{"GA", "[", 
        RowBox[{"6", ",", "\[Mu]", ",", "7"}], "]"}]}]], "Input",
  CellLabel->"In[498]:=  (21:53:12 on 5/16/01)",
  CellTags->"DiracTrick"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", "6"], ".", 
        SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
        SuperscriptBox["\[Gamma]", "7"]}], TraditionalForm]], "Output",
  CellLabel->"Out[498]=  (21:53:12 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracTrick", "[", "t4", "]"}]], "Input",
  CellLabel->"In[499]:=  (21:53:12 on 5/16/01)",
  CellTags->"DiracTrick"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        SuperscriptBox["\[Gamma]", "7"]}], TraditionalForm]], "Output",
  CellLabel->"Out[499]=  (21:53:12 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t5", "=", 
      RowBox[{
        RowBox[{"GS", "[", 
          RowBox[{"a", "+", "b"}], "]"}], " ", ".", " ", 
        RowBox[{"GS", "[", "p", "]"}], ".", 
        RowBox[{"GS", "[", "p", "]"}], ".", 
        RowBox[{"GS", "[", 
          RowBox[{"c", "+", "d"}], "]"}]}]}]], "Input",
  CellLabel->"In[500]:=  (21:53:12 on 5/16/01)",
  CellTags->"DiracTrick"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
          "\[Gamma]", "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "(", 
            "\[NoBreak]", 
            FormBox[
              RowBox[{"a", "+", "b"}],
              "TraditionalForm"], "\[NoBreak]", ")"}], ")"}], ".", 
        RowBox[{"(", 
          RowBox[{
          "\[Gamma]", "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "p"}], 
          ")"}], ".", 
        RowBox[{"(", 
          RowBox[{
          "\[Gamma]", "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "p"}], 
          ")"}], ".", 
        RowBox[{"(", 
          RowBox[{
          "\[Gamma]", "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "(", 
            "\[NoBreak]", 
            FormBox[
              RowBox[{"c", "+", "d"}],
              "TraditionalForm"], "\[NoBreak]", ")"}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[500]=  (21:53:12 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracTrick", "[", "t5", "]"}]], "Input",
  CellLabel->"In[501]:=  (21:53:12 on 5/16/01)",
  CellTags->"DiracTrick"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              FormBox["\<\"\[Gamma]\"\>",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", "(", "\[NoBreak]", 
              FormBox[
                RowBox[{"a", "+", "b"}],
                "TraditionalForm"], "\[NoBreak]", ")"}], ")"}], ".", 
          RowBox[{"(", 
            RowBox[{
              FormBox["\<\"\[Gamma]\"\>",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", "(", "\[NoBreak]", 
              FormBox[
                RowBox[{"c", "+", "d"}],
                "TraditionalForm"], "\[NoBreak]", ")"}], ")"}]}], " ", 
        SuperscriptBox[
          FormBox["p",
            "TraditionalForm"], "2"]}], TraditionalForm]], "Output",
  CellLabel->"Out[501]=  (21:53:12 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Calc", "[", "t5", "]"}]], "Input",
  CellLabel->"In[502]:=  (21:53:12 on 5/16/01)",
  CellTags->"DiracTrick"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                FormBox["\<\"\[Gamma]\"\>",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["a",
                  "TraditionalForm"]}], ")"}], ".", 
            RowBox[{"(", 
              RowBox[{
                FormBox["\<\"\[Gamma]\"\>",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["c",
                  "TraditionalForm"]}], ")"}]}], " ", 
          SuperscriptBox[
            FormBox["p",
              "TraditionalForm"], "2"]}], "+", 
        RowBox[{
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                FormBox["\<\"\[Gamma]\"\>",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["a",
                  "TraditionalForm"]}], ")"}], ".", 
            RowBox[{"(", 
              RowBox[{
                FormBox["\<\"\[Gamma]\"\>",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["d",
                  "TraditionalForm"]}], ")"}]}], " ", 
          SuperscriptBox[
            FormBox["p",
              "TraditionalForm"], "2"]}], "+", 
        RowBox[{
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                FormBox["\<\"\[Gamma]\"\>",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["b",
                  "TraditionalForm"]}], ")"}], ".", 
            RowBox[{"(", 
              RowBox[{
                FormBox["\<\"\[Gamma]\"\>",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["c",
                  "TraditionalForm"]}], ")"}]}], " ", 
          SuperscriptBox[
            FormBox["p",
              "TraditionalForm"], "2"]}], "+", 
        RowBox[{
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                FormBox["\<\"\[Gamma]\"\>",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["b",
                  "TraditionalForm"]}], ")"}], ".", 
            RowBox[{"(", 
              RowBox[{
                FormBox["\<\"\[Gamma]\"\>",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["d",
                  "TraditionalForm"]}], ")"}]}], " ", 
          SuperscriptBox[
            FormBox["p",
              "TraditionalForm"], "2"]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[502]=  (21:53:12 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GAD", "@@", 
      RowBox[{"Join", "[", 
        RowBox[{
          RowBox[{"{", "\[Mu]", "}"}], ",", 
          RowBox[{"Table", "[", 
            RowBox[{
              SubscriptBox["\[Nu]", "i"], ",", 
              RowBox[{"{", 
                RowBox[{"i", ",", "6"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", "\[Mu]", "}"}]}], "]"}]}]], "Input",
  CellLabel->"In[503]:=  (21:53:12 on 5/16/01)",
  CellTags->"DiracTrick"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
        SuperscriptBox["\[Gamma]", 
          SubscriptBox["\[Nu]", "1"]], ".", 
        SuperscriptBox["\[Gamma]", 
          SubscriptBox["\[Nu]", "2"]], ".", 
        SuperscriptBox["\[Gamma]", 
          SubscriptBox["\[Nu]", "3"]], ".", 
        SuperscriptBox["\[Gamma]", 
          SubscriptBox["\[Nu]", "4"]], ".", 
        SuperscriptBox["\[Gamma]", 
          SubscriptBox["\[Nu]", "5"]], ".", 
        SuperscriptBox["\[Gamma]", 
          SubscriptBox["\[Nu]", "6"]], ".", 
        SuperscriptBox["\[Gamma]", "\[Mu]"]}], TraditionalForm]], "Output",
  CellLabel->"Out[503]=  (21:53:12 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracTrick", "[", "%", "]"}]], "Input",
  CellLabel->"In[504]:=  (21:53:12 on 5/16/01)",
  CellTags->"DiracTrick"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{"D", "-", "12"}], ")"}], " ", 
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "1"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "2"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "3"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "4"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "5"],
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox[
                  SubscriptBox["\[Nu]", "6"],
                  "TraditionalForm"],
                "TraditionalForm"]]}]}], "-", 
        RowBox[{"4", " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  RowBox[{
                    SuperscriptBox["\[Gamma]", 
                      FormBox[
                        FormBox[
                          SubscriptBox["\[Nu]", "3"],
                          "TraditionalForm"],
                        "TraditionalForm"]], ".", 
                    SuperscriptBox["\[Gamma]", 
                      FormBox[
                        FormBox[
                          SubscriptBox["\[Nu]", "4"],
                          "TraditionalForm"],
                        "TraditionalForm"]], ".", 
                    SuperscriptBox["\[Gamma]", 
                      FormBox[
                        FormBox[
                          SubscriptBox["\[Nu]", "5"],
                          "TraditionalForm"],
                        "TraditionalForm"]], ".", 
                    SuperscriptBox["\[Gamma]", 
                      FormBox[
                        FormBox[
                          SubscriptBox["\[Nu]", "6"],
                          "TraditionalForm"],
                        "TraditionalForm"]]}]}], " ", 
                SuperscriptBox["g", 
                  RowBox[{
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "1"],
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "2"],
                        "TraditionalForm"],
                      "TraditionalForm"]}]]}], "+", 
              RowBox[{
                RowBox[{
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "2"],
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "4"],
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "5"],
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "6"],
                        "TraditionalForm"],
                      "TraditionalForm"]]}], " ", 
                SuperscriptBox["g", 
                  RowBox[{
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "1"],
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "3"],
                        "TraditionalForm"],
                      "TraditionalForm"]}]]}], "-", 
              RowBox[{
                RowBox[{
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "2"],
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "3"],
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "5"],
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "6"],
                        "TraditionalForm"],
                      "TraditionalForm"]]}], " ", 
                SuperscriptBox["g", 
                  RowBox[{
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "1"],
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "4"],
                        "TraditionalForm"],
                      "TraditionalForm"]}]]}], "+", 
              RowBox[{
                RowBox[{
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "2"],
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "3"],
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "4"],
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "6"],
                        "TraditionalForm"],
                      "TraditionalForm"]]}], " ", 
                SuperscriptBox["g", 
                  RowBox[{
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "1"],
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "5"],
                        "TraditionalForm"],
                      "TraditionalForm"]}]]}], "-", 
              RowBox[{
                RowBox[{
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "2"],
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "3"],
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "4"],
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "5"],
                        "TraditionalForm"],
                      "TraditionalForm"]]}], " ", 
                SuperscriptBox["g", 
                  RowBox[{
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "1"],
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "6"],
                        "TraditionalForm"],
                      "TraditionalForm"]}]]}], "-", 
              RowBox[{
                RowBox[{
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "1"],
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "4"],
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "5"],
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "6"],
                        "TraditionalForm"],
                      "TraditionalForm"]]}], " ", 
                SuperscriptBox["g", 
                  RowBox[{
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "2"],
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "3"],
                        "TraditionalForm"],
                      "TraditionalForm"]}]]}], "+", 
              RowBox[{
                RowBox[{
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "1"],
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "3"],
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "5"],
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "6"],
                        "TraditionalForm"],
                      "TraditionalForm"]]}], " ", 
                SuperscriptBox["g", 
                  RowBox[{
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "2"],
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "4"],
                        "TraditionalForm"],
                      "TraditionalForm"]}]]}], "-", 
              RowBox[{
                RowBox[{
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "1"],
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "3"],
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "4"],
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "6"],
                        "TraditionalForm"],
                      "TraditionalForm"]]}], " ", 
                SuperscriptBox["g", 
                  RowBox[{
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "2"],
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "5"],
                        "TraditionalForm"],
                      "TraditionalForm"]}]]}], "+", 
              RowBox[{
                RowBox[{
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "1"],
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "3"],
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "4"],
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "5"],
                        "TraditionalForm"],
                      "TraditionalForm"]]}], " ", 
                SuperscriptBox["g", 
                  RowBox[{
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "2"],
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "6"],
                        "TraditionalForm"],
                      "TraditionalForm"]}]]}], "-", 
              RowBox[{
                RowBox[{
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "1"],
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "2"],
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "5"],
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "6"],
                        "TraditionalForm"],
                      "TraditionalForm"]]}], " ", 
                SuperscriptBox["g", 
                  RowBox[{
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "3"],
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "4"],
                        "TraditionalForm"],
                      "TraditionalForm"]}]]}], "+", 
              RowBox[{
                RowBox[{
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "1"],
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "2"],
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "4"],
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "6"],
                        "TraditionalForm"],
                      "TraditionalForm"]]}], " ", 
                SuperscriptBox["g", 
                  RowBox[{
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "3"],
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "5"],
                        "TraditionalForm"],
                      "TraditionalForm"]}]]}], "-", 
              RowBox[{
                RowBox[{
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "1"],
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "2"],
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "4"],
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "5"],
                        "TraditionalForm"],
                      "TraditionalForm"]]}], " ", 
                SuperscriptBox["g", 
                  RowBox[{
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "3"],
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "6"],
                        "TraditionalForm"],
                      "TraditionalForm"]}]]}], "-", 
              RowBox[{
                RowBox[{
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "1"],
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "2"],
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "3"],
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "6"],
                        "TraditionalForm"],
                      "TraditionalForm"]]}], " ", 
                SuperscriptBox["g", 
                  RowBox[{
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "4"],
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "5"],
                        "TraditionalForm"],
                      "TraditionalForm"]}]]}], "+", 
              RowBox[{
                RowBox[{
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "1"],
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "2"],
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "3"],
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "5"],
                        "TraditionalForm"],
                      "TraditionalForm"]]}], " ", 
                SuperscriptBox["g", 
                  RowBox[{
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "4"],
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "6"],
                        "TraditionalForm"],
                      "TraditionalForm"]}]]}], "-", 
              RowBox[{
                RowBox[{
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "1"],
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "2"],
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "3"],
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SuperscriptBox["\[Gamma]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "4"],
                        "TraditionalForm"],
                      "TraditionalForm"]]}], " ", 
                SuperscriptBox["g", 
                  RowBox[{
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "5"],
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox[
                        SubscriptBox["\[Nu]", "6"],
                        "TraditionalForm"],
                      "TraditionalForm"]}]]}]}], ")"}]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[504]=  (21:53:12 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["DotSimplify", "ObjectName",
  CellTags->"DotSimplify"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"DotSimplify"],

Cell["\<\
DotSimplify[expr] expands and reorders noncommutative terms in expr. \
Simplifying relations may be specified by the option DotSimplifyRelations or \
by Commutator and AntiCommutator definitions. Whether expr is expanded \
noncommutatively depends on the option Expanding.\
\>", "Text",
  CellTags->"DotSimplify"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "DotSimplify", "]"}]], "Input",
  CellLabel->"In[505]:=  (21:53:12 on 5/16/01)",
  CellTags->"DotSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"Expanding", "\[Rule]", "True"}], ",", 
          RowBox[{"DotSimplifyRelations", "\[Rule]", 
            RowBox[{"{", "}"}]}], ",", 
          RowBox[{"DotPower", "\[Rule]", "True"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[505]=  (21:53:12 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["AntiCommutator",
    ButtonData:>"AntiCommutator",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"AntiCommutator"],
  ", ",
  ButtonBox["Commutator",
    ButtonData:>"Commutator",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Commutator"],
  ", ",
  ButtonBox["Calc",
    ButtonData:>"Calc",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Calc"],
  "."
}], "Text",
  CellTags->"DotSimplify"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"DotSimplify"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t1", "=", 
      RowBox[{
        RowBox[{"GA", "[", "\[Mu]", "]"}], ".", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"2", " ", 
              RowBox[{"GS", "[", "p", "]"}]}], "-", 
            RowBox[{"GS", "[", "q", "]"}]}], ")"}], ".", 
        RowBox[{"GA", "[", "\[Nu]", "]"}]}]}]], "Input",
  CellLabel->"In[506]:=  (21:53:12 on 5/16/01)",
  CellTags->"DotSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"2", " ", 
              RowBox[{
              "\[Gamma]", "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "p"}]}],
             "-", 
            RowBox[{
            "\[Gamma]", "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "q"}]}], 
          ")"}], ".", 
        SuperscriptBox["\[Gamma]", "\[Nu]"]}], TraditionalForm]], "Output",
  CellLabel->"Out[506]=  (21:53:12 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DotSimplify", "[", "t1", "]"}]], "Input",
  CellLabel->"In[507]:=  (21:53:13 on 5/16/01)",
  CellTags->"DotSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"2", " ", 
          RowBox[{
            SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
            RowBox[{"(", 
              RowBox[{
              "\[Gamma]", "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "p"}], 
              ")"}], ".", 
            SuperscriptBox["\[Gamma]", "\[Nu]"]}]}], "-", 
        RowBox[{
          SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
          RowBox[{"(", 
            RowBox[{
            "\[Gamma]", "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "q"}], 
            ")"}], ".", 
          SuperscriptBox["\[Gamma]", "\[Nu]"]}]}], TraditionalForm]], "Output",\

  CellLabel->"Out[507]=  (21:53:13 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{"DeclareNonCommutative", "[", 
      RowBox[{"a", ",", "b", ",", "c"}], "]"}]], "Input",
  CellLabel->"In[508]:=  (21:53:13 on 5/16/01)",
  CellTags->"DotSimplify"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t2", "=", 
      RowBox[{"a", ".", 
        RowBox[{"(", 
          RowBox[{"b", "-", 
            RowBox[{"z", " ", "c"}]}], ")"}], ".", "a"}]}]], "Input",
  CellLabel->"In[509]:=  (21:53:13 on 5/16/01)",
  CellTags->"DotSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{"a", ".", 
        RowBox[{"(", 
          RowBox[{"b", "-", 
            RowBox[{"c", " ", "z"}]}], ")"}], ".", "a"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[509]=  (21:53:13 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DotSimplify", "[", "t2", "]"}]], "Input",
  CellLabel->"In[510]:=  (21:53:13 on 5/16/01)",
  CellTags->"DotSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"a", ".", "b", ".", "a"}], "-", 
        RowBox[{"z", " ", 
          RowBox[{"a", ".", "c", ".", "a"}]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[510]=  (21:53:13 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Commutator", "[", 
        RowBox[{"a", ",", "c"}], "]"}], "=", "1"}]], "Input",
  CellLabel->"In[511]:=  (21:53:13 on 5/16/01)",
  CellTags->"DotSimplify"],

Cell[BoxData[
    FormBox["1", TraditionalForm]], "Output",
  CellLabel->"Out[511]=  (21:53:13 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DotSimplify", "[", "t2", "]"}]], "Input",
  CellLabel->"In[512]:=  (21:53:13 on 5/16/01)",
  CellTags->"DotSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"a", ".", "b", ".", "a"}], "-", 
        RowBox[{"z", " ", 
          RowBox[{"(", 
            RowBox[{"a", "+", 
              RowBox[{"c", ".", 
                SuperscriptBox["a", "2"]}]}], ")"}]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[512]=  (21:53:13 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      RowBox[{"Commutator", "[", 
        RowBox[{"a", ",", "c"}], "]"}], "=", "."}]], "Input",
  CellLabel->"In[513]:=  (21:53:13 on 5/16/01)",
  CellTags->"DotSimplify"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DotSimplify", "[", "t2", "]"}]], "Input",
  CellLabel->"In[514]:=  (21:53:13 on 5/16/01)",
  CellTags->"DotSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"a", ".", "b", ".", "a"}], "-", 
        RowBox[{"z", " ", 
          RowBox[{"a", ".", "c", ".", "a"}]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[514]=  (21:53:13 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"AntiCommutator", "[", 
        RowBox[{"b", ",", "a"}], "]"}], "=", "c"}]], "Input",
  CellLabel->"In[515]:=  (21:53:13 on 5/16/01)",
  CellTags->"DotSimplify"],

Cell[BoxData[
    FormBox["c", TraditionalForm]], "Output",
  CellLabel->"Out[515]=  (21:53:13 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DotSimplify", "[", "t2", "]"}]], "Input",
  CellLabel->"In[516]:=  (21:53:13 on 5/16/01)",
  CellTags->"DotSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"a", ".", "c"}], "-", 
        RowBox[{
          SuperscriptBox["a", "2"], ".", "b"}], "-", 
        RowBox[{"z", " ", 
          RowBox[{"a", ".", "c", ".", "a"}]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[516]=  (21:53:13 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      RowBox[{"AntiCommutator", "[", 
        RowBox[{"b", ",", "a"}], "]"}], "=", "."}]], "Input",
  CellLabel->"In[517]:=  (21:53:13 on 5/16/01)",
  CellTags->"DotSimplify"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DotSimplify", "[", 
      RowBox[{"t2", ",", 
        RowBox[{"DotSimplifyRelations", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"a", ".", "c"}], "\[Rule]", 
              RowBox[{"1", "/", "z"}]}], "}"}]}]}], "]"}]], "Input",
  CellLabel->"In[518]:=  (21:53:13 on 5/16/01)",
  CellTags->"DotSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"a", ".", "b", ".", "a"}], "-", "a"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[518]=  (21:53:13 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{"DeclareNonCommutative", "[", "x", "]"}]], "Input",
  CellLabel->"In[519]:=  (21:53:13 on 5/16/01)",
  CellTags->"DotSimplify"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DotSimplify", "[", 
      RowBox[{"x", ".", "x", ".", "x"}], "]"}]], "Input",
  CellLabel->"In[520]:=  (21:53:13 on 5/16/01)",
  CellTags->"DotSimplify"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["x", "3"], TraditionalForm]], "Output",
  CellLabel->"Out[520]=  (21:53:13 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DotSimplify", "[", 
      RowBox[{
        RowBox[{"x", ".", "x", ".", "x"}], ",", 
        RowBox[{"DotPower", "\[Rule]", "False"}]}], "]"}]], "Input",
  CellLabel->"In[521]:=  (21:53:13 on 5/16/01)",
  CellTags->"DotSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{"x", ".", "x", ".", "x"}], TraditionalForm]], "Output",
  CellLabel->"Out[521]=  (21:53:13 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{"UnDeclareNonCommutative", "[", 
      RowBox[{"a", ",", "b", ",", "c", ",", "x"}], "]"}]], "Input",
  CellLabel->"In[522]:=  (21:53:13 on 5/16/01)",
  CellTags->"DotSimplify"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["EpsChisholm", "ObjectName",
  CellTags->"EpsChisholm"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"EpsChisholm"],

Cell["\<\
EpsChisholm[expr] substitutes for a gamma matrix contracted with a \
Levi-Civita tensor (Eps) the Chisholm identity.\
\>", "Text",
  CellTags->"EpsChisholm"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["Chisholm",
    ButtonData:>"Chisholm",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Chisholm"],
  "."
}], "Text",
  CellTags->"EpsChisholm"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"EpsChisholm"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Chisholm", "[", 
      RowBox[{"GA", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Sigma]"}], 
        "]"}], "]"}]], "Input",
  CellLabel->"In[523]:=  (21:53:14 on 5/16/01)",
  CellTags->"EpsChisholm"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", 
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["$MU$200",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", "5"]}], " ", 
          SuperscriptBox["\[Epsilon]", 
            RowBox[{
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Rho]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["$MU$200",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "+", 
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Rho]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]]}], "-", 
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Rho]"}]]}], "+", 
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Nu]", "\[NoBreak]", "\[Rho]"}]]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[523]=  (21:53:14 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"EpsChisholm", "[", "%", "]"}]], "Input",
  CellLabel->"In[524]:=  (21:53:14 on 5/16/01)",
  CellTags->"EpsChisholm"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Nu]",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Rho]",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Sigma]",
              "TraditionalForm"],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[524]=  (21:53:15 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["EpsEvaluate", "ObjectName",
  CellTags->"EpsEvaluate"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"EpsEvaluate"],

Cell["\<\
EpsEvaluate[expr] applies total antisymmetry and linearity (w.r.t. \
Momentum's) to all Levi-Civita tensors (Eps') in expr.\
\>", "Text",
  CellTags->"EpsEvaluate"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["Contract",
    ButtonData:>"Contract",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Contract"],
  ", ",
  ButtonBox["Eps",
    ButtonData:>"Eps",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Eps"],
  ", ",
  ButtonBox["LeviCivita",
    ButtonData:>"LeviCivita",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"LeviCivita"],
  ", ",
  ButtonBox["Trick",
    ButtonData:>"Trick",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Trick"],
  "."
}], "Text",
  CellTags->"EpsEvaluate"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"EpsEvaluate"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Trick", "[", 
      RowBox[{
        RowBox[{"LeviCivita", "[", 
          RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Sigma]"}], 
          "]"}], " ", 
        RowBox[{"FourVector", "[", 
          RowBox[{
            RowBox[{"p", "+", "q"}], ",", "\[Sigma]"}], "]"}]}], 
      "]"}]], "Input",
  CellLabel->"In[525]:=  (21:53:15 on 5/16/01)",
  CellTags->"EpsEvaluate"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["\[Epsilon]", 
        RowBox[{
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", 
          FormBox[
            FormBox["\[Nu]",
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", 
          FormBox[
            FormBox["\[Rho]",
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", 
          FormBox[
            RowBox[{"p", "+", "q"}],
            "TraditionalForm"]}]], TraditionalForm]], "Output",
  CellLabel->"Out[525]=  (21:53:15 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"EpsEvaluate", "[", "%", "]"}]], "Input",
  CellLabel->"In[526]:=  (21:53:15 on 5/16/01)",
  CellTags->"EpsEvaluate"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Epsilon]", 
          RowBox[{
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["\[Rho]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox["p",
              "TraditionalForm"]}]], "+", 
        SuperscriptBox["\[Epsilon]", 
          RowBox[{
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["\[Rho]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox["q",
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[526]=  (21:53:15 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StandardForm", "[", "%", "]"}]], "Input",
  CellLabel->"In[527]:=  (21:53:15 on 5/16/01)",
  CellTags->"EpsEvaluate"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Eps", "[", 
        RowBox[{
          RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
          RowBox[{"LorentzIndex", "[", "\[Nu]", "]"}], ",", 
          RowBox[{"LorentzIndex", "[", "\[Rho]", "]"}], ",", 
          RowBox[{"Momentum", "[", "p", "]"}]}], "]"}], "+", 
      RowBox[{"Eps", "[", 
        RowBox[{
          RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
          RowBox[{"LorentzIndex", "[", "\[Nu]", "]"}], ",", 
          RowBox[{"LorentzIndex", "[", "\[Rho]", "]"}], ",", 
          RowBox[{"Momentum", "[", "q", "]"}]}], "]"}]}]], "Output",
  CellLabel->"Out[527]//StandardForm=  (21:53:15 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Epsilon", "ObjectName",
  CellTags->"Epsilon"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"Epsilon"],

Cell[TextData[{
  "Epsilon is (",
  StyleBox["n",
    FontSlant->"Italic"],
  "-4), where ",
  StyleBox["n",
    FontSlant->"Italic"],
  " is the space-time dimension. Epsilon stands for a small positive number."
}], "Text",
  CellTags->"Epsilon"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["Series2",
    ButtonData:>"Series2",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Series2"],
  "."
}], "Text",
  CellTags->"Epsilon"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"Epsilon"],

Cell[CellGroupData[{

Cell[BoxData["Epsilon"], "Input",
  CellLabel->"In[528]:=  (21:53:15 on 5/16/01)",
  CellTags->"Epsilon"],

Cell[BoxData[
    FormBox[
      TagBox["\[CurlyEpsilon]",
        TraditionalForm], TraditionalForm]], "Output",
  CellLabel->"Out[528]=  (21:53:15 on 5/16/01)"]
}, Closed]],

Cell["\<\
Epsilon has no functional properties, but some upvalues are changed:\
\>", "Text",
  CellTags->"Epsilon"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{"Re", "[", "Epsilon", "]"}], " ", ">", " ", 
          RowBox[{"-", "4"}]}], ",", 
        RowBox[{
          RowBox[{"Re", "[", "Epsilon", "]"}], " ", ">", " ", 
          RowBox[{"-", "3"}]}], ",", 
        RowBox[{
          RowBox[{"Re", "[", "Epsilon", "]"}], " ", ">", " ", 
          RowBox[{"-", "2"}]}], ",", 
        RowBox[{
          RowBox[{"Re", "[", "Epsilon", "]"}], " ", ">", " ", 
          RowBox[{"-", "1"}]}], ",", 
        RowBox[{
          RowBox[{"Re", "[", "Epsilon", "]"}], " ", ">", " ", "0"}]}], 
      "}"}]], "Input",
  CellLabel->"In[529]:=  (21:53:15 on 5/16/01)",
  CellTags->"Epsilon"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"True", ",", "True", ",", "True", ",", "True", ",", "True"}], 
        "}"}], TraditionalForm]], "Output",
  CellLabel->"Out[529]=  (21:53:15 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Eps", "ObjectName",
  CellTags->"Eps"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"Eps"],

Cell[TextData[{
  "Eps[a, b, c, d] is the head of the totally antisymmetric ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", "\[Epsilon]"}], TraditionalForm]]],
  " (Levi-Civita) tensor. The a,b, ... may have head LorentzIndex, Momentum \
or Integer. In case of integers the Levi-Civita tensor is evaluated \
immediately. "
}], "Text",
  CellTags->"Eps"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "Eps", "]"}]], "Input",
  CellLabel->"In[530]:=  (21:53:15 on 5/16/01)",
  CellTags->"Eps"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"Dimension", "\[Rule]", "4"}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[530]=  (21:53:15 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["EpsEvaluate",
    ButtonData:>"EpsEvaluate",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"EpsEvaluate"],
  ", ",
  ButtonBox["LC",
    ButtonData:>"LC",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"LC"],
  ", ",
  ButtonBox["LCD",
    ButtonData:>"LCD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"LCD"],
  ", ",
  ButtonBox["LeviCivita",
    ButtonData:>"LeviCivita",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"LeviCivita"],
  "."
}], "Text",
  CellTags->"Eps"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"Eps"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Eps", "[", 
      RowBox[{
        RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
        RowBox[{"LorentzIndex", "[", "\[Nu]", "]"}], ",", 
        RowBox[{"LorentzIndex", "[", "\[Rho]", "]"}], ",", 
        RowBox[{"LorentzIndex", "[", "\[Sigma]", "]"}]}], "]"}]], "Input",
  CellLabel->"In[531]:=  (21:53:16 on 5/16/01)",
  CellTags->"Eps"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["\[Epsilon]", 
        RowBox[{
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", 
          FormBox[
            FormBox["\[Nu]",
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", 
          FormBox[
            FormBox["\[Rho]",
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", 
          FormBox[
            FormBox["\[Sigma]",
              "TraditionalForm"],
            "TraditionalForm"]}]], TraditionalForm]], "Output",
  CellLabel->"Out[531]=  (21:53:16 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Eps", "[", 
      RowBox[{
        RowBox[{"Momentum", "[", "p", "]"}], ",", 
        RowBox[{"LorentzIndex", "[", "\[Nu]", "]"}], ",", 
        RowBox[{"LorentzIndex", "[", "\[Rho]", "]"}], ",", 
        RowBox[{"LorentzIndex", "[", "\[Sigma]", "]"}]}], "]"}]], "Input",
  CellLabel->"In[532]:=  (21:53:16 on 5/16/01)",
  CellTags->"Eps"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["\[Epsilon]", 
        RowBox[{
          FormBox["p",
            "TraditionalForm"], "\[NoBreak]", 
          FormBox[
            FormBox["\[Nu]",
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", 
          FormBox[
            FormBox["\[Rho]",
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", 
          FormBox[
            FormBox["\[Sigma]",
              "TraditionalForm"],
            "TraditionalForm"]}]], TraditionalForm]], "Output",
  CellLabel->"Out[532]=  (21:53:16 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Eps", "[", 
        RowBox[{"b", ",", "a", ",", "c", ",", "d"}], "]"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[533]:=  (21:53:16 on 5/16/01)",
  CellTags->"Eps"],

Cell[BoxData[
    RowBox[{"-", 
      RowBox[{"Eps", "[", 
        RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}]}]], "Output",
  CellLabel->"Out[533]//StandardForm=  (21:53:16 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Eps", "[", 
      RowBox[{"0", ",", "1", ",", "2", ",", "3"}], "]"}]], "Input",
  CellLabel->"In[534]:=  (21:53:16 on 5/16/01)",
  CellTags->"Eps"],

Cell[BoxData[
    FormBox["1", TraditionalForm]], "Output",
  CellLabel->"Out[534]=  (21:53:16 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Eps", "[", 
      RowBox[{"1", ",", "0", ",", "2", ",", "3"}], "]"}]], "Input",
  CellLabel->"In[535]:=  (21:53:16 on 5/16/01)",
  CellTags->"Eps"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", "1"}], TraditionalForm]], "Output",
  CellLabel->"Out[535]=  (21:53:16 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      RowBox[{"SetOptions", "[", 
        RowBox[{"Eps", ",", 
          RowBox[{"Dimension", "\[Rule]", "4"}]}], "]"}], ";"}]], "Input",
  CellLabel->"In[536]:=  (21:53:16 on 5/16/01)",
  CellTags->"Eps"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"a1", " ", "=", 
      RowBox[{"Eps", "[", 
        RowBox[{
          RowBox[{"LorentzIndex", "[", 
            RowBox[{"\[Mu]", ",", "D"}], "]"}], ",", 
          RowBox[{"LorentzIndex", "[", 
            RowBox[{"\[Nu]", ",", "D"}], "]"}], ",", 
          RowBox[{"LorentzIndex", "[", 
            RowBox[{"\[Rho]", ",", "D"}], "]"}], ",", 
          RowBox[{"LorentzIndex", "[", 
            RowBox[{"\[Sigma]", ",", "D"}], "]"}]}], "]"}]}]], "Input",
  CellLabel->"In[537]:=  (21:53:16 on 5/16/01)",
  CellTags->"Eps"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["\[Epsilon]", 
        RowBox[{
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", 
          FormBox[
            FormBox["\[Nu]",
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", 
          FormBox[
            FormBox["\[Rho]",
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", 
          FormBox[
            FormBox["\[Sigma]",
              "TraditionalForm"],
            "TraditionalForm"]}]], TraditionalForm]], "Output",
  CellLabel->"Out[537]=  (21:53:16 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Contract", "[", 
      RowBox[{"a1", "a1"}], "]"}]], "Input",
  CellLabel->"In[538]:=  (21:53:16 on 5/16/01)",
  CellTags->"Eps"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", "24"}], TraditionalForm]], "Output",
  CellLabel->"Out[538]=  (21:53:16 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      RowBox[{"SetOptions", "[", 
        RowBox[{"Eps", ",", 
          RowBox[{"Dimension", "\[Rule]", "D"}]}], "]"}], ";"}]], "Input",
  CellLabel->"In[539]:=  (21:53:16 on 5/16/01)",
  CellTags->"Eps"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"a2", " ", "=", 
      RowBox[{"Eps", "[", 
        RowBox[{
          RowBox[{"LorentzIndex", "[", 
            RowBox[{"\[Mu]", ",", "D"}], "]"}], ",", 
          RowBox[{"LorentzIndex", "[", 
            RowBox[{"\[Nu]", ",", "D"}], "]"}], ",", 
          RowBox[{"LorentzIndex", "[", 
            RowBox[{"\[Rho]", ",", "D"}], "]"}], ",", 
          RowBox[{"LorentzIndex", "[", 
            RowBox[{"\[Sigma]", ",", "D"}], "]"}]}], "]"}]}]], "Input",
  CellLabel->"In[540]:=  (21:53:16 on 5/16/01)",
  CellTags->"Eps"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["\[Epsilon]", 
        RowBox[{
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", 
          FormBox[
            FormBox["\[Nu]",
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", 
          FormBox[
            FormBox["\[Rho]",
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", 
          FormBox[
            FormBox["\[Sigma]",
              "TraditionalForm"],
            "TraditionalForm"]}]], TraditionalForm]], "Output",
  CellLabel->"Out[540]=  (21:53:16 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Contract", "[", 
        RowBox[{"a2", "a2"}], "]"}], "//", "Factor2"}]], "Input",
  CellLabel->"In[541]:=  (21:53:16 on 5/16/01)",
  CellTags->"Eps"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"(", 
          RowBox[{"1", "-", "D"}], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{"2", "-", "D"}], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{"3", "-", "D"}], ")"}], " ", "D"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[541]=  (21:53:16 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"g5", "=", 
      RowBox[{
        RowBox[{
          RowBox[{"-", 
            FractionBox["\[ImaginaryI]", "24"]}], " ", 
          RowBox[{
            RowBox[{"LCD", "[", 
              RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Alpha]"}],
               "]"}], ".", 
            RowBox[{"GAD", "[", 
              RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Alpha]"}],
               "]"}]}]}], "//", "FCI"}]}]], "Input",
  CellLabel->"In[542]:=  (21:53:16 on 5/16/01)",
  CellTags->"Eps"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          FractionBox["1", "24"]}], " ", "\[ImaginaryI]", " ", 
        RowBox[{
          SuperscriptBox["\[Epsilon]", 
            RowBox[{
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Rho]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Alpha]",
                  "TraditionalForm"],
                "TraditionalForm"]}]], ".", 
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], ".", 
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"]], ".", 
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox["\[Rho]",
                "TraditionalForm"],
              "TraditionalForm"]], ".", 
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox["\[Alpha]",
                "TraditionalForm"],
              "TraditionalForm"]]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[542]=  (21:53:16 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"g5p", "=", 
      RowBox[{
        RowBox[{
          RowBox[{"-", 
            FractionBox["\[ImaginaryI]", "24"]}], " ", 
          RowBox[{
            RowBox[{"LCD", "[", 
              RowBox[{
                SuperscriptBox["\[Mu]", "\[Prime]",
                  MultilineFunction->None], ",", 
                SuperscriptBox["\[Nu]", "\[Prime]",
                  MultilineFunction->None], ",", 
                SuperscriptBox["\[Rho]", "\[Prime]",
                  MultilineFunction->None], ",", 
                SuperscriptBox["\[Alpha]", "\[Prime]",
                  MultilineFunction->None]}], "]"}], ".", 
            RowBox[{"GAD", "[", 
              RowBox[{
                SuperscriptBox["\[Mu]", "\[Prime]",
                  MultilineFunction->None], ",", 
                SuperscriptBox["\[Nu]", "\[Prime]",
                  MultilineFunction->None], ",", 
                SuperscriptBox["\[Rho]", "\[Prime]",
                  MultilineFunction->None], ",", 
                SuperscriptBox["\[Alpha]", "\[Prime]",
                  MultilineFunction->None]}], "]"}]}]}], "//", 
        "FCI"}]}]], "Input",
  CellLabel->"In[543]:=  (21:53:16 on 5/16/01)",
  CellTags->"Eps"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          FractionBox["1", "24"]}], " ", "\[ImaginaryI]", " ", 
        RowBox[{
          SuperscriptBox["\[Epsilon]", 
            RowBox[{
              FormBox[
                FormBox[
                  SuperscriptBox["\[Mu]", "\[Prime]",
                    MultilineFunction->None],
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox[
                  SuperscriptBox["\[Nu]", "\[Prime]",
                    MultilineFunction->None],
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox[
                  SuperscriptBox["\[Rho]", "\[Prime]",
                    MultilineFunction->None],
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox[
                  SuperscriptBox["\[Alpha]", "\[Prime]",
                    MultilineFunction->None],
                  "TraditionalForm"],
                "TraditionalForm"]}]], ".", 
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox[
                SuperscriptBox["\[Mu]", "\[Prime]",
                  MultilineFunction->None],
                "TraditionalForm"],
              "TraditionalForm"]], ".", 
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox[
                SuperscriptBox["\[Nu]", "\[Prime]",
                  MultilineFunction->None],
                "TraditionalForm"],
              "TraditionalForm"]], ".", 
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox[
                SuperscriptBox["\[Rho]", "\[Prime]",
                  MultilineFunction->None],
                "TraditionalForm"],
              "TraditionalForm"]], ".", 
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox[
                SuperscriptBox["\[Alpha]", "\[Prime]",
                  MultilineFunction->None],
                "TraditionalForm"],
              "TraditionalForm"]]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[543]=  (21:53:16 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"g52", "=", 
      RowBox[{"Factor2", "[", 
        RowBox[{"Calc", "[", 
          RowBox[{"g5", ".", "g5p"}], "]"}], "]"}]}]], "Input",
  CellLabel->"In[544]:=  (21:53:16 on 5/16/01)",
  CellTags->"Eps"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          FractionBox["1", "24"]}], " ", 
        RowBox[{"(", 
          RowBox[{"1", "-", "D"}], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{"2", "-", "D"}], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{"3", "-", "D"}], ")"}], " ", "D"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[544]=  (21:53:18 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"g52", "/.", 
      RowBox[{"D", "\[Rule]", "4"}]}]], "Input",
  CellLabel->"In[545]:=  (21:53:18 on 5/16/01)",
  CellTags->"Eps"],

Cell[BoxData[
    FormBox["1", TraditionalForm]], "Output",
  CellLabel->"Out[545]=  (21:53:18 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{"Clear", "[", 
      RowBox[{"a1", ",", "a2", ",", "g5", ",", "g5p", ",", "g52"}], 
      "]"}]], "Input",
  CellLabel->"In[546]:=  (21:53:18 on 5/16/01)",
  CellTags->"Eps"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["ExpandPartialD", "ObjectName",
  CellTags->"ExpandPartialD"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"ExpandPartialD"],

Cell["\<\
ExpandPartialD[exp] expands all products of QuantumField's and partial \
differentiation operators in exp and applies Leibniz rule.\
\>", "Text",
  CellTags->"ExpandPartialD"],

Cell[TextData[{
  "See also: ",
  ButtonBox["ExplicitPartialD",
    ButtonData:>"ExplicitPartialD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"ExplicitPartialD"],
  ", ",
  ButtonBox["LeftPartialD",
    ButtonData:>"LeftPartialD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"LeftPartialD"],
  ", ",
  ButtonBox["LeftRightPartialD",
    ButtonData:>"LeftRightPartialD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"LeftRightPartialD"],
  ", ",
  ButtonBox["RightPartialD",
    ButtonData:>"RightPartialD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"RightPartialD"],
  "."
}], "Text",
  CellTags->"ExpandPartialD"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"ExpandPartialD"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"RightPartialD", "[", "\[Mu]", "]"}], ".", 
      RowBox[{"QuantumField", "[", 
        RowBox[{"A", ",", 
          RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}]}], "]"}], ".", 
      RowBox[{"QuantumField", "[", 
        RowBox[{"A", ",", 
          RowBox[{"LorentzIndex", "[", "\[Nu]", "]"}]}], "]"}]}]], "Input",
  CellLabel->"In[547]:=  (21:53:18 on 5/16/01)",
  CellTags->"ExpandPartialD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox[
          OverscriptBox["\[PartialD]", "\[RightArrow]"], 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        SubscriptBox["A", "\[Mu]"], ".", 
        SubscriptBox["A", "\[Nu]"]}], TraditionalForm]], "Output",
  CellLabel->"Out[547]=  (21:53:18 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ExpandPartialD", "[", "%", "]"}]], "Input",
  CellLabel->"In[548]:=  (21:53:18 on 5/16/01)",
  CellTags->"ExpandPartialD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["A", "\[Mu]"], ".", 
          RowBox[{
            SubscriptBox["\[PartialD]", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"]], 
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[Null]"]}]}], "+", 
        RowBox[{
          RowBox[{
            SubscriptBox["\[PartialD]", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"]], 
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[Null]"]}], ".", 
          SubscriptBox["A", "\[Nu]"]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[548]=  (21:53:19 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "StandardForm"}]], "Input",
  CellLabel->"In[549]:=  (21:53:19 on 5/16/01)",
  CellTags->"ExpandPartialD"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"QuantumField", "[", 
          RowBox[{"A", ",", 
            RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}]}], "]"}], ".", 
        RowBox[{"QuantumField", "[", 
          RowBox[{
            RowBox[{"PartialD", "[", 
              RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], "]"}], ",", "A", 
            ",", 
            RowBox[{"LorentzIndex", "[", "\[Nu]", "]"}]}], "]"}]}], "+", 
      RowBox[{
        RowBox[{"QuantumField", "[", 
          RowBox[{
            RowBox[{"PartialD", "[", 
              RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], "]"}], ",", "A", 
            ",", 
            RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}]}], "]"}], ".", 
        RowBox[{"QuantumField", "[", 
          RowBox[{"A", ",", 
            RowBox[{"LorentzIndex", "[", "\[Nu]", "]"}]}], 
          "]"}]}]}]], "Output",
  CellLabel->"Out[549]//StandardForm=  (21:53:19 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"LeftRightPartialD", "[", "\[Mu]", "]"}], ".", 
      RowBox[{"QuantumField", "[", 
        RowBox[{"A", ",", 
          RowBox[{"LorentzIndex", "[", "\[Nu]", "]"}]}], "]"}]}]], "Input",
  CellLabel->"In[550]:=  (21:53:19 on 5/16/01)",
  CellTags->"ExpandPartialD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox[
          OverscriptBox["\[PartialD]", "\[LeftRightArrow]"], 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        SubscriptBox["A", "\[Nu]"]}], TraditionalForm]], "Output",
  CellLabel->"Out[550]=  (21:53:19 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ExpandPartialD", "[", "%", "]"}]], "Input",
  CellLabel->"In[551]:=  (21:53:19 on 5/16/01)",
  CellTags->"ExpandPartialD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{
            SubscriptBox["\[PartialD]", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"]], 
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[Null]"]}], "2"], "-", 
        RowBox[{
          FractionBox["1", "2"], " ", 
          SubscriptBox[
            OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubscriptBox["A", "\[Nu]"]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[551]=  (21:53:19 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"QuantumField", "[", 
        RowBox[{"A", ",", 
          RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}]}], "]"}], ".", 
      RowBox[{"(", 
        RowBox[{
          RowBox[{"LeftRightPartialD", "[", "OPEDelta", "]"}], "^", "2"}], 
        ")"}], ".", 
      RowBox[{"QuantumField", "[", 
        RowBox[{"A", ",", 
          RowBox[{"LorentzIndex", "[", "\[Rho]", "]"}]}], "]"}]}]], "Input",
  CellLabel->"In[552]:=  (21:53:19 on 5/16/01)",
  CellTags->"ExpandPartialD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["A", "\[Mu]"], ".", 
        SubsuperscriptBox[
          OverscriptBox["\[PartialD]", "\[LeftRightArrow]"], 
          FormBox["\[CapitalDelta]",
            "TraditionalForm"], "2"], ".", 
        SubscriptBox["A", "\[Rho]"]}], TraditionalForm]], "Output",
  CellLabel->"Out[552]=  (21:53:19 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ExpandPartialD", "[", "%", "]"}]], "Input",
  CellLabel->"In[553]:=  (21:53:19 on 5/16/01)",
  CellTags->"ExpandPartialD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox["1", "4"], " ", 
          RowBox[{
            SubscriptBox["A", "\[Mu]"], ".", 
            RowBox[{
              SubscriptBox["\[PartialD]", 
                FormBox[
                  SuperscriptBox["\[CapitalDelta]", "2"],
                  "TraditionalForm"]], 
              SubsuperscriptBox["A", 
                FormBox[
                  FormBox["\[Rho]",
                    "TraditionalForm"],
                  "TraditionalForm"], "\[Null]"]}]}]}], "-", 
        RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{
            SubscriptBox["A", "\[Mu]"], ".", 
            RowBox[{
              SubscriptBox["\[PartialD]", 
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"]], 
              SubsuperscriptBox["A", 
                FormBox[
                  FormBox["\[Rho]",
                    "TraditionalForm"],
                  "TraditionalForm"], "\[Null]"]}]}], " ", 
          SubscriptBox[
            OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
            FormBox["\[CapitalDelta]",
              "TraditionalForm"]]}], "+", 
        RowBox[{
          FractionBox["1", "4"], " ", 
          RowBox[{
            SubscriptBox["A", "\[Mu]"], ".", 
            SubscriptBox["A", "\[Rho]"]}], " ", 
          SubsuperscriptBox[
            OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
            RowBox[{" ", "\[NoBreak]", 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"]}], 
            FormBox["2",
              "TraditionalForm"]]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[553]=  (21:53:20 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"8", " ", 
      RowBox[{
        RowBox[{"LeftRightPartialD", "[", "OPEDelta", "]"}], "^", 
        "3"}]}]], "Input",
  CellLabel->"In[554]:=  (21:53:20 on 5/16/01)",
  CellTags->"ExpandPartialD"],

Cell[BoxData[
    FormBox[
      RowBox[{"8", " ", 
        SubsuperscriptBox[
          OverscriptBox["\[PartialD]", "\[LeftRightArrow]"], 
          FormBox["\[CapitalDelta]",
            "TraditionalForm"], "3"]}], TraditionalForm]], "Output",
  CellLabel->"Out[554]=  (21:53:20 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ExplicitPartialD", "[", "%", "]"}]], "Input",
  CellLabel->"In[555]:=  (21:53:20 on 5/16/01)",
  CellTags->"ExpandPartialD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            SubscriptBox[
              OverscriptBox["\[PartialD]", "\[RightArrow]"], 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"]], "-", 
            SubscriptBox[
              OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"]]}], ")"}], ".", 
        RowBox[{"(", 
          RowBox[{
            SubscriptBox[
              OverscriptBox["\[PartialD]", "\[RightArrow]"], 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"]], "-", 
            SubscriptBox[
              OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"]]}], ")"}], ".", 
        RowBox[{"(", 
          RowBox[{
            SubscriptBox[
              OverscriptBox["\[PartialD]", "\[RightArrow]"], 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"]], "-", 
            SubscriptBox[
              OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"]]}], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[555]=  (21:53:20 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ExpandPartialD", "[", "%", "]"}]], "Input",
  CellLabel->"In[556]:=  (21:53:20 on 5/16/01)",
  CellTags->"ExpandPartialD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          SubsuperscriptBox[
            OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
            RowBox[{" ", "\[NoBreak]", 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"]}], 
            FormBox["3",
              "TraditionalForm"]]}], "+", 
        RowBox[{"3", " ", 
          SubsuperscriptBox[
            OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
            RowBox[{" ", "\[NoBreak]", 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"]}], 
            FormBox["2",
              "TraditionalForm"]], " ", 
          SubscriptBox[
            OverscriptBox["\[PartialD]", "\[RightArrow]"], 
            FormBox["\[CapitalDelta]",
              "TraditionalForm"]]}], "-", 
        RowBox[{"3", " ", 
          SubscriptBox[
            OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
            FormBox["\[CapitalDelta]",
              "TraditionalForm"]], " ", 
          SubsuperscriptBox[
            OverscriptBox["\[PartialD]", "\[RightArrow]"], 
            RowBox[{" ", "\[NoBreak]", 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"]}], 
            FormBox["2",
              "TraditionalForm"]]}], "+", 
        SubsuperscriptBox[
          OverscriptBox["\[PartialD]", "\[RightArrow]"], 
          RowBox[{" ", "\[NoBreak]", 
            FormBox["\[CapitalDelta]",
              "TraditionalForm"]}], 
          FormBox["3",
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[556]=  (21:53:20 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"LeviCivita", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Tau]"}], "]"}], 
      " ", 
      RowBox[{"RightPartialD", "[", 
        RowBox[{"\[Alpha]", ",", "\[Mu]", ",", "\[Beta]", ",", "\[Nu]"}], 
        "]"}]}]], "Input",
  CellLabel->"In[557]:=  (21:53:20 on 5/16/01)",
  CellTags->"ExpandPartialD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox[
            OverscriptBox["\[PartialD]", "\[RightArrow]"], 
            FormBox[
              FormBox["\[Alpha]",
                "TraditionalForm"],
              "TraditionalForm"]], ".", 
          SubscriptBox[
            OverscriptBox["\[PartialD]", "\[RightArrow]"], 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], ".", 
          SubscriptBox[
            OverscriptBox["\[PartialD]", "\[RightArrow]"], 
            FormBox[
              FormBox["\[Beta]",
                "TraditionalForm"],
              "TraditionalForm"]], ".", 
          SubscriptBox[
            OverscriptBox["\[PartialD]", "\[RightArrow]"], 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"]]}], " ", 
        SuperscriptBox["\[Epsilon]", 
          RowBox[{
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["\[Rho]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["\[Tau]",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[557]=  (21:53:20 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ExpandPartialD", "[", "%", "]"}]], "Input",
  CellLabel->"In[558]:=  (21:53:20 on 5/16/01)",
  CellTags->"ExpandPartialD"],

Cell[BoxData[
    FormBox["0", TraditionalForm]], "Output",
  CellLabel->"Out[558]=  (21:53:20 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["ExpandScalarProduct", "ObjectName",
  CellTags->"ExpandScalarProduct"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"ExpandScalarProduct"],

Cell["\<\
ExpandScalarProduct[expr] expands scalar products of sums of momenta in expr. \
ExpandScalarProduct does not use Expand on expr.\
\>", "Text",
  CellTags->"ExpandScalarProduct"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["Calc",
    ButtonData:>"Calc",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Calc"],
  "."
}], "Text",
  CellTags->"ExpandScalarProduct"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"ExpandScalarProduct"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SP", "[", 
      RowBox[{"p", ",", 
        RowBox[{"p", "-", "q"}]}], "]"}]], "Input",
  CellLabel->"In[559]:=  (21:53:21 on 5/16/01)",
  CellTags->"ExpandScalarProduct"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox["p",
          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "(",
         "\[NoBreak]", 
        FormBox[
          RowBox[{"p", "-", "q"}],
          "TraditionalForm"], "\[NoBreak]", ")"}], TraditionalForm]], "Output",\

  CellLabel->"Out[559]=  (21:53:21 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ExpandScalarProduct", "[", "%", "]"}]], "Input",
  CellLabel->"In[560]:=  (21:53:21 on 5/16/01)",
  CellTags->"ExpandScalarProduct"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox[
          FormBox["p",
            "TraditionalForm"], "2"], "-", 
        RowBox[{
          FormBox["p",
            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
          FormBox["q",
            "TraditionalForm"]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[560]=  (21:53:21 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FV", "[", 
      RowBox[{
        RowBox[{"p", "-", "q"}], ",", "\[Mu]"}], "]"}]], "Input",
  CellLabel->"In[561]:=  (21:53:21 on 5/16/01)",
  CellTags->"ExpandScalarProduct"],

Cell[BoxData[
    FormBox[
      SuperscriptBox[
        RowBox[{"(", 
          FormBox[
            RowBox[{"p", "-", "q"}],
            "TraditionalForm"], ")"}], "\[Mu]"], TraditionalForm]], "Output",
  CellLabel->"Out[561]=  (21:53:21 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ExpandScalarProduct", "[", "%", "]"}]], "Input",
  CellLabel->"In[562]:=  (21:53:21 on 5/16/01)",
  CellTags->"ExpandScalarProduct"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox[
          FormBox["p",
            "TraditionalForm"], 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]], "-", 
        SuperscriptBox[
          FormBox["q",
            "TraditionalForm"], 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[562]=  (21:53:21 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"SP", "[", 
        RowBox[{
          RowBox[{"p", "-", "q"}], ",", 
          RowBox[{"q", "-", "r"}]}], "]"}], "//", "FCI"}]], "Input",
  CellLabel->"In[563]:=  (21:53:21 on 5/16/01)",
  CellTags->"ExpandScalarProduct"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", 
        FormBox[
          RowBox[{"p", "-", "q"}],
          "TraditionalForm"], "\[NoBreak]", ")", "\[NoBreak]", "\[CenterDot]",
         "\[NoBreak]", "(", "\[NoBreak]", 
        FormBox[
          RowBox[{"q", "-", "r"}],
          "TraditionalForm"], "\[NoBreak]", ")"}], TraditionalForm]], "Output",\

  CellLabel->"Out[563]=  (21:53:21 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "/.", 
      RowBox[{"Pair", "\[Rule]", "ExpandScalarProduct"}]}]], "Input",
  CellLabel->"In[564]:=  (21:53:21 on 5/16/01)",
  CellTags->"ExpandScalarProduct"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FormBox["p",
            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
          FormBox["q",
            "TraditionalForm"]}], "-", 
        RowBox[{
          FormBox["p",
            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
          FormBox["r",
            "TraditionalForm"]}], "-", 
        SuperscriptBox[
          FormBox["q",
            "TraditionalForm"], "2"], "+", 
        RowBox[{
          FormBox["q",
            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
          FormBox["r",
            "TraditionalForm"]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[564]=  (21:53:21 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Explicit", "ObjectName",
  CellTags->"Explicit"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"Explicit"],

Cell[TextData[{
  "Explicit",
  " is an option for FieldStrength, GluonVertex, SUNF, and \
Twist2GluonOperator. If set to True the full form of the operator is \
inserted. ",
  StyleBox["Explicit[exp]",
    FontWeight->"Bold"],
  " inserts explicit expressions of GluonVertex, Twist2GluonOperator, etc., \
in exp. SUNF's are replaced by SUNTrace objects."
}], "Text",
  CellTags->"Explicit"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["GluonVertex",
    ButtonData:>"GluonVertex",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"GluonVertex"],
  ", ",
  ButtonBox["Twist2GluonOperator",
    ButtonData:>"Twist2GluonOperator",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Twist2GluonOperator"],
  "."
}], "Text",
  CellTags->"Explicit"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"Explicit"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GluonVertex", "[", 
      RowBox[{
      "p", ",", "\[Mu]", ",", "a", ",", " ", "q", ",", "\[Nu]", ",", "b", ",",
         "r", ",", "\[Rho]", ",", "c"}], "]"}]], "Input",
  CellLabel->"In[565]:=  (21:53:21 on 5/16/01)",
  CellTags->"Explicit"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["g", "s"], " ", 
        RowBox[{
          SuperscriptBox["V", 
            RowBox[{
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Rho]",
                  "TraditionalForm"],
                "TraditionalForm"]}]], "(", 
          RowBox[{
            FormBox["p",
              "TraditionalForm"], "\[NoBreak]", 
            RowBox[{",", " "}], "\[NoBreak]", 
            FormBox["q",
              "TraditionalForm"], "\[NoBreak]", 
            RowBox[{",", " "}], "\[NoBreak]", 
            FormBox["r",
              "TraditionalForm"]}], ")"}], " ", 
        SubscriptBox["f", 
          RowBox[{
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["c",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[565]=  (21:53:21 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Explicit", "[", "%", "]"}]], "Input",
  CellLabel->"In[566]:=  (21:53:22 on 5/16/01)",
  CellTags->"Explicit"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["g", "s"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}], "-", 
            RowBox[{
              SuperscriptBox[
                FormBox["r",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}], "-", 
            RowBox[{
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], "+", 
            RowBox[{
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox[
                FormBox["r",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], "+", 
            RowBox[{
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Rho]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], "-", 
            RowBox[{
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Rho]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}]}], ")"}], " ", 
        SubscriptBox["f", 
          RowBox[{
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["c",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[566]=  (21:53:22 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Twist2GluonOperator", "[", 
      RowBox[{"p", ",", "\[Mu]", ",", "a", ",", "\[Nu]", ",", "b"}], 
      "]"}]], "Input",
  CellLabel->"In[567]:=  (21:53:22 on 5/16/01)",
  CellTags->"Explicit"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
          RowBox[{
            FormBox[
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"-", "1"}], ")"}], "m"],
              "TraditionalForm"], "+", "1"}], ")"}], " ", 
        SubscriptBox["\[Delta]", 
          RowBox[{
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"]}]], " ", 
        RowBox[{"(", 
          RowBox[{
            SubsuperscriptBox["O", 
              RowBox[{
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"], "\[VeryThinSpace]", 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]}], "G2"], "(", 
            FormBox["p",
              "TraditionalForm"], ")"}], ")"}]}], TraditionalForm]], "Output",\

  CellLabel->"Out[567]=  (21:53:22 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Explicit", "[", "%", "]"}]], "Input",
  CellLabel->"In[568]:=  (21:53:22 on 5/16/01)",
  CellTags->"Explicit"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  FormBox[
                    RowBox[{
                      FormBox["\[CapitalDelta]",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["p",
                        "TraditionalForm"]}],
                    "TraditionalForm"], ")"}], "2"]}], "-", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"]], " ", 
                    SuperscriptBox[
                      FormBox["\[CapitalDelta]",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"]]}], "+", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["\[CapitalDelta]",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"]], " ", 
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"]]}]}], ")"}], " ", 
              RowBox[{
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["p",
                  "TraditionalForm"]}]}], "+", 
            RowBox[{
              SuperscriptBox[
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"]}]}], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{
            FormBox[
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"-", "1"}], ")"}], "m"],
              "TraditionalForm"], "+", "1"}], ")"}], " ", 
        FormBox[
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["p",
                  "TraditionalForm"]}], ")"}], 
            RowBox[{"m", "-", "2"}]],
          "TraditionalForm"], " ", 
        SubscriptBox["\[Delta]", 
          RowBox[{
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[568]=  (21:53:22 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FieldStrength", "[", 
      RowBox[{"\[Mu]", ",", "\[Nu]", ",", "a"}], "]"}]], "Input",
  CellLabel->"In[569]:=  (21:53:22 on 5/16/01)",
  CellTags->"Explicit"],

Cell[BoxData[
    FormBox[
      SubsuperscriptBox["F", 
        RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}], "a"], 
      TraditionalForm]], "Output",
  CellLabel->"Out[569]=  (21:53:22 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Explicit", "[", "%", "]"}]], "Input",
  CellLabel->"In[570]:=  (21:53:22 on 5/16/01)",
  CellTags->"Explicit"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["\[PartialD]", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], 
          SubsuperscriptBox[
            FormBox["A",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"]]}], "-", 
        RowBox[{
          SubscriptBox["\[PartialD]", 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"]], 
          SubsuperscriptBox[
            FormBox["A",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"]]}], "+", 
        RowBox[{
          SubscriptBox["g", "s"], " ", 
          RowBox[{
            SubsuperscriptBox[
              FormBox["A",
                "TraditionalForm"], 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["b1",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SubsuperscriptBox[
              FormBox["A",
                "TraditionalForm"], 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["c10",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SubscriptBox["f", 
            RowBox[{"a", "\[NoBreak]", "b1", "\[NoBreak]", "c10"}]]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[570]=  (21:53:22 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["ExplicitPartialD", "ObjectName",
  CellTags->"ExplicitPartialD"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"ExplicitPartialD"],

Cell["\<\
ExplicitPartialD[exp] inserts in exp the definition for LeftRightPartialD[z] \
(and LeftRightPartialD2[z]).\
\>", "Text",
  CellTags->"ExplicitPartialD"],

Cell[TextData[{
  "See also: ",
  ButtonBox["ExpandPartialD",
    ButtonData:>"ExpandPartialD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"ExpandPartialD"],
  ", ",
  ButtonBox["LeftRightPartialD",
    ButtonData:>"LeftRightPartialD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"LeftRightPartialD"],
  ", ",
  ButtonBox["LeftRightPartialD2",
    ButtonData:>"LeftRightPartialD2",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"LeftRightPartialD2"],
  "."
}], "Text",
  CellTags->"ExplicitPartialD"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"ExplicitPartialD"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ExplicitPartialD", "[", " ", 
      RowBox[{"LeftRightPartialD", "[", "\[Mu]", "]"}], " ", "]"}]], "Input",
  CellLabel->"In[571]:=  (21:53:22 on 5/16/01)",
  CellTags->"ExplicitPartialD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
          RowBox[{
            SubscriptBox[
              OverscriptBox["\[PartialD]", "\[RightArrow]"], 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"]], "-", 
            SubscriptBox[
              OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"]]}], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[571]=  (21:53:22 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ExplicitPartialD", "[", " ", 
      RowBox[{"LeftRightPartialD2", "[", "\[Mu]", "]"}], " ", "]"}]], "Input",\

  CellLabel->"In[572]:=  (21:53:22 on 5/16/01)",
  CellTags->"ExplicitPartialD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox[
          OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]], "+", 
        SubscriptBox[
          OverscriptBox["\[PartialD]", "\[RightArrow]"], 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[572]=  (21:53:22 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ExplicitPartialD", "[", " ", 
      RowBox[{"LeftRightPartialD", "[", "OPEDelta", "]"}], " ", 
      "]"}]], "Input",
  CellLabel->"In[573]:=  (21:53:23 on 5/16/01)",
  CellTags->"ExplicitPartialD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
          RowBox[{
            SubscriptBox[
              OverscriptBox["\[PartialD]", "\[RightArrow]"], 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"]], "-", 
            SubscriptBox[
              OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"]]}], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[573]=  (21:53:23 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"16", " ", 
      RowBox[{
        RowBox[{"LeftRightPartialD", "[", "OPEDelta", "]"}], "^", 
        "4"}]}]], "Input",
  CellLabel->"In[574]:=  (21:53:23 on 5/16/01)",
  CellTags->"ExplicitPartialD"],

Cell[BoxData[
    FormBox[
      RowBox[{"16", " ", 
        SubsuperscriptBox[
          OverscriptBox["\[PartialD]", "\[LeftRightArrow]"], 
          FormBox["\[CapitalDelta]",
            "TraditionalForm"], "4"]}], TraditionalForm]], "Output",
  CellLabel->"Out[574]=  (21:53:23 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["ExplicitSUNIndex", "ObjectName",
  CellTags->"ExplicitSUNIndex"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"ExplicitSUNIndex"],

Cell["\<\
ExplicitSUNIndex[ind] is a specific SU(N) index, i.e., ind is an integer.\
\>", "Text",
  CellTags->"ExplicitSUNIndex"],

Cell[TextData[{
  "See also: ",
  ButtonBox["FCI",
    ButtonData:>"FCI",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FCI"],
  ", ",
  ButtonBox["SUNDelta",
    ButtonData:>"SUNDelta",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SUNDelta"],
  ", ",
  ButtonBox["SUNF",
    ButtonData:>"SUNF",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SUNF"],
  ", ",
  ButtonBox["SUNIndex",
    ButtonData:>"SUNIndex",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SUNIndex"],
  "."
}], "Text",
  CellTags->"ExplicitSUNIndex"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"ExplicitSUNIndex"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ExplicitSUNIndex", "[", "1", "]"}]], "Input",
  CellLabel->"In[575]:=  (21:53:23 on 5/16/01)",
  CellTags->"ExplicitSUNIndex"],

Cell[BoxData[
    FormBox["1", TraditionalForm]], "Output",
  CellLabel->"Out[575]=  (21:53:23 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"SUNDelta", "[", 
          RowBox[{"1", ",", "a"}], "]"}], "//", "FCI"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[576]:=  (21:53:23 on 5/16/01)",
  CellTags->"ExplicitSUNIndex"],

Cell[BoxData[
    RowBox[{"SUNDelta", "[", 
      RowBox[{
        RowBox[{"ExplicitSUNIndex", "[", "1", "]"}], ",", 
        RowBox[{"SUNIndex", "[", "a", "]"}]}], "]"}]], "Output",
  CellLabel->"Out[576]//StandardForm=  (21:53:23 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Factor2", "ObjectName",
  CellTags->"Factor2"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"Factor2"],

Cell["\<\
Factor2[poly] factors a polynomial in a standard way. Factor2 works sometimes \
better than Factor on polynomials involving rationals with sums in the \
denominator. Factor2 uses Factor internally and is in general slower than \
Factor. There are four possible settings of the option Method (0,1,2,3). In \
general Factor will work faster than Factor2.\
\>", "Text",
  CellTags->"Factor2"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "Factor2", "]"}]], "Input",
  CellLabel->"In[577]:=  (21:53:23 on 5/16/01)",
  CellTags->"Factor2"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"FactorFull", "\[Rule]", "False"}], ",", 
          RowBox[{"Method", "\[Rule]", "3"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[577]=  (21:53:23 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["Collect2",
    ButtonData:>"Collect2",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Collect2"],
  "."
}], "Text",
  CellTags->"Factor2"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"Factor2"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t1", "=", 
      RowBox[{
        RowBox[{"(", 
          RowBox[{"a", "-", "x"}], ")"}], 
        RowBox[{"(", 
          RowBox[{"b", "-", "x"}], ")"}]}]}]], "Input",
  CellLabel->"In[578]:=  (21:53:23 on 5/16/01)",
  CellTags->"Factor2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"(", 
          RowBox[{"a", "-", "x"}], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{"b", "-", "x"}], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[578]=  (21:53:23 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t2", "=", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"Factor2", "[", "t1", "]"}], ",", " ", 
          RowBox[{"Factor", "[", "t1", "]"}]}], "}"}]}]], "Input",
  CellLabel->"In[579]:=  (21:53:23 on 5/16/01)",
  CellTags->"Factor2"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{
            RowBox[{"(", 
              RowBox[{"a", "-", "x"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"b", "-", "x"}], ")"}]}], ",", 
          RowBox[{
            RowBox[{"-", 
              RowBox[{"(", 
                RowBox[{"a", "-", "x"}], ")"}]}], " ", 
            RowBox[{"(", 
              RowBox[{"x", "-", "b"}], ")"}]}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[579]=  (21:53:23 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t3", "=", 
      RowBox[{"Expand", "[", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"a", "-", "b"}], ")"}], 
          RowBox[{"(", 
            RowBox[{"a", "+", "b"}], ")"}]}], "]"}]}]], "Input",
  CellLabel->"In[580]:=  (21:53:23 on 5/16/01)",
  CellTags->"Factor2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["b", "2"]}], TraditionalForm]], "Output",
  CellLabel->"Out[580]=  (21:53:24 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Factor", "[", "t3", "]"}]], "Input",
  CellLabel->"In[581]:=  (21:53:24 on 5/16/01)",
  CellTags->"Factor2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"(", 
          RowBox[{"a", "-", "b"}], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{"a", "+", "b"}], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[581]=  (21:53:24 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Factor2", "[", "t3", "]"}]], "Input",
  CellLabel->"In[582]:=  (21:53:24 on 5/16/01)",
  CellTags->"Factor2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["b", "2"]}], TraditionalForm]], "Output",
  CellLabel->"Out[582]=  (21:53:24 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Factor2", "[", 
      RowBox[{"t3", ",", 
        RowBox[{"FactorFull", "\[Rule]", "True"}]}], "]"}]], "Input",
  CellLabel->"In[583]:=  (21:53:24 on 5/16/01)",
  CellTags->"Factor2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"(", 
          RowBox[{"a", "-", "b"}], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{"a", "+", "b"}], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[583]=  (21:53:24 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{"Clear", "[", 
      RowBox[{"t1", ",", "t2", ",", "t3"}], "]"}]], "Input",
  CellLabel->"In[584]:=  (21:53:24 on 5/16/01)",
  CellTags->"Factor2"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["FAD", "ObjectName",
  CellTags->"FAD"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"FAD"],

Cell["\<\
FAD is the FeynCalc external form of FeynAmpDenominator and denotes an \
inverse propagator. FAD[q, q-p, ...] is 1/(q^2 (q-p)^2 ...). FAD[{q1,m}, \
{q1-p,m}, q2, ...] is 1/( (q1^2 - m^2) ( (q1-p)^2 - m^2 ) q2^2 ... ). \
Translation into FeynCalc internal form is performed by FeynCalcInternal.\
\>", "Text",
  CellTags->"FAD"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["FAD",
    ButtonData:>"FAD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FAD"],
  ", ",
  ButtonBox["FCE",
    ButtonData:>"FCE",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FCE"],
  ", ",
  ButtonBox["FCI",
    ButtonData:>"FCI",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FCI"],
  ", ",
  ButtonBox["FeynAmpDenominator",
    ButtonData:>"FeynAmpDenominator",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FeynAmpDenominator"],
  ", ",
  ButtonBox["FeynAmpDenominatorSimplify",
    ButtonData:>"FeynAmpDenominatorSimplify",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FeynAmpDenominatorSimplify"],
  ", ",
  ButtonBox["PropagatorDenominator",
    ButtonData:>"PropagatorDenominator",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"PropagatorDenominator"],
  "."
}], "Text",
  CellTags->"FAD"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"FAD"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FAD", "[", 
      RowBox[{"q", ",", 
        RowBox[{"p", "-", "q"}]}], "]"}]], "Input",
  CellLabel->"In[585]:=  (21:53:24 on 5/16/01)",
  CellTags->"FAD"],

Cell[BoxData[
    FormBox[
      FractionBox["1", 
        RowBox[{
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"p", "-", "q"}], ")"}], "2"], 
                "\[InvisibleSpace]", "\<\"]\"\>"}],
              SequenceForm[ "[", 
                Power[ 
                  Plus[ p, 
                    Times[ -1, q]], 2], "]"],
              Editable->False], ")"}], " ", 
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
                SuperscriptBox["q", "2"], "\[InvisibleSpace]", "\<\"]\"\>"}],
              SequenceForm[ "[", 
                Power[ q, 2], "]"],
              Editable->False], ")"}]}]], TraditionalForm]], "Output",
  CellLabel->"Out[585]=  (21:53:24 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FAD", "[", 
      RowBox[{"p", ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"p", "-", "q"}], ",", "m"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[586]:=  (21:53:24 on 5/16/01)",
  CellTags->"FAD"],

Cell[BoxData[
    FormBox[
      FractionBox["1", 
        RowBox[{
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
                SuperscriptBox["p", "2"], "\[InvisibleSpace]", "\<\"]\"\>"}],
              SequenceForm[ "[", 
                Power[ p, 2], "]"],
              Editable->False], ")"}], " ", 
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"p", "-", "q"}], ")"}], "2"], 
                "\[InvisibleSpace]", "\<\"-\"\>", "\[InvisibleSpace]", 
                SuperscriptBox["m", "2"], "\[InvisibleSpace]", "\<\"]\"\>"}],
              SequenceForm[ "[", 
                Power[ 
                  Plus[ p, 
                    Times[ -1, q]], 2], "-", 
                Power[ m, 2], "]"],
              Editable->False], ")"}]}]], TraditionalForm]], "Output",
  CellLabel->"Out[586]=  (21:53:24 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          RowBox[{"FAD", "[", 
            RowBox[{"q", ",", 
              RowBox[{"p", "-", "q"}]}], "]"}], "//", "FCI"}], "//", "FCE"}], 
      "//", "StandardForm"}]], "Input",
  CellLabel->"In[587]:=  (21:53:24 on 5/16/01)",
  CellTags->"FAD"],

Cell[BoxData[
    RowBox[{"FAD", "[", 
      RowBox[{"q", ",", 
        RowBox[{"p", "-", "q"}]}], "]"}]], "Output",
  CellLabel->"Out[587]//StandardForm=  (21:53:24 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"FAD", "[", 
          RowBox[{"q", ",", 
            RowBox[{"p", "-", "q"}]}], "]"}], "//", "FCI"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[588]:=  (21:53:24 on 5/16/01)",
  CellTags->"FAD"],

Cell[BoxData[
    RowBox[{"FeynAmpDenominator", "[", 
      RowBox[{
        RowBox[{"PropagatorDenominator", "[", 
          RowBox[{
            RowBox[{"Momentum", "[", 
              RowBox[{"q", ",", "D"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"PropagatorDenominator", "[", 
          RowBox[{
            RowBox[{
              RowBox[{"Momentum", "[", 
                RowBox[{"p", ",", "D"}], "]"}], "-", 
              RowBox[{"Momentum", "[", 
                RowBox[{"q", ",", "D"}], "]"}]}], ",", "0"}], "]"}]}], 
      "]"}]], "Output",
  CellLabel->"Out[588]//StandardForm=  (21:53:25 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          RowBox[{"FAD", "[", "p", "]"}], " ", 
          RowBox[{"FAD", "[", 
            RowBox[{"p", "-", "q"}], "]"}]}], " ", "//", " ", 
        "FeynAmpDenominatorCombine"}], "//", "StandardForm"}]], "Input",
  CellLabel->"In[589]:=  (21:53:25 on 5/16/01)",
  CellTags->"FAD"],

Cell[BoxData[
    RowBox[{"FeynAmpDenominator", "[", 
      RowBox[{
        RowBox[{"PropagatorDenominator", "[", 
          RowBox[{
            RowBox[{"Momentum", "[", 
              RowBox[{"p", ",", "D"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"PropagatorDenominator", "[", 
          RowBox[{
            RowBox[{
              RowBox[{"Momentum", "[", 
                RowBox[{"p", ",", "D"}], "]"}], "-", 
              RowBox[{"Momentum", "[", 
                RowBox[{"q", ",", "D"}], "]"}]}], ",", "0"}], "]"}]}], 
      "]"}]], "Output",
  CellLabel->"Out[589]//StandardForm=  (21:53:25 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["FCE", "ObjectName",
  CellTags->"FCE"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"FCE"],

Cell["\<\
FCE[exp] translates exp from the internal FeynCalc representation to a short \
form.\
\>", "Text",
  CellTags->"FCE"],

Cell["FCE is equivalent to FeynCalcExternal.", "Text",
  CellTags->"FCE"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["FeynCalcExternal",
    ButtonData:>"FeynCalcExternal",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FeynCalcExternal"],
  ", ",
  ButtonBox["FCI",
    ButtonData:>"FCI",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FCI"],
  ", ",
  ButtonBox["FeynCalcInternal",
    ButtonData:>"FeynCalcInternal",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FeynCalcInternal"],
  "."
}], "Text",
  CellTags->"FCE"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"FCE"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FCE", "[", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"DiracGamma", "[", "5", "]"}], ",", 
          RowBox[{"DiracGamma", "[", 
            RowBox[{"Momentum", "[", "p", "]"}], "]"}]}], "}"}], 
      "]"}]], "Input",
  CellLabel->"In[590]:=  (21:53:25 on 5/16/01)",
  CellTags->"FCE"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          SuperscriptBox["\[Gamma]", "5"], ",", 
          RowBox[{
          "\[Gamma]", "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "p"}]}], 
        "}"}], TraditionalForm]], "Output",
  CellLabel->"Out[590]=  (21:53:25 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "StandardForm"}]], "Input",
  CellLabel->"In[591]:=  (21:53:25 on 5/16/01)",
  CellTags->"FCE"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"GA", "[", "5", "]"}], ",", 
        RowBox[{"GS", "[", "p", "]"}]}], "}"}]], "Output",
  CellLabel->"Out[591]//StandardForm=  (21:53:25 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"GA", "[", "\[Mu]", "]"}], ",", 
        RowBox[{"GAD", "[", "\[Rho]", "]"}], ",", 
        RowBox[{"GS", "[", "p", "]"}], ",", 
        RowBox[{"SP", "[", 
          RowBox[{"p", ",", "q"}], "]"}], ",", 
        RowBox[{"MT", "[", 
          RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], ",", 
        RowBox[{"FV", "[", 
          RowBox[{"p", ",", "\[Mu]"}], "]"}]}], "}"}]], "Input",
  CellLabel->"In[592]:=  (21:53:25 on 5/16/01)",
  CellTags->"FCE"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          SuperscriptBox["\[Gamma]", "\[Mu]"], ",", 
          SuperscriptBox["\[Gamma]", "\[Rho]"], ",", 
          RowBox[{
          "\[Gamma]", "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "p"}], ",", 
          
          FormBox[
            RowBox[{
              FormBox["p",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox["q",
                "TraditionalForm"]}],
            "TraditionalForm"], ",", 
          SuperscriptBox["g", 
            RowBox[{"\[Alpha]", "\[NoBreak]", "\[Beta]"}]], ",", 
          SuperscriptBox["p", "\[Mu]"]}], "}"}], TraditionalForm]], "Output",
  CellLabel->"Out[592]=  (21:53:25 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "StandardForm"}]], "Input",
  CellLabel->"In[593]:=  (21:53:25 on 5/16/01)",
  CellTags->"FCE"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"GA", "[", "\[Mu]", "]"}], ",", 
        RowBox[{"GAD", "[", "\[Rho]", "]"}], ",", 
        RowBox[{"GS", "[", "p", "]"}], ",", 
        RowBox[{"SP", "[", 
          RowBox[{"p", ",", "q"}], "]"}], ",", 
        RowBox[{"MT", "[", 
          RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], ",", 
        RowBox[{"FV", "[", 
          RowBox[{"p", ",", "\[Mu]"}], "]"}]}], "}"}]], "Output",
  CellLabel->"Out[593]//StandardForm=  (21:53:25 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "FCI"}]], "Input",
  CellLabel->"In[594]:=  (21:53:25 on 5/16/01)",
  CellTags->"FCE"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], ",", 
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox["\[Rho]",
                "TraditionalForm"],
              "TraditionalForm"]], ",", 
          RowBox[{
            FormBox["\<\"\[Gamma]\"\>",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["p",
              "TraditionalForm"]}], ",", 
          RowBox[{
            FormBox["p",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["q",
              "TraditionalForm"]}], ",", 
          SuperscriptBox["g", 
            RowBox[{"\[Alpha]", "\[NoBreak]", "\[Beta]"}]], ",", 
          SuperscriptBox[
            FormBox["p",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]]}], "}"}], TraditionalForm]], "Output",
  CellLabel->"Out[594]=  (21:53:25 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "StandardForm"}]], "Input",
  CellLabel->"In[595]:=  (21:53:25 on 5/16/01)",
  CellTags->"FCE"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"DiracGamma", "[", 
          RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], "]"}], ",", 
        RowBox[{"DiracGamma", "[", 
          RowBox[{
            RowBox[{"LorentzIndex", "[", 
              RowBox[{"\[Rho]", ",", "D"}], "]"}], ",", "D"}], "]"}], ",", 
        RowBox[{"DiracGamma", "[", 
          RowBox[{"Momentum", "[", "p", "]"}], "]"}], ",", 
        RowBox[{"Pair", "[", 
          RowBox[{
            RowBox[{"Momentum", "[", "p", "]"}], ",", 
            RowBox[{"Momentum", "[", "q", "]"}]}], "]"}], ",", 
        RowBox[{"Pair", "[", 
          RowBox[{
            RowBox[{"LorentzIndex", "[", "\[Alpha]", "]"}], ",", 
            RowBox[{"LorentzIndex", "[", "\[Beta]", "]"}]}], "]"}], ",", 
        RowBox[{"Pair", "[", 
          RowBox[{
            RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
            RowBox[{"Momentum", "[", "p", "]"}]}], "]"}]}], "}"}]], "Output",
  CellLabel->"Out[595]//StandardForm=  (21:53:25 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"FCE", "[", "%", "]"}], "//", "StandardForm"}]], "Input",
  CellLabel->"In[596]:=  (21:53:25 on 5/16/01)",
  CellTags->"FCE"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"GA", "[", "\[Mu]", "]"}], ",", 
        RowBox[{"GAD", "[", "\[Rho]", "]"}], ",", 
        RowBox[{"GS", "[", "p", "]"}], ",", 
        RowBox[{"SP", "[", 
          RowBox[{"p", ",", "q"}], "]"}], ",", 
        RowBox[{"MT", "[", 
          RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], ",", 
        RowBox[{"FV", "[", 
          RowBox[{"p", ",", "\[Mu]"}], "]"}]}], "}"}]], "Output",
  CellLabel->"Out[596]//StandardForm=  (21:53:25 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["FCI", "ObjectName",
  CellTags->"FCI"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"FCI"],

Cell["\<\
FCI[exp] translates exp into the internal FeynCalc \
(datatype-)representation.FCI is equivalent to FeynCalcInternal.\
\>", "Text",
  CellTags->"FCI"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["FeynCalcExternal",
    ButtonData:>"FeynCalcExternal",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FeynCalcExternal"],
  ", ",
  ButtonBox["FeynCalcInternal",
    ButtonData:>"FeynCalcInternal",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FeynCalcInternal"],
  ", ",
  ButtonBox["FCE",
    ButtonData:>"FCE",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FCE"],
  "."
}], "Text",
  CellTags->"FCI"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"FCI"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"GA", "[", "\[Mu]", "]"}], ",", 
        RowBox[{"GAD", "[", "\[Rho]", "]"}], ",", 
        RowBox[{"GS", "[", "p", "]"}], ",", 
        RowBox[{"SP", "[", 
          RowBox[{"p", ",", "q"}], "]"}], ",", 
        RowBox[{"MT", "[", 
          RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], ",", 
        RowBox[{"FV", "[", 
          RowBox[{"p", ",", "\[Mu]"}], "]"}]}], "}"}]], "Input",
  CellLabel->"In[597]:=  (21:53:25 on 5/16/01)",
  CellTags->"FCI"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          SuperscriptBox["\[Gamma]", "\[Mu]"], ",", 
          SuperscriptBox["\[Gamma]", "\[Rho]"], ",", 
          RowBox[{
          "\[Gamma]", "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "p"}], ",", 
          
          FormBox[
            RowBox[{
              FormBox["p",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox["q",
                "TraditionalForm"]}],
            "TraditionalForm"], ",", 
          SuperscriptBox["g", 
            RowBox[{"\[Alpha]", "\[NoBreak]", "\[Beta]"}]], ",", 
          SuperscriptBox["p", "\[Mu]"]}], "}"}], TraditionalForm]], "Output",
  CellLabel->"Out[597]=  (21:53:25 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "StandardForm"}]], "Input",
  CellLabel->"In[598]:=  (21:53:25 on 5/16/01)",
  CellTags->"FCI"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"GA", "[", "\[Mu]", "]"}], ",", 
        RowBox[{"GAD", "[", "\[Rho]", "]"}], ",", 
        RowBox[{"GS", "[", "p", "]"}], ",", 
        RowBox[{"SP", "[", 
          RowBox[{"p", ",", "q"}], "]"}], ",", 
        RowBox[{"MT", "[", 
          RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], ",", 
        RowBox[{"FV", "[", 
          RowBox[{"p", ",", "\[Mu]"}], "]"}]}], "}"}]], "Output",
  CellLabel->"Out[598]//StandardForm=  (21:53:25 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "FCI"}]], "Input",
  CellLabel->"In[599]:=  (21:53:25 on 5/16/01)",
  CellTags->"FCI"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], ",", 
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox["\[Rho]",
                "TraditionalForm"],
              "TraditionalForm"]], ",", 
          RowBox[{
            FormBox["\<\"\[Gamma]\"\>",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["p",
              "TraditionalForm"]}], ",", 
          RowBox[{
            FormBox["p",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["q",
              "TraditionalForm"]}], ",", 
          SuperscriptBox["g", 
            RowBox[{"\[Alpha]", "\[NoBreak]", "\[Beta]"}]], ",", 
          SuperscriptBox[
            FormBox["p",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]]}], "}"}], TraditionalForm]], "Output",
  CellLabel->"Out[599]=  (21:53:25 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "StandardForm"}]], "Input",
  CellLabel->"In[600]:=  (21:53:25 on 5/16/01)",
  CellTags->"FCI"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"DiracGamma", "[", 
          RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], "]"}], ",", 
        RowBox[{"DiracGamma", "[", 
          RowBox[{
            RowBox[{"LorentzIndex", "[", 
              RowBox[{"\[Rho]", ",", "D"}], "]"}], ",", "D"}], "]"}], ",", 
        RowBox[{"DiracGamma", "[", 
          RowBox[{"Momentum", "[", "p", "]"}], "]"}], ",", 
        RowBox[{"Pair", "[", 
          RowBox[{
            RowBox[{"Momentum", "[", "p", "]"}], ",", 
            RowBox[{"Momentum", "[", "q", "]"}]}], "]"}], ",", 
        RowBox[{"Pair", "[", 
          RowBox[{
            RowBox[{"LorentzIndex", "[", "\[Alpha]", "]"}], ",", 
            RowBox[{"LorentzIndex", "[", "\[Beta]", "]"}]}], "]"}], ",", 
        RowBox[{"Pair", "[", 
          RowBox[{
            RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
            RowBox[{"Momentum", "[", "p", "]"}]}], "]"}]}], "}"}]], "Output",
  CellLabel->"Out[600]//StandardForm=  (21:53:25 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"FCE", "[", "%", "]"}], "//", "StandardForm"}]], "Input",
  CellLabel->"In[601]:=  (21:53:25 on 5/16/01)",
  CellTags->"FCI"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"GA", "[", "\[Mu]", "]"}], ",", 
        RowBox[{"GAD", "[", "\[Rho]", "]"}], ",", 
        RowBox[{"GS", "[", "p", "]"}], ",", 
        RowBox[{"SP", "[", 
          RowBox[{"p", ",", "q"}], "]"}], ",", 
        RowBox[{"MT", "[", 
          RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], ",", 
        RowBox[{"FV", "[", 
          RowBox[{"p", ",", "\[Mu]"}], "]"}]}], "}"}]], "Output",
  CellLabel->"Out[601]//StandardForm=  (21:53:25 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["FermionSpinSum", "ObjectName",
  CellTags->"FermionSpinSum"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"FermionSpinSum"],

Cell["\<\
FermionSpinSum[x] constructs the Traces out of squared ampliudes.\
\>", "Text",
  CellTags->"FermionSpinSum"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "FermionSpinSum", "]"}]], "Input",
  CellLabel->"In[602]:=  (21:53:25 on 5/16/01)",
  CellTags->"FermionSpinSum"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"SpinPolarizationSum", "\[Rule]", "Identity"}], ",", 
          RowBox[{"SpinorCollect", "\[Rule]", "False"}], ",", 
          RowBox[{"ExtraFactor", "\[Rule]", "1"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[602]=  (21:53:26 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["ComplexConjugate",
    ButtonData:>"ComplexConjugate",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"ComplexConjugate"],
  ", ",
  ButtonBox["DiracTrace",
    ButtonData:>"DiracTrace",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracTrace"],
  ", ",
  ButtonBox["Tr",
    ButtonData:>"Tr",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Tr"],
  "."
}], "Text",
  CellTags->"FermionSpinSum"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"FermionSpinSum"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t", "=", 
      RowBox[{
        RowBox[{"Spinor", "[", 
          RowBox[{"k1", ",", "m"}], "]"}], ".", 
        RowBox[{"DiracSlash", "[", "p", "]"}], ".", 
        RowBox[{"GA", "[", "5", "]"}], ".", 
        RowBox[{"Spinor", "[", 
          RowBox[{"p1", ",", "m"}], "]"}]}]}]], "Input",
  CellLabel->"In[603]:=  (21:53:26 on 5/16/01)",
  CellTags->"FermionSpinSum"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[CurlyPhi]", "\[NoBreak]", "(", "\[NoBreak]", 
          FormBox["k1",
            "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", "m", 
          "\[NoBreak]", ")"}], ".", 
        RowBox[{"(", 
          RowBox[{
            FormBox["\<\"\[Gamma]\"\>",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["p",
              "TraditionalForm"]}], ")"}], ".", 
        SuperscriptBox["\[Gamma]", "5"], ".", 
        RowBox[{"\[CurlyPhi]", "\[NoBreak]", "(", "\[NoBreak]", 
          FormBox["p1",
            "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", "m", 
          "\[NoBreak]", ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[603]=  (21:53:26 on 5/16/01)"]
}, Closed]],

Cell["\<\
Notice that SpinorUBar and SpinorU are only input functions. Internally they \
are converted to Spinor objects.\
\>", "Text",
  CellTags->"FermionSpinSum"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ct", "=", 
      RowBox[{"ComplexConjugate", "[", "t", "]"}]}]], "Input",
  CellLabel->"In[604]:=  (21:53:26 on 5/16/01)",
  CellTags->"FermionSpinSum"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        RowBox[{
          RowBox[{"\[CurlyPhi]", "\[NoBreak]", "(", "\[NoBreak]", 
            FormBox["p1",
              "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", "m", 
            "\[NoBreak]", ")"}], ".", 
          SuperscriptBox["\[Gamma]", "5"], ".", 
          RowBox[{"(", 
            RowBox[{
              FormBox["\<\"\[Gamma]\"\>",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox["p",
                "TraditionalForm"]}], ")"}], ".", 
          RowBox[{"\[CurlyPhi]", "\[NoBreak]", "(", "\[NoBreak]", 
            FormBox["k1",
              "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", "m", 
            "\[NoBreak]", ")"}]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[604]=  (21:53:26 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FermionSpinSum", "[", 
      RowBox[{"t", " ", "ct"}], "]"}]], "Input",
  CellLabel->"In[605]:=  (21:53:26 on 5/16/01)",
  CellTags->"FermionSpinSum"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        RowBox[{"tr", "(", 
          FormBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{"m", "+", 
                  RowBox[{
                    FormBox["\<\"\[Gamma]\"\>",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["k1",
                      "TraditionalForm"]}]}], ")"}], ".", 
              RowBox[{"(", 
                RowBox[{
                  FormBox["\<\"\[Gamma]\"\>",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["p",
                    "TraditionalForm"]}], ")"}], ".", 
              SuperscriptBox["\[Gamma]", "5"], ".", 
              RowBox[{"(", 
                RowBox[{"m", "+", 
                  RowBox[{
                    FormBox["\<\"\[Gamma]\"\>",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["p1",
                      "TraditionalForm"]}]}], ")"}], ".", 
              SuperscriptBox["\[Gamma]", "5"], ".", 
              RowBox[{"(", 
                RowBox[{
                  FormBox["\<\"\[Gamma]\"\>",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["p",
                    "TraditionalForm"]}], ")"}]}],
            "TraditionalForm"], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[605]=  (21:53:26 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", " ", "/.", 
      RowBox[{"DiracTrace", "->", "Tr"}]}]], "Input",
  CellLabel->"In[606]:=  (21:53:26 on 5/16/01)",
  CellTags->"FermionSpinSum"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", "4"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"], " ", 
              SuperscriptBox["m", "2"]}], "+", 
            RowBox[{
              RowBox[{
                FormBox["k1",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["p1",
                  "TraditionalForm"]}], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"]}], "-", 
            RowBox[{"2", " ", 
              RowBox[{
                FormBox["k1",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["p",
                  "TraditionalForm"]}], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["p1",
                  "TraditionalForm"]}]}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[606]=  (21:53:26 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{"Clear", "[", 
      RowBox[{"t", ",", " ", "ct"}], "]"}]], "Input",
  CellLabel->"In[607]:=  (21:53:26 on 5/16/01)",
  CellTags->"FermionSpinSum"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["FeynAmpDenominatorCombine", "ObjectName",
  CellTags->"FeynAmpDenominatorCombine"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"FeynAmpDenominatorCombine"],

Cell["\<\
FeynAmpDenominatorCombine[expr] expands expr with respect to \
FeynAmpDenominator and combines products of FeynAmpDenominator in expr into \
one FeynAmpDenominator.\
\>", "Text",
  CellTags->"FeynAmpDenominatorCombine"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["FeynAmpDenominatorSplit",
    ButtonData:>"FeynAmpDenominatorSplit",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FeynAmpDenominatorSplit"],
  "."
}], "Text",
  CellTags->"FeynAmpDenominatorCombine"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"FeynAmpDenominatorCombine"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t", " ", "=", " ", 
      RowBox[{
        RowBox[{"FAD", "[", "q", "]"}], " ", 
        RowBox[{"FAD", "[", 
          RowBox[{"q", "-", "p"}], "]"}]}]}]], "Input",
  CellLabel->"In[608]:=  (21:53:26 on 5/16/01)",
  CellTags->"FeynAmpDenominatorCombine"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          FractionBox["1", 
            InterpretationBox[
              RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
                SuperscriptBox["q", "2"], "\[InvisibleSpace]", "\<\"]\"\>"}],
              SequenceForm[ "[", 
                Power[ q, 2], "]"],
              Editable->False]],
          "TraditionalForm"], " ", 
        FormBox[
          FractionBox["1", 
            InterpretationBox[
              RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"q", "-", "p"}], ")"}], "2"], 
                "\[InvisibleSpace]", "\<\"]\"\>"}],
              SequenceForm[ "[", 
                Power[ 
                  Plus[ 
                    Times[ -1, p], q], 2], "]"],
              Editable->False]],
          "TraditionalForm"]}], TraditionalForm]], "Output",
  CellLabel->"Out[608]=  (21:53:26 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"FeynAmpDenominatorCombine", "[", "%", "]"}], "//", "FCE"}], "//",
       "StandardForm"}]], "Input",
  CellLabel->"In[609]:=  (21:53:26 on 5/16/01)",
  CellTags->"FeynAmpDenominatorCombine"],

Cell[BoxData[
    RowBox[{"FAD", "[", 
      RowBox[{"q", ",", 
        RowBox[{
          RowBox[{"-", "p"}], "+", "q"}]}], "]"}]], "Output",
  CellLabel->"Out[609]//StandardForm=  (21:53:26 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"FeynAmpDenominatorSplit", "[", "%", "]"}], "//", "FCE"}], "//",
       "StandardForm"}]], "Input",
  CellLabel->"In[610]:=  (21:53:26 on 5/16/01)",
  CellTags->"FeynAmpDenominatorCombine"],

Cell[BoxData[
    RowBox[{
      RowBox[{"FAD", "[", "q", "]"}], " ", 
      RowBox[{"FAD", "[", 
        RowBox[{
          RowBox[{"-", "p"}], "+", "q"}], "]"}]}]], "Output",
  CellLabel->"Out[610]//StandardForm=  (21:53:27 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["FeynAmpDenominator", "ObjectName",
  CellTags->"FeynAmpDenominator"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"FeynAmpDenominator"],

Cell["\<\
FeynAmpDenominator[ PropagatorDenominator[ ... ], PropagatorDenominator[ ... \
], ...] is the head of the denominators of the propagators, i.e., \
FeynAmpDenominator[x] is the representation of 1/x .\
\>", "Text",
  CellTags->"FeynAmpDenominator"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["FAD",
    ButtonData:>"FAD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FAD"],
  ", ",
  ButtonBox["FeynAmpDenominatorSimplify",
    ButtonData:>"FeynAmpDenominatorSimplify",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FeynAmpDenominatorSimplify"],
  "."
}], "Text",
  CellTags->"FeynAmpDenominator"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"FeynAmpDenominator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FeynAmpDenominator", "[", 
      RowBox[{"PropagatorDenominator", "[", 
        RowBox[{"p", ",", "m"}], "]"}], "]"}]], "Input",
  CellLabel->"In[611]:=  (21:53:27 on 5/16/01)",
  CellTags->"FeynAmpDenominator"],

Cell[BoxData[
    FormBox[
      FractionBox["1", 
        RowBox[{
          SuperscriptBox["p", "2"], "-", 
          SuperscriptBox["m", "2"]}]], TraditionalForm]], "Output",
  CellLabel->"Out[611]=  (21:53:27 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FeynAmpDenominator", "[", 
      RowBox[{
        RowBox[{"PropagatorDenominator", "[", 
          RowBox[{"p", ",", "m"}], "]"}], ",", 
        RowBox[{"PropagatorDenominator", "[", 
          RowBox[{
            RowBox[{"p", "-", "q"}], ",", "m"}], "]"}]}], "]"}]], "Input",
  CellLabel->"In[612]:=  (21:53:27 on 5/16/01)",
  CellTags->"FeynAmpDenominator"],

Cell[BoxData[
    FormBox[
      FractionBox["1", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox["p", "2"], "-", 
              SuperscriptBox["m", "2"]}], ")"}], ".", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"p", "-", "q"}], ")"}], "2"], "-", 
              SuperscriptBox["m", "2"]}], ")"}]}]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[612]=  (21:53:27 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      RowBox[{"t", "=", 
        RowBox[{"FeynAmpDenominator", "[", 
          RowBox[{"PropagatorDenominator", "[", 
            RowBox[{"p", ",", "m"}], "]"}], "]"}]}], ";"}]], "Input",
  CellLabel->"In[613]:=  (21:53:27 on 5/16/01)",
  CellTags->"FeynAmpDenominator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StandardForm", "[", 
      RowBox[{"t", "//", "FCI"}], "]"}]], "Input",
  CellLabel->"In[614]:=  (21:53:27 on 5/16/01)",
  CellTags->"FeynAmpDenominator"],

Cell[BoxData[
    RowBox[{"FeynAmpDenominator", "[", 
      RowBox[{"PropagatorDenominator", "[", 
        RowBox[{
          RowBox[{"Momentum", "[", 
            RowBox[{"p", ",", "D"}], "]"}], ",", "m"}], "]"}], 
      "]"}]], "Output",
  CellLabel->"Out[614]//StandardForm=  (21:53:27 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StandardForm", "[", 
      RowBox[{"t", "//", "FCE"}], "]"}]], "Input",
  CellLabel->"In[615]:=  (21:53:27 on 5/16/01)",
  CellTags->"FeynAmpDenominator"],

Cell[BoxData[
    RowBox[{"FAD", "[", 
      RowBox[{"{", 
        RowBox[{"p", ",", "m"}], "}"}], "]"}]], "Output",
  CellLabel->"Out[615]//StandardForm=  (21:53:27 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      RowBox[{"Clear", "[", "t", "]"}], ";"}]], "Input",
  CellLabel->"In[616]:=  (21:53:27 on 5/16/01)",
  CellTags->"FeynAmpDenominator"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["FeynAmpDenominatorSimplify", "ObjectName",
  CellTags->"FeynAmpDenominatorSimplify"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"FeynAmpDenominatorSimplify"],

Cell["\<\
FeynAmpDenominatorSimplify[exp] tries to simplify each PropagatorDenominator \
in a canonical way. FeynAmpDenominatorSimplify[exp, q1] simplifies all \
FeynAmpDenominator's in exp in a canonical way, including some translation of \
momenta. FeynAmpDenominatorSimplify[exp, q1, q2] additionally removes \
integrals with no mass scale.\
\>", "Text",
  CellTags->"FeynAmpDenominatorSimplify"],

Cell["FDS can be used as an alias.", "Text",
  CellTags->"FeynAmpDenominatorSimplify"],

Cell[CellGroupData[{

Cell[BoxData["FDS"], "Input",
  CellLabel->"In[617]:=  (21:53:27 on 5/16/01)",
  CellTags->"FeynAmpDenominatorSimplify"],

Cell[BoxData[
    FormBox["FeynAmpDenominatorSimplify", TraditionalForm]], "Output",
  CellLabel->"Out[617]=  (21:53:27 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["OneLoopSimplify",
    ButtonData:>"OneLoopSimplify",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"OneLoopSimplify"],
  "."
}], "Text",
  CellTags->"FeynAmpDenominatorSimplify"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"FeynAmpDenominatorSimplify"],

Cell[TextData[{
  "The cornerstone of dimensional regularization is that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[Integral]", 
            RowBox[{
              SuperscriptBox["d", "n"], "k", " ", 
              RowBox[{
                RowBox[{"f", "(", "k", ")"}], "/", 
                SuperscriptBox["k", 
                  RowBox[{"2", "m"}]]}]}]}], "=", " ", 
          RowBox[{"0", " ", "."}]}], TraditionalForm]]]
}], "Text",
  CellTags->"FeynAmpDenominatorSimplify"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FeynAmpDenominatorSimplify", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"f", "[", "k", "]"}], " ", 
          RowBox[{"FAD", "[", 
            RowBox[{"k", ",", "k"}], "]"}]}], ",", "k"}], "]"}]], "Input",
  CellLabel->"In[618]:=  (21:53:27 on 5/16/01)",
  CellTags->"FeynAmpDenominatorSimplify"],

Cell[BoxData[
    FormBox["0", TraditionalForm]], "Output",
  CellLabel->"Out[618]=  (21:53:27 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "This brings ",
  Cell[BoxData[
      FormBox[
        RowBox[{"1", "/", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"k", "-", 
                    SubscriptBox["p", "1"]}], ")"}], "2"], " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"k", "-", 
                    SubscriptBox["p", "2"]}], ")"}], "2"]}], ")"}]}], 
        TraditionalForm]]],
  " into a standard form."
}], "Text",
  CellTags->"FeynAmpDenominatorSimplify"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FeynAmpDenominatorSimplify", "[", 
      RowBox[{
        RowBox[{"FAD", "[", 
          RowBox[{
            RowBox[{"k", "-", 
              SubscriptBox["p", "1"]}], ",", 
            RowBox[{"k", "-", 
              SubscriptBox["p", "2"]}]}], "]"}], ",", "k"}], "]"}]], "Input",
  CellLabel->"In[619]:=  (21:53:27 on 5/16/01)",
  CellTags->"FeynAmpDenominatorSimplify"],

Cell[BoxData[
    FormBox[
      FractionBox["1", 
        RowBox[{
          SuperscriptBox[
            FormBox[
              TagBox[
                StyleBox["\<\"k\"\>",
                  FontSlant->"Italic"],
                (StyleForm[ #, FontSlant -> "Italic"]&)],
              "TraditionalForm"], "2"], ".", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"], "-", 
                SubscriptBox["p", "1"], "+", 
                SubscriptBox["p", "2"]}], ")"}], "2"]}]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[619]=  (21:53:28 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t", "=", 
      RowBox[{"FeynAmpDenominatorSimplify", "[", 
        RowBox[{
          RowBox[{
            RowBox[{"FAD", "[", 
              RowBox[{
                RowBox[{"k", "-", 
                  SubscriptBox["p", "1"]}], ",", 
                RowBox[{"k", "-", 
                  SubscriptBox["p", "2"]}]}], "]"}], " ", 
            RowBox[{"SPD", "[", 
              RowBox[{"k", ",", "k"}], "]"}]}], ",", "k"}], "]"}]}]], "Input",\

  CellLabel->"In[620]:=  (21:53:28 on 5/16/01)",
  CellTags->"FeynAmpDenominatorSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          SuperscriptBox[
            FormBox[
              FormBox[
                TagBox[
                  StyleBox["\<\"k\"\>",
                    FontSlant->"Italic"],
                  (StyleForm[ #, FontSlant -> "Italic"]&)],
                "TraditionalForm"],
              "TraditionalForm"], "2"], 
          RowBox[{
            SuperscriptBox[
              FormBox[
                TagBox[
                  StyleBox["\<\"k\"\>",
                    FontSlant->"Italic"],
                  (StyleForm[ #, FontSlant -> "Italic"]&)],
                "TraditionalForm"], "2"], ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  FormBox[
                    TagBox[
                      StyleBox["\<\"k\"\>",
                        FontSlant->"Italic"],
                      (StyleForm[ #, FontSlant -> "Italic"]&)],
                    "TraditionalForm"], "-", 
                  SubscriptBox["p", "1"], "+", 
                  SubscriptBox["p", "2"]}], ")"}], "2"]}]], "+", 
        FractionBox[
          RowBox[{"2", " ", 
            RowBox[{
              FormBox[
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox[
                SubscriptBox["p", "2"],
                "TraditionalForm"]}]}], 
          RowBox[{
            SuperscriptBox[
              FormBox[
                TagBox[
                  StyleBox["\<\"k\"\>",
                    FontSlant->"Italic"],
                  (StyleForm[ #, FontSlant -> "Italic"]&)],
                "TraditionalForm"], "2"], ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  FormBox[
                    TagBox[
                      StyleBox["\<\"k\"\>",
                        FontSlant->"Italic"],
                      (StyleForm[ #, FontSlant -> "Italic"]&)],
                    "TraditionalForm"], "-", 
                  SubscriptBox["p", "1"], "+", 
                  SubscriptBox["p", "2"]}], ")"}], "2"]}]], "+", 
        FractionBox[
          SubsuperscriptBox["p", "2", "2"], 
          RowBox[{
            SuperscriptBox[
              FormBox[
                TagBox[
                  StyleBox["\<\"k\"\>",
                    FontSlant->"Italic"],
                  (StyleForm[ #, FontSlant -> "Italic"]&)],
                "TraditionalForm"], "2"], ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  FormBox[
                    TagBox[
                      StyleBox["\<\"k\"\>",
                        FontSlant->"Italic"],
                      (StyleForm[ #, FontSlant -> "Italic"]&)],
                    "TraditionalForm"], "-", 
                  SubscriptBox["p", "1"], "+", 
                  SubscriptBox["p", "2"]}], ")"}], "2"]}]]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[620]=  (21:53:28 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"r", "=", 
      RowBox[{"SPC", "[", 
        RowBox[{"t", ",", "k", ",", 
          RowBox[{"FDS", "\[Rule]", "True"}]}], "]"}]}]], "Input",
  CellLabel->"In[621]:=  (21:53:28 on 5/16/01)",
  CellTags->"FeynAmpDenominatorSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          SubsuperscriptBox["p", "2", "2"], 
          RowBox[{
            SuperscriptBox[
              FormBox[
                TagBox[
                  StyleBox["\<\"k\"\>",
                    FontSlant->"Italic"],
                  (StyleForm[ #, FontSlant -> "Italic"]&)],
                "TraditionalForm"], "2"], ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  FormBox[
                    TagBox[
                      StyleBox["\<\"k\"\>",
                        FontSlant->"Italic"],
                      (StyleForm[ #, FontSlant -> "Italic"]&)],
                    "TraditionalForm"], "-", 
                  SubscriptBox["p", "1"], "+", 
                  SubscriptBox["p", "2"]}], ")"}], "2"]}]], "-", 
        FractionBox[
          RowBox[{"2", " ", 
            RowBox[{
              FormBox[
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox[
                SubscriptBox["p", "2"],
                "TraditionalForm"]}]}], 
          RowBox[{
            SuperscriptBox[
              FormBox[
                TagBox[
                  StyleBox["\<\"k\"\>",
                    FontSlant->"Italic"],
                  (StyleForm[ #, FontSlant -> "Italic"]&)],
                "TraditionalForm"], "2"], ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  FormBox[
                    TagBox[
                      StyleBox["\<\"k\"\>",
                        FontSlant->"Italic"],
                      (StyleForm[ #, FontSlant -> "Italic"]&)],
                    "TraditionalForm"], "+", 
                  SubscriptBox["p", "1"], "-", 
                  SubscriptBox["p", "2"]}], ")"}], "2"]}]]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[621]=  (21:53:28 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"OneLoopSimplify", "[", 
      RowBox[{"r", ",", "k"}], "]"}]], "Input",
  CellLabel->"In[622]:=  (21:53:29 on 5/16/01)",
  CellTags->"FeynAmpDenominatorSimplify"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{
          FormBox[
            SubscriptBox["p", "1"],
            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
          FormBox[
            SubscriptBox["p", "2"],
            "TraditionalForm"]}], 
        RowBox[{
          SuperscriptBox[
            FormBox[
              TagBox[
                StyleBox["\<\"k\"\>",
                  FontSlant->"Italic"],
                (StyleForm[ #, FontSlant -> "Italic"]&)],
              "TraditionalForm"], "2"], ".", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"], "-", 
                SubscriptBox["p", "1"], "+", 
                SubscriptBox["p", "2"]}], ")"}], "2"]}]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[622]=  (21:53:30 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FDS", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"FAD", "[", 
            RowBox[{
              RowBox[{"k", "-", "p1"}], ",", 
              RowBox[{"k", "-", "p2"}]}], "]"}], 
          RowBox[{
            RowBox[{"SPD", "[", 
              RowBox[{"k", ",", "OPEDelta"}], "]"}], "^", "2"}]}], ",", "k"}],
       "]"}]], "Input",
  CellLabel->"In[623]:=  (21:53:30 on 5/16/01)",
  CellTags->"FeynAmpDenominatorSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          SuperscriptBox[
            RowBox[{"(", 
              FormBox[
                RowBox[{
                  FormBox[
                    FormBox[
                      TagBox[
                        StyleBox["\<\"k\"\>",
                          FontSlant->"Italic"],
                        (StyleForm[ #, FontSlant -> "Italic"]&)],
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"]}],
                "TraditionalForm"], ")"}], "2"], 
          RowBox[{
            SuperscriptBox[
              FormBox[
                TagBox[
                  StyleBox["\<\"k\"\>",
                    FontSlant->"Italic"],
                  (StyleForm[ #, FontSlant -> "Italic"]&)],
                "TraditionalForm"], "2"], ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  FormBox[
                    TagBox[
                      StyleBox["\<\"k\"\>",
                        FontSlant->"Italic"],
                      (StyleForm[ #, FontSlant -> "Italic"]&)],
                    "TraditionalForm"], "-", "p1", "+", "p2"}], ")"}], 
              "2"]}]], "+", 
        FractionBox[
          RowBox[{"2", " ", 
            RowBox[{
              FormBox[
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"]}], " ", 
            RowBox[{
              FormBox["\[CapitalDelta]",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox["p2",
                "TraditionalForm"]}]}], 
          RowBox[{
            SuperscriptBox[
              FormBox[
                TagBox[
                  StyleBox["\<\"k\"\>",
                    FontSlant->"Italic"],
                  (StyleForm[ #, FontSlant -> "Italic"]&)],
                "TraditionalForm"], "2"], ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  FormBox[
                    TagBox[
                      StyleBox["\<\"k\"\>",
                        FontSlant->"Italic"],
                      (StyleForm[ #, FontSlant -> "Italic"]&)],
                    "TraditionalForm"], "-", "p1", "+", "p2"}], ")"}], 
              "2"]}]], "+", 
        FractionBox[
          SuperscriptBox[
            RowBox[{"(", 
              FormBox[
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["p2",
                    "TraditionalForm"]}],
                "TraditionalForm"], ")"}], "2"], 
          RowBox[{
            SuperscriptBox[
              FormBox[
                TagBox[
                  StyleBox["\<\"k\"\>",
                    FontSlant->"Italic"],
                  (StyleForm[ #, FontSlant -> "Italic"]&)],
                "TraditionalForm"], "2"], ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  FormBox[
                    TagBox[
                      StyleBox["\<\"k\"\>",
                        FontSlant->"Italic"],
                      (StyleForm[ #, FontSlant -> "Italic"]&)],
                    "TraditionalForm"], "-", "p1", "+", "p2"}], ")"}], 
              "2"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[623]=  (21:53:30 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{"Clear", "[", 
      RowBox[{"t", ",", "r"}], "]"}]], "Input",
  CellLabel->"In[624]:=  (21:53:30 on 5/16/01)",
  CellTags->"FeynAmpDenominatorSimplify"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["FeynAmpDenominatorSplit", "ObjectName",
  CellTags->"FeynAmpDenominatorSplit"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"FeynAmpDenominatorSplit"],

Cell["\<\
FeynAmpDenominatorSplit[expr] splits all FeynAmpDenominator[a,b, ...] in expr \
into FeynAmpDenominator[a]*FeynAmpDenominator[b] ... . \
FeynAmpDenominatorSplit[expr, q1] splits all FeynAmpDenominator in expr into \
a product of two, one containing q1 and other momenta, the second without q1.\
\
\>", "Text",
  CellTags->"FeynAmpDenominatorSplit"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["FeynAmpDenominatorCombine",
    ButtonData:>"FeynAmpDenominatorCombine",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FeynAmpDenominatorCombine"],
  "."
}], "Text",
  CellTags->"FeynAmpDenominatorSplit"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"FeynAmpDenominatorSplit"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t", "=", 
      RowBox[{
        RowBox[{"FAD", "[", 
          RowBox[{"q1", ",", 
            RowBox[{"q1", "-", "p"}], ",", 
            RowBox[{"q1", "-", "q2"}], ",", "q2", ",", 
            RowBox[{"q2", "-", "p"}]}], "]"}], "//", "FCI"}]}]], "Input",
  CellLabel->"In[625]:=  (21:53:31 on 5/16/01)",
  CellTags->"FeynAmpDenominatorSplit"],

Cell[BoxData[
    FormBox[
      FractionBox["1", 
        RowBox[{
          SubsuperscriptBox[
            StyleBox["\<\"q\"\>",
              FontSlant->"Italic"], "1", "2"], ".", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                SubscriptBox[
                  StyleBox["\<\"q\"\>",
                    FontSlant->"Italic"], "1"], "-", "p"}], ")"}], "2"], ".", 
          
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                SubscriptBox[
                  StyleBox["\<\"q\"\>",
                    FontSlant->"Italic"], "1"], "-", 
                SubscriptBox[
                  StyleBox["\<\"q\"\>",
                    FontSlant->"Italic"], "2"]}], ")"}], "2"], ".", 
          SubsuperscriptBox[
            StyleBox["\<\"q\"\>",
              FontSlant->"Italic"], "2", "2"], ".", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                SubscriptBox[
                  StyleBox["\<\"q\"\>",
                    FontSlant->"Italic"], "2"], "-", "p"}], ")"}], "2"]}]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[625]=  (21:53:31 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t", "//", "Head"}]], "Input",
  CellLabel->"In[626]:=  (21:53:31 on 5/16/01)",
  CellTags->"FeynAmpDenominatorSplit"],

Cell[BoxData[
    FormBox["FeynAmpDenominator", TraditionalForm]], "Output",
  CellLabel->"Out[626]=  (21:53:31 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FeynAmpDenominatorSplit", "[", "t", "]"}]], "Input",
  CellLabel->"In[627]:=  (21:53:31 on 5/16/01)",
  CellTags->"FeynAmpDenominatorSplit"],

Cell[BoxData[
    FormBox[
      FractionBox["1", 
        RowBox[{
          SubsuperscriptBox[
            StyleBox["\<\"q\"\>",
              FontSlant->"Italic"], "1", "2"], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                SubscriptBox[
                  StyleBox["\<\"q\"\>",
                    FontSlant->"Italic"], "1"], "-", "p"}], ")"}], "2"], " ", 
          
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                SubscriptBox[
                  StyleBox["\<\"q\"\>",
                    FontSlant->"Italic"], "1"], "-", 
                SubscriptBox[
                  StyleBox["\<\"q\"\>",
                    FontSlant->"Italic"], "2"]}], ")"}], "2"], " ", 
          SubsuperscriptBox[
            StyleBox["\<\"q\"\>",
              FontSlant->"Italic"], "2", "2"], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                SubscriptBox[
                  StyleBox["\<\"q\"\>",
                    FontSlant->"Italic"], "2"], "-", "p"}], ")"}], "2"]}]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[627]=  (21:53:31 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"%", "//", "FCE"}], "//", "StandardForm"}]], "Input",
  CellLabel->"In[628]:=  (21:53:31 on 5/16/01)",
  CellTags->"FeynAmpDenominatorSplit"],

Cell[BoxData[
    RowBox[{
      RowBox[{"FAD", "[", "q1", "]"}], " ", 
      RowBox[{"FAD", "[", 
        RowBox[{
          RowBox[{"-", "p"}], "+", "q1"}], "]"}], " ", 
      RowBox[{"FAD", "[", 
        RowBox[{"q1", "-", "q2"}], "]"}], " ", 
      RowBox[{"FAD", "[", "q2", "]"}], " ", 
      RowBox[{"FAD", "[", 
        RowBox[{
          RowBox[{"-", "p"}], "+", "q2"}], "]"}]}]], "Output",
  CellLabel->"Out[628]//StandardForm=  (21:53:31 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"FeynAmpDenominatorSplit", "[", 
          RowBox[{"t", ",", "q1"}], "]"}], "//", "FCE"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[629]:=  (21:53:31 on 5/16/01)",
  CellTags->"FeynAmpDenominatorSplit"],

Cell[BoxData[
    RowBox[{
      RowBox[{"FAD", "[", 
        RowBox[{"q2", ",", 
          RowBox[{
            RowBox[{"-", "p"}], "+", "q2"}]}], "]"}], " ", 
      RowBox[{"FAD", "[", 
        RowBox[{"q1", ",", 
          RowBox[{
            RowBox[{"-", "p"}], "+", "q1"}], ",", 
          RowBox[{"q1", "-", "q2"}]}], "]"}]}]], "Output",
  CellLabel->"Out[629]//StandardForm=  (21:53:31 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"FeynAmpDenominatorCombine", "[", "%", "]"}], "//", "FCE"}], "//",
       "StandardForm"}]], "Input",
  CellLabel->"In[630]:=  (21:53:31 on 5/16/01)",
  CellTags->"FeynAmpDenominatorSplit"],

Cell[BoxData[
    RowBox[{"FAD", "[", 
      RowBox[{"q1", ",", "q2", ",", 
        RowBox[{"q1", "-", "q2"}], ",", 
        RowBox[{
          RowBox[{"-", "p"}], "+", "q1"}], ",", 
        RowBox[{
          RowBox[{"-", "p"}], "+", "q2"}]}], "]"}]], "Output",
  CellLabel->"Out[630]//StandardForm=  (21:53:32 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{"Clear", "[", "t", "]"}]], "Input",
  CellLabel->"In[631]:=  (21:53:32 on 5/16/01)",
  CellTags->"FeynAmpDenominatorSplit"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["FeynAmp", "ObjectName",
  CellTags->"FeynAmp"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"FeynAmp"],

Cell["\<\
FeynAmp[q, amp] is the head of a Feynman amplitude. amp denotes the \
analytical expression for the amplitude and q is the integration variable. \
FeynAmp[q1, q2, amp] denotes a two-loop amplitude.\
\>", "Text",
  CellTags->"FeynAmp"],

Cell["\<\
FeynAmp has no functional properties and serves just as a head. There are \
however special typesetting rules attached.\
\>", "Text",
  CellTags->"FeynAmp"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["Amplitudes",
    ButtonData:>"Amplitudes",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Amplitudes"],
  "."
}], "Text",
  CellTags->"FeynAmp"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"FeynAmp"],

Cell["\<\
This is a 1-loop gluon self-energy amplitude (ignoring factors of (2 \[Pi])).\
\
\>", "Text",
  CellTags->"FeynAmp"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FeynAmp", "[", 
      RowBox[{"q", ",", 
        RowBox[{
          RowBox[{"GV", "[", 
            RowBox[{"p", ",", "\[Mu]", ",", "a", ",", " ", 
              RowBox[{"q", "-", "p"}], ",", "\[Alpha]", ",", "c", ",", " ", 
              RowBox[{"-", "q"}], ",", "\[Beta]", ",", "e"}], "]"}], " ", 
          RowBox[{"GP", "[", 
            RowBox[{
              RowBox[{"p", "-", "q"}], ",", " ", "\[Alpha]", ",", "c", ",", 
              " ", "\[Rho]", ",", "d"}], "]"}], 
          RowBox[{"GV", "[", 
            RowBox[{
              RowBox[{"-", "p"}], ",", "\[Nu]", ",", "b", ",", " ", 
              RowBox[{"p", "-", "q"}], ",", "\[Rho]", ",", "d", ",", " ", "q",
               ",", "\[Sigma]", ",", "f"}], "]"}], " ", 
          RowBox[{"GP", "[", 
            RowBox[{
            "q", ",", " ", "\[Beta]", ",", "e", ",", " ", "\[Sigma]", ",", 
              "f"}], "]"}]}]}], "]"}]], "Input",
  CellLabel->"In[632]:=  (21:53:32 on 5/16/01)",
  CellTags->"FeynAmp"],

Cell[BoxData[
    FormBox[
      RowBox[{"\[Integral]", 
        StyleBox[
          RowBox[{
            SuperscriptBox["\[DifferentialD]", "D"], "q"}],
          ZeroWidthTimes->True], "(", 
        FormBox[
          RowBox[{"-", 
            FractionBox[
              RowBox[{
                SubsuperscriptBox["g", "s", "2"], " ", 
                RowBox[{
                  SuperscriptBox["V", 
                    RowBox[{
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["\[Rho]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["\[Sigma]",
                          "TraditionalForm"],
                        "TraditionalForm"]}]], "(", 
                  RowBox[{
                    FormBox[
                      RowBox[{"-", "p"}],
                      "TraditionalForm"], "\[NoBreak]", 
                    RowBox[{",", " "}], "\[NoBreak]", 
                    FormBox[
                      RowBox[{"p", "-", "q"}],
                      "TraditionalForm"], "\[NoBreak]", 
                    RowBox[{",", " "}], "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}], ")"}], " ", 
                RowBox[{
                  SuperscriptBox["V", 
                    RowBox[{
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["\[Alpha]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["\[Beta]",
                          "TraditionalForm"],
                        "TraditionalForm"]}]], "(", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", 
                    RowBox[{",", " "}], "\[NoBreak]", 
                    FormBox[
                      RowBox[{"q", "-", "p"}],
                      "TraditionalForm"], "\[NoBreak]", 
                    RowBox[{",", " "}], "\[NoBreak]", 
                    FormBox[
                      RowBox[{"-", "q"}],
                      "TraditionalForm"]}], ")"}], " ", 
                SuperscriptBox["g", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Alpha]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Rho]",
                        "TraditionalForm"],
                      "TraditionalForm"]}]], " ", 
                SuperscriptBox["g", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Beta]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Sigma]",
                        "TraditionalForm"],
                      "TraditionalForm"]}]], " ", 
                SubscriptBox["\[Delta]", 
                  RowBox[{
                    FormBox[
                      FormBox["c",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["d",
                        "TraditionalForm"],
                      "TraditionalForm"]}]], " ", 
                SubscriptBox["\[Delta]", 
                  RowBox[{
                    FormBox[
                      FormBox["e",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["f",
                        "TraditionalForm"],
                      "TraditionalForm"]}]], " ", 
                SubscriptBox["f", 
                  RowBox[{
                    FormBox[
                      FormBox["a",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["c",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["e",
                        "TraditionalForm"],
                      "TraditionalForm"]}]], " ", 
                SubscriptBox["f", 
                  RowBox[{
                    FormBox[
                      FormBox["b",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["d",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["f",
                        "TraditionalForm"],
                      "TraditionalForm"]}]]}], 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"p", "-", "q"}], ")"}], "2"], " ", 
                SuperscriptBox["q", "2"]}]]}],
          "TraditionalForm"], ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[632]=  (21:53:32 on 5/16/01)"]
}, Closed]],

Cell["This is a generic 2-loop amplitude.", "Text",
  CellTags->"FeynAmp"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FeynAmp", "[", 
      RowBox[{
        SubscriptBox["q", "1"], ",", 
        SubscriptBox["q", "2"], ",", "anyexpression"}], "]"}]], "Input",
  CellLabel->"In[633]:=  (21:53:32 on 5/16/01)",
  CellTags->"FeynAmp"],

Cell[BoxData[
    FormBox[
      RowBox[{"\[Integral]", 
        RowBox[{
          StyleBox[
            RowBox[{
              SuperscriptBox["\[DifferentialD]", "D"], 
              SubscriptBox["q", "1"]}],
            ZeroWidthTimes->True], "\[Integral]", 
          RowBox[{
            SuperscriptBox["\[DifferentialD]", "D"], 
            SubscriptBox["q", "2"]}]}], "(", "anyexpression", ")"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[633]=  (21:53:32 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["FeynCalc2FORM", "ObjectName",
  CellTags->"FeynCalc2FORM"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"FeynCalc2FORM"],

Cell["\<\
FeynCalc2FORM[expr] displays expr in FORM syntax. FeynCalc2FORM[file, x] \
writes x in FORM syntax to a file. FeynCalc2FORM[file, x==y] writes x=y to a \
file in FORM syntax.\
\>", "Text",
  CellTags->"FeynCalc2FORM"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["FORM2FeynCalc",
    ButtonData:>"FORM2FeynCalc",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FORM2FeynCalc"],
  "."
}], "Text",
  CellTags->"FeynCalc2FORM"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "FeynCalc2FORM", "]"}]], "Input",
  CellLabel->"In[634]:=  (21:53:32 on 5/16/01)",
  CellTags->"FeynCalc2FORM"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"EpsDiscard", "\[Rule]", "False"}], ",", 
          RowBox[{"FORMEpilog", "\[Rule]", "\<\"\"\>"}], ",", 
          RowBox[{"FORMProlog", "\[Rule]", "\<\"write statistics;\"\>"}], ",",
           
          RowBox[{"Replace", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{"\<\"\\\\[Alpha]\"\>", "\[Rule]", "\<\"al\"\>"}], ",",
                 
                RowBox[{"\<\"\\\\[Beta]\"\>", "\[Rule]", "\<\"be\"\>"}], ",", 
                
                RowBox[{"\<\"\\\\[Gamma]\"\>", "\[Rule]", "\<\"ga\"\>"}], ",",
                 
                RowBox[{"\<\"\\\\[Delta]\"\>", "\[Rule]", "\<\"de\"\>"}], ",",
                 
                RowBox[{"\<\"\\\\[Mu]\"\>", "\[Rule]", "\<\"mu\"\>"}], ",", 
                RowBox[{"\<\"\\\\[Nu]\"\>", "\[Rule]", "\<\"nu\"\>"}], ",", 
                RowBox[{"\<\"\\\\[Rho]\"\>", "\[Rule]", "\<\"ro\"\>"}], ",", 
                RowBox[{"\<\"\\\\[Sigma]\"\>", "\[Rule]", "\<\"si\"\>"}]}], 
              "}"}]}], ",", 
          RowBox[{"TraceDimension", "\[Rule]", "4"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[634]=  (21:53:32 on 5/16/01)"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"FeynCalc2FORM"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"MT", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], 
      RowBox[{"FV", "[", 
        RowBox[{"p", ",", "\[Rho]"}], "]"}], " ", 
      RowBox[{
        RowBox[{"y", "^", "2"}], "/", "d"}]}]], "Input",
  CellLabel->"In[635]:=  (21:53:32 on 5/16/01)",
  CellTags->"FeynCalc2FORM"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SuperscriptBox["p", "\[Rho]"], " ", 
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]]}], "d"], 
      TraditionalForm]], "Output",
  CellLabel->"Out[635]=  (21:53:32 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"FeynCalc2FORM", "[", "%", "]"}], ";"}]], "Input",
  CellLabel->"In[636]:=  (21:53:33 on 5/16/01)",
  CellTags->"FeynCalc2FORM"],

Cell[BoxData[
    FormBox["\<\"(y^2*d_(mu,nu)*p(ro))/d\"\>", TraditionalForm]], "Print"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{" ", 
      RowBox[{"LC", "[", 
        RowBox[{"\[Alpha]", ",", "\[Beta]", ",", "\[Delta]", ",", "\[Rho]"}], 
        "]"}]}]], "Input",
  CellLabel->"In[637]:=  (21:53:33 on 5/16/01)",
  CellTags->"FeynCalc2FORM"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["\[Epsilon]", 
        RowBox[{
        "\[Alpha]", "\[NoBreak]", "\[Beta]", "\[NoBreak]", "\[Delta]", 
          "\[NoBreak]", "\[Rho]"}]], TraditionalForm]], "Output",
  CellLabel->"Out[637]=  (21:53:33 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"FeynCalc2FORM", "[", "%", "]"}], ";"}]], "Input",
  CellLabel->"In[638]:=  (21:53:33 on 5/16/01)",
  CellTags->"FeynCalc2FORM"],

Cell[BoxData[
    FormBox["\<\"-i_*e_(al,be,de,ro)\"\>", TraditionalForm]], "Print"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracTrace", "[", 
      RowBox[{"GA", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Sigma]"}], 
        "]"}], "]"}]], "Input",
  CellLabel->"In[639]:=  (21:53:33 on 5/16/01)",
  CellTags->"FeynCalc2FORM"],

Cell[BoxData[
    FormBox[
      RowBox[{"tr", "(", 
        FormBox[
          RowBox[{
            SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
            SuperscriptBox["\[Gamma]", "\[Nu]"], ".", 
            SuperscriptBox["\[Gamma]", "\[Rho]"], ".", 
            SuperscriptBox["\[Gamma]", "\[Sigma]"]}],
          "TraditionalForm"], ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[639]=  (21:53:33 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"FeynCalc2FORM", "[", "%", "]"}], ";"}]], "Input",
  CellLabel->"In[640]:=  (21:53:33 on 5/16/01)",
  CellTags->"FeynCalc2FORM"],

Cell[BoxData[
    FormBox["\<\"g_(0,mu)*g_(0,nu)*g_(0,ro)*g_(0,si)\"\>", 
      TraditionalForm]], "Print"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"DiracTrace", "[", 
        RowBox[{"GA", "[", 
          RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], "]"}], 
      RowBox[{"DiracTrace", "[", 
        RowBox[{"GA", "[", 
          RowBox[{"\[Mu]", ",", "\[Rho]"}], "]"}], "]"}]}]], "Input",
  CellLabel->"In[641]:=  (21:53:33 on 5/16/01)",
  CellTags->"FeynCalc2FORM"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"tr", "(", 
          FormBox[
            RowBox[{
              SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
              SuperscriptBox["\[Gamma]", "\[Nu]"]}],
            "TraditionalForm"], ")"}], " ", 
        RowBox[{"tr", "(", 
          FormBox[
            RowBox[{
              SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
              SuperscriptBox["\[Gamma]", "\[Rho]"]}],
            "TraditionalForm"], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[641]=  (21:53:33 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"FeynCalc2FORM", "[", "%", "]"}], ";"}]], "Input",
  CellLabel->"In[642]:=  (21:53:33 on 5/16/01)",
  CellTags->"FeynCalc2FORM"],

Cell[BoxData[
    FormBox["\<\"g_(0,mu)*g_(0,nu)*g_(1,mu)*g_(1,ro)\"\>", 
      TraditionalForm]], "Print"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      RowBox[{"FeynCalc2FORM", "[", 
        RowBox[{"\"\<fc2ftest.f\>\"", ",", 
          RowBox[{
            RowBox[{"MT", "[", 
              RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], 
            RowBox[{"FV", "[", 
              RowBox[{"p", ",", "\[Mu]"}], "]"}]}]}], "]"}], ";"}]], "Input",
  CellLabel->"In[643]:=  (21:53:33 on 5/16/01)",
  CellTags->"FeynCalc2FORM"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ReadList", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"If", "[", 
            RowBox[{
              RowBox[{"$OperatingSystem", "===", "\"\<MacOS\>\""}], ",", 
              "\"\<:\>\"", ",", "\"\<\>\""}], "]"}], "<>", 
          "\"\<fc2ftest.f\>\""}], ",", "String"}], "]"}]], "Input",
  CellLabel->"In[644]:=  (21:53:34 on 5/16/01)",
  CellTags->"FeynCalc2FORM"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", "\<\"d_(mu,nu)*p(mu)\"\>", "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[644]=  (21:53:34 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t", "=", 
      RowBox[{"Tr", "[", 
        RowBox[{
          RowBox[{"GA", "[", 
            RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Sigma]"}], 
            "]"}], ".", 
          RowBox[{"GS", "[", 
            RowBox[{"p", ",", "q"}], "]"}]}], "]"}]}]], "Input",
  CellLabel->"In[645]:=  (21:53:34 on 5/16/01)",
  CellTags->"FeynCalc2FORM"],

Cell[BoxData[
    FormBox[
      RowBox[{"4", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox["g", 
                RowBox[{"\[Rho]", "\[NoBreak]", "\[Sigma]"}]]}], "-", 
            RowBox[{
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox["g", 
                RowBox[{"\[Rho]", "\[NoBreak]", "\[Sigma]"}]]}], "+", 
            RowBox[{
              SuperscriptBox["g", 
                RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}], " ", 
              SuperscriptBox["g", 
                RowBox[{"\[Rho]", "\[NoBreak]", "\[Sigma]"}]]}], "-", 
            RowBox[{
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox["g", 
                RowBox[{"\[Nu]", "\[NoBreak]", "\[Sigma]"}]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Rho]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], "+", 
            RowBox[{
              SuperscriptBox["g", 
                RowBox[{"\[Mu]", "\[NoBreak]", "\[Sigma]"}]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Rho]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], "+", 
            RowBox[{
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox["g", 
                RowBox[{"\[Nu]", "\[NoBreak]", "\[Sigma]"}]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Rho]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], "-", 
            RowBox[{
              SuperscriptBox["g", 
                RowBox[{"\[Mu]", "\[NoBreak]", "\[Sigma]"}]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Rho]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], "+", 
            RowBox[{
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox["g", 
                RowBox[{"\[Nu]", "\[NoBreak]", "\[Rho]"}]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Sigma]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], "-", 
            RowBox[{
              SuperscriptBox["g", 
                RowBox[{"\[Mu]", "\[NoBreak]", "\[Rho]"}]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Sigma]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], "+", 
            RowBox[{
              SuperscriptBox["g", 
                RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Rho]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Sigma]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], "-", 
            RowBox[{
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox["g", 
                RowBox[{"\[Nu]", "\[NoBreak]", "\[Rho]"}]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Sigma]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], "+", 
            RowBox[{
              SuperscriptBox["g", 
                RowBox[{"\[Mu]", "\[NoBreak]", "\[Rho]"}]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Sigma]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], "-", 
            RowBox[{
              SuperscriptBox["g", 
                RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Rho]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Sigma]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], "+", 
            RowBox[{
              SuperscriptBox["g", 
                RowBox[{"\[Mu]", "\[NoBreak]", "\[Sigma]"}]], " ", 
              SuperscriptBox["g", 
                RowBox[{"\[Nu]", "\[NoBreak]", "\[Rho]"}]], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}]}], "-", 
            RowBox[{
              SuperscriptBox["g", 
                RowBox[{"\[Mu]", "\[NoBreak]", "\[Rho]"}]], " ", 
              SuperscriptBox["g", 
                RowBox[{"\[Nu]", "\[NoBreak]", "\[Sigma]"}]], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}]}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[645]=  (21:53:34 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      RowBox[{"FeynCalc2FORM", "[", 
        RowBox[{"\"\<fc2ftest.f\>\"", ",", 
          RowBox[{"L", " ", "==", "t"}]}], "]"}], ";"}]], "Input",
  CellLabel->"In[646]:=  (21:53:34 on 5/16/01)",
  CellTags->"FeynCalc2FORM"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"TableForm", "[", 
      RowBox[{"ReadList", "[", 
        RowBox[{
          RowBox[{
            RowBox[{"If", "[", 
              RowBox[{
                RowBox[{"$OperatingSystem", "===", "\"\<MacOS\>\""}], ",", 
                "\"\<:\>\"", ",", "\"\<\>\""}], "]"}], "<>", 
            "\"\<fc2ftest.f\>\""}], ",", "String"}], "]"}], "]"}]], "Input",
  CellLabel->"In[647]:=  (21:53:34 on 5/16/01)",
  CellTags->"FeynCalc2FORM"],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {"\<\"Indices \.03\.bc,\.03\.bd,\.03\[CapitalAAcute],\.03\
\[CapitalATilde];\"\>"},
            {"\<\"Vectors p,q;\"\>"},
            {"\<\"\"\>"},
            {"\<\"write statistics;\"\>"},
            {"\<\"\"\>"},
            {"\<\"Local L = ( \"\>"},
            {"\<\"4*(d_(mu,si)*d_(nu,ro)*q.p-d_(mu,ro)*d_(nu,si)*q.p+d_(mu,nu)\
*d_(ro,si)*q.p+\"\>"},
            {"\<\"d_(ro,si)*p(nu)*q(mu)-d_(nu,si)*p(ro)*q(mu)+d_(nu,ro)*p(si)*\
q(mu)-\"\>"},
            {"\<\"d_(ro,si)*p(mu)*q(nu)+d_(mu,si)*p(ro)*q(nu)-d_(mu,ro)*p(si)*\
q(nu)+\"\>"},
            {"\<\"d_(nu,si)*p(mu)*q(ro)-d_(mu,si)*p(nu)*q(ro)+d_(mu,nu)*p(si)*\
q(ro)-\"\>"},
            {"\<\"d_(nu,ro)*p(mu)*q(si)+d_(mu,ro)*p(nu)*q(si)-d_(mu,nu)*p(ro)*\
q(si)) ); \"\>"},
            {"\<\"   \"\>"},
            {"\<\"Print; \"\>"},
            {"\<\".end\"\>"}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        TableForm[ {
          "Indices \
\.03\.bc,\.03\.bd,\.03\[CapitalAAcute],\.03\[CapitalATilde];", "Vectors p,q;",
           "", "write statistics;", "", "Local L = ( ", 
          "4*(d_(mu,si)*d_(nu,ro)*q.p-d_(mu,ro)*d_(nu,si)*q.p+d_(mu,nu)*d_(ro,\
si)*q.p+", 
          "d_(ro,si)*p(nu)*q(mu)-d_(nu,si)*p(ro)*q(mu)+d_(nu,ro)*p(si)*q(mu)-\
", "d_(ro,si)*p(mu)*q(nu)+d_(mu,si)*p(ro)*q(nu)-d_(mu,ro)*p(si)*q(nu)+", 
          "d_(nu,si)*p(mu)*q(ro)-d_(mu,si)*p(nu)*q(ro)+d_(mu,nu)*p(si)*q(ro)-\
", "d_(nu,ro)*p(mu)*q(si)+d_(mu,ro)*p(nu)*q(si)-d_(mu,nu)*p(ro)*q(si)) ); ", 
          "   ", "Print; ", ".end"}]], TraditionalForm]], "Output",
  CellLabel->"Out[647]//TableForm=  (21:53:34 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      RowBox[{"If", "[", 
        RowBox[{
          RowBox[{
            RowBox[{"FileNames", "[", "\"\<fc2ftest.f\>\"", "]"}], "=!=", 
            RowBox[{"{", "}"}]}], ",", 
          RowBox[{"DeleteFile", "[", "\"\<fc2ftest.f\>\"", "]"}]}], "]"}], 
      ";"}]], "Input",
  CellLabel->"In[648]:=  (21:53:35 on 5/16/01)",
  CellTags->"FeynCalc2FORM"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Clear", "[", "t", "]"}], ";"}]], "Input",
  CellLabel->"In[649]:=  (21:53:35 on 5/16/01)",
  CellTags->"FeynCalc2FORM"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["FeynCalcExternal", "ObjectName",
  CellTags->"FeynCalcExternal"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"FeynCalcExternal"],

Cell["\<\
FeynCalcExternal[exp] translates exp from the internal FeynCalc \
representation to a shorthand form.\
\>", "Text",
  CellTags->"FeynCalcExternal"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["FeynCalcInternal",
    ButtonData:>"FeynCalcInternal",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FeynCalcInternal"],
  "."
}], "Text",
  CellTags->"FeynCalcExternal"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"FeynCalcExternal"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FeynCalcExternal", "[", 
      RowBox[{"DiracGamma", "[", "5", "]"}], "]"}]], "Input",
  CellLabel->"In[650]:=  (21:53:35 on 5/16/01)",
  CellTags->"FeynCalcExternal"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["\[Gamma]", "5"], TraditionalForm]], "Output",
  CellLabel->"Out[650]=  (21:53:35 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "StandardForm"}]], "Input",
  CellLabel->"In[651]:=  (21:53:35 on 5/16/01)",
  CellTags->"FeynCalcExternal"],

Cell[BoxData[
    RowBox[{"GA", "[", "5", "]"}]], "Output",
  CellLabel->"Out[651]//StandardForm=  (21:53:35 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"GA", "[", "\[Mu]", "]"}], ",", 
        RowBox[{"GAD", "[", "\[Rho]", "]"}], ",", 
        RowBox[{"GS", "[", "p", "]"}], ",", 
        RowBox[{"SP", "[", 
          RowBox[{"p", ",", "q"}], "]"}], ",", 
        RowBox[{"MT", "[", 
          RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], ",", 
        RowBox[{"FV", "[", 
          RowBox[{"p", ",", "\[Mu]"}], "]"}]}], "}"}]], "Input",
  CellLabel->"In[652]:=  (21:53:35 on 5/16/01)",
  CellTags->"FeynCalcExternal"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          SuperscriptBox["\[Gamma]", "\[Mu]"], ",", 
          SuperscriptBox["\[Gamma]", "\[Rho]"], ",", 
          RowBox[{
          "\[Gamma]", "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "p"}], ",", 
          
          FormBox[
            RowBox[{
              FormBox["p",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox["q",
                "TraditionalForm"]}],
            "TraditionalForm"], ",", 
          SuperscriptBox["g", 
            RowBox[{"\[Alpha]", "\[NoBreak]", "\[Beta]"}]], ",", 
          SuperscriptBox["p", "\[Mu]"]}], "}"}], TraditionalForm]], "Output",
  CellLabel->"Out[652]=  (21:53:35 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "StandardForm"}]], "Input",
  CellLabel->"In[653]:=  (21:53:35 on 5/16/01)",
  CellTags->"FeynCalcExternal"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"GA", "[", "\[Mu]", "]"}], ",", 
        RowBox[{"GAD", "[", "\[Rho]", "]"}], ",", 
        RowBox[{"GS", "[", "p", "]"}], ",", 
        RowBox[{"SP", "[", 
          RowBox[{"p", ",", "q"}], "]"}], ",", 
        RowBox[{"MT", "[", 
          RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], ",", 
        RowBox[{"FV", "[", 
          RowBox[{"p", ",", "\[Mu]"}], "]"}]}], "}"}]], "Output",
  CellLabel->"Out[653]//StandardForm=  (21:53:35 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "FeynCalcInternal"}]], "Input",
  CellLabel->"In[654]:=  (21:53:35 on 5/16/01)",
  CellTags->"FeynCalcExternal"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], ",", 
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox["\[Rho]",
                "TraditionalForm"],
              "TraditionalForm"]], ",", 
          RowBox[{
            FormBox["\<\"\[Gamma]\"\>",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["p",
              "TraditionalForm"]}], ",", 
          RowBox[{
            FormBox["p",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["q",
              "TraditionalForm"]}], ",", 
          SuperscriptBox["g", 
            RowBox[{"\[Alpha]", "\[NoBreak]", "\[Beta]"}]], ",", 
          SuperscriptBox[
            FormBox["p",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]]}], "}"}], TraditionalForm]], "Output",
  CellLabel->"Out[654]=  (21:53:35 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "StandardForm"}]], "Input",
  CellLabel->"In[655]:=  (21:53:35 on 5/16/01)",
  CellTags->"FeynCalcExternal"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"DiracGamma", "[", 
          RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], "]"}], ",", 
        RowBox[{"DiracGamma", "[", 
          RowBox[{
            RowBox[{"LorentzIndex", "[", 
              RowBox[{"\[Rho]", ",", "D"}], "]"}], ",", "D"}], "]"}], ",", 
        RowBox[{"DiracGamma", "[", 
          RowBox[{"Momentum", "[", "p", "]"}], "]"}], ",", 
        RowBox[{"Pair", "[", 
          RowBox[{
            RowBox[{"Momentum", "[", "p", "]"}], ",", 
            RowBox[{"Momentum", "[", "q", "]"}]}], "]"}], ",", 
        RowBox[{"Pair", "[", 
          RowBox[{
            RowBox[{"LorentzIndex", "[", "\[Alpha]", "]"}], ",", 
            RowBox[{"LorentzIndex", "[", "\[Beta]", "]"}]}], "]"}], ",", 
        RowBox[{"Pair", "[", 
          RowBox[{
            RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
            RowBox[{"Momentum", "[", "p", "]"}]}], "]"}]}], "}"}]], "Output",
  CellLabel->"Out[655]//StandardForm=  (21:53:35 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"FeynCalcExternal", "[", "%", "]"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[656]:=  (21:53:35 on 5/16/01)",
  CellTags->"FeynCalcExternal"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"GA", "[", "\[Mu]", "]"}], ",", 
        RowBox[{"GAD", "[", "\[Rho]", "]"}], ",", 
        RowBox[{"GS", "[", "p", "]"}], ",", 
        RowBox[{"SP", "[", 
          RowBox[{"p", ",", "q"}], "]"}], ",", 
        RowBox[{"MT", "[", 
          RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], ",", 
        RowBox[{"FV", "[", 
          RowBox[{"p", ",", "\[Mu]"}], "]"}]}], "}"}]], "Output",
  CellLabel->"Out[656]//StandardForm=  (21:53:35 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["FeynCalcInternal", "ObjectName",
  CellTags->"FeynCalcInternal"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"FeynCalcInternal"],

Cell["\<\
FeynCalcInternal[exp] translates exp into the internal FeynCalc (abstract \
data-type) representation.\
\>", "Text",
  CellTags->"FeynCalcInternal"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["FeynCalcExternal",
    ButtonData:>"FeynCalcExternal",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FeynCalcExternal"],
  ", ",
  ButtonBox["FCI",
    ButtonData:>"FCI",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FCI"],
  ", ",
  ButtonBox["FCE",
    ButtonData:>"FCE",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FCE"],
  "."
}], "Text",
  CellTags->"FeynCalcInternal"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"FeynCalcInternal"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"GA", "[", "\[Mu]", "]"}], ",", 
        RowBox[{"GAD", "[", "\[Rho]", "]"}], ",", 
        RowBox[{"GS", "[", "p", "]"}], ",", 
        RowBox[{"SP", "[", 
          RowBox[{"p", ",", "q"}], "]"}], ",", 
        RowBox[{"MT", "[", 
          RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], ",", 
        RowBox[{"FV", "[", 
          RowBox[{"p", ",", "\[Mu]"}], "]"}]}], "}"}]], "Input",
  CellLabel->"In[657]:=  (21:53:35 on 5/16/01)",
  CellTags->"FeynCalcInternal"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          SuperscriptBox["\[Gamma]", "\[Mu]"], ",", 
          SuperscriptBox["\[Gamma]", "\[Rho]"], ",", 
          RowBox[{
          "\[Gamma]", "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "p"}], ",", 
          
          FormBox[
            RowBox[{
              FormBox["p",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox["q",
                "TraditionalForm"]}],
            "TraditionalForm"], ",", 
          SuperscriptBox["g", 
            RowBox[{"\[Alpha]", "\[NoBreak]", "\[Beta]"}]], ",", 
          SuperscriptBox["p", "\[Mu]"]}], "}"}], TraditionalForm]], "Output",
  CellLabel->"Out[657]=  (21:53:35 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "StandardForm"}]], "Input",
  CellLabel->"In[658]:=  (21:53:35 on 5/16/01)",
  CellTags->"FeynCalcInternal"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"GA", "[", "\[Mu]", "]"}], ",", 
        RowBox[{"GAD", "[", "\[Rho]", "]"}], ",", 
        RowBox[{"GS", "[", "p", "]"}], ",", 
        RowBox[{"SP", "[", 
          RowBox[{"p", ",", "q"}], "]"}], ",", 
        RowBox[{"MT", "[", 
          RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], ",", 
        RowBox[{"FV", "[", 
          RowBox[{"p", ",", "\[Mu]"}], "]"}]}], "}"}]], "Output",
  CellLabel->"Out[658]//StandardForm=  (21:53:35 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "FeynCalcInternal"}]], "Input",
  CellLabel->"In[659]:=  (21:53:35 on 5/16/01)",
  CellTags->"FeynCalcInternal"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], ",", 
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox["\[Rho]",
                "TraditionalForm"],
              "TraditionalForm"]], ",", 
          RowBox[{
            FormBox["\<\"\[Gamma]\"\>",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["p",
              "TraditionalForm"]}], ",", 
          RowBox[{
            FormBox["p",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["q",
              "TraditionalForm"]}], ",", 
          SuperscriptBox["g", 
            RowBox[{"\[Alpha]", "\[NoBreak]", "\[Beta]"}]], ",", 
          SuperscriptBox[
            FormBox["p",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]]}], "}"}], TraditionalForm]], "Output",
  CellLabel->"Out[659]=  (21:53:35 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "StandardForm"}]], "Input",
  CellLabel->"In[660]:=  (21:53:35 on 5/16/01)",
  CellTags->"FeynCalcInternal"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"DiracGamma", "[", 
          RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], "]"}], ",", 
        RowBox[{"DiracGamma", "[", 
          RowBox[{
            RowBox[{"LorentzIndex", "[", 
              RowBox[{"\[Rho]", ",", "D"}], "]"}], ",", "D"}], "]"}], ",", 
        RowBox[{"DiracGamma", "[", 
          RowBox[{"Momentum", "[", "p", "]"}], "]"}], ",", 
        RowBox[{"Pair", "[", 
          RowBox[{
            RowBox[{"Momentum", "[", "p", "]"}], ",", 
            RowBox[{"Momentum", "[", "q", "]"}]}], "]"}], ",", 
        RowBox[{"Pair", "[", 
          RowBox[{
            RowBox[{"LorentzIndex", "[", "\[Alpha]", "]"}], ",", 
            RowBox[{"LorentzIndex", "[", "\[Beta]", "]"}]}], "]"}], ",", 
        RowBox[{"Pair", "[", 
          RowBox[{
            RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
            RowBox[{"Momentum", "[", "p", "]"}]}], "]"}]}], "}"}]], "Output",
  CellLabel->"Out[660]//StandardForm=  (21:53:35 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"FeynCalcExternal", "[", "%", "]"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[661]:=  (21:53:35 on 5/16/01)",
  CellTags->"FeynCalcInternal"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"GA", "[", "\[Mu]", "]"}], ",", 
        RowBox[{"GAD", "[", "\[Rho]", "]"}], ",", 
        RowBox[{"GS", "[", "p", "]"}], ",", 
        RowBox[{"SP", "[", 
          RowBox[{"p", ",", "q"}], "]"}], ",", 
        RowBox[{"MT", "[", 
          RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], ",", 
        RowBox[{"FV", "[", 
          RowBox[{"p", ",", "\[Mu]"}], "]"}]}], "}"}]], "Output",
  CellLabel->"Out[661]//StandardForm=  (21:53:35 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FCI", "[", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"SD", "[", 
            RowBox[{"a", ",", "b"}], "]"}], ",", 
          RowBox[{"SUND", "[", 
            RowBox[{"a", ",", "b", ",", "c"}], "]"}], ",", 
          RowBox[{"SUNF", "[", 
            RowBox[{"a", ",", "b", ",", "c"}], "]"}], ",", 
          RowBox[{"FAD", "[", "q", "]"}], ",", 
          RowBox[{"LC", "[", 
            RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Sigma]"}], 
            "]"}]}], "}"}], "]"}]], "Input",
  CellLabel->"In[662]:=  (21:53:35 on 5/16/01)",
  CellTags->"FeynCalcInternal"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          SubscriptBox["\[Delta]", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]}]], ",", 
          SubscriptBox["d", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"]}]], ",", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"]}]], ",", 
          FractionBox["1", 
            SuperscriptBox["q", "2"]], ",", 
          SuperscriptBox["\[Epsilon]", 
            RowBox[{
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Rho]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "}"}], TraditionalForm]], "Output",
  CellLabel->"Out[662]=  (21:53:35 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "StandardForm"}]], "Input",
  CellLabel->"In[663]:=  (21:53:35 on 5/16/01)",
  CellTags->"FeynCalcInternal"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"SUNDelta", "[", 
          RowBox[{
            RowBox[{"SUNIndex", "[", "a", "]"}], ",", 
            RowBox[{"SUNIndex", "[", "b", "]"}]}], "]"}], ",", 
        RowBox[{"SUND", "[", 
          RowBox[{
            RowBox[{"SUNIndex", "[", "a", "]"}], ",", 
            RowBox[{"SUNIndex", "[", "b", "]"}], ",", 
            RowBox[{"SUNIndex", "[", "c", "]"}]}], "]"}], ",", 
        RowBox[{"SUNF", "[", 
          RowBox[{
            RowBox[{"SUNIndex", "[", "a", "]"}], ",", 
            RowBox[{"SUNIndex", "[", "b", "]"}], ",", 
            RowBox[{"SUNIndex", "[", "c", "]"}]}], "]"}], ",", 
        RowBox[{"FeynAmpDenominator", "[", 
          RowBox[{"PropagatorDenominator", "[", 
            RowBox[{
              RowBox[{"Momentum", "[", 
                RowBox[{"q", ",", "D"}], "]"}], ",", "0"}], "]"}], "]"}], ",",
         
        RowBox[{"Eps", "[", 
          RowBox[{
            RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
            RowBox[{"LorentzIndex", "[", "\[Nu]", "]"}], ",", 
            RowBox[{"LorentzIndex", "[", "\[Rho]", "]"}], ",", 
            RowBox[{"LorentzIndex", "[", "\[Sigma]", "]"}]}], "]"}]}], 
      "}"}]], "Output",
  CellLabel->"Out[663]//StandardForm=  (21:53:35 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["FeynRule", "ObjectName",
  CellTags->"FeynRule"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"FeynRule"],

Cell["\<\
FeynRule[lag, {fields}] derives the Feynman rule corresponding to the field \
configuration fields of the lagrangian lag.\
\>", "Text",
  CellTags->"FeynRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "FeynRule", "]"}]], "Input",
  CellLabel->"In[664]:=  (21:53:35 on 5/16/01)",
  CellTags->"FeynRule"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"Anti5", "\[Rule]", 
            InterpretationBox[
              RowBox[{"-", "\[Infinity]"}],
              DirectedInfinity[ -1]]}], ",", 
          RowBox[{"Contract", "\[Rule]", "False"}], ",", 
          RowBox[{"Factor1", "\[Rule]", "False"}], ",", 
          RowBox[{"FinalSubstitutions", "\[Rule]", 
            RowBox[{"{", "}"}]}], ",", 
          RowBox[{"PartialD", "\[Rule]", "RightPartialD"}], ",", 
          RowBox[{"Schouten", "\[Rule]", "False"}], ",", 
          RowBox[{"ZeroMomentumInsertion", "\[Rule]", "True"}], ",", 
          RowBox[{"InitialFunction", "\[Rule]", "Identity"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[664]=  (21:53:36 on 5/16/01)"]
}, Closed]],

Cell["FeynRule does not calculate propagator Feynman rules.", "Text",
  CellTags->"FeynRule"],

Cell["\<\
The option ZeroMomentumInsertion can be used for twist-2 and higher twist \
operators.\
\>", "Text",
  CellTags->"FeynRule"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["Lagrangian",
    ButtonData:>"Lagrangian",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Lagrangian"],
  "."
}], "Text",
  CellTags->"FeynRule"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"FeynRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"gou", "=", 
      RowBox[{"Lagrangian", "[", "\"\<ogu\>\"", "]"}]}]], "Input",
  CellLabel->"In[665]:=  (21:53:36 on 5/16/01)",
  CellTags->"FeynRule"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox["\[ImaginaryI]", 
          RowBox[{"m", "-", "1"}]], " ", 
        RowBox[{
          SubsuperscriptBox["F", 
            RowBox[{"\[Alpha]", "\[NoBreak]", 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"]}], "a"], ".", 
          SuperscriptBox[
            RowBox[{"(", 
              SubsuperscriptBox["D", 
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], 
                RowBox[{"a", "\[NoBreak]", "b"}]], ")"}], 
            RowBox[{"m", "-", "2"}]], ".", 
          SubsuperscriptBox["F", 
            RowBox[{"\[Alpha]", "\[NoBreak]", 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"]}], "b"]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[665]=  (21:53:36 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"gop", "=", 
      RowBox[{"Lagrangian", "[", "\"\<ogp\>\"", "]"}]}]], "Input",
  CellLabel->"In[666]:=  (21:53:36 on 5/16/01)",
  CellTags->"FeynRule"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox["\[ImaginaryI]", "m"], " ", 
        RowBox[{
          SuperscriptBox["\[Epsilon]", 
            RowBox[{
              FormBox[
                FormBox["\[Alpha]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Beta]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Gamma]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"]}]], ".", 
          SubsuperscriptBox["F", 
            RowBox[{"\[Beta]", "\[NoBreak]", "\[Gamma]"}], "a"], ".", 
          SuperscriptBox[
            RowBox[{"(", 
              SubsuperscriptBox["D", 
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], 
                RowBox[{"a", "\[NoBreak]", "b"}]], ")"}], 
            RowBox[{"m", "-", "2"}]], ".", 
          SubsuperscriptBox["F", 
            RowBox[{"\[Alpha]", "\[NoBreak]", 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"]}], "b"]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[666]=  (21:53:36 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Explicit", "[", "gop", "]"}]], "Input",
  CellLabel->"In[667]:=  (21:53:36 on 5/16/01)",
  CellTags->"FeynRule"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox["\[ImaginaryI]", "m"], " ", 
        RowBox[{
          SuperscriptBox["\[Epsilon]", 
            RowBox[{
              FormBox[
                FormBox["\[Alpha]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Beta]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Gamma]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"]}]], ".", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SubscriptBox["\[PartialD]", 
                  FormBox[
                    FormBox["\[Beta]",
                      "TraditionalForm"],
                    "TraditionalForm"]], 
                SubsuperscriptBox[
                  FormBox["A",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Gamma]",
                      "TraditionalForm"],
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["a",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], "-", 
              RowBox[{
                SubscriptBox["\[PartialD]", 
                  FormBox[
                    FormBox["\[Gamma]",
                      "TraditionalForm"],
                    "TraditionalForm"]], 
                SubsuperscriptBox[
                  FormBox["A",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Beta]",
                      "TraditionalForm"],
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["a",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], "+", 
              RowBox[{
                SubscriptBox["g", "s"], " ", 
                RowBox[{
                  SubsuperscriptBox[
                    FormBox["A",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["\[Beta]",
                        "TraditionalForm"],
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["b2",
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SubsuperscriptBox[
                    FormBox["A",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["\[Gamma]",
                        "TraditionalForm"],
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["c11",
                        "TraditionalForm"],
                      "TraditionalForm"]]}], " ", 
                SubscriptBox["f", 
                  RowBox[{"a", "\[NoBreak]", "b2", "\[NoBreak]", "c11"}]]}]}],
             ")"}], ".", 
          SuperscriptBox[
            RowBox[{"(", 
              SubsuperscriptBox["D", 
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], 
                RowBox[{"a", "\[NoBreak]", "b"}]], ")"}], 
            RowBox[{"m", "-", "2"}]], ".", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                FormBox[
                  SubscriptBox["\[PartialD]", 
                    FormBox[
                      FormBox["\[Alpha]",
                        "TraditionalForm"],
                      "TraditionalForm"]],
                  "TraditionalForm"], 
                SubsuperscriptBox[
                  FormBox["A",
                    "TraditionalForm"], 
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["b",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], "-", 
              RowBox[{
                SubscriptBox["\[PartialD]", 
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"]], 
                SubsuperscriptBox[
                  FormBox["A",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Alpha]",
                      "TraditionalForm"],
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["b",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], "+", 
              RowBox[{
                SubscriptBox["g", "s"], " ", 
                RowBox[{
                  SubsuperscriptBox[
                    FormBox["A",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["\[Alpha]",
                        "TraditionalForm"],
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["b3",
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SubsuperscriptBox[
                    FormBox["A",
                      "TraditionalForm"], 
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["c12",
                        "TraditionalForm"],
                      "TraditionalForm"]]}], " ", 
                SubscriptBox["f", 
                  RowBox[{"b", "\[NoBreak]", "b3", "\[NoBreak]", "c12"}]]}]}],
             ")"}]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[667]=  (21:53:36 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Cases2", "[", 
      RowBox[{"%", ",", "QuantumField"}], "]"}]], "Input",
  CellLabel->"In[668]:=  (21:53:36 on 5/16/01)",
  CellTags->"FeynRule"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          SubsuperscriptBox[
            FormBox["A",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Alpha]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["b3",
                "TraditionalForm"],
              "TraditionalForm"]], ",", 
          SubsuperscriptBox[
            FormBox["A",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Beta]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["b2",
                "TraditionalForm"],
              "TraditionalForm"]], ",", 
          SubsuperscriptBox[
            FormBox["A",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Gamma]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["c11",
                "TraditionalForm"],
              "TraditionalForm"]], ",", 
          SubsuperscriptBox[
            FormBox["A",
              "TraditionalForm"], 
            FormBox["\[CapitalDelta]",
              "TraditionalForm"], 
            FormBox[
              FormBox["c12",
                "TraditionalForm"],
              "TraditionalForm"]], ",", 
          RowBox[{
            FormBox[
              SubscriptBox["\[PartialD]", 
                FormBox[
                  FormBox["\[Alpha]",
                    "TraditionalForm"],
                  "TraditionalForm"]],
              "TraditionalForm"], 
            SubsuperscriptBox[
              FormBox["A",
                "TraditionalForm"], 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"], 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]]}], ",", 
          RowBox[{
            SubscriptBox["\[PartialD]", 
              FormBox[
                FormBox["\[Beta]",
                  "TraditionalForm"],
                "TraditionalForm"]], 
            SubsuperscriptBox[
              FormBox["A",
                "TraditionalForm"], 
              FormBox[
                FormBox["\[Gamma]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"]]}], ",", 
          RowBox[{
            SubscriptBox["\[PartialD]", 
              FormBox[
                FormBox["\[Gamma]",
                  "TraditionalForm"],
                "TraditionalForm"]], 
            SubsuperscriptBox[
              FormBox["A",
                "TraditionalForm"], 
              FormBox[
                FormBox["\[Beta]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"]]}], ",", 
          RowBox[{
            SubscriptBox["\[PartialD]", 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"]], 
            SubsuperscriptBox[
              FormBox["A",
                "TraditionalForm"], 
              FormBox[
                FormBox["\[Alpha]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]]}]}], "}"}], TraditionalForm]], "Output",
  CellLabel->"Out[668]=  (21:53:36 on 5/16/01)"]
}, Closed]],

Cell["2-gluon Feynman rules (unpolarized)", "Text",
  CellTags->"FeynRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"fi", "=", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{
            RowBox[{"QuantumField", "[", 
              RowBox[{"GaugeField", ",", 
                RowBox[{"{", "\[Mu]", "}"}], ",", 
                RowBox[{"{", "a", "}"}]}], "]"}], "[", "p", "]"}], ",", 
          RowBox[{
            RowBox[{"QuantumField", "[", 
              RowBox[{"GaugeField", ",", 
                RowBox[{"{", "\[Nu]", "}"}], ",", 
                RowBox[{"{", "b", "}"}]}], "]"}], "[", "q", "]"}]}], 
        "}"}]}]], "Input",
  CellLabel->"In[669]:=  (21:53:36 on 5/16/01)",
  CellTags->"FeynRule"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{
            SubsuperscriptBox[
              FormBox["A",
                "TraditionalForm"], 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"]], "(", "p", ")"}], ",", 
          RowBox[{
            SubsuperscriptBox[
              FormBox["A",
                "TraditionalForm"], 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]], "(", "q", ")"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[669]=  (21:53:36 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"f2u", "=", 
      RowBox[{"FullSimplify", "/@", 
        RowBox[{"Factor2", "[", 
          RowBox[{"FeynRule", "[", 
            RowBox[{"gou", ",", "fi", ",", 
              RowBox[{"ZeroMomentumInsertion", "\[Rule]", "False"}]}], "]"}], 
          "]"}]}]}]], "Input",
  CellLabel->"In[670]:=  (21:53:36 on 5/16/01)",
  CellTags->"FeynRule"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}],
                      "TraditionalForm"], ")"}], "2"], " ", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{
                      FormBox["\[CapitalDelta]",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["p",
                        "TraditionalForm"]}], ")"}], "m"]}], "+", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{
                      FormBox["\[CapitalDelta]",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["q",
                        "TraditionalForm"]}], ")"}], "m"], " ", 
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["p",
                          "TraditionalForm"]}],
                      "TraditionalForm"], ")"}], "2"]}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["p",
                    "TraditionalForm"]}]}], "-", 
              RowBox[{
                SuperscriptBox["g", 
                  RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["p",
                    "TraditionalForm"]}]}], "+", 
              RowBox[{
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      SuperscriptBox[
                        FormBox["p",
                          "TraditionalForm"], 
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"]], " ", 
                      RowBox[{
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "-", 
                    RowBox[{
                      SuperscriptBox[
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], 
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"]], " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}]}], ")"}]}]}], ")"}], " ", 
          SubscriptBox["\[Delta]", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], 
        RowBox[{"2", " ", 
          SuperscriptBox[
            RowBox[{"(", 
              FormBox[
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["p",
                    "TraditionalForm"]}],
                "TraditionalForm"], ")"}], "2"], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              FormBox[
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}],
                "TraditionalForm"], ")"}], "2"]}]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[670]=  (21:53:41 on 5/16/01)"]
}, Closed]],

Cell["2-gluon Feynman rules (polarized)", "Text",
  CellTags->"FeynRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"fi", "=", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{
            RowBox[{"QuantumField", "[", 
              RowBox[{"GaugeField", ",", 
                RowBox[{"{", "\[Mu]", "}"}], ",", 
                RowBox[{"{", "a", "}"}]}], "]"}], "[", "p", "]"}], ",", 
          RowBox[{
            RowBox[{"QuantumField", "[", 
              RowBox[{"GaugeField", ",", 
                RowBox[{"{", "\[Nu]", "}"}], ",", 
                RowBox[{"{", "b", "}"}]}], "]"}], "[", "q", "]"}]}], 
        "}"}]}]], "Input",
  CellLabel->"In[671]:=  (21:53:41 on 5/16/01)",
  CellTags->"FeynRule"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{
            SubsuperscriptBox[
              FormBox["A",
                "TraditionalForm"], 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"]], "(", "p", ")"}], ",", 
          RowBox[{
            SubsuperscriptBox[
              FormBox["A",
                "TraditionalForm"], 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]], "(", "q", ")"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[671]=  (21:53:41 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"f2p", "=", 
      RowBox[{"FullSimplify", "/@", 
        RowBox[{"Factor2", "[", 
          RowBox[{"FeynRule", "[", 
            RowBox[{"gop", ",", "fi", ",", 
              RowBox[{"ZeroMomentumInsertion", "\[Rule]", "False"}]}], "]"}], 
          "]"}]}]}]], "Input",
  CellLabel->"In[672]:=  (21:53:41 on 5/16/01)",
  CellTags->"FeynRule"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        FractionBox[
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["p",
                          "TraditionalForm"]}], ")"}], "m"], " ", 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox["\[Epsilon]", 
                          RowBox[{
                            FormBox[
                              FormBox["\[Nu]",
                                "TraditionalForm"],
                              "TraditionalForm"], "\[NoBreak]", 
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"], "\[NoBreak]", 
                            FormBox["\[CapitalDelta]",
                              "TraditionalForm"]}]], " ", 
                        SuperscriptBox[
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], 
                          FormBox[
                            FormBox["\[Mu]",
                              "TraditionalForm"],
                            "TraditionalForm"]]}], "+", 
                      RowBox[{
                        SuperscriptBox["\[Epsilon]", 
                          RowBox[{
                            FormBox[
                              FormBox["\[Mu]",
                                "TraditionalForm"],
                              "TraditionalForm"], "\[NoBreak]", 
                            FormBox[
                              FormBox["\[Nu]",
                                "TraditionalForm"],
                              "TraditionalForm"], "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"], "\[NoBreak]", 
                            FormBox["\[CapitalDelta]",
                              "TraditionalForm"]}]], " ", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["p",
                            "TraditionalForm"]}]}]}], ")"}], " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      FormBox[
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["q",
                            "TraditionalForm"]}],
                        "TraditionalForm"], ")"}], "2"]}], "-", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"(", 
                      FormBox[
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["p",
                            "TraditionalForm"]}],
                        "TraditionalForm"], ")"}], "2"], " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}], ")"}], "m"], " ", 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox["\[Epsilon]", 
                          RowBox[{
                            FormBox[
                              FormBox["\[Mu]",
                                "TraditionalForm"],
                              "TraditionalForm"], "\[NoBreak]", 
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"], "\[NoBreak]", 
                            FormBox["\[CapitalDelta]",
                              "TraditionalForm"]}]], " ", 
                        SuperscriptBox[
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], 
                          FormBox[
                            FormBox["\[Nu]",
                              "TraditionalForm"],
                            "TraditionalForm"]]}], "+", 
                      RowBox[{
                        SuperscriptBox["\[Epsilon]", 
                          RowBox[{
                            FormBox[
                              FormBox["\[Mu]",
                                "TraditionalForm"],
                              "TraditionalForm"], "\[NoBreak]", 
                            FormBox[
                              FormBox["\[Nu]",
                                "TraditionalForm"],
                              "TraditionalForm"], "\[NoBreak]", 
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            FormBox["\[CapitalDelta]",
                              "TraditionalForm"]}]], " ", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["q",
                            "TraditionalForm"]}]}]}], ")"}]}]}], ")"}], " ", 
            SubscriptBox["\[Delta]", 
              RowBox[{
                FormBox[
                  FormBox["a",
                    "TraditionalForm"],
                  "TraditionalForm"], "\[NoBreak]", 
                FormBox[
                  FormBox["b",
                    "TraditionalForm"],
                  "TraditionalForm"]}]]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                FormBox[
                  RowBox[{
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["p",
                      "TraditionalForm"]}],
                  "TraditionalForm"], ")"}], "2"], " ", 
            SuperscriptBox[
              RowBox[{"(", 
                FormBox[
                  RowBox[{
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}],
                  "TraditionalForm"], ")"}], "2"]}]]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[672]=  (21:53:45 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Factor2", "[", 
      RowBox[{"Calc", "[", 
        RowBox[{"f2p", "/.", 
          RowBox[{"p", "\[Rule]", 
            RowBox[{"-", "q"}]}]}], "]"}], "]"}]], "Input",
  CellLabel->"In[673]:=  (21:53:45 on 5/16/01)",
  CellTags->"FeynRule"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        RowBox[{"(", 
          RowBox[{"1", "-", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "m"]}], ")"}], " ", 
        SuperscriptBox["\[Epsilon]", 
          RowBox[{
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox["q",
              "TraditionalForm"], "\[NoBreak]", 
            FormBox["\[CapitalDelta]",
              "TraditionalForm"]}]], " ", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              FormBox["\[CapitalDelta]",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox["q",
                "TraditionalForm"]}], ")"}], 
          RowBox[{"m", "-", "1"}]], " ", 
        SubscriptBox["\[Delta]", 
          RowBox[{
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[673]=  (21:53:46 on 5/16/01)"]
}, Closed]],

Cell["\<\
Compare with the Feynman rule tabulated in Twist2GluonOperator.\
\>", "Text",
  CellTags->"FeynRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Twist2GluonOperator", "[", 
      RowBox[{"q", ",", 
        RowBox[{"{", 
          RowBox[{"\[Mu]", ",", "a"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"\[Nu]", ",", "b"}], "}"}], ",", 
        RowBox[{"Polarization", "\[Rule]", "1"}], ",", 
        RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]], "Input",
  CellLabel->"In[674]:=  (21:53:46 on 5/16/01)",
  CellTags->"FeynRule"],

Cell[BoxData[
    FormBox[
      RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Epsilon]", 
          RowBox[{
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox["\[CapitalDelta]",
              "TraditionalForm"], "\[NoBreak]", 
            FormBox["q",
              "TraditionalForm"]}]], " ", 
        RowBox[{"(", 
          RowBox[{"1", "-", 
            FormBox[
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"-", "1"}], ")"}], "m"],
              "TraditionalForm"]}], ")"}], " ", 
        FormBox[
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}], ")"}], 
            RowBox[{"m", "-", "1"}]],
          "TraditionalForm"], " ", 
        SubscriptBox["\[Delta]", 
          RowBox[{
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[674]=  (21:53:46 on 5/16/01)"]
}, Closed]],

Cell["quark-quark Feynman rule (unpolarized)", "Text",
  CellTags->"FeynRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"qo", "=", 
      RowBox[{"Lagrangian", "[", "\"\<oqu\>\"", "]"}]}]], "Input",
  CellLabel->"In[675]:=  (21:53:46 on 5/16/01)",
  CellTags->"FeynRule"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[ImaginaryI]", "m"], " ", 
        RowBox[{
          FormBox[
            OverscriptBox["\[Psi]", "_"],
            "TraditionalForm"], ".", 
          RowBox[{"(", 
            RowBox[{
              FormBox["\<\"\[Gamma]\"\>",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"]}], ")"}], ".", 
          SuperscriptBox[
            SubscriptBox["D", 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"]], 
            RowBox[{"m", "-", "1"}]], ".", 
          FormBox["\[Psi]",
            "TraditionalForm"]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[675]=  (21:53:46 on 5/16/01)"]
}, Closed]],

Cell["quark-quark -gluon-gluon Feynman rule (unpolarized)", "Text",
  CellTags->"FeynRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"qo", "=", 
      RowBox[{"Lagrangian", "[", "\"\<oqu\>\"", "]"}]}]], "Input",
  CellLabel->"In[676]:=  (21:53:46 on 5/16/01)",
  CellTags->"FeynRule"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[ImaginaryI]", "m"], " ", 
        RowBox[{
          FormBox[
            OverscriptBox["\[Psi]", "_"],
            "TraditionalForm"], ".", 
          RowBox[{"(", 
            RowBox[{
              FormBox["\<\"\[Gamma]\"\>",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"]}], ")"}], ".", 
          SuperscriptBox[
            SubscriptBox["D", 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"]], 
            RowBox[{"m", "-", "1"}]], ".", 
          FormBox["\[Psi]",
            "TraditionalForm"]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[676]=  (21:53:46 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"qggf", "=", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{
            RowBox[{"QuantumField", "[", "QuarkField", "]"}], "[", "p", "]"}],
           ",", 
          RowBox[{
            RowBox[{"QuantumField", "[", "AntiQuarkField", "]"}], "[", "q", 
            "]"}], ",", 
          RowBox[{
            RowBox[{"QuantumField", "[", 
              RowBox[{"GaugeField", ",", 
                RowBox[{"{", "\[Mu]", "}"}], ",", 
                RowBox[{"{", "a", "}"}]}], "]"}], "[", "r", "]"}], ",", 
          RowBox[{
            RowBox[{"QuantumField", "[", 
              RowBox[{"GaugeField", ",", 
                RowBox[{"{", "\[Nu]", "}"}], ",", 
                RowBox[{"{", "b", "}"}]}], "]"}], "[", "s", "]"}]}], 
        "}"}]}]], "Input",
  CellLabel->"In[677]:=  (21:53:46 on 5/16/01)",
  CellTags->"FeynRule"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{
            FormBox["\[Psi]",
              "TraditionalForm"], "\[NoBreak]", "(", "\[NoBreak]", "p", 
            "\[NoBreak]", ")"}], ",", 
          RowBox[{
            FormBox[
              OverscriptBox["\[Psi]", "_"],
              "TraditionalForm"], "\[NoBreak]", "(", "\[NoBreak]", "q", 
            "\[NoBreak]", ")"}], ",", 
          RowBox[{
            SubsuperscriptBox[
              FormBox["A",
                "TraditionalForm"], 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"]], "(", "r", ")"}], ",", 
          RowBox[{
            SubsuperscriptBox[
              FormBox["A",
                "TraditionalForm"], 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]], "(", "s", ")"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[677]=  (21:53:47 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"n4", "=", 
      RowBox[{"FeynRule", "[", 
        RowBox[{"qo", ",", "qggf", ",", 
          RowBox[{"ZeroMomentumInsertion", "\[Rule]", "True"}]}], 
        "]"}]}]], "Input",
  CellLabel->"In[678]:=  (21:53:47 on 5/16/01)",
  CellTags->"FeynRule"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubsuperscriptBox["g", "s", "2"], " ", 
          RowBox[{
            SubscriptBox["T", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            RowBox[{"(", 
              RowBox[{
                FormBox["\<\"\[Gamma]\"\>",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"]}], ")"}], ".", 
            SubscriptBox["T", 
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          RowBox[{"(", 
            RowBox[{
              FormBox[
                TagBox[
                  RowBox[{
                    UnderoverscriptBox["\[Sum]", 
                      RowBox[{"j", "=", "0"}], 
                      RowBox[{"m", "-", "3"}]], "\<\"\"\>"}],
                  HoldForm],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                RowBox[{
                  UnderoverscriptBox["\[Sum]", 
                    RowBox[{"i", "=", "0"}], "j"], "\<\"\"\>"}],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{"-", "1"}], ")"}], "j"], " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["p",
                          "TraditionalForm"]}], ")"}], 
                    RowBox[{
                      RowBox[{"-", "j"}], "+", "m", "-", "3"}]], " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}], ")"}], "i"], " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["q",
                            "TraditionalForm"]}], "+", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["s",
                            "TraditionalForm"]}]}], ")"}], 
                    RowBox[{"j", "-", "i"}]]}],
                "TraditionalForm"]}], ")"}], " ", 
          SuperscriptBox[
            FormBox["\[CapitalDelta]",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SuperscriptBox[
            FormBox["\[CapitalDelta]",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"]]}], "-", 
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "m"], " ", 
          SubsuperscriptBox["g", "s", "2"], " ", 
          RowBox[{
            SubscriptBox["T", 
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            RowBox[{"(", 
              RowBox[{
                FormBox["\<\"\[Gamma]\"\>",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"]}], ")"}], ".", 
            SubscriptBox["T", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          RowBox[{"(", 
            RowBox[{
              FormBox[
                TagBox[
                  RowBox[{
                    UnderoverscriptBox["\[Sum]", 
                      RowBox[{"j", "=", "0"}], 
                      RowBox[{"m", "-", "3"}]], "\<\"\"\>"}],
                  HoldForm],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                RowBox[{
                  UnderoverscriptBox["\[Sum]", 
                    RowBox[{"i", "=", "0"}], "j"], "\<\"\"\>"}],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{"-", "1"}], ")"}], "j"], " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["p",
                          "TraditionalForm"]}], ")"}], "i"], " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}], ")"}], 
                    RowBox[{
                      RowBox[{"-", "j"}], "+", "m", "-", "3"}]], " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["p",
                            "TraditionalForm"]}], "+", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["s",
                            "TraditionalForm"]}]}], ")"}], 
                    RowBox[{"j", "-", "i"}]]}],
                "TraditionalForm"]}], ")"}], " ", 
          SuperscriptBox[
            FormBox["\[CapitalDelta]",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SuperscriptBox[
            FormBox["\[CapitalDelta]",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"]]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[678]=  (21:53:52 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t4", "=", 
      RowBox[{"Twist2QuarkOperator", "[", 
        RowBox[{
          RowBox[{"{", "p", "}"}], ",", 
          RowBox[{"{", "q", "}"}], ",", 
          RowBox[{"{", 
            RowBox[{"r", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{"s", ",", "\[Nu]", ",", "b"}], "}"}], ",", 
          RowBox[{"Polarization", "\[Rule]", "0"}]}], "]"}]}]], "Input",
  CellLabel->"In[679]:=  (21:53:52 on 5/16/01)",
  CellTags->"FeynRule"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "m"]}], " ", 
        SubsuperscriptBox["g", "s", "2"], " ", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              FormBox["\<\"\[Gamma]\"\>",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"]}], ")"}], ".", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{
                  SubscriptBox["T", 
                    FormBox[
                      FormBox["a",
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SubscriptBox["T", 
                    FormBox[
                      FormBox["b",
                        "TraditionalForm"],
                      "TraditionalForm"]]}], " ", 
                RowBox[{"(", 
                  RowBox[{
                    FormBox[
                      TagBox[
                        RowBox[{
                          UnderoverscriptBox["\[Sum]", 
                            RowBox[{"i", "=", "0"}], 
                            RowBox[{"m", "-", "3"}]], "\<\"\"\>"}],
                        HoldForm],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      RowBox[{
                        UnderoverscriptBox["\[Sum]", 
                          RowBox[{"j", "=", "0"}], "i"], "\<\"\"\>"}],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      RowBox[{
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{"-", 
                              RowBox[{"(", 
                                RowBox[{
                                  FormBox["\[CapitalDelta]",
                                    "TraditionalForm"], "\[NoBreak]", 
                                  "\[CenterDot]", "\[NoBreak]", 
                                  FormBox["p",
                                    "TraditionalForm"]}], ")"}]}], ")"}], 
                          RowBox[{
                            RowBox[{"-", "i"}], "+", "m", "-", "3"}]], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["q",
                                "TraditionalForm"]}], ")"}], "j"], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["q",
                                  "TraditionalForm"]}], "+", 
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["r",
                                  "TraditionalForm"]}]}], ")"}], 
                          RowBox[{"i", "-", "j"}]]}],
                      "TraditionalForm"]}], ")"}]}], "+", 
              RowBox[{
                RowBox[{
                  SubscriptBox["T", 
                    FormBox[
                      FormBox["b",
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SubscriptBox["T", 
                    FormBox[
                      FormBox["a",
                        "TraditionalForm"],
                      "TraditionalForm"]]}], " ", 
                RowBox[{"(", 
                  RowBox[{
                    FormBox[
                      TagBox[
                        RowBox[{
                          UnderoverscriptBox["\[Sum]", 
                            RowBox[{"i", "=", "0"}], 
                            RowBox[{"m", "-", "3"}]], "\<\"\"\>"}],
                        HoldForm],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      RowBox[{
                        UnderoverscriptBox["\[Sum]", 
                          RowBox[{"j", "=", "0"}], "i"], "\<\"\"\>"}],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      RowBox[{
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{"-", 
                              RowBox[{"(", 
                                RowBox[{
                                  FormBox["\[CapitalDelta]",
                                    "TraditionalForm"], "\[NoBreak]", 
                                  "\[CenterDot]", "\[NoBreak]", 
                                  FormBox["p",
                                    "TraditionalForm"]}], ")"}]}], ")"}], 
                          RowBox[{
                            RowBox[{"-", "i"}], "+", "m", "-", "3"}]], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["q",
                                "TraditionalForm"]}], ")"}], "j"], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["q",
                                  "TraditionalForm"]}], "+", 
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["s",
                                  "TraditionalForm"]}]}], ")"}], 
                          RowBox[{"i", "-", "j"}]]}],
                      "TraditionalForm"]}], ")"}]}]}], ")"}]}], " ", 
        SuperscriptBox[
          FormBox["\[CapitalDelta]",
            "TraditionalForm"], 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]], " ", 
        SuperscriptBox[
          FormBox["\[CapitalDelta]",
            "TraditionalForm"], 
          FormBox[
            FormBox["\[Nu]",
              "TraditionalForm"],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[679]=  (21:53:52 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Calc", "[", 
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{"n4", "-", "t4"}], "/.", 
            RowBox[{"OPEm", "\[Rule]", "5"}]}], "/.", 
          RowBox[{"s", "\[Rule]", 
            RowBox[{
              RowBox[{"-", "p"}], "-", "q", "-", "r"}]}]}], "/.", 
        RowBox[{"D", "\[Rule]", "4"}]}], "]"}]], "Input",
  CellLabel->"In[680]:=  (21:53:52 on 5/16/01)",
  CellTags->"FeynRule"],

Cell[BoxData[
    FormBox["0", TraditionalForm]], "Output",
  CellLabel->"Out[680]=  (21:53:55 on 5/16/01)"]
}, Closed]],

Cell["\<\
 In general equality can be shown by Timing[Factor2[ \
FCE[Calc[ChangeDimension[FCE[OPESumExplicit[n4-t4]],4]/.s\[Rule]-p-q-r]]]] \
but it is a little bit slow ...\
\>", "Text",
  CellTags->"FeynRule"],

Cell[BoxData[
    RowBox[{"Clear", "[", 
      RowBox[{"qggf", ",", "n2", ",", "n4"}], "]"}]], "Input",
  CellLabel->"In[681]:=  (21:53:55 on 5/16/01)",
  CellTags->"FeynRule"],

Cell["QCD vertices", "Text",
  CellTags->"FeynRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"fii", "=", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{
            RowBox[{"QuantumField", "[", 
              RowBox[{"GaugeField", ",", 
                RowBox[{"{", "\[Mu]", "}"}], ",", 
                RowBox[{"{", "a", "}"}]}], "]"}], "[", "p", "]"}], ",", 
          RowBox[{
            RowBox[{"QuantumField", "[", 
              RowBox[{"GaugeField", ",", 
                RowBox[{"{", "\[Nu]", "}"}], ",", 
                RowBox[{"{", "b", "}"}]}], "]"}], "[", "q", "]"}], ",", 
          RowBox[{
            RowBox[{"QuantumField", "[", 
              RowBox[{"GaugeField", ",", 
                RowBox[{"{", "\[Rho]", "}"}], ",", 
                RowBox[{"{", "c", "}"}]}], "]"}], "[", "r", "]"}]}], 
        "}"}]}]], "Input",
  CellLabel->"In[682]:=  (21:53:55 on 5/16/01)",
  CellTags->"FeynRule"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{
            SubsuperscriptBox[
              FormBox["A",
                "TraditionalForm"], 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"]], "(", "p", ")"}], ",", 
          RowBox[{
            SubsuperscriptBox[
              FormBox["A",
                "TraditionalForm"], 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]], "(", "q", ")"}], ",", 
          RowBox[{
            SubsuperscriptBox[
              FormBox["A",
                "TraditionalForm"], 
              FormBox[
                FormBox["\[Rho]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"]], "(", "r", ")"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[682]=  (21:53:55 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"g3", "=", 
      RowBox[{"FeynRule", "[", 
        RowBox[{
          RowBox[{"Lagrangian", "[", "\"\<QCD\>\"", "]"}], ",", "fii"}], 
        "]"}]}]], "Input",
  CellLabel->"In[683]:=  (21:53:55 on 5/16/01)",
  CellTags->"FeynRule"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["g", "s"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    FormBox["q",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"]], "-", 
                  SuperscriptBox[
                    FormBox["r",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"]]}], ")"}], " ", 
              SuperscriptBox["g", 
                RowBox[{"\[Nu]", "\[NoBreak]", "\[Rho]"}]]}], "-", 
            RowBox[{
              SuperscriptBox["g", 
                RowBox[{"\[Mu]", "\[NoBreak]", "\[Rho]"}]], " ", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    FormBox["p",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"]], "-", 
                  SuperscriptBox[
                    FormBox["r",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"]]}], ")"}]}], "+", 
            RowBox[{
              SuperscriptBox["g", 
                RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]], " ", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    FormBox["p",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["\[Rho]",
                        "TraditionalForm"],
                      "TraditionalForm"]], "-", 
                  SuperscriptBox[
                    FormBox["q",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["\[Rho]",
                        "TraditionalForm"],
                      "TraditionalForm"]]}], ")"}]}]}], ")"}], " ", 
        SubscriptBox["f", 
          RowBox[{
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["c",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[683]=  (21:53:58 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GluonVertex", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"q", ",", "\[Nu]", ",", "b"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"r", ",", "\[Rho]", ",", "c"}], "}"}], ",", 
        RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]], "Input",
  CellLabel->"In[684]:=  (21:53:58 on 5/16/01)",
  CellTags->"FeynRule"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["g", "s"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{"q", "-", "r"}],
                      "TraditionalForm"], ")"}], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], ")"}], " ", 
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}], "+", 
            RowBox[{
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              RowBox[{"(", 
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{"r", "-", "p"}],
                      "TraditionalForm"], ")"}], 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], ")"}]}], "+", 
            RowBox[{
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              RowBox[{"(", 
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{"p", "-", "q"}],
                      "TraditionalForm"], ")"}], 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]], ")"}]}]}], ")"}], " ", 
        SubscriptBox["f", 
          RowBox[{
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["c",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[684]=  (21:53:58 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Calc", "[", 
      RowBox[{"g3", "-", 
        RowBox[{"ChangeDimension", "[", 
          RowBox[{"%", ",", "4"}], "]"}]}], "]"}]], "Input",
  CellLabel->"In[685]:=  (21:53:58 on 5/16/01)",
  CellTags->"FeynRule"],

Cell[BoxData[
    FormBox["0", TraditionalForm]], "Output",
  CellLabel->"Out[685]=  (21:53:59 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"fi4", "=", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{
            RowBox[{"QuantumField", "[", 
              RowBox[{"GaugeField", ",", 
                RowBox[{"{", "\[Mu]", "}"}], ",", 
                RowBox[{"{", "a", "}"}]}], "]"}], "[", "p", "]"}], ",", 
          RowBox[{
            RowBox[{"QuantumField", "[", 
              RowBox[{"GaugeField", ",", 
                RowBox[{"{", "\[Nu]", "}"}], ",", 
                RowBox[{"{", "b", "}"}]}], "]"}], "[", "q", "]"}], ",", 
          RowBox[{
            RowBox[{"QuantumField", "[", 
              RowBox[{"GaugeField", ",", 
                RowBox[{"{", "\[Rho]", "}"}], ",", 
                RowBox[{"{", "c", "}"}]}], "]"}], "[", "r", "]"}], ",", 
          RowBox[{
            RowBox[{"QuantumField", "[", 
              RowBox[{"GaugeField", ",", 
                RowBox[{"{", "\[Sigma]", "}"}], ",", 
                RowBox[{"{", "d", "}"}]}], "]"}], "[", "s", "]"}]}], 
        "}"}]}]], "Input",
  CellLabel->"In[686]:=  (21:53:59 on 5/16/01)",
  CellTags->"FeynRule"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{
            SubsuperscriptBox[
              FormBox["A",
                "TraditionalForm"], 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"]], "(", "p", ")"}], ",", 
          RowBox[{
            SubsuperscriptBox[
              FormBox["A",
                "TraditionalForm"], 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]], "(", "q", ")"}], ",", 
          RowBox[{
            SubsuperscriptBox[
              FormBox["A",
                "TraditionalForm"], 
              FormBox[
                FormBox["\[Rho]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"]], "(", "r", ")"}], ",", 
          RowBox[{
            SubsuperscriptBox[
              FormBox["A",
                "TraditionalForm"], 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["d",
                  "TraditionalForm"],
                "TraditionalForm"]], "(", "s", ")"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[686]=  (21:53:59 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"g4", "=", 
      RowBox[{"FeynRule", "[", 
        RowBox[{
          RowBox[{"Lagrangian", "[", "\"\<QCD\>\"", "]"}], ",", "fi4"}], 
        "]"}]}]], "Input",
  CellLabel->"In[687]:=  (21:53:59 on 5/16/01)",
  CellTags->"FeynRule"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SuperscriptBox["g", 
                  RowBox[{"\[Mu]", "\[NoBreak]", "\[Rho]"}]], " ", 
                SuperscriptBox["g", 
                  RowBox[{"\[Nu]", "\[NoBreak]", "\[Sigma]"}]]}], "-", 
              RowBox[{
                SuperscriptBox["g", 
                  RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]], " ", 
                SuperscriptBox["g", 
                  RowBox[{"\[Rho]", "\[NoBreak]", "\[Sigma]"}]]}]}], ")"}], 
          " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["d",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["si1",
                  "TraditionalForm"],
                "TraditionalForm"]}]], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["si1",
                  "TraditionalForm"],
                "TraditionalForm"]}]], " ", 
          SubsuperscriptBox["g", "s", "2"]}], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SuperscriptBox["g", 
                  RowBox[{"\[Mu]", "\[NoBreak]", "\[Sigma]"}]], " ", 
                SuperscriptBox["g", 
                  RowBox[{"\[Nu]", "\[NoBreak]", "\[Rho]"}]]}], "-", 
              RowBox[{
                SuperscriptBox["g", 
                  RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]], " ", 
                SuperscriptBox["g", 
                  RowBox[{"\[Rho]", "\[NoBreak]", "\[Sigma]"}]]}]}], ")"}], 
          " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["si1",
                  "TraditionalForm"],
                "TraditionalForm"]}]], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["d",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["si1",
                  "TraditionalForm"],
                "TraditionalForm"]}]], " ", 
          SubsuperscriptBox["g", "s", "2"]}], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SuperscriptBox["g", 
                  RowBox[{"\[Mu]", "\[NoBreak]", "\[Sigma]"}]], " ", 
                SuperscriptBox["g", 
                  RowBox[{"\[Nu]", "\[NoBreak]", "\[Rho]"}]]}], "-", 
              RowBox[{
                SuperscriptBox["g", 
                  RowBox[{"\[Mu]", "\[NoBreak]", "\[Rho]"}]], " ", 
                SuperscriptBox["g", 
                  RowBox[{"\[Nu]", "\[NoBreak]", "\[Sigma]"}]]}]}], ")"}], 
          " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["si1",
                  "TraditionalForm"],
                "TraditionalForm"]}]], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["d",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["si1",
                  "TraditionalForm"],
                "TraditionalForm"]}]], " ", 
          SubsuperscriptBox["g", "s", "2"]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[687]=  (21:54:03 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GluonVertex", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"q", ",", "\[Nu]", ",", "b"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"r", ",", "\[Rho]", ",", "c"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"s", ",", "\[Sigma]", ",", "d"}], "}"}], ",", 
        RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]], "Input",
  CellLabel->"In[688]:=  (21:54:03 on 5/16/01)",
  CellTags->"FeynRule"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        SubsuperscriptBox["g", "s", "2"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Rho]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Sigma]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}], "-", 
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Rho]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Sigma]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}]}], ")"}], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["a",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["d",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["u8",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["b",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["c",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["u8",
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Rho]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Sigma]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}], "-", 
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Sigma]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Rho]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}]}], ")"}], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["a",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["c",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["u8",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["b",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["d",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["u8",
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Rho]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Sigma]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}], "-", 
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Sigma]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Rho]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}]}], ")"}], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["a",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["b",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["u8",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["c",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["d",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["u8",
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[688]=  (21:54:05 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Calc", "[", 
      RowBox[{"g4", "-", 
        RowBox[{"ChangeDimension", "[", 
          RowBox[{"%", ",", "4"}], "]"}]}], "]"}]], "Input",
  CellLabel->"In[689]:=  (21:54:05 on 5/16/01)",
  CellTags->"FeynRule"],

Cell[BoxData[
    FormBox["0", TraditionalForm]], "Output",
  CellLabel->"Out[689]=  (21:54:05 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{"Clear", "[", 
      RowBox[{
      "f2p", ",", "f2u", ",", "f3", ",", "f32", ",", "fi", ",", "fi4", ",", 
        "fii", ",", "g3", ",", "g4", ",", "gop", ",", "gou", ",", "n3", ",", 
        "nf3", ",", "n4", ",", "np2", ",", "npf3", ",", "p33", ",", "pf3", 
        ",", "pn3", ",", "pqo", ",", "qf", ",", "qp", ",", "qgf", ",", "qo", 
        ",", "t4"}], "]"}]], "Input",
  CellLabel->"In[690]:=  (21:54:05 on 5/16/01)",
  CellTags->"FeynRule"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["FieldStrength", "ObjectName",
  CellTags->"FieldStrength"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"FieldStrength"],

Cell[TextData[{
  "FieldStrength[\[Mu], \[Nu], a] is the field strength tensor ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubscriptBox["\[PartialD]", "\[Mu]"], 
            SubsuperscriptBox["A", "\[Nu]", "a"]}], "-", 
          RowBox[{
            SubscriptBox["\[PartialD]", "\[Nu]"], 
            SubsuperscriptBox["A", "\[Mu]", "a"]}], "+", 
          RowBox[{
            SubscriptBox["g", "s"], " ", 
            SubsuperscriptBox["A", "\[Mu]", "b1"], 
            SubsuperscriptBox["A", "\[Nu]", "c1"]}]}], TraditionalForm]]],
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          SuperscriptBox["f", 
            RowBox[{"a", " ", "b1", " ", "c1"}]]}], TraditionalForm]]],
  ". FieldStrength[\[Mu], \[Nu]] is the field strength tensor ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubscriptBox["\[PartialD]", "\[Mu]"], 
            SubsuperscriptBox["A", "\[Nu]", "\[Null]"]}], "-", 
          RowBox[{
            RowBox[{
              SubscriptBox["\[PartialD]", "\[Nu]"], 
              SubsuperscriptBox["A", "\[Mu]", "\[Null]"]}], "."}]}], 
        TraditionalForm]]],
  " The name of the field (A) and the coupling constant (g) can be set \
through the options or by additional arguments. The first two indices are \
interpreted as type LorentzIndex, except OPEDelta, which is converted to \
Momentum[OPEDelta]."
}], "Text",
  CellTags->"FieldStrength"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "FieldStrength", "]"}]], "Input",
  CellLabel->"In[691]:=  (21:54:06 on 5/16/01)",
  CellTags->"FieldStrength"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"CouplingConstant", "\[Rule]", 
            SubscriptBox["g", "s"]}], ",", 
          RowBox[{"Explicit", "\[Rule]", "False"}], ",", 
          RowBox[{"IndexPosition", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{"0", ",", "0"}], "}"}]}], ",", 
          RowBox[{"Symbol", "\[Rule]", "\<\"F\"\>"}], ",", 
          RowBox[{"QuantumField", "\[Rule]", "A"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[691]=  (21:54:06 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["QuantumField",
    ButtonData:>"QuantumField",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"QuantumField"],
  "."
}], "Text",
  CellTags->"FieldStrength"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"FieldStrength"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FieldStrength", "[", 
      RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}]], "Input",
  CellLabel->"In[692]:=  (21:54:06 on 5/16/01)",
  CellTags->"FieldStrength"],

Cell[BoxData[
    FormBox[
      SubsuperscriptBox["F", 
        RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}], "\[Null]"], 
      TraditionalForm]], "Output",
  CellLabel->"Out[692]=  (21:54:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FieldStrength", "[", 
      RowBox[{"\[Mu]", ",", "\[Nu]", ",", "a"}], "]"}]], "Input",
  CellLabel->"In[693]:=  (21:54:06 on 5/16/01)",
  CellTags->"FieldStrength"],

Cell[BoxData[
    FormBox[
      SubsuperscriptBox["F", 
        RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}], "a"], 
      TraditionalForm]], "Output",
  CellLabel->"Out[693]=  (21:54:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FieldStrength", "[", 
      RowBox[{"\[Mu]", ",", "\[Nu]", ",", 
        RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]], "Input",
  CellLabel->"In[694]:=  (21:54:06 on 5/16/01)",
  CellTags->"FieldStrength"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["\[PartialD]", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], 
          SubsuperscriptBox[
            FormBox["A",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"], "\[Null]"]}], "-", 
        RowBox[{
          SubscriptBox["\[PartialD]", 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"]], 
          SubsuperscriptBox[
            FormBox["A",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], "\[Null]"]}]}], TraditionalForm]], "Output",\

  CellLabel->"Out[694]=  (21:54:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FieldStrength", "[", 
      RowBox[{"\[Mu]", ",", "\[Nu]", ",", "a", ",", 
        RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]], "Input",
  CellLabel->"In[695]:=  (21:54:06 on 5/16/01)",
  CellTags->"FieldStrength"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["\[PartialD]", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], 
          SubsuperscriptBox[
            FormBox["A",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"]]}], "-", 
        RowBox[{
          SubscriptBox["\[PartialD]", 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"]], 
          SubsuperscriptBox[
            FormBox["A",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"]]}], "+", 
        RowBox[{
          SubscriptBox["g", "s"], " ", 
          RowBox[{
            SubsuperscriptBox[
              FormBox["A",
                "TraditionalForm"], 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["b12",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SubsuperscriptBox[
              FormBox["A",
                "TraditionalForm"], 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["c47",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SubscriptBox["f", 
            RowBox[{"a", "\[NoBreak]", "b12", "\[NoBreak]", "c47"}]]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[695]=  (21:54:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StandardForm", "[", 
      RowBox[{"FieldStrength", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]", ",", 
          RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}], "]"}]], "Input",
  CellLabel->"In[696]:=  (21:54:06 on 5/16/01)",
  CellTags->"FieldStrength"],

Cell[BoxData[
    RowBox[{
      RowBox[{"QuantumField", "[", 
        RowBox[{
          RowBox[{"PartialD", "[", 
            RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], "]"}], ",", 
          "GaugeField", ",", 
          RowBox[{"LorentzIndex", "[", "\[Nu]", "]"}]}], "]"}], "-", 
      RowBox[{"QuantumField", "[", 
        RowBox[{
          RowBox[{"PartialD", "[", 
            RowBox[{"LorentzIndex", "[", "\[Nu]", "]"}], "]"}], ",", 
          "GaugeField", ",", 
          RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}]}], "]"}]}]], "Output",
  CellLabel->"Out[696]//StandardForm=  (21:54:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StandardForm", "[", 
      RowBox[{"FieldStrength", "[", 
        RowBox[{"\[Mu]", ",", "OPEDelta", ",", 
          RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}], "]"}]], "Input",
  CellLabel->"In[697]:=  (21:54:06 on 5/16/01)",
  CellTags->"FieldStrength"],

Cell[BoxData[
    RowBox[{
      RowBox[{"QuantumField", "[", 
        RowBox[{
          RowBox[{"PartialD", "[", 
            RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], "]"}], ",", 
          "GaugeField", ",", 
          RowBox[{"Momentum", "[", "OPEDelta", "]"}]}], "]"}], "-", 
      RowBox[{"QuantumField", "[", 
        RowBox[{
          RowBox[{"PartialD", "[", 
            RowBox[{"Momentum", "[", "OPEDelta", "]"}], "]"}], ",", 
          "GaugeField", ",", 
          RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}]}], "]"}]}]], "Output",
  CellLabel->"Out[697]//StandardForm=  (21:54:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FieldStrength", "[", 
      RowBox[{"\[Mu]", ",", "\[Nu]", ",", "a", ",", 
        RowBox[{"CouplingConstant", "\[Rule]", 
          RowBox[{"-", "Gstrong"}]}], ",", 
        RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]], "Input",
  CellLabel->"In[698]:=  (21:54:06 on 5/16/01)",
  CellTags->"FieldStrength"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["\[PartialD]", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], 
          SubsuperscriptBox[
            FormBox["A",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"]]}], "-", 
        RowBox[{
          SubscriptBox["\[PartialD]", 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"]], 
          SubsuperscriptBox[
            FormBox["A",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"]]}], "-", 
        RowBox[{
          SubscriptBox["g", "s"], " ", 
          RowBox[{
            SubsuperscriptBox[
              FormBox["A",
                "TraditionalForm"], 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["b13",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SubsuperscriptBox[
              FormBox["A",
                "TraditionalForm"], 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["c48",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SubscriptBox["f", 
            RowBox[{"a", "\[NoBreak]", "b13", "\[NoBreak]", "c48"}]]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[698]=  (21:54:06 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["FORM2FeynCalc", "ObjectName",
  CellTags->"FORM2FeynCalc"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"FORM2FeynCalc"],

Cell["\<\
FORM2FeynCalc[expr] translates the FORM expr into FeynCalc notation. \
FORM2FeynCalc[file] translates the FORM expresssions in file into \
FeynCalcnotation. FORM2FeynCalc[file, x1, x2, ...] reads in a file in \
FORM-format and translates the assignments for the variables a, b, ... into \
FeynCalc syntax. If the option Set is True, the variables x1, x2 are assigned \
to the right hand sides defined in the FORM - file.\
\>", "Text",
  CellTags->"FORM2FeynCalc"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["FeynCalc2FORM",
    ButtonData:>"FeynCalc2FORM",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FeynCalc2FORM"],
  "."
}], "Text",
  CellTags->"FORM2FeynCalc"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "FORM2FeynCalc", "]"}]], "Input",
  CellLabel->"In[699]:=  (21:54:06 on 5/16/01)",
  CellTags->"FORM2FeynCalc"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"Dimension", "\[Rule]", "4"}], ",", 
          RowBox[{"FinalSubstitutions", "\[Rule]", 
            RowBox[{"{", "}"}]}], ",", 
          RowBox[{"Dot", "\[Rule]", "Times"}], ",", 
          RowBox[{"HoldForm", "\[Rule]", "False"}], ",", 
          RowBox[{"LorentzIndex", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{"mu", ",", "nu", ",", "al", ",", "be"}], "}"}]}], ",", 
          RowBox[{"Set", "\[Rule]", "False"}], ",", 
          RowBox[{"Replace", "\[Rule]", 
            RowBox[{"{", "}"}]}], ",", 
          RowBox[{"Vectors", "\[Rule]", "Automatic"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[699]=  (21:54:06 on 5/16/01)"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"FORM2FeynCalc"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FORM2FeynCalc", "[", "\"\<p.q + 2*x m^2\>\"", "]"}]], "Input",
  CellLabel->"In[700]:=  (21:54:07 on 5/16/01)",
  CellTags->"FORM2FeynCalc"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"2", " ", "x", " ", 
          SuperscriptBox["m", "2"]}], "+", 
        FormBox[
          RowBox[{
            FormBox["p",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["q",
              "TraditionalForm"]}],
          "TraditionalForm"]}], TraditionalForm]], "Output",
  CellLabel->"Out[700]=  (21:54:07 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "StandardForm"}]], "Input",
  CellLabel->"In[701]:=  (21:54:07 on 5/16/01)",
  CellTags->"FORM2FeynCalc"],

Cell[BoxData[
    RowBox[{
      RowBox[{"2", " ", 
        SuperscriptBox["m", "2"], " ", "x"}], "+", 
      RowBox[{"SP", "[", 
        RowBox[{"p", ",", "q"}], "]"}]}]], "Output",
  CellLabel->"Out[701]//StandardForm=  (21:54:07 on 5/16/01)"]
}, Closed]],

Cell["\<\
Functions are automatically converted right, but bracketed expressions need \
to be substituted explicitly.\
\>", "Text",
  CellTags->"FORM2FeynCalc"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FORM2FeynCalc", "[", 
      RowBox[{"\"\<x +f(z)+ log(x)^2+[li2(1-x)]\>\"", ",", 
        RowBox[{"Replace", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{"\"\<[li2(1-x)]\>\"", "->", "\"\<PolyLog[2,1-x]\>\""}], 
            "}"}]}]}], "]"}]], "Input",
  CellLabel->"In[702]:=  (21:54:07 on 5/16/01)",
  CellTags->"FORM2FeynCalc"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SuperscriptBox["log", "2"], "(", "x", ")"}], "+", "x", "+", 
        RowBox[{"f", "(", "z", ")"}], "+", 
        RowBox[{
          SubscriptBox["Li", "2"], "(", 
          RowBox[{"1", "-", "x"}], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[702]=  (21:54:07 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "StandardForm"}]], "Input",
  CellLabel->"In[703]:=  (21:54:07 on 5/16/01)",
  CellTags->"FORM2FeynCalc"],

Cell[BoxData[
    RowBox[{"x", "+", 
      RowBox[{"f", "[", "z", "]"}], "+", 
      SuperscriptBox[
        RowBox[{"Log", "[", "x", "]"}], "2"], "+", 
      RowBox[{"PolyLog", "[", 
        RowBox[{"2", ",", 
          RowBox[{"1", "-", "x"}]}], "]"}]}]], "Output",
  CellLabel->"Out[703]//StandardForm=  (21:54:07 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
    "FORM2FeynCalc", "[", "\"\<x + [(1)]*y -[(-1)^m]\>\"", "]"}]], "Input",
  CellLabel->"In[704]:=  (21:54:07 on 5/16/01)",
  CellTags->"FORM2FeynCalc"],

Cell[BoxData[
    FormBox[
      RowBox[{"x", "+", 
        RowBox[{"y", " ", 
          RowBox[{"Hold", "[", "1", "]"}]}], "-", 
        RowBox[{"Hold", "[", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "m"], "]"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[704]=  (21:54:07 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ReleaseHold", "[", "%", "]"}]], "Input",
  CellLabel->"In[705]:=  (21:54:07 on 5/16/01)",
  CellTags->"FORM2FeynCalc"],

Cell[BoxData[
    FormBox[
      RowBox[{"x", "-", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "m"], "+", "y"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[705]=  (21:54:07 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
    "FORM2FeynCalc", "[", "\"\<p(mu)*q(nu)+d_(mu,nu)\>\"", "]"}]], "Input",
  CellLabel->"In[706]:=  (21:54:07 on 5/16/01)",
  CellTags->"FORM2FeynCalc"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SuperscriptBox["p", "mu"], " ", 
          SuperscriptBox["q", "nu"]}], "+", 
        SuperscriptBox["g", 
          RowBox[{"mu", "\[NoBreak]", "nu"}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[706]=  (21:54:07 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "StandardForm"}]], "Input",
  CellLabel->"In[707]:=  (21:54:07 on 5/16/01)",
  CellTags->"FORM2FeynCalc"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"FV", "[", 
          RowBox[{"p", ",", "mu"}], "]"}], " ", 
        RowBox[{"FV", "[", 
          RowBox[{"q", ",", "nu"}], "]"}]}], "+", 
      RowBox[{"MT", "[", 
        RowBox[{"mu", ",", "nu"}], "]"}]}]], "Output",
  CellLabel->"Out[707]//StandardForm=  (21:54:07 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FORM2FeynCalc", "[", 
      RowBox[{"\"\<p(mu)*q(nu)+d_(mu,nu)\>\"", ",", 
        RowBox[{"Replace", "->", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"mu", "->", "\[Mu]"}], ",", 
              RowBox[{"nu", "->", "\[Nu]"}]}], "}"}]}]}], "]"}]], "Input",
  CellLabel->"In[708]:=  (21:54:07 on 5/16/01)",
  CellTags->"FORM2FeynCalc"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SuperscriptBox["p", "\[Mu]"], " ", 
          SuperscriptBox["q", "\[Nu]"]}], "+", 
        SuperscriptBox["g", 
          RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[708]=  (21:54:07 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
    "FORM2FeynCalc", "[", 
      "\"\<i_*az*bz*aM^2*D1*[(1)]*b_G1 * ( 4*eperp(mu,nu)*avec.bvec*blam \
)\>\"", "]"}]], "Input",
  CellLabel->"In[709]:=  (21:54:07 on 5/16/01)",
  CellTags->"FORM2FeynCalc"],

Cell[BoxData[
    FormBox[
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["aM", "2"], " ", "az", " ", "blam", " ", "bz", " ", 
        "b$G1", " ", "D1", " ", 
        RowBox[{"eperp", "(", 
          RowBox[{"mu", ",", "nu"}], ")"}], " ", 
        RowBox[{"Hold", "[", "1", "]"}], " ", 
        FormBox[
          RowBox[{
            FormBox["avec",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["bvec",
              "TraditionalForm"]}],
          "TraditionalForm"]}], TraditionalForm]], "Output",
  CellLabel->"Out[709]=  (21:54:08 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["FourDivergence", "ObjectName",
  CellTags->"FourDivergence"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"FourDivergence"],

Cell["\<\
FourDivergence[exp, FourVector[p, mu]] calculates the partial derivative of \
exp w.r.t. p(mu). FourDivergence[exp, FourVector[p, mu], FourVector[p,nu], \
...]gives the multiple derivative.\
\>", "Text",
  CellTags->"FourDivergence"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["RussianTrick",
    ButtonData:>"RussianTrick",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"RussianTrick"],
  "."
}], "Text",
  CellTags->"FourDivergence"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"FourDivergence"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t", "=", 
      RowBox[{"ScalarProduct", "[", 
        RowBox[{"p", ",", "q"}], "]"}]}]], "Input",
  CellLabel->"In[710]:=  (21:54:08 on 5/16/01)",
  CellTags->"FourDivergence"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox["p",
          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
        FormBox["q",
          "TraditionalForm"]}], TraditionalForm]], "Output",
  CellLabel->"Out[710]=  (21:54:08 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FourDivergence", "[", 
      RowBox[{"t", ",", 
        RowBox[{"FourVector", "[", 
          RowBox[{"q", ",", "\[Mu]"}], "]"}]}], "]"}]], "Input",
  CellLabel->"In[711]:=  (21:54:08 on 5/16/01)",
  CellTags->"FourDivergence"],

Cell[BoxData[
    FormBox[
      SuperscriptBox[
        FormBox["p",
          "TraditionalForm"], 
        FormBox[
          FormBox["\[Mu]",
            "TraditionalForm"],
          "TraditionalForm"]], TraditionalForm]], "Output",
  CellLabel->"Out[711]=  (21:54:08 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t", "=", 
      RowBox[{"ScalarProduct", "[", 
        RowBox[{
          RowBox[{"p", "-", "k"}], ",", "q"}], "]"}]}]], "Input",
  CellLabel->"In[712]:=  (21:54:08 on 5/16/01)",
  CellTags->"FourDivergence"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", 
        FormBox[
          RowBox[{"p", "-", 
            FormBox[
              TagBox[
                StyleBox["\<\"k\"\>",
                  FontSlant->"Italic"],
                (StyleForm[ #, FontSlant -> "Italic"]&)],
              "TraditionalForm"]}],
          "TraditionalForm"], "\[NoBreak]", ")", "\[NoBreak]", "\[CenterDot]",
         "\[NoBreak]", 
        FormBox["q",
          "TraditionalForm"]}], TraditionalForm]], "Output",
  CellLabel->"Out[712]=  (21:54:08 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FourDivergence", "[", 
      RowBox[{"t", ",", 
        RowBox[{"FourVector", "[", 
          RowBox[{
            RowBox[{"k", "-", "p"}], ",", "\[Mu]"}], "]"}]}], "]"}]], "Input",\

  CellLabel->"In[713]:=  (21:54:08 on 5/16/01)",
  CellTags->"FourDivergence"],

Cell[BoxData[
    FormBox["0", TraditionalForm]], "Output",
  CellLabel->"Out[713]=  (21:54:09 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{"Clear", "[", "t", "]"}]], "Input",
  CellLabel->"In[714]:=  (21:54:09 on 5/16/01)",
  CellTags->"FourDivergence"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["FourLaplacian", "ObjectName",
  CellTags->"FourLaplacian"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"FourLaplacian"],

Cell[TextData[{
  "FourLaplacian[exp, p, q] is ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[PartialD]", 
          RowBox[{"/", 
            RowBox[{"\[PartialD]", 
              SubscriptBox["p", "\[Mu]"]}]}], " "}], TraditionalForm]]],
  Cell[BoxData[
      FormBox[
        RowBox[{"\[PartialD]", 
          RowBox[{"/", 
            RowBox[{"\[PartialD]", 
              SubscriptBox["q", "\[Mu]"]}]}], " "}], TraditionalForm]]],
  "exp."
}], "Text",
  CellTags->"FourLaplacian"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "FourLaplacian", "]"}]], "Input",
  CellLabel->"In[715]:=  (21:54:09 on 5/16/01)",
  CellTags->"FourLaplacian"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"Dimension", "\[Rule]", "D"}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[715]=  (21:54:09 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["FourDivergence",
    ButtonData:>"FourDivergence",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FourDivergence"],
  ", ",
  ButtonBox["RussianTrick",
    ButtonData:>"RussianTrick",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"RussianTrick"],
  "."
}], "Text",
  CellTags->"FourLaplacian"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"FourLaplacian"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SP", "[", 
      RowBox[{"q", ",", "q"}], "]"}]], "Input",
  CellLabel->"In[716]:=  (21:54:09 on 5/16/01)",
  CellTags->"FourLaplacian"],

Cell[BoxData[
    FormBox[
      SuperscriptBox[
        FormBox["q",
          "TraditionalForm"], "2"], TraditionalForm]], "Output",
  CellLabel->"Out[716]=  (21:54:09 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FourLaplacian", "[", 
      RowBox[{"%", ",", "q", ",", "q"}], "]"}]], "Input",
  CellLabel->"In[717]:=  (21:54:09 on 5/16/01)",
  CellTags->"FourLaplacian"],

Cell[BoxData[
    FormBox[
      RowBox[{"2", " ", "D"}], TraditionalForm]], "Output",
  CellLabel->"Out[717]=  (21:54:09 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          RowBox[{"SOD", "[", "q", "]"}], "^", "OPEm"}], 
        RowBox[{"FAD", "[", 
          RowBox[{"q", ",", 
            RowBox[{"q", "-", "p"}]}], "]"}]}], "//", "FCI"}]], "Input",
  CellLabel->"In[718]:=  (21:54:09 on 5/16/01)",
  CellTags->"FourLaplacian"],

Cell[BoxData[
    FormBox[
      FractionBox[
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              FormBox["\[CapitalDelta]",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox["q",
                "TraditionalForm"]}], ")"}], "m"], 
        RowBox[{
          SuperscriptBox["q", "2"], ".", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"q", "-", "p"}], ")"}], "2"]}]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[718]=  (21:54:09 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FourLaplacian", "[", 
      RowBox[{"%", ",", "q", ",", " ", "q"}], "]"}]], "Input",
  CellLabel->"In[719]:=  (21:54:09 on 5/16/01)",
  CellTags->"FourLaplacian"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{"4", " ", "m", " ", 
            RowBox[{
              FormBox["\[CapitalDelta]",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox["p",
                "TraditionalForm"]}], " ", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}], ")"}], 
              RowBox[{"m", "-", "1"}]]}], 
          RowBox[{
            SuperscriptBox["q", "2"], ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"q", "-", "p"}], ")"}], "2"], ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"q", "-", "p"}], ")"}], "2"]}]], "-", 
        FractionBox[
          RowBox[{"2", " ", "D", " ", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}], ")"}], "m"]}], 
          RowBox[{
            SuperscriptBox["q", "2"], ".", 
            SuperscriptBox["q", "2"], ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"q", "-", "p"}], ")"}], "2"]}]], "-", 
        FractionBox[
          RowBox[{"4", " ", "m", " ", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}], ")"}], "m"]}], 
          RowBox[{
            SuperscriptBox["q", "2"], ".", 
            SuperscriptBox["q", "2"], ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"q", "-", "p"}], ")"}], "2"]}]], "+", 
        FractionBox[
          RowBox[{"12", " ", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}], ")"}], "m"]}], 
          RowBox[{
            SuperscriptBox["q", "2"], ".", 
            SuperscriptBox["q", "2"], ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"q", "-", "p"}], ")"}], "2"]}]], "-", 
        FractionBox[
          RowBox[{"2", " ", "D", " ", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}], ")"}], "m"]}], 
          RowBox[{
            SuperscriptBox["q", "2"], ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"q", "-", "p"}], ")"}], "2"], ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"q", "-", "p"}], ")"}], "2"]}]], "-", 
        FractionBox[
          RowBox[{"4", " ", "m", " ", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}], ")"}], "m"]}], 
          RowBox[{
            SuperscriptBox["q", "2"], ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"q", "-", "p"}], ")"}], "2"], ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"q", "-", "p"}], ")"}], "2"]}]], "+", 
        FractionBox[
          RowBox[{"12", " ", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}], ")"}], "m"]}], 
          RowBox[{
            SuperscriptBox["q", "2"], ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"q", "-", "p"}], ")"}], "2"], ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"q", "-", "p"}], ")"}], "2"]}]], "-", 
        FractionBox[
          RowBox[{"4", " ", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}], ")"}], "m"], " ", 
            SuperscriptBox[
              FormBox["p",
                "TraditionalForm"], "2"]}], 
          RowBox[{
            SuperscriptBox["q", "2"], ".", 
            SuperscriptBox["q", "2"], ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"q", "-", "p"}], ")"}], "2"], ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"q", "-", "p"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[719]=  (21:54:10 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["FourVector", "ObjectName",
  CellTags->"FourVector"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"FourVector"],

Cell[TextData[{
  "FourVector[p, ",
  Cell[BoxData[
      FormBox["\[Mu]", TraditionalForm]]],
  "] is the four-dimensional vector p with Lorentz index ",
  Cell[BoxData[
      FormBox["\[Mu]", TraditionalForm]]],
  ". A vector with space-time Dimension D is obtained by supplying the option \
Dimension \[Rule] D."
}], "Text",
  CellTags->"FourVector"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["FV",
    ButtonData:>"FV",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FV"],
  ", ",
  ButtonBox["FVD",
    ButtonData:>"FVD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FVD"],
  ", ",
  ButtonBox["Pair",
    ButtonData:>"Pair",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Pair"],
  "."
}], "Text",
  CellTags->"FourVector"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"FourVector"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FourVector", "[", 
      RowBox[{"p", ",", "\[Mu]"}], "]"}]], "Input",
  CellLabel->"In[720]:=  (21:54:10 on 5/16/01)",
  CellTags->"FourVector"],

Cell[BoxData[
    FormBox[
      SubscriptBox["p", "\[Mu]"], TraditionalForm]], "Output",
  CellLabel->"Out[720]=  (21:54:10 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FourVector", "[", 
      RowBox[{
        RowBox[{"p", "-", "q"}], ",", "\[Mu]"}], "]"}]], "Input",
  CellLabel->"In[721]:=  (21:54:10 on 5/16/01)",
  CellTags->"FourVector"],

Cell[BoxData[
    FormBox[
      SubscriptBox[
        RowBox[{"(", "\[NoBreak]", 
          FormBox[
            TagBox[
              RowBox[{"p", "-", "q"}],
              HoldForm],
            "TraditionalForm"], "\[NoBreak]", ")"}], "\[Mu]"], 
      TraditionalForm]], "Output",
  CellLabel->"Out[721]=  (21:54:10 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StandardForm", "[", 
      RowBox[{"FourVector", "[", 
        RowBox[{"p", ",", "\[Mu]"}], "]"}], "]"}]], "Input",
  CellLabel->"In[722]:=  (21:54:10 on 5/16/01)",
  CellTags->"FourVector"],

Cell[BoxData[
    RowBox[{"FourVector", "[", 
      RowBox[{"p", ",", "\[Mu]"}], "]"}]], "Output",
  CellLabel->"Out[722]//StandardForm=  (21:54:10 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StandardForm", "[", 
      RowBox[{"FourVector", "[", 
        RowBox[{"p", ",", "\[Mu]", ",", 
          RowBox[{"Dimension", "\[Rule]", "D"}]}], "]"}], "]"}]], "Input",
  CellLabel->"In[723]:=  (21:54:10 on 5/16/01)",
  CellTags->"FourVector"],

Cell[BoxData[
    RowBox[{"FourVector", "[", 
      RowBox[{"p", ",", "\[Mu]", ",", 
        RowBox[{"Dimension", "\[Rule]", "D"}]}], "]"}]], "Output",
  CellLabel->"Out[723]//StandardForm=  (21:54:10 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StandardForm", "[", 
      RowBox[{"FCE", "[", 
        RowBox[{"FourVector", "[", 
          RowBox[{"p", ",", "\[Mu]"}], "]"}], "]"}], "]"}]], "Input",
  CellLabel->"In[724]:=  (21:54:10 on 5/16/01)",
  CellTags->"FourVector"],

Cell[BoxData[
    RowBox[{"FourVector", "[", 
      RowBox[{"p", ",", "\[Mu]"}], "]"}]], "Output",
  CellLabel->"Out[724]//StandardForm=  (21:54:10 on 5/16/01)"]
}, Closed]],

Cell["\<\
There is no special function to expand momenta in FourVector. Since \
FourVector is turned into Pair internally ExpandScalarProduct may be used.\
\>", "Text",
  CellTags->"FourVector"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ExpandScalarProduct", "[", 
      RowBox[{"FourVector", "[", 
        RowBox[{
          RowBox[{"p", "-", "q"}], ",", "\[Mu]"}], "]"}], "]"}]], "Input",
  CellLabel->"In[725]:=  (21:54:10 on 5/16/01)",
  CellTags->"FourVector"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox[
          FormBox["p",
            "TraditionalForm"], 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]], "-", 
        SuperscriptBox[
          FormBox["q",
            "TraditionalForm"], 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[725]=  (21:54:11 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["FreeQ2", "ObjectName",
  CellTags->"FreeQ2"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"FreeQ2"],

Cell["\<\
FreeQ2[expr, {form1, form2, ...}] yields True if expr does not contain any \
occurence of form1, form2, ... and False otherwise. FreeQ2[expr, form] is the \
same as FreeQ[expr, form].\
\>", "Text",
  CellTags->"FreeQ2"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["SelectFree",
    ButtonData:>"SelectFree",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SelectFree"],
  ", ",
  ButtonBox["SelectNotFree",
    ButtonData:>"SelectNotFree",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SelectNotFree"],
  "."
}], "Text",
  CellTags->"FreeQ2"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"FreeQ2"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FreeQ2", "[", 
      RowBox[{
        RowBox[{"x", "+", 
          RowBox[{"f", "[", "x", "]"}], "+", "y"}], ",", " ", 
        RowBox[{"{", 
          RowBox[{"a", ",", "x"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[726]:=  (21:54:11 on 5/16/01)",
  CellTags->"FreeQ2"],

Cell[BoxData[
    FormBox["False", TraditionalForm]], "Output",
  CellLabel->"Out[726]=  (21:54:11 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FreeQ2", "[", 
      RowBox[{
        RowBox[{"x", "+", 
          RowBox[{"f", "[", "x", "]"}], "+", "y"}], ",", 
        RowBox[{"{", 
          RowBox[{"a", ",", "b"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[727]:=  (21:54:11 on 5/16/01)",
  CellTags->"FreeQ2"],

Cell[BoxData[
    FormBox["True", TraditionalForm]], "Output",
  CellLabel->"Out[727]=  (21:54:11 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FreeQ2", "[", 
      RowBox[{"x", ",", " ", "y"}], "]"}]], "Input",
  CellLabel->"In[728]:=  (21:54:11 on 5/16/01)",
  CellTags->"FreeQ2"],

Cell[BoxData[
    FormBox["True", TraditionalForm]], "Output",
  CellLabel->"Out[728]=  (21:54:11 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FreeQ2", "[", 
      RowBox[{
        RowBox[{"f", "[", "x", "]"}], ",", " ", "f"}], "]"}]], "Input",
  CellLabel->"In[729]:=  (21:54:11 on 5/16/01)",
  CellTags->"FreeQ2"],

Cell[BoxData[
    FormBox["False", TraditionalForm]], "Output",
  CellLabel->"Out[729]=  (21:54:11 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["FromTFi", "ObjectName",
  CellTags->"FromTFi"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"FromTFi"],

Cell["\<\
FromTFi[expr, q1, q2, p] translates the TFi notatation from the TARCER \
package to the usual FeynCalc notation. See TFi for details on the \
conventions.\
\>", "Text",
  CellTags->"FromTFi"],

Cell[TextData[{
  "See also: ",
  ButtonBox["TFi",
    ButtonData:>"TFi",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"TFi"],
  ", ",
  ButtonBox["ToTFi",
    ButtonData:>"ToTFi",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"ToTFi"],
  "."
}], "Text",
  CellTags->"FromTFi"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"FromTFi"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"FAD", "[", 
        RowBox[{"q1", ",", 
          RowBox[{"q1", "-", "p"}], ",", 
          RowBox[{"{", 
            RowBox[{"q2", ",", "M"}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"q2", "-", "p"}], ",", "m"}], "}"}], ",", 
          RowBox[{"q1", "-", "q2"}]}], "]"}], "//", "ToTFi"}]], "Input",
  CellLabel->"In[730]:=  (21:54:11 on 5/16/01)",
  CellTags->"FromTFi"],

Cell[BoxData[
    FormBox[
      InterpretationBox[
        SubsuperscriptBox[
          StyleBox["F",
            SingleLetterItalics->False,
            FontWeight->"Bold"], 
          RowBox[{
            FormBox[
              RowBox[{"{", 
                RowBox[{"1", ",", "0"}], "}"}],
              "TraditionalForm"], 
            FormBox[
              RowBox[{"{", 
                RowBox[{"1", ",", "M"}], "}"}],
              "TraditionalForm"], 
            FormBox[
              RowBox[{"{", 
                RowBox[{"1", ",", "0"}], "}"}],
              "TraditionalForm"], 
            FormBox[
              RowBox[{"{", 
                RowBox[{"1", ",", "m"}], "}"}],
              "TraditionalForm"], 
            FormBox[
              RowBox[{"{", 
                RowBox[{"1", ",", "0"}], "}"}],
              "TraditionalForm"]}], 
          RowBox[{"(", 
            FormBox["D",
              "TraditionalForm"], ")"}]],
        TFi[ D, 
          SPD[ p, p], {{1, 0}, {1, M}, {1, 0}, {1, m}, {1, 0}}],
        Editable->True], TraditionalForm]], "Output",
  CellLabel->"Out[730]=  (21:54:11 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FromTFi", "[", 
      RowBox[{
        RowBox[{"TFi", "[", 
          RowBox[{"D", ",", 
            RowBox[{"SPD", "[", 
              RowBox[{"p", ",", "p"}], "]"}], ",", 
            RowBox[{"SOD", "[", "p", "]"}], ",", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{"{", 
                  RowBox[{"1", ",", "0"}], "}"}], ",", 
                RowBox[{"{", 
                  RowBox[{"1", ",", "M"}], "}"}], ",", 
                RowBox[{"{", 
                  RowBox[{"1", ",", "0"}], "}"}], ",", 
                RowBox[{"{", 
                  RowBox[{"1", ",", "m"}], "}"}], ",", 
                RowBox[{"{", 
                  RowBox[{"1", ",", "0"}], "}"}]}], "}"}]}], "]"}], ",", "q1",
         ",", "q2", ",", "p"}], "]"}]], "Input",
  CellLabel->"In[731]:=  (21:54:12 on 5/16/01)",
  CellTags->"FromTFi"],

Cell[BoxData[
    FormBox[
      FractionBox["1", 
        RowBox[{
          SubsuperscriptBox[
            StyleBox["\<\"q\"\>",
              FontSlant->"Italic"], "2", "2"], ".", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["\<\"q\"\>",
                        FontSlant->"Italic"], "1"], "-", "p"}], ")"}], "2"], 
              "-", 
              SuperscriptBox["M", "2"]}], ")"}], ".", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                SubscriptBox[
                  StyleBox["\<\"q\"\>",
                    FontSlant->"Italic"], "2"], "-", "p"}], ")"}], "2"], ".", 
          
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                SubscriptBox[
                  StyleBox["\<\"q\"\>",
                    FontSlant->"Italic"], "1"], "-", 
                SubscriptBox[
                  StyleBox["\<\"q\"\>",
                    FontSlant->"Italic"], "2"]}], ")"}], "2"], ".", 
          RowBox[{"(", 
            RowBox[{
              SubsuperscriptBox[
                StyleBox["\<\"q\"\>",
                  FontSlant->"Italic"], "1", "2"], "-", 
              SuperscriptBox["m", "2"]}], ")"}]}]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[731]=  (21:54:12 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FromTFi", "[", 
      RowBox[{
        RowBox[{"TFi", "[", 
          RowBox[{"D", ",", 
            RowBox[{"SPD", "[", 
              RowBox[{"p", ",", "p"}], "]"}], ",", 
            RowBox[{"SOD", "[", "p", "]"}], ",", 
            RowBox[{"{", 
              RowBox[{"0", ",", "1"}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{"{", 
                  RowBox[{"1", ",", "m"}], "}"}], ",", 
                RowBox[{"{", 
                  RowBox[{"1", ",", "M"}], "}"}], ",", 
                RowBox[{"{", 
                  RowBox[{"1", ",", "0"}], "}"}], ",", 
                RowBox[{"{", 
                  RowBox[{"1", ",", "m"}], "}"}], ",", 
                RowBox[{"{", 
                  RowBox[{"1", ",", "0"}], "}"}]}], "}"}]}], "]"}], ",", "q1",
         ",", "q2", ",", "p"}], "]"}]], "Input",
  CellLabel->"In[732]:=  (21:54:12 on 5/16/01)",
  CellTags->"FromTFi"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{
          FormBox["\[CapitalDelta]",
            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
          FormBox[
            SubscriptBox[
              StyleBox["\<\"q\"\>",
                FontSlant->"Italic"], "2"],
            "TraditionalForm"]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                SubscriptBox[
                  StyleBox["\<\"q\"\>",
                    FontSlant->"Italic"], "1"], "-", 
                SubscriptBox[
                  StyleBox["\<\"q\"\>",
                    FontSlant->"Italic"], "2"]}], ")"}], "2"], ".", 
          RowBox[{"(", 
            RowBox[{
              SubsuperscriptBox[
                StyleBox["\<\"q\"\>",
                  FontSlant->"Italic"], "2", "2"], "-", 
              SuperscriptBox["M", "2"]}], ")"}], ".", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["\<\"q\"\>",
                        FontSlant->"Italic"], "2"], "-", "p"}], ")"}], "2"], 
              "-", 
              SuperscriptBox["m", "2"]}], ")"}], ".", 
          RowBox[{"(", 
            RowBox[{
              SubsuperscriptBox[
                StyleBox["\<\"q\"\>",
                  FontSlant->"Italic"], "1", "2"], "-", 
              SuperscriptBox["m", "2"]}], ")"}], ".", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                SubscriptBox[
                  StyleBox["\<\"q\"\>",
                    FontSlant->"Italic"], "1"], "-", "p"}], ")"}], "2"]}]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[732]=  (21:54:12 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["FRH", "ObjectName",
  CellTags->"FRH"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"FRH"],

Cell["\<\
FRH[exp_] := FixedPoint[ReleaseHold, exp], i.e., FRH removes all HoldForm and \
Hold in exp.\
\>", "Text",
  CellTags->"FRH"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["Isolate",
    ButtonData:>"Isolate",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Isolate"],
  "."
}], "Text",
  CellTags->"FRH"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"FRH"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Hold", "[", 
      RowBox[{"1", "-", "1", " ", "-", " ", 
        RowBox[{"Hold", "[", 
          RowBox[{"2", "-", "2"}], "]"}]}], "]"}]], "Input",
  CellLabel->"In[733]:=  (21:54:12 on 5/16/01)",
  CellTags->"FRH"],

Cell[BoxData[
    FormBox[
      RowBox[{"Hold", "[", 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"Hold", "[", 
              RowBox[{"2", "-", "2"}], "]"}]}], "+", "1", "-", "1"}], "]"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[733]=  (21:54:12 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FRH", "[", "%", "]"}]], "Input",
  CellLabel->"In[734]:=  (21:54:12 on 5/16/01)",
  CellTags->"FRH"],

Cell[BoxData[
    FormBox["0", TraditionalForm]], "Output",
  CellLabel->"Out[734]=  (21:54:12 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Isolate", "[", 
      RowBox[{
        RowBox[{"Solve", "[", 
          RowBox[{
            RowBox[{
              RowBox[{"x", "^", "3"}], "-", "x", "-", "1"}], "==", "0"}], 
          "]"}], ",", "x", ",", 
        RowBox[{"IsolateNames", "->", "H"}]}], "]"}]], "Input",
  CellLabel->"In[735]:=  (21:54:12 on 5/16/01)",
  CellTags->"FRH"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{"x", "\[Rule]", 
              TagBox[
                RowBox[{"H", "(", "3", ")"}],
                HoldForm]}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{"x", "\[Rule]", 
              TagBox[
                RowBox[{"H", "(", "6", ")"}],
                HoldForm]}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{"x", "\[Rule]", 
              TagBox[
                RowBox[{"H", "(", "7", ")"}],
                HoldForm]}], "}"}]}], "}"}], TraditionalForm]], "Output",
  CellLabel->"Out[735]=  (21:54:12 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FRH", "[", 
      RowBox[{"H", "[", "3", "]"}], "]"}]], "Input",
  CellLabel->"In[736]:=  (21:54:12 on 5/16/01)",
  CellTags->"FRH"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox["1", "3"], " ", 
          RadicalBox[
            RowBox[{
              FractionBox["27", "2"], "-", 
              FractionBox[
                RowBox[{"3", " ", 
                  SqrtBox["69"]}], "2"]}], "3"]}], "+", 
        FractionBox[
          RadicalBox[
            RowBox[{
              FractionBox["1", "2"], " ", 
              RowBox[{"(", 
                RowBox[{"9", "+", 
                  SqrtBox["69"]}], ")"}]}], "3"], 
          SuperscriptBox["3", 
            RowBox[{"2", "/", "3"}]]]}], TraditionalForm]], "Output",
  CellLabel->"Out[736]=  (21:54:12 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["FunctionalD", "ObjectName",
  CellTags->"FunctionalD"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"FunctionalD"],

Cell["\<\
FunctionalD[expr, {QuantumField[name, {mu}, {a}][p], ...}] calculates the \
functional derivative of expr with respect to the field list (with incoming \
momenta p, etc.) and does the fourier transform. FunctionalD[expr, \
{QuantumField[name, {mu},{a}], ...}] calculates the functional derivate and \
does partial integration but omits the x-space delta functions.\
\>", "Text",
  CellTags->"FunctionalD"],

Cell["FunctionalD is a low level function used in FeynRule.", "Text",
  CellTags->"FunctionalD"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["FeynRule",
    ButtonData:>"FeynRule",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FeynRule"],
  ", ",
  ButtonBox["QuantumField",
    ButtonData:>"QuantumField",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"QuantumField"],
  "."
}], "Text",
  CellTags->"FunctionalD"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"FunctionalD"],

Cell[TextData[{
  "Instead of the usual ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{"\[Delta]\[Phi]", "(", "x", ")"}], "/", 
            RowBox[{"\[Delta]\[Phi]", "(", "y", ")"}]}], "=", 
          RowBox[{
            SuperscriptBox["\[Delta]", 
              RowBox[{"(", "D", ")"}]], "(", 
            RowBox[{"x", "-", "y"}], ")"}]}], TraditionalForm]]],
  " the arguments and the \[Delta] function are omitted, i.e., for the \
program for simplicity: ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[Delta]\[Phi]", "/", "\[Delta]\[Phi]"}], "=", "1"}], 
        TraditionalForm]]]
}], "Text",
  CellTags->"FunctionalD"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FunctionalD", "[", 
      RowBox[{
        RowBox[{"QuantumField", "[", "\[Phi]", "]"}], ",", 
        RowBox[{"QuantumField", "[", "\[Phi]", "]"}]}], "]"}]], "Input",
  CellLabel->"In[737]:=  (21:54:13 on 5/16/01)",
  CellTags->"FunctionalD"],

Cell[BoxData[
    FormBox["1", TraditionalForm]], "Output",
  CellLabel->"Out[737]=  (21:54:13 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FunctionalD", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"QuantumField", "[", "\[Phi]", "]"}], "^", "2"}], ",", 
        RowBox[{"QuantumField", "[", "\[Phi]", "]"}]}], "]"}]], "Input",
  CellLabel->"In[738]:=  (21:54:13 on 5/16/01)",
  CellTags->"FunctionalD"],

Cell[BoxData[
    FormBox[
      RowBox[{"2", " ", "\[Phi]"}], TraditionalForm]], "Output",
  CellLabel->"Out[738]=  (21:54:13 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "Instead of the usual ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{"(", 
              RowBox[{"\[Delta]", " ", 
                RowBox[{
                  SubscriptBox["\[PartialD]", "\[Mu]"], 
                  RowBox[{"\[Phi]", "(", "x", ")"}]}]}], ")"}], "/", 
            RowBox[{"\[Delta]\[Phi]", "(", "y", ")"}]}], "=", 
          RowBox[{
            SubscriptBox["\[PartialD]", "\[Mu]"], 
            RowBox[{
              SuperscriptBox["\[Delta]", 
                RowBox[{"(", "D", ")"}]], "(", 
              RowBox[{"x", "-", "y"}], ")"}]}]}], TraditionalForm]]],
  " the arguments are omitted, and the ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["\[PartialD]", "\[Mu]"], TraditionalForm]]],
  "operator is specified by default to be an integration by parts operator, \
i.e., the right hand side will be just ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"-", 
            FormBox[
              SubscriptBox["\[PartialD]", "\[Mu]"],
              "TraditionalForm"]}], ","}], TraditionalForm]]],
  " or, more precisely (by default) ",
  Cell[BoxData[
      FormBox[
        RowBox[{"-", 
          SubscriptBox[
            OverscriptBox["\[PartialD]", "\[RightArrow]"], 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]]}], TraditionalForm]]],
  "."
}], "Text",
  ZeroWidthTimes->True,
  CellTags->"FunctionalD"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FunctionalD", "[", 
      RowBox[{
        RowBox[{"QuantumField", "[", 
          RowBox[{
            RowBox[{"PartialD", "[", "\[Mu]", "]"}], ",", "\[Phi]"}], "]"}], 
        ",", 
        RowBox[{"QuantumField", "[", "\[Phi]", "]"}]}], "]"}]], "Input",
  CellLabel->"In[739]:=  (21:54:13 on 5/16/01)",
  CellTags->"FunctionalD"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        SubscriptBox[
          OverscriptBox["\[PartialD]", "\[RightArrow]"], 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[739]=  (21:54:13 on 5/16/01)"]
}, Closed]],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"S", "[", "\[Phi]", "]"}], " ", "=", 
        RowBox[{
          RowBox[{"1", "/", "2"}], 
          RowBox[{"\[Integral]", " ", 
            RowBox[{
              SuperscriptBox["d", "D"], 
              RowBox[{"x", " ", "[", " ", 
                RowBox[{
                  RowBox[{
                    RowBox[{
                      SubscriptBox["\[PartialD]", "\[Mu]"], 
                      RowBox[{"\[Phi]", "(", "x", ")"}]}], " ", 
                    RowBox[{
                      SuperscriptBox["\[PartialD]", "\[Mu]"], 
                      RowBox[{"\[Phi]", "(", "x", ")"}]}]}], "-", 
                  RowBox[{
                    SuperscriptBox["m", "2"], 
                    RowBox[{"\[Phi]", "(", "x", ")"}], " ", 
                    RowBox[{"\[Phi]", "(", "y", ")"}]}]}], "]"}]}]}]}]}], 
      TraditionalForm]]]], "Text",
  ZeroWidthTimes->True,
  CellTags->"FunctionalD"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"s", "[", "\[Phi]", "]"}], "=", 
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"QuantumField", "[", 
                RowBox[{
                  RowBox[{"PartialD", "[", "\[Mu]", "]"}], ",", "\[Phi]"}], 
                "]"}], ".", 
              RowBox[{"QuantumField", "[", 
                RowBox[{
                  RowBox[{"PartialD", "[", "\[Mu]", "]"}], ",", "\[Phi]"}], 
                "]"}]}], "-", 
            RowBox[{
              RowBox[{"m", "^", "2"}], " ", 
              RowBox[{
                RowBox[{"QuantumField", "[", "\[Phi]", "]"}], ".", 
                RowBox[{"QuantumField", "[", "\[Phi]", "]"}]}]}]}], ")"}], 
        "/", "2"}]}]], "Input",
  CellLabel->"In[740]:=  (21:54:13 on 5/16/01)",
  CellTags->"FunctionalD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{
                SubscriptBox["\[PartialD]", 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], 
                SubsuperscriptBox["\[Phi]", "\[Null]", "\[Null]"]}], ".", 
              RowBox[{
                SubscriptBox["\[PartialD]", 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], 
                SubsuperscriptBox["\[Phi]", "\[Null]", "\[Null]"]}]}], "-", 
            RowBox[{
              SuperscriptBox["m", "2"], " ", 
              RowBox[{"\[Phi]", ".", "\[Phi]"}]}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[740]=  (21:54:13 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FunctionalD", "[", 
      RowBox[{
        RowBox[{"s", "[", "\[Phi]", "]"}], ",", 
        RowBox[{"QuantumField", "[", "\[Phi]", "]"}]}], "]"}]], "Input",
  CellLabel->"In[741]:=  (21:54:13 on 5/16/01)",
  CellTags->"FunctionalD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"-", "\[Phi]"}], " ", 
          SuperscriptBox["m", "2"]}], "-", 
        RowBox[{
          RowBox[{
            FormBox[
              SubscriptBox["\[PartialD]", 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]],
              "TraditionalForm"], 
            FormBox[
              SubscriptBox["\[PartialD]", 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]],
              "TraditionalForm"]}], 
          SubsuperscriptBox["\[Phi]", "\[Null]", "\[Null]"]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[741]=  (21:54:13 on 5/16/01)"]
}, Closed]],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"S", "[", "A", "]"}], " ", "=", " ", 
        RowBox[{"-", 
          RowBox[{"\[Integral]", " ", 
            RowBox[{
              SuperscriptBox["d", "D"], "x", " ", 
              FractionBox["1", "4"], " ", 
              RowBox[{
                SubsuperscriptBox["F", "a", "\[Mu]\[Nu]"], "(", "x", ")"}], 
              " ", 
              RowBox[{
                SubscriptBox["F", "\[Mu]\[Nu]a"], "(", "x", ")"}]}]}]}]}], 
      TraditionalForm]]]], "Text",
  ZeroWidthTimes->True,
  CellTags->"FunctionalD"],

Cell[TextData[StyleBox["First approach",
  FontWeight->"Bold"]], "Text",
  CellTags->"FunctionalD"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"F1", "=", 
      RowBox[{"FieldStrength", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]", ",", "a", ",", 
          RowBox[{"{", 
            RowBox[{"A", ",", "b", ",", "c"}], "}"}], ",", "1", ",", 
          RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]}]], "Input",
  CellLabel->"In[742]:=  (21:54:13 on 5/16/01)",
  CellTags->"FunctionalD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["\[PartialD]", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"]]}], "-", 
        RowBox[{
          SubscriptBox["\[PartialD]", 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"]], 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"]]}], "+", 
        RowBox[{
          RowBox[{
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SubscriptBox["f", 
            RowBox[{"a", "\[NoBreak]", "b", "\[NoBreak]", "c"}]]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[742]=  (21:54:14 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"F2", "=", 
      RowBox[{"FieldStrength", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]", ",", "a", ",", 
          RowBox[{"{", 
            RowBox[{"A", ",", "d", ",", "e"}], "}"}], ",", "1", ",", 
          RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]}]], "Input",
  CellLabel->"In[743]:=  (21:54:14 on 5/16/01)",
  CellTags->"FunctionalD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["\[PartialD]", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"]]}], "-", 
        RowBox[{
          SubscriptBox["\[PartialD]", 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"]], 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"]]}], "+", 
        RowBox[{
          RowBox[{
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["d",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["e",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SubscriptBox["f", 
            RowBox[{"a", "\[NoBreak]", "d", "\[NoBreak]", "e"}]]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[743]=  (21:54:14 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"S", "[", "A", "]"}], "=", 
      RowBox[{
        RowBox[{"-", 
          RowBox[{"1", "/", "4"}]}], 
        RowBox[{"F1", ".", "F2"}]}]}]], "Input",
  CellLabel->"In[744]:=  (21:54:14 on 5/16/01)",
  CellTags->"FunctionalD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          FractionBox["1", "4"]}], " ", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SubscriptBox["\[PartialD]", 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], 
                SubsuperscriptBox["A", 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["a",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], "-", 
              RowBox[{
                SubscriptBox["\[PartialD]", 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], 
                SubsuperscriptBox["A", 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["a",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], "+", 
              RowBox[{
                RowBox[{
                  SubsuperscriptBox["A", 
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["b",
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SubsuperscriptBox["A", 
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["c",
                        "TraditionalForm"],
                      "TraditionalForm"]]}], " ", 
                SubscriptBox["f", 
                  RowBox[{"a", "\[NoBreak]", "b", "\[NoBreak]", "c"}]]}]}], 
            ")"}], ".", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SubscriptBox["\[PartialD]", 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], 
                SubsuperscriptBox["A", 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["a",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], "-", 
              RowBox[{
                SubscriptBox["\[PartialD]", 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], 
                SubsuperscriptBox["A", 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["a",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], "+", 
              RowBox[{
                RowBox[{
                  SubsuperscriptBox["A", 
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["d",
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SubsuperscriptBox["A", 
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["e",
                        "TraditionalForm"],
                      "TraditionalForm"]]}], " ", 
                SubscriptBox["f", 
                  RowBox[{"a", "\[NoBreak]", "d", "\[NoBreak]", "e"}]]}]}], 
            ")"}]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[744]=  (21:54:14 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "In order to derive the equation of motion the functional derivative of ",
  Cell[BoxData[
      FormBox["S", TraditionalForm]]],
  " with respect to ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["A", "\[Sigma]", "g"], TraditionalForm]]],
  "has to be set to zero. Bearing in mind that for FeynCalc we have to be \
precise as to where which operators (coming from the substitution of the \
derivative of the \[Delta] function) act:, act with the functional derivative \
operator on the first field strength:"
}], "Text",
  CellTags->"FunctionalD"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox[
              RowBox[{
                FormBox[
                  RowBox[{
                    FormBox[
                      RowBox[{"0", " ", "=", " ", 
                        RowBox[{
                          FormBox[
                            RowBox[{
                              RowBox[{"(", 
                                RowBox[{"\[Delta]", "S"}], ")"}], "/", 
                              RowBox[{"(", 
                                RowBox[{"\[Delta]", 
                                  RowBox[{
                                    SubsuperscriptBox["A", "\[Sigma]", "g"], 
                                    "(", "y", ")"}]}], ")"}]}],
                            "TraditionalForm"], "=", 
                          RowBox[{"-", 
                            RowBox[{"2", "/", "4"}]}]}]}],
                      "TraditionalForm"], 
                    RowBox[{"\[Integral]", 
                      RowBox[{
                        SuperscriptBox["d", "D"], "x"}]}]}],
                  "TraditionalForm"], " ", 
                RowBox[{"(", 
                  RowBox[{"\[Delta]", "/", 
                    RowBox[{"(", 
                      RowBox[{"\[Delta]", 
                        RowBox[{
                          SubsuperscriptBox["A", "\[Sigma]", "g"], "(", "y", 
                          ")"}]}], ")"}]}]}]}],
              "TraditionalForm"], " ", 
            RowBox[{
              SubscriptBox["F", "\[Mu]\[Nu]a"], "(", "x", ")"}]}], ")"}], 
        TraditionalForm]]],
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            RowBox[{" ", 
              SubsuperscriptBox["F", "a", 
                RowBox[{",", "\[Mu]\[Nu]"}]]}],
            "TraditionalForm"], "(", "x", ")"}], TraditionalForm]]]
}], "Text",
  ZeroWidthTimes->True,
  CellTags->"FunctionalD"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{"See", " ", "what", " ", "happens", " ", "with", " ", "just", 
        RowBox[{
          FormBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{"\[Delta]", 
                  RowBox[{"S", "[", "A", "]"}]}], ")"}], "/", 
              RowBox[{"(", 
                RowBox[{"\[Delta]", 
                  SubsuperscriptBox["A", "\[Sigma]", "g"]}], ")"}]}],
            "TraditionalForm"], "."}]}], TraditionalForm]]]], "Text",
  CellTags->"FunctionalD"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Ag", "=", 
      RowBox[{"QuantumField", "[", 
        RowBox[{"A", ",", 
          RowBox[{"{", "\[Sigma]", "}"}], ",", 
          RowBox[{"{", "g", "}"}]}], "]"}]}]], "Input",
  CellLabel->"In[745]:=  (21:54:14 on 5/16/01)",
  CellTags->"FunctionalD"],

Cell[BoxData[
    FormBox[
      SubsuperscriptBox["A", 
        FormBox[
          FormBox["\[Sigma]",
            "TraditionalForm"],
          "TraditionalForm"], 
        FormBox[
          FormBox["g",
            "TraditionalForm"],
          "TraditionalForm"]], TraditionalForm]], "Output",
  CellLabel->"Out[745]=  (21:54:14 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t1", "=", 
      RowBox[{"FunctionalD", "[", 
        RowBox[{"F1", ",", "Ag"}], "]"}]}]], "Input",
  CellLabel->"In[746]:=  (21:54:14 on 5/16/01)",
  CellTags->"FunctionalD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"-", 
            SuperscriptBox["g", 
              RowBox[{"\[Nu]", "\[NoBreak]", "\[Sigma]"}]]}], " ", 
          SubscriptBox[
            OverscriptBox["\[PartialD]", "\[RightArrow]"], 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubscriptBox["\[Delta]", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "+", 
        RowBox[{
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Sigma]"}]], " ", 
          SubscriptBox[
            OverscriptBox["\[PartialD]", "\[RightArrow]"], 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubscriptBox["\[Delta]", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "+", 
        RowBox[{
          SuperscriptBox["g", 
            RowBox[{"\[Nu]", "\[NoBreak]", "\[Sigma]"}]], " ", 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "-", 
        RowBox[{
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Sigma]"}]], " ", 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["c",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[746]=  (21:54:14 on 5/16/01)"]
}, Closed]],

Cell["\<\
In order to minimize the number of dummy indices, replace b \[Rule] c.\
\>", "Text",
  CellTags->"FunctionalD"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t1", " ", "=", " ", 
      RowBox[{"t1", " ", "/.", " ", 
        RowBox[{"b", "\[Rule]", "c"}]}]}]], "Input",
  CellLabel->"In[747]:=  (21:54:14 on 5/16/01)",
  CellTags->"FunctionalD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"-", 
            SuperscriptBox["g", 
              RowBox[{"\[Nu]", "\[NoBreak]", "\[Sigma]"}]]}], " ", 
          SubscriptBox[
            OverscriptBox["\[PartialD]", "\[RightArrow]"], 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubscriptBox["\[Delta]", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "+", 
        RowBox[{
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Sigma]"}]], " ", 
          SubscriptBox[
            OverscriptBox["\[PartialD]", "\[RightArrow]"], 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubscriptBox["\[Delta]", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "+", 
        RowBox[{
          SuperscriptBox["g", 
            RowBox[{"\[Nu]", "\[NoBreak]", "\[Sigma]"}]], " ", 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["c",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "-", 
        RowBox[{
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Sigma]"}]], " ", 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["c",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[747]=  (21:54:14 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "Instead of inserting the definition for the second ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["F", "a", "\[Mu]\[Nu]"], TraditionalForm]]],
  ", introduce a QuantumField object with antisymmetry built into the Lorentz \
indices:"
}], "Text",
  CellTags->"FunctionalD"],

Cell[BoxData[
    RowBox[{"F", "/:", " ", 
      RowBox[{"QuantumField", "[", 
        RowBox[{
        "pard___", ",", "F", ",", "\[Beta]_", ",", "\[Alpha]_", ",", "s_"}], 
        "]"}], ":=", 
      RowBox[{
        RowBox[{"-", 
          RowBox[{"QuantumField", "[", 
            RowBox[{
            "pard", ",", "F", ",", "\[Alpha]", ",", "\[Beta]", ",", "s"}], 
            "]"}]}], "/;", 
        RowBox[{"!", 
          RowBox[{"OrderedQ", "[", 
            RowBox[{"{", 
              RowBox[{"\[Beta]", ",", "\[Alpha]"}], "}"}], 
            "]"}]}]}]}]], "Input",
  CellLabel->"In[748]:=  (21:54:14 on 5/16/01)",
  CellTags->"FunctionalD"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"QuantumField", "[", 
      RowBox[{"F", ",", 
        RowBox[{"{", 
          RowBox[{"\[Mu]", ",", "\[Nu]"}], "}"}], ",", 
        RowBox[{"{", "a", "}"}]}], "]"}]], "Input",
  CellLabel->"In[749]:=  (21:54:15 on 5/16/01)",
  CellTags->"FunctionalD"],

Cell[BoxData[
    FormBox[
      SubsuperscriptBox["F", 
        RowBox[{
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", 
          FormBox[
            FormBox["\[Nu]",
              "TraditionalForm"],
            "TraditionalForm"]}], 
        FormBox[
          FormBox["a",
            "TraditionalForm"],
          "TraditionalForm"]], TraditionalForm]], "Output",
  CellLabel->"Out[749]=  (21:54:15 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "/.", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Mu]", "\[RuleDelayed]", "\[Nu]"}], ",", 
          RowBox[{"\[Nu]", "\[RuleDelayed]", "\[Mu]"}]}], "}"}]}]], "Input",
  CellLabel->"In[750]:=  (21:54:15 on 5/16/01)",
  CellTags->"FunctionalD"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        SubsuperscriptBox["F", 
          RowBox[{
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"]}], 
          FormBox[
            FormBox["a",
              "TraditionalForm"],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[750]=  (21:54:15 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t2", "=", 
      RowBox[{
        RowBox[{"Contract", "[", 
          RowBox[{"ExpandPartialD", "[", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"1", "/", "2"}]}], " ", 
              RowBox[{"t1", ".", 
                RowBox[{"QuantumField", "[", 
                  RowBox[{"F", ",", 
                    RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
                    RowBox[{"LorentzIndex", "[", "\[Nu]", "]"}], ",", 
                    RowBox[{"SUNIndex", "[", "a", "]"}]}], "]"}]}]}], "]"}], 
          "]"}], "/.", 
        RowBox[{"Dot", "\[Rule]", "Times"}]}]}]], "Input",
  CellLabel->"In[751]:=  (21:54:15 on 5/16/01)",
  CellTags->"FunctionalD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{
            SubscriptBox["\[PartialD]", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"]], 
            SubsuperscriptBox["F", 
              RowBox[{
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"], "\[NoBreak]", 
                FormBox[
                  FormBox["\[Sigma]",
                    "TraditionalForm"],
                  "TraditionalForm"]}], 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]]}]}], "+", 
        RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{
            SubscriptBox["\[PartialD]", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"]], 
            SubsuperscriptBox["F", 
              RowBox[{
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"], "\[NoBreak]", 
                FormBox[
                  FormBox["\[Sigma]",
                    "TraditionalForm"],
                  "TraditionalForm"]}], 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]]}]}], "-", 
        RowBox[{
          FractionBox["1", "2"], " ", 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["c",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubsuperscriptBox["F", 
            RowBox[{
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"]}], 
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "-", 
        RowBox[{
          FractionBox["1", "2"], " ", 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["c",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubsuperscriptBox["F", 
            RowBox[{
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"]}], 
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[751]=  (21:54:15 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t3", " ", "=", " ", 
      RowBox[{"t2", " ", "/.", " ", 
        RowBox[{"\[Nu]", "\[Rule]", "\[Mu]"}]}]}]], "Input",
  CellLabel->"In[752]:=  (21:54:15 on 5/16/01)",
  CellTags->"FunctionalD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["\[PartialD]", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], 
          SubsuperscriptBox["F", 
            RowBox[{
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"]}], 
            FormBox[
              FormBox["g",
                "TraditionalForm"],
              "TraditionalForm"]]}], "-", 
        RowBox[{
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["c",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubsuperscriptBox["F", 
            RowBox[{
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"]}], 
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[752]=  (21:54:15 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t4", "=", 
      RowBox[{
        RowBox[{"FCE", "[", "t3", "]"}], "/.", " ", 
        RowBox[{
          RowBox[{"SUNF", "[", 
            RowBox[{"a", ",", "c", ",", "g"}], "]"}], "\[Rule]", 
          RowBox[{"-", 
            RowBox[{"SUNF", "[", 
              RowBox[{"g", ",", "c", ",", "a"}], "]"}]}]}]}]}]], "Input",
  CellLabel->"In[753]:=  (21:54:15 on 5/16/01)",
  CellTags->"FunctionalD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["\[PartialD]", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], 
          SubsuperscriptBox["F", 
            RowBox[{
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"]}], 
            FormBox[
              FormBox["g",
                "TraditionalForm"],
              "TraditionalForm"]]}], "+", 
        RowBox[{
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["c",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubsuperscriptBox["F", 
            RowBox[{
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"]}], 
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubscriptBox["f", 
            RowBox[{"g", "\[NoBreak]", "c", "\[NoBreak]", "a"}]]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[753]=  (21:54:15 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "Since the variational derivative vanishes t4 implies that 0 = ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox["D", "\[Mu]"], 
          SubsuperscriptBox["F", "g", "\[Mu]\[Sigma]"]}], TraditionalForm]]],
  " ."
}], "Text",
  CellTags->"FunctionalD"],

Cell[TextData[StyleBox["Second approach",
  FontWeight->"Bold"]], "Text",
  CellTags->"FunctionalD"],

Cell["\<\
It is of course also possible to do the functional deriviate on the S[A] with \
both field strength tensors inserted.\
\>", "Text",
  CellTags->"FunctionalD"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"S", "[", "A", "]"}]], "Input",
  CellLabel->"In[754]:=  (21:54:15 on 5/16/01)",
  CellTags->"FunctionalD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          FractionBox["1", "4"]}], " ", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SubscriptBox["\[PartialD]", 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], 
                SubsuperscriptBox["A", 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["a",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], "-", 
              RowBox[{
                SubscriptBox["\[PartialD]", 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], 
                SubsuperscriptBox["A", 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["a",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], "+", 
              RowBox[{
                RowBox[{
                  SubsuperscriptBox["A", 
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["b",
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SubsuperscriptBox["A", 
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["c",
                        "TraditionalForm"],
                      "TraditionalForm"]]}], " ", 
                SubscriptBox["f", 
                  RowBox[{"a", "\[NoBreak]", "b", "\[NoBreak]", "c"}]]}]}], 
            ")"}], ".", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SubscriptBox["\[PartialD]", 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], 
                SubsuperscriptBox["A", 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["a",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], "-", 
              RowBox[{
                SubscriptBox["\[PartialD]", 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], 
                SubsuperscriptBox["A", 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["a",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], "+", 
              RowBox[{
                RowBox[{
                  SubsuperscriptBox["A", 
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["d",
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SubsuperscriptBox["A", 
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["e",
                        "TraditionalForm"],
                      "TraditionalForm"]]}], " ", 
                SubscriptBox["f", 
                  RowBox[{"a", "\[NoBreak]", "d", "\[NoBreak]", "e"}]]}]}], 
            ")"}]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[754]=  (21:54:15 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"r1", "=", 
      RowBox[{"FunctionalD", "[", 
        RowBox[{
          RowBox[{"S", "[", "A", "]"}], ",", "Ag"}], "]"}]}]], "Input",
  CellLabel->"In[755]:=  (21:54:15 on 5/16/01)",
  CellTags->"FunctionalD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                FormBox[
                  SubscriptBox["\[PartialD]", 
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"]],
                  "TraditionalForm"], 
                FormBox[
                  SubscriptBox["\[PartialD]", 
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"]],
                  "TraditionalForm"]}], 
              SubsuperscriptBox["A", 
                FormBox[
                  FormBox["\[Sigma]",
                    "TraditionalForm"],
                  "TraditionalForm"], 
                FormBox[
                  FormBox["g",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], ")"}]}], "-", 
        RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                FormBox[
                  SubscriptBox["\[PartialD]", 
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"]],
                  "TraditionalForm"], 
                FormBox[
                  SubscriptBox["\[PartialD]", 
                    FormBox[
                      FormBox["\[Sigma]",
                        "TraditionalForm"],
                      "TraditionalForm"]],
                  "TraditionalForm"]}], 
              SubsuperscriptBox["A", 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"], 
                FormBox[
                  FormBox["g",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], ")"}]}], "+", 
        RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                FormBox[
                  SubscriptBox["\[PartialD]", 
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"]],
                  "TraditionalForm"], 
                FormBox[
                  SubscriptBox["\[PartialD]", 
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"]],
                  "TraditionalForm"]}], 
              SubsuperscriptBox["A", 
                FormBox[
                  FormBox["\[Sigma]",
                    "TraditionalForm"],
                  "TraditionalForm"], 
                FormBox[
                  FormBox["g",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], ")"}]}], "-", 
        RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                FormBox[
                  SubscriptBox["\[PartialD]", 
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"]],
                  "TraditionalForm"], 
                FormBox[
                  SubscriptBox["\[PartialD]", 
                    FormBox[
                      FormBox["\[Sigma]",
                        "TraditionalForm"],
                      "TraditionalForm"]],
                  "TraditionalForm"]}], 
              SubsuperscriptBox["A", 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"], 
                FormBox[
                  FormBox["g",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], ")"}]}], "-", 
        RowBox[{
          FractionBox["1", "4"], " ", 
          RowBox[{
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            RowBox[{
              SubscriptBox["\[PartialD]", 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], 
              SubsuperscriptBox["A", 
                FormBox[
                  FormBox["\[Sigma]",
                    "TraditionalForm"],
                  "TraditionalForm"], 
                FormBox[
                  FormBox["a",
                    "TraditionalForm"],
                  "TraditionalForm"]]}]}], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "+", 
        RowBox[{
          FractionBox["1", "4"], " ", 
          RowBox[{
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            RowBox[{
              SubscriptBox["\[PartialD]", 
                FormBox[
                  FormBox["\[Sigma]",
                    "TraditionalForm"],
                  "TraditionalForm"]], 
              SubsuperscriptBox["A", 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"], 
                FormBox[
                  FormBox["a",
                    "TraditionalForm"],
                  "TraditionalForm"]]}]}], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "-", 
        RowBox[{
          FractionBox["1", "4"], " ", 
          RowBox[{
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            RowBox[{
              SubscriptBox["\[PartialD]", 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], 
              SubsuperscriptBox["A", 
                FormBox[
                  FormBox["\[Sigma]",
                    "TraditionalForm"],
                  "TraditionalForm"], 
                FormBox[
                  FormBox["a",
                    "TraditionalForm"],
                  "TraditionalForm"]]}]}], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "+", 
        RowBox[{
          FractionBox["1", "4"], " ", 
          RowBox[{
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            RowBox[{
              SubscriptBox["\[PartialD]", 
                FormBox[
                  FormBox["\[Sigma]",
                    "TraditionalForm"],
                  "TraditionalForm"]], 
              SubsuperscriptBox["A", 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"], 
                FormBox[
                  FormBox["a",
                    "TraditionalForm"],
                  "TraditionalForm"]]}]}], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "-", 
        RowBox[{
          FractionBox["1", "4"], " ", 
          RowBox[{
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["d",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["e",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["d",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["e",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "+", 
        RowBox[{
          FractionBox["1", "4"], " ", 
          RowBox[{
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["d",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["e",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["d",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["e",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "-", 
        RowBox[{
          FractionBox["1", "4"], " ", 
          RowBox[{
            RowBox[{
              SubscriptBox["\[PartialD]", 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], 
              SubsuperscriptBox["A", 
                FormBox[
                  FormBox["\[Sigma]",
                    "TraditionalForm"],
                  "TraditionalForm"], 
                FormBox[
                  FormBox["a",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], ".", 
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["d",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["d",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "+", 
        RowBox[{
          FractionBox["1", "4"], " ", 
          RowBox[{
            RowBox[{
              SubscriptBox["\[PartialD]", 
                FormBox[
                  FormBox["\[Sigma]",
                    "TraditionalForm"],
                  "TraditionalForm"]], 
              SubsuperscriptBox["A", 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"], 
                FormBox[
                  FormBox["a",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], ".", 
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["d",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["d",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "-", 
        RowBox[{
          FractionBox["1", "4"], " ", 
          RowBox[{
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["d",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"]}]], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["d",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "-", 
        RowBox[{
          FractionBox["1", "4"], " ", 
          RowBox[{
            RowBox[{
              SubscriptBox["\[PartialD]", 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], 
              SubsuperscriptBox["A", 
                FormBox[
                  FormBox["\[Sigma]",
                    "TraditionalForm"],
                  "TraditionalForm"], 
                FormBox[
                  FormBox["a",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], ".", 
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["e",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["e",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "+", 
        RowBox[{
          FractionBox["1", "4"], " ", 
          RowBox[{
            RowBox[{
              SubscriptBox["\[PartialD]", 
                FormBox[
                  FormBox["\[Sigma]",
                    "TraditionalForm"],
                  "TraditionalForm"]], 
              SubsuperscriptBox["A", 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"], 
                FormBox[
                  FormBox["a",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], ".", 
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["e",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["e",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "+", 
        RowBox[{
          FractionBox["1", "4"], " ", 
          RowBox[{
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["e",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"]}]], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["e",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "+", 
        RowBox[{
          FractionBox["1", "4"], " ", 
          RowBox[{
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            RowBox[{
              SubscriptBox["\[PartialD]", 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], 
              SubsuperscriptBox["A", 
                FormBox[
                  FormBox["\[Sigma]",
                    "TraditionalForm"],
                  "TraditionalForm"], 
                FormBox[
                  FormBox["c",
                    "TraditionalForm"],
                  "TraditionalForm"]]}]}], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "-", 
        RowBox[{
          FractionBox["1", "4"], " ", 
          RowBox[{
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            RowBox[{
              SubscriptBox["\[PartialD]", 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], 
              SubsuperscriptBox["A", 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"], 
                FormBox[
                  FormBox["c",
                    "TraditionalForm"],
                  "TraditionalForm"]]}]}], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "+", 
        RowBox[{
          FractionBox["1", "4"], " ", 
          RowBox[{
            RowBox[{
              SubscriptBox["\[PartialD]", 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], 
              SubsuperscriptBox["A", 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"], 
                FormBox[
                  FormBox["b",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], ".", 
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "-", 
        RowBox[{
          FractionBox["1", "4"], " ", 
          RowBox[{
            RowBox[{
              SubscriptBox["\[PartialD]", 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], 
              SubsuperscriptBox["A", 
                FormBox[
                  FormBox["\[Sigma]",
                    "TraditionalForm"],
                  "TraditionalForm"], 
                FormBox[
                  FormBox["b",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], ".", 
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "+", 
        RowBox[{
          FractionBox["1", "4"], " ", 
          RowBox[{
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["d",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            RowBox[{
              SubscriptBox["\[PartialD]", 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], 
              SubsuperscriptBox["A", 
                FormBox[
                  FormBox["\[Sigma]",
                    "TraditionalForm"],
                  "TraditionalForm"], 
                FormBox[
                  FormBox["e",
                    "TraditionalForm"],
                  "TraditionalForm"]]}]}], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["d",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["e",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "-", 
        RowBox[{
          FractionBox["1", "4"], " ", 
          RowBox[{
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["d",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            RowBox[{
              SubscriptBox["\[PartialD]", 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], 
              SubsuperscriptBox["A", 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"], 
                FormBox[
                  FormBox["e",
                    "TraditionalForm"],
                  "TraditionalForm"]]}]}], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["d",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["e",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "+", 
        RowBox[{
          FractionBox["1", "4"], " ", 
          RowBox[{
            RowBox[{
              SubscriptBox["\[PartialD]", 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], 
              SubsuperscriptBox["A", 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"], 
                FormBox[
                  FormBox["d",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], ".", 
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["e",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["d",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["e",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "-", 
        RowBox[{
          FractionBox["1", "4"], " ", 
          RowBox[{
            RowBox[{
              SubscriptBox["\[PartialD]", 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], 
              SubsuperscriptBox["A", 
                FormBox[
                  FormBox["\[Sigma]",
                    "TraditionalForm"],
                  "TraditionalForm"], 
                FormBox[
                  FormBox["d",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], ".", 
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["e",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["d",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["e",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[755]=  (21:54:18 on 5/16/01)"]
}, Closed]],

Cell["\<\
This is just funcional derivatves and partial integration and simple \
contraction of indices. No attempt is made to rename dummy indices (since \
this is difficult in general ...).\
\>", "Text",
  CellTags->"FunctionalD"],

Cell["\<\
With a general replacement rule only valid for commuting fields the color \
indices can be canonicalized a bit more. The idea is to use the commutative \
properties of the vector fields, and canonicalize the color indices by a \
trick. This function will work on any commuting product of fields.\
\>", "Text",
  CellTags->"FunctionalD"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Clear", "[", "symfun", "]"}], ";"}]], "Input",
  CellLabel->"In[756]:=  (21:54:18 on 5/16/01)",
  CellTags->"FunctionalD"],

Cell[BoxData[
    RowBox[{
      RowBox[{"symfun", "[", 
        RowBox[{"z_", ",", "fieldname_Symbol"}], "]"}], ":=", 
      RowBox[{"Expand", "[", 
        RowBox[{"SUNSimplify", "[", 
          RowBox[{"FixedPoint", "[", 
            RowBox[{
              RowBox[{
                RowBox[{"Collect2", "[", 
                  RowBox[{
                    RowBox[{
                      RowBox[{
                        RowBox[{"DotSimplify", "[", 
                          RowBox[{"#1", "/.", 
                            RowBox[{"Times", "\[Rule]", "Dot"}]}], "]"}], "/.",
                         
                        RowBox[{
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{"(", 
                                RowBox[{
                                  RowBox[{"(", "qi___", ")"}], ".", 
                                  RowBox[{"QuantumField", "[", 
                                    RowBox[{
                                    "par1___", ",", "fieldname", ",", "li1_", 
                                      ",", "sui1_"}], "]"}], ".", 
                                  RowBox[{"QuantumField", "[", 
                                    RowBox[{
                                    "par2___", ",", "fieldname", ",", "li2_", 
                                      ",", "sui2_"}], "]"}], ".", "qf___"}], 
                                " ", ")"}], "any_"}], ")"}], "\[RuleDelayed]",
                           
                          RowBox[{
                            RowBox[{"(", 
                              RowBox[{
                                RowBox[{"(", 
                                  RowBox[{"qi", ".", 
                                    RowBox[{"QuantumField", "[", 
                                      RowBox[{
                                      "par1", ",", "A", ",", "li1", ",", 
                                        "sui2"}], "]"}], ".", 
                                    RowBox[{"QuantumField", "[", 
                                      RowBox[{
                                      "par2", ",", "fieldname", ",", "li2", 
                                        ",", "sui1"}], "]"}], ".", "qf"}], 
                                  " ", ")"}], 
                                RowBox[{"(", 
                                  RowBox[{"any", "/.", 
                                    RowBox[{"{", 
                                      RowBox[{
                                        RowBox[{
                                        "sui1", "\[RuleDelayed]", "sui2"}], 
                                        ",", 
                                        RowBox[{
                                        "sui2", "\[RuleDelayed]", "sui1"}]}], 
                                      "}"}]}], ")"}]}], ")"}], "/;", 
                            RowBox[{
                              RowBox[{"(", 
                                RowBox[{"!", 
                                  RowBox[{"(", 
                                    RowBox[{"FreeQ2", "[", 
                                      RowBox[{"any", ",", 
                                        RowBox[{"{", 
                                        RowBox[{"sui1", ",", "su2"}], "}"}]}],
                                       "]"}], ")"}]}], ")"}], "&&", 
                              RowBox[{"!", 
                                RowBox[{"(", 
                                  RowBox[{"OrderedQ", "[", 
                                    RowBox[{"{", 
                                      RowBox[{"sui1", ",", "sui2"}], "}"}], 
                                    "]"}], ")"}]}]}]}]}]}], "/.", 
                      RowBox[{"Dot", "\[Rule]", "Times"}]}], ",", 
                    "QuantumField"}], "]"}], "&"}], ",", "z", ",", "42"}], 
            "]"}], "]"}], "]"}]}]], "Input",
  CellLabel->"In[757]:=  (21:54:18 on 5/16/01)",
  CellTags->"FunctionalD"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"r2", " ", "=", " ", 
      RowBox[{"symfun", "[", 
        RowBox[{"r1", ",", "A"}], "]"}]}]], "Input",
  CellLabel->"In[758]:=  (21:54:18 on 5/16/01)",
  CellTags->"FunctionalD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                FormBox[
                  SubscriptBox["\[PartialD]", 
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"]],
                  "TraditionalForm"], 
                FormBox[
                  SubscriptBox["\[PartialD]", 
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"]],
                  "TraditionalForm"]}], 
              SubsuperscriptBox["A", 
                FormBox[
                  FormBox["\[Sigma]",
                    "TraditionalForm"],
                  "TraditionalForm"], 
                FormBox[
                  FormBox["g",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], ")"}]}], "-", 
        RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                FormBox[
                  SubscriptBox["\[PartialD]", 
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"]],
                  "TraditionalForm"], 
                FormBox[
                  SubscriptBox["\[PartialD]", 
                    FormBox[
                      FormBox["\[Sigma]",
                        "TraditionalForm"],
                      "TraditionalForm"]],
                  "TraditionalForm"]}], 
              SubsuperscriptBox["A", 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"], 
                FormBox[
                  FormBox["g",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], ")"}]}], "+", 
        RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                FormBox[
                  SubscriptBox["\[PartialD]", 
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"]],
                  "TraditionalForm"], 
                FormBox[
                  SubscriptBox["\[PartialD]", 
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"]],
                  "TraditionalForm"]}], 
              SubsuperscriptBox["A", 
                FormBox[
                  FormBox["\[Sigma]",
                    "TraditionalForm"],
                  "TraditionalForm"], 
                FormBox[
                  FormBox["g",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], ")"}]}], "-", 
        RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                FormBox[
                  SubscriptBox["\[PartialD]", 
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"]],
                  "TraditionalForm"], 
                FormBox[
                  SubscriptBox["\[PartialD]", 
                    FormBox[
                      FormBox["\[Sigma]",
                        "TraditionalForm"],
                      "TraditionalForm"]],
                  "TraditionalForm"]}], 
              SubsuperscriptBox["A", 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"], 
                FormBox[
                  FormBox["g",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], ")"}]}], "-", 
        RowBox[{
          FractionBox["1", "2"], " ", 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Sigma]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          RowBox[{
            SubscriptBox["\[PartialD]", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"]], 
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "+", 
        RowBox[{
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          RowBox[{
            SubscriptBox["\[PartialD]", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"]], 
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "-", 
        RowBox[{
          FractionBox["1", "2"], " ", 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Sigma]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          RowBox[{
            SubscriptBox["\[PartialD]", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"]], 
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "+", 
        RowBox[{
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          RowBox[{
            SubscriptBox["\[PartialD]", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"]], 
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "-", 
        RowBox[{
          FractionBox["1", "2"], " ", 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          RowBox[{
            SubscriptBox["\[PartialD]", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"]], 
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "-", 
        RowBox[{
          FractionBox["1", "2"], " ", 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          RowBox[{
            SubscriptBox["\[PartialD]", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"]], 
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "-", 
        RowBox[{
          FractionBox["1", "4"], " ", 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["c",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Sigma]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["e",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["e",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "-", 
        RowBox[{
          FractionBox["1", "2"], " ", 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["c",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Sigma]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["e",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["e",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "-", 
        RowBox[{
          FractionBox["1", "4"], " ", 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["c",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Sigma]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["e",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["e",
                  "TraditionalForm"],
                "TraditionalForm"]}]], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[758]=  (21:54:20 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"r3", "=", 
      RowBox[{"r2", "/.", 
        RowBox[{"\[Nu]", "\[Rule]", "\[Mu]"}]}]}]], "Input",
  CellLabel->"In[759]:=  (21:54:20 on 5/16/01)",
  CellTags->"FunctionalD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            FormBox[
              SubscriptBox["\[PartialD]", 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]],
              "TraditionalForm"], 
            FormBox[
              SubscriptBox["\[PartialD]", 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]],
              "TraditionalForm"]}], 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Sigma]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["g",
                "TraditionalForm"],
              "TraditionalForm"]]}], "-", 
        RowBox[{
          RowBox[{
            FormBox[
              SubscriptBox["\[PartialD]", 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]],
              "TraditionalForm"], 
            FormBox[
              SubscriptBox["\[PartialD]", 
                FormBox[
                  FormBox["\[Sigma]",
                    "TraditionalForm"],
                  "TraditionalForm"]],
              "TraditionalForm"]}], 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["g",
                "TraditionalForm"],
              "TraditionalForm"]]}], "-", 
        RowBox[{
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Sigma]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          RowBox[{
            SubscriptBox["\[PartialD]", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"]], 
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "+", 
        RowBox[{"2", " ", 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          RowBox[{
            SubscriptBox["\[PartialD]", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"]], 
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "-", 
        RowBox[{
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          RowBox[{
            SubscriptBox["\[PartialD]", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"]], 
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "-", 
        RowBox[{
          FractionBox["3", "4"], " ", 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["c",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Sigma]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["e",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["e",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "-", 
        RowBox[{
          FractionBox["1", "4"], " ", 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["c",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Sigma]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["e",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["e",
                  "TraditionalForm"],
                "TraditionalForm"]}]], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[759]=  (21:54:20 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "Inspection reveals that still terms are the same. Gather the terms with \
two ",
  Cell[BoxData[
      FormBox[
        RowBox[{"f", " "}], TraditionalForm]]],
  "'s:"
}], "Text",
  CellTags->"FunctionalD"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"twof", "=", 
      RowBox[{"Select", "[", 
        RowBox[{"r3", ",", 
          RowBox[{
            RowBox[{
              RowBox[{"Count", "[", 
                RowBox[{"#", ",", 
                  RowBox[{"SUNF", "[", "__", "]"}]}], "]"}], "===", "2"}], 
            "&"}]}], "]"}]}]], "Input",
  CellLabel->"In[760]:=  (21:54:20 on 5/16/01)",
  CellTags->"FunctionalD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"-", 
            FractionBox["3", "4"]}], " ", 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["c",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Sigma]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["e",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["e",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "-", 
        RowBox[{
          FractionBox["1", "4"], " ", 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["c",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Sigma]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["e",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["e",
                  "TraditionalForm"],
                "TraditionalForm"]}]], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[760]=  (21:54:20 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"twofnew", "=", 
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
            "twof", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
            "+", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"twof", "[", 
                  RowBox[{"[", "2", "]"}], "]"}], "/.", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"b", "\[RuleDelayed]", "c"}], ",", 
                    RowBox[{"c", "\[RuleDelayed]", "b"}]}], "}"}]}], ")"}]}], 
          ")"}], "/.", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"a", "\[RuleDelayed]", "c"}], ",", 
            RowBox[{"c", "\[RuleDelayed]", "a"}]}], "}"}]}]}]], "Input",
  CellLabel->"In[761]:=  (21:54:20 on 5/16/01)",
  CellTags->"FunctionalD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"]]}], " ", 
        SubsuperscriptBox["A", 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"], 
          FormBox[
            FormBox["b",
              "TraditionalForm"],
            "TraditionalForm"]], " ", 
        SubsuperscriptBox["A", 
          FormBox[
            FormBox["\[Sigma]",
              "TraditionalForm"],
            "TraditionalForm"], 
          FormBox[
            FormBox["e",
              "TraditionalForm"],
            "TraditionalForm"]], " ", 
        SubscriptBox["f", 
          RowBox[{
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["c",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["e",
                "TraditionalForm"],
              "TraditionalForm"]}]], " ", 
        SubscriptBox["f", 
          RowBox[{
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["c",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["g",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[761]=  (21:54:20 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"r4", " ", "=", " ", 
      RowBox[{"r3", "-", "twof", "+", "twofnew"}]}]], "Input",
  CellLabel->"In[762]:=  (21:54:20 on 5/16/01)",
  CellTags->"FunctionalD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            FormBox[
              SubscriptBox["\[PartialD]", 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]],
              "TraditionalForm"], 
            FormBox[
              SubscriptBox["\[PartialD]", 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]],
              "TraditionalForm"]}], 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Sigma]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["g",
                "TraditionalForm"],
              "TraditionalForm"]]}], "-", 
        RowBox[{
          RowBox[{
            FormBox[
              SubscriptBox["\[PartialD]", 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]],
              "TraditionalForm"], 
            FormBox[
              SubscriptBox["\[PartialD]", 
                FormBox[
                  FormBox["\[Sigma]",
                    "TraditionalForm"],
                  "TraditionalForm"]],
              "TraditionalForm"]}], 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["g",
                "TraditionalForm"],
              "TraditionalForm"]]}], "-", 
        RowBox[{
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Sigma]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          RowBox[{
            SubscriptBox["\[PartialD]", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"]], 
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "+", 
        RowBox[{"2", " ", 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          RowBox[{
            SubscriptBox["\[PartialD]", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"]], 
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "-", 
        RowBox[{
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          RowBox[{
            SubscriptBox["\[PartialD]", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"]], 
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "-", 
        RowBox[{
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Sigma]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["e",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["e",
                  "TraditionalForm"],
                "TraditionalForm"]}]], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[762]=  (21:54:20 on 5/16/01)"]
}, Closed]],

Cell["\<\
Check that this is now indeed the same as the t4 result from the first \
attempt.\
\>", "Text",
  CellTags->"FunctionalD"],

Cell[CellGroupData[{

Cell[BoxData["t4"], "Input",
  CellLabel->"In[763]:=  (21:54:20 on 5/16/01)",
  CellTags->"FunctionalD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["\[PartialD]", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], 
          SubsuperscriptBox["F", 
            RowBox[{
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"]}], 
            FormBox[
              FormBox["g",
                "TraditionalForm"],
              "TraditionalForm"]]}], "+", 
        RowBox[{
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["c",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubsuperscriptBox["F", 
            RowBox[{
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"]}], 
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubscriptBox["f", 
            RowBox[{"g", "\[NoBreak]", "c", "\[NoBreak]", "a"}]]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[763]=  (21:54:20 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"w0", "=", 
      RowBox[{
        RowBox[{
          RowBox[{"RightPartialD", "[", "\[Mu]", "]"}], ".", 
          RowBox[{"FieldStrength", "[", 
            RowBox[{"\[Mu]", ",", "\[Sigma]", ",", "g", ",", 
              RowBox[{"{", 
                RowBox[{"A", ",", "a", ",", "b"}], "}"}], ",", "1"}], "]"}]}],
         "+", 
        RowBox[{
          RowBox[{"QuantumField", "[", 
            RowBox[{"A", ",", 
              RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
              RowBox[{"SUNIndex", "[", "c", "]"}]}], "]"}], 
          RowBox[{"FieldStrength", "[", 
            RowBox[{"\[Mu]", ",", "\[Sigma]", ",", "a", ",", 
              RowBox[{"{", 
                RowBox[{"A", ",", "b", ",", "d"}], "}"}], ",", "1"}], "]"}], 
          RowBox[{"SUNF", "[", 
            RowBox[{"g", ",", "c", ",", "a"}], "]"}]}]}]}]], "Input",
  CellLabel->"In[764]:=  (21:54:20 on 5/16/01)",
  CellTags->"FunctionalD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox[
            OverscriptBox["\[PartialD]", "\[RightArrow]"], 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], ".", 
          SubsuperscriptBox["F", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Sigma]"}], 
            RowBox[{"g", "\[NoBreak]", 
              FormBox[
                RowBox[{"{", 
                  RowBox[{"A", ",", "a", ",", "b"}], "}"}],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox["1",
                "TraditionalForm"]}]]}], "+", 
        RowBox[{
          SubsuperscriptBox["F", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Sigma]"}], 
            RowBox[{"a", "\[NoBreak]", 
              FormBox[
                RowBox[{"{", 
                  RowBox[{"A", ",", "b", ",", "d"}], "}"}],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox["1",
                "TraditionalForm"]}]], " ", 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["c",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubscriptBox["f", 
            RowBox[{"g", "\[NoBreak]", "c", "\[NoBreak]", "a"}]]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[764]=  (21:54:20 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"w1", "=", 
      RowBox[{"Explicit", "[", "w0", "]"}]}]], "Input",
  CellLabel->"In[765]:=  (21:54:20 on 5/16/01)",
  CellTags->"FunctionalD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox[
            OverscriptBox["\[PartialD]", "\[RightArrow]"], 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], ".", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SubscriptBox["\[PartialD]", 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], 
                SubsuperscriptBox["A", 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["g",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], "-", 
              RowBox[{
                SubscriptBox["\[PartialD]", 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"]], 
                SubsuperscriptBox["A", 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["g",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], "+", 
              RowBox[{
                RowBox[{
                  SubsuperscriptBox["A", 
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["a",
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SubsuperscriptBox["A", 
                    FormBox[
                      FormBox["\[Sigma]",
                        "TraditionalForm"],
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["b",
                        "TraditionalForm"],
                      "TraditionalForm"]]}], " ", 
                SubscriptBox["f", 
                  RowBox[{"g", "\[NoBreak]", "a", "\[NoBreak]", "b"}]]}]}], 
            ")"}]}], "+", 
        RowBox[{
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["c",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SubscriptBox["\[PartialD]", 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], 
                SubsuperscriptBox["A", 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["a",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], "-", 
              RowBox[{
                SubscriptBox["\[PartialD]", 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"]], 
                SubsuperscriptBox["A", 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["a",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], "+", 
              RowBox[{
                RowBox[{
                  SubsuperscriptBox["A", 
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["b",
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SubsuperscriptBox["A", 
                    FormBox[
                      FormBox["\[Sigma]",
                        "TraditionalForm"],
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["d",
                        "TraditionalForm"],
                      "TraditionalForm"]]}], " ", 
                SubscriptBox["f", 
                  RowBox[{"a", "\[NoBreak]", "b", "\[NoBreak]", "d"}]]}]}], 
            ")"}], " ", 
          SubscriptBox["f", 
            RowBox[{"g", "\[NoBreak]", "c", "\[NoBreak]", "a"}]]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[765]=  (21:54:21 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"w2", "=", 
      RowBox[{
        RowBox[{"ExpandPartialD", "[", "w1", "]"}], "/.", 
        RowBox[{"Dot", "\[Rule]", "Times"}]}]}]], "Input",
  CellLabel->"In[766]:=  (21:54:21 on 5/16/01)",
  CellTags->"FunctionalD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            FormBox[
              SubscriptBox["\[PartialD]", 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]],
              "TraditionalForm"], 
            FormBox[
              SubscriptBox["\[PartialD]", 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]],
              "TraditionalForm"]}], 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Sigma]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["g",
                "TraditionalForm"],
              "TraditionalForm"]]}], "-", 
        RowBox[{
          RowBox[{
            FormBox[
              SubscriptBox["\[PartialD]", 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]],
              "TraditionalForm"], 
            FormBox[
              SubscriptBox["\[PartialD]", 
                FormBox[
                  FormBox["\[Sigma]",
                    "TraditionalForm"],
                  "TraditionalForm"]],
              "TraditionalForm"]}], 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["g",
                "TraditionalForm"],
              "TraditionalForm"]]}], "+", 
        RowBox[{
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Sigma]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          RowBox[{
            SubscriptBox["\[PartialD]", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"]], 
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "+", 
        RowBox[{
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          RowBox[{
            SubscriptBox["\[PartialD]", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"]], 
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "-", 
        RowBox[{
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["c",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          RowBox[{
            SubscriptBox["\[PartialD]", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"]], 
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "+", 
        RowBox[{
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["c",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          RowBox[{
            SubscriptBox["\[PartialD]", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"]], 
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "-", 
        RowBox[{
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["c",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Sigma]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["d",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["d",
                  "TraditionalForm"],
                "TraditionalForm"]}]], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[766]=  (21:54:21 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"dif1", " ", "=", " ", 
      RowBox[{"w2", "-", "r4"}]}]], "Input",
  CellLabel->"In[767]:=  (21:54:21 on 5/16/01)",
  CellTags->"FunctionalD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Sigma]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          RowBox[{
            SubscriptBox["\[PartialD]", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"]], 
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "+", 
        RowBox[{
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Sigma]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          RowBox[{
            SubscriptBox["\[PartialD]", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"]], 
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "-", 
        RowBox[{
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          RowBox[{
            SubscriptBox["\[PartialD]", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"]], 
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "+", 
        RowBox[{
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          RowBox[{
            SubscriptBox["\[PartialD]", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"]], 
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "-", 
        RowBox[{
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["c",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          RowBox[{
            SubscriptBox["\[PartialD]", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"]], 
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "+", 
        RowBox[{
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["c",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          RowBox[{
            SubscriptBox["\[PartialD]", 
              FormBox[
                FormBox["\[Sigma]",
                  "TraditionalForm"],
                "TraditionalForm"]], 
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "-", 
        RowBox[{
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["c",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Sigma]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["d",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["d",
                  "TraditionalForm"],
                "TraditionalForm"]}]], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "+", 
        RowBox[{
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Sigma]",
                "TraditionalForm"],
              "TraditionalForm"], 
            FormBox[
              FormBox["e",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["e",
                  "TraditionalForm"],
                "TraditionalForm"]}]], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["g",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[767]=  (21:54:21 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"dif2", "=", 
      RowBox[{"symfun", "[", 
        RowBox[{"dif1", ",", "A"}], "]"}]}]], "Input",
  CellLabel->"In[768]:=  (21:54:21 on 5/16/01)",
  CellTags->"FunctionalD"],

Cell[BoxData[
    FormBox["0", TraditionalForm]], "Output",
  CellLabel->"Out[768]=  (21:54:22 on 5/16/01)"]
}, Closed]],

Cell["quod erat demonstrandum.", "Text",
  CellTags->"FunctionalD"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Unset", "[", 
        RowBox[{"s", "[", "\[Phi]", "]"}], "]"}], ";", 
      RowBox[{"Unset", "[", 
        RowBox[{"S", "[", "A", "]"}], "]"}], ";", 
      RowBox[{"Clear", "[", 
        RowBox[{
        "Ag", ",", "F1", ",", "F2", ",", "t1", ",", "t2", ",", "t3", ",", 
          "t4", ",", "F", ",", "r1", ",", "r2", ",", "r3", ",", "r4", ",", 
          "symfun", ",", "twof", ",", "twofnew", ",", "w0", ",", "w1", ",", 
          "w2", ",", "dif1", ",", "dif2", ",", "dif3"}], "]"}]}]], "Input",
  CellLabel->"In[769]:=  (21:54:22 on 5/16/01)",
  CellTags->"FunctionalD"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples of funcional differentiation as used in FeynRule", \
"Subsubsection",
  CellTags->"FunctionalD"],

Cell["This is a part of the QCD Lagrangian.", "Text",
  CellTags->"FunctionalD"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"(", 
        RowBox[{"Gstrong", "*", 
          RowBox[{
            RowBox[{
              RowBox[{"QuantumField", "[", 
                RowBox[{"GaugeField", ",", " ", 
                  RowBox[{"LorentzIndex", "[", "li1", "]"}], ",", " ", " ", 
                  RowBox[{"SUNIndex", "[", "si2", "]"}]}], "]"}], "[", "]"}], 
            " ", ".", " ", " ", 
            RowBox[{
              RowBox[{"QuantumField", "[", 
                RowBox[{"GaugeField", ",", " ", 
                  RowBox[{"LorentzIndex", "[", "li2", "]"}], ",", " ", " ", 
                  " ", 
                  RowBox[{"SUNIndex", "[", "si4", "]"}]}], "]"}], "[", "]"}], 
            " ", ".", " ", " ", 
            RowBox[{
              RowBox[{"QuantumField", "[", 
                RowBox[{
                  RowBox[{"PartialD", "[", 
                    RowBox[{"LorentzIndex", "[", "li1", "]"}], "]"}], ",", 
                  " ", "GaugeField", ",", " ", " ", " ", 
                  RowBox[{"LorentzIndex", "[", "li2", "]"}], ",", " ", 
                  RowBox[{"SUNIndex", "[", "si1", "]"}]}], "]"}], "[", 
              "]"}]}], "*", " ", " ", 
          RowBox[{"SUNF", "[", 
            RowBox[{
              RowBox[{"SUNIndex", "[", "si1", "]"}], ",", " ", 
              RowBox[{"SUNIndex", "[", "si2", "]"}], ",", " ", 
              RowBox[{"SUNIndex", "[", "si4", "]"}]}], "]"}]}], ")"}], "/", 
      "4"}]], "Input",
  CellLabel->"In[770]:=  (21:54:22 on 5/16/01)",
  CellTags->"FunctionalD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox["1", "4"], " ", 
        SubscriptBox["g", "s"], " ", 
        RowBox[{
          RowBox[{
            SubsuperscriptBox[
              FormBox["A",
                "TraditionalForm"], 
              FormBox[
                FormBox["li1",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["si2",
                  "TraditionalForm"],
                "TraditionalForm"]], "(", ")"}], ".", 
          RowBox[{
            SubsuperscriptBox[
              FormBox["A",
                "TraditionalForm"], 
              FormBox[
                FormBox["li2",
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["si4",
                  "TraditionalForm"],
                "TraditionalForm"]], "(", ")"}], ".", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SubscriptBox["\[PartialD]", 
                  FormBox[
                    FormBox["li1",
                      "TraditionalForm"],
                    "TraditionalForm"]], 
                SubsuperscriptBox[
                  FormBox["A",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["li2",
                      "TraditionalForm"],
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["si1",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], ")"}], "(", ")"}]}], " ", 
        SubscriptBox["f", 
          RowBox[{
            FormBox[
              FormBox["si1",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["si2",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["si4",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[770]=  (21:54:22 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FunctionalD", "[", 
      RowBox[{"%", ",", " ", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{"QuantumField", "[", 
                RowBox[{"GaugeField", ",", 
                  RowBox[{"{", "\[Mu]", "}"}], ",", 
                  RowBox[{"{", "a", "}"}]}], "]"}], "[", "p", "]"}], ",", " ",
             
            RowBox[{
              RowBox[{"QuantumField", "[", 
                RowBox[{"GaugeField", ",", 
                  RowBox[{"{", "\[Nu]", "}"}], ",", 
                  RowBox[{"{", "b", "}"}]}], "]"}], "[", "q", "]"}], ",", " ",
             
            RowBox[{
              RowBox[{"QuantumField", "[", 
                RowBox[{"GaugeField", ",", 
                  RowBox[{"{", "\[Rho]", "}"}], ",", 
                  RowBox[{"{", "c", "}"}]}], "]"}], "[", "r", "]"}]}], 
          "}"}]}], "]"}]], "Input",
  CellLabel->"In[771]:=  (21:54:22 on 5/16/01)",
  CellTags->"FunctionalD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox["1", "4"], " ", 
        SubscriptBox["g", "s"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox["g", 
                    RowBox[{"li1", "\[NoBreak]", "\[Mu]"}]], " ", 
                  SubscriptBox["\[Delta]", 
                    RowBox[{
                      FormBox[
                        FormBox["a",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["si2",
                          "TraditionalForm"],
                        "TraditionalForm"]}]]}], ")"}], ".", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox["g", 
                    RowBox[{"li2", "\[NoBreak]", "\[Nu]"}]], " ", 
                  SubscriptBox["\[Delta]", 
                    RowBox[{
                      FormBox[
                        FormBox["b",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["si4",
                          "TraditionalForm"],
                        "TraditionalForm"]}]]}], ")"}], ".", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"-", "\[ImaginaryI]"}], " ", 
                  SuperscriptBox[
                    FormBox["r",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["li1",
                        "TraditionalForm"],
                      "TraditionalForm"]], " ", 
                  SuperscriptBox["g", 
                    RowBox[{"li2", "\[NoBreak]", "\[Rho]"}]], " ", 
                  SubscriptBox["\[Delta]", 
                    RowBox[{
                      FormBox[
                        FormBox["c",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["si1",
                          "TraditionalForm"],
                        "TraditionalForm"]}]]}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox["g", 
                    RowBox[{"li1", "\[NoBreak]", "\[Mu]"}]], " ", 
                  SubscriptBox["\[Delta]", 
                    RowBox[{
                      FormBox[
                        FormBox["a",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["si2",
                          "TraditionalForm"],
                        "TraditionalForm"]}]]}], ")"}], ".", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox["g", 
                    RowBox[{"li2", "\[NoBreak]", "\[Rho]"}]], " ", 
                  SubscriptBox["\[Delta]", 
                    RowBox[{
                      FormBox[
                        FormBox["c",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["si4",
                          "TraditionalForm"],
                        "TraditionalForm"]}]]}], ")"}], ".", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"-", "\[ImaginaryI]"}], " ", 
                  SuperscriptBox[
                    FormBox["q",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["li1",
                        "TraditionalForm"],
                      "TraditionalForm"]], " ", 
                  SuperscriptBox["g", 
                    RowBox[{"li2", "\[NoBreak]", "\[Nu]"}]], " ", 
                  SubscriptBox["\[Delta]", 
                    RowBox[{
                      FormBox[
                        FormBox["b",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["si1",
                          "TraditionalForm"],
                        "TraditionalForm"]}]]}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox["g", 
                    RowBox[{"li1", "\[NoBreak]", "\[Nu]"}]], " ", 
                  SubscriptBox["\[Delta]", 
                    RowBox[{
                      FormBox[
                        FormBox["b",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["si2",
                          "TraditionalForm"],
                        "TraditionalForm"]}]]}], ")"}], ".", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox["g", 
                    RowBox[{"li2", "\[NoBreak]", "\[Mu]"}]], " ", 
                  SubscriptBox["\[Delta]", 
                    RowBox[{
                      FormBox[
                        FormBox["a",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["si4",
                          "TraditionalForm"],
                        "TraditionalForm"]}]]}], ")"}], ".", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"-", "\[ImaginaryI]"}], " ", 
                  SuperscriptBox[
                    FormBox["r",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["li1",
                        "TraditionalForm"],
                      "TraditionalForm"]], " ", 
                  SuperscriptBox["g", 
                    RowBox[{"li2", "\[NoBreak]", "\[Rho]"}]], " ", 
                  SubscriptBox["\[Delta]", 
                    RowBox[{
                      FormBox[
                        FormBox["c",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["si1",
                          "TraditionalForm"],
                        "TraditionalForm"]}]]}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox["g", 
                    RowBox[{"li1", "\[NoBreak]", "\[Nu]"}]], " ", 
                  SubscriptBox["\[Delta]", 
                    RowBox[{
                      FormBox[
                        FormBox["b",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["si2",
                          "TraditionalForm"],
                        "TraditionalForm"]}]]}], ")"}], ".", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox["g", 
                    RowBox[{"li2", "\[NoBreak]", "\[Rho]"}]], " ", 
                  SubscriptBox["\[Delta]", 
                    RowBox[{
                      FormBox[
                        FormBox["c",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["si4",
                          "TraditionalForm"],
                        "TraditionalForm"]}]]}], ")"}], ".", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"-", "\[ImaginaryI]"}], " ", 
                  SuperscriptBox[
                    FormBox["p",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["li1",
                        "TraditionalForm"],
                      "TraditionalForm"]], " ", 
                  SuperscriptBox["g", 
                    RowBox[{"li2", "\[NoBreak]", "\[Mu]"}]], " ", 
                  SubscriptBox["\[Delta]", 
                    RowBox[{
                      FormBox[
                        FormBox["a",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["si1",
                          "TraditionalForm"],
                        "TraditionalForm"]}]]}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox["g", 
                    RowBox[{"li1", "\[NoBreak]", "\[Rho]"}]], " ", 
                  SubscriptBox["\[Delta]", 
                    RowBox[{
                      FormBox[
                        FormBox["c",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["si2",
                          "TraditionalForm"],
                        "TraditionalForm"]}]]}], ")"}], ".", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox["g", 
                    RowBox[{"li2", "\[NoBreak]", "\[Mu]"}]], " ", 
                  SubscriptBox["\[Delta]", 
                    RowBox[{
                      FormBox[
                        FormBox["a",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["si4",
                          "TraditionalForm"],
                        "TraditionalForm"]}]]}], ")"}], ".", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"-", "\[ImaginaryI]"}], " ", 
                  SuperscriptBox[
                    FormBox["q",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["li1",
                        "TraditionalForm"],
                      "TraditionalForm"]], " ", 
                  SuperscriptBox["g", 
                    RowBox[{"li2", "\[NoBreak]", "\[Nu]"}]], " ", 
                  SubscriptBox["\[Delta]", 
                    RowBox[{
                      FormBox[
                        FormBox["b",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["si1",
                          "TraditionalForm"],
                        "TraditionalForm"]}]]}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox["g", 
                    RowBox[{"li1", "\[NoBreak]", "\[Rho]"}]], " ", 
                  SubscriptBox["\[Delta]", 
                    RowBox[{
                      FormBox[
                        FormBox["c",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["si2",
                          "TraditionalForm"],
                        "TraditionalForm"]}]]}], ")"}], ".", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox["g", 
                    RowBox[{"li2", "\[NoBreak]", "\[Nu]"}]], " ", 
                  SubscriptBox["\[Delta]", 
                    RowBox[{
                      FormBox[
                        FormBox["b",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["si4",
                          "TraditionalForm"],
                        "TraditionalForm"]}]]}], ")"}], ".", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"-", "\[ImaginaryI]"}], " ", 
                  SuperscriptBox[
                    FormBox["p",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["li1",
                        "TraditionalForm"],
                      "TraditionalForm"]], " ", 
                  SuperscriptBox["g", 
                    RowBox[{"li2", "\[NoBreak]", "\[Mu]"}]], " ", 
                  SubscriptBox["\[Delta]", 
                    RowBox[{
                      FormBox[
                        FormBox["a",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["si1",
                          "TraditionalForm"],
                        "TraditionalForm"]}]]}], ")"}]}]}], ")"}], " ", 
        SubscriptBox["f", 
          RowBox[{
            FormBox[
              FormBox["si1",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["si2",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["si4",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[771]=  (21:54:22 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Calc", "[", 
        RowBox[{"%", "//", "Calc"}], "]"}], "//", "Factor"}]], "Input",
  CellLabel->"In[772]:=  (21:54:22 on 5/16/01)",
  CellTags->"FunctionalD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
        SubscriptBox["g", "s"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox["g", 
                RowBox[{"\[Nu]", "\[NoBreak]", "\[Rho]"}]]}], "-", 
            RowBox[{
              SuperscriptBox[
                FormBox["r",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox["g", 
                RowBox[{"\[Nu]", "\[NoBreak]", "\[Rho]"}]]}], "-", 
            RowBox[{
              SuperscriptBox["g", 
                RowBox[{"\[Mu]", "\[NoBreak]", "\[Rho]"}]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], "+", 
            RowBox[{
              SuperscriptBox["g", 
                RowBox[{"\[Mu]", "\[NoBreak]", "\[Rho]"}]], " ", 
              SuperscriptBox[
                FormBox["r",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], "+", 
            RowBox[{
              SuperscriptBox["g", 
                RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Rho]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], "-", 
            RowBox[{
              SuperscriptBox["g", 
                RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Rho]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}]}], ")"}], " ", 
        SubscriptBox["f", 
          RowBox[{
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["c",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[772]=  (21:54:24 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["FV", "ObjectName",
  CellTags->"FV"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"FV"],

Cell[TextData[{
  "FV[",
  StyleBox["p",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      FormBox["\[Mu]", TraditionalForm]]],
  "] is the four-dimensional vector ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox["p", "\[Mu]"], TraditionalForm]]],
  ". "
}], "Text",
  CellTags->"FV"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["FCE",
    ButtonData:>"FCE",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FCE"],
  ", ",
  ButtonBox["FCI",
    ButtonData:>"FCI",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FCI"],
  ", ",
  ButtonBox["FVD",
    ButtonData:>"FVD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FVD"],
  ", ",
  ButtonBox["FourVector",
    ButtonData:>"FourVector",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FourVector"],
  ", ",
  ButtonBox["Pair",
    ButtonData:>"Pair",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Pair"],
  "."
}], "Text",
  CellTags->"FV"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"FV"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FV", "[", 
      RowBox[{"p", ",", "\[Mu]"}], "]"}]], "Input",
  CellLabel->"In[773]:=  (21:54:24 on 5/16/01)",
  CellTags->"FV"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["p", "\[Mu]"], TraditionalForm]], "Output",
  CellLabel->"Out[773]=  (21:54:24 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FV", "[", 
      RowBox[{
        RowBox[{"p", "-", "q"}], ",", "\[Mu]"}], "]"}]], "Input",
  CellLabel->"In[774]:=  (21:54:24 on 5/16/01)",
  CellTags->"FV"],

Cell[BoxData[
    FormBox[
      SuperscriptBox[
        RowBox[{"(", 
          FormBox[
            RowBox[{"p", "-", "q"}],
            "TraditionalForm"], ")"}], "\[Mu]"], TraditionalForm]], "Output",
  CellLabel->"Out[774]=  (21:54:24 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"FV", "[", 
        RowBox[{"p", ",", "\[Mu]"}], "]"}], "//", "StandardForm"}]], "Input",
  CellLabel->"In[775]:=  (21:54:24 on 5/16/01)",
  CellTags->"FV"],

Cell[BoxData[
    RowBox[{"FV", "[", 
      RowBox[{"p", ",", "\[Mu]"}], "]"}]], "Output",
  CellLabel->"Out[775]//StandardForm=  (21:54:24 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"FCI", "[", 
        RowBox[{"FV", "[", 
          RowBox[{"p", ",", "\[Mu]"}], "]"}], "]"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[776]:=  (21:54:24 on 5/16/01)",
  CellTags->"FV"],

Cell[BoxData[
    RowBox[{"Pair", "[", 
      RowBox[{
        RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
        RowBox[{"Momentum", "[", "p", "]"}]}], "]"}]], "Output",
  CellLabel->"Out[776]//StandardForm=  (21:54:24 on 5/16/01)"]
}, Closed]],

Cell["\<\
There is no special function to expand momenta in FV; ExpandScalarProduct \
does the job.\
\>", "Text",
  CellTags->"FV"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ExpandScalarProduct", "[", 
      RowBox[{"FV", "[", 
        RowBox[{
          RowBox[{"p", "-", "q"}], ",", "\[Mu]"}], "]"}], "]"}]], "Input",
  CellLabel->"In[777]:=  (21:54:24 on 5/16/01)",
  CellTags->"FV"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox[
          FormBox["p",
            "TraditionalForm"], 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]], "-", 
        SuperscriptBox[
          FormBox["q",
            "TraditionalForm"], 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[777]=  (21:54:25 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StandardForm", "[", "%", "]"}]], "Input",
  CellLabel->"In[778]:=  (21:54:25 on 5/16/01)",
  CellTags->"FV"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Pair", "[", 
        RowBox[{
          RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
          RowBox[{"Momentum", "[", "p", "]"}]}], "]"}], "-", 
      RowBox[{"Pair", "[", 
        RowBox[{
          RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
          RowBox[{"Momentum", "[", "q", "]"}]}], "]"}]}]], "Output",
  CellLabel->"Out[778]//StandardForm=  (21:54:25 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["FVD", "ObjectName",
  CellTags->"FVD"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"FVD"],

Cell[TextData[{
  "FVD[",
  StyleBox["p",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      FormBox["\[Mu]", TraditionalForm]]],
  "] is the D-dimensional vector ",
  StyleBox["p",
    FontSlant->"Italic"],
  " with Lorentz index ",
  Cell[BoxData[
      FormBox["\[Mu]", TraditionalForm]]],
  "."
}], "Text",
  CellTags->"FVD"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["FCE",
    ButtonData:>"FCE",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FCE"],
  ", ",
  ButtonBox["FCI",
    ButtonData:>"FCI",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FCI"],
  ", ",
  ButtonBox["FV",
    ButtonData:>"FV",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FV"],
  ", ",
  ButtonBox["FourVector",
    ButtonData:>"FourVector",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FourVector"],
  ", ",
  ButtonBox["Pair",
    ButtonData:>"Pair",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Pair"],
  "."
}], "Text",
  CellTags->"FVD"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"FVD"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FVD", "[", 
      RowBox[{"p", ",", "\[Mu]"}], "]"}]], "Input",
  CellLabel->"In[779]:=  (21:54:25 on 5/16/01)",
  CellTags->"FVD"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["p", "\[Mu]"], TraditionalForm]], "Output",
  CellLabel->"Out[779]=  (21:54:25 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FVD", "[", 
      RowBox[{
        RowBox[{"p", "-", "q"}], ",", "\[Mu]"}], "]"}]], "Input",
  CellLabel->"In[780]:=  (21:54:25 on 5/16/01)",
  CellTags->"FVD"],

Cell[BoxData[
    FormBox[
      SuperscriptBox[
        RowBox[{"(", 
          FormBox[
            RowBox[{"p", "-", "q"}],
            "TraditionalForm"], ")"}], "\[Mu]"], TraditionalForm]], "Output",
  CellLabel->"Out[780]=  (21:54:25 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"FVD", "[", 
        RowBox[{"p", ",", "\[Mu]"}], "]"}], "//", "StandardForm"}]], "Input",
  CellLabel->"In[781]:=  (21:54:25 on 5/16/01)",
  CellTags->"FVD"],

Cell[BoxData[
    RowBox[{"FVD", "[", 
      RowBox[{"p", ",", "\[Mu]"}], "]"}]], "Output",
  CellLabel->"Out[781]//StandardForm=  (21:54:25 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"FCI", "[", 
        RowBox[{"FVD", "[", 
          RowBox[{"p", ",", "\[Mu]"}], "]"}], "]"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[782]:=  (21:54:25 on 5/16/01)",
  CellTags->"FVD"],

Cell[BoxData[
    RowBox[{"Pair", "[", 
      RowBox[{
        RowBox[{"LorentzIndex", "[", 
          RowBox[{"\[Mu]", ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
          RowBox[{"p", ",", "D"}], "]"}]}], "]"}]], "Output",
  CellLabel->"Out[782]//StandardForm=  (21:54:25 on 5/16/01)"]
}, Closed]],

Cell["There is no special function to expand momenta in FVD.", "Text",
  CellTags->"FVD"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ExpandScalarProduct", "[", 
      RowBox[{"FVD", "[", 
        RowBox[{
          RowBox[{"p", "-", "q"}], ",", "\[Mu]"}], "]"}], "]"}]], "Input",
  CellLabel->"In[783]:=  (21:54:25 on 5/16/01)",
  CellTags->"FVD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox[
          FormBox["p",
            "TraditionalForm"], 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]], "-", 
        SuperscriptBox[
          FormBox["q",
            "TraditionalForm"], 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[783]=  (21:54:25 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StandardForm", "[", "%", "]"}]], "Input",
  CellLabel->"In[784]:=  (21:54:25 on 5/16/01)",
  CellTags->"FVD"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Pair", "[", 
        RowBox[{
          RowBox[{"LorentzIndex", "[", 
            RowBox[{"\[Mu]", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
            RowBox[{"p", ",", "D"}], "]"}]}], "]"}], "-", 
      RowBox[{"Pair", "[", 
        RowBox[{
          RowBox[{"LorentzIndex", "[", 
            RowBox[{"\[Mu]", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
            RowBox[{"q", ",", "D"}], "]"}]}], "]"}]}]], "Output",
  CellLabel->"Out[784]//StandardForm=  (21:54:25 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["GA", "ObjectName",
  CellTags->"GA"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"GA"],

Cell[TextData[{
  "GA[",
  Cell[BoxData[
      FormBox["\[Mu]", TraditionalForm]]],
  "] can be used as input for a 4-dimensional ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox["\[Gamma]", "\[Mu]"], " "}], TraditionalForm]]],
  "and is transformed into DiracGamma[LorentzIndex[",
  Cell[BoxData[
      FormBox["\[Mu]", TraditionalForm]]],
  "]] by FeynCalcInternal (=FCI).GA[",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Mu]", ",", "\[Nu]", ","}], TraditionalForm]]],
  " ...] is a short form for GA[",
  Cell[BoxData[
      FormBox["\[Mu]", TraditionalForm]]],
  "].GA[",
  Cell[BoxData[
      FormBox["\[Nu]", TraditionalForm]]],
  "]. ... ."
}], "Text",
  CellTags->"GA"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["DiracMatrix",
    ButtonData:>"DiracMatrix",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracMatrix"],
  ", ",
  ButtonBox["GAD",
    ButtonData:>"GAD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"GAD"],
  ", ",
  ButtonBox["GS",
    ButtonData:>"GS",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"GS"],
  "."
}], "Text",
  CellTags->"GA"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"GA"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GA", "[", "\[Mu]", "]"}]], "Input",
  CellLabel->"In[785]:=  (21:54:26 on 5/16/01)",
  CellTags->"GA"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["\[Gamma]", "\[Mu]"], TraditionalForm]], "Output",
  CellLabel->"Out[785]=  (21:54:26 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"GA", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], "-", 
      RowBox[{"GA", "[", 
        RowBox[{"\[Nu]", ",", "\[Mu]"}], "]"}]}]], "Input",
  CellLabel->"In[786]:=  (21:54:26 on 5/16/01)",
  CellTags->"GA"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
          SuperscriptBox["\[Gamma]", "\[Nu]"]}], "-", 
        RowBox[{
          SuperscriptBox["\[Gamma]", "\[Nu]"], ".", 
          SuperscriptBox["\[Gamma]", "\[Mu]"]}]}], TraditionalForm]], "Output",\

  CellLabel->"Out[786]=  (21:54:26 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StandardForm", "[", 
      RowBox[{"FCI", "[", 
        RowBox[{"GA", "[", "\[Mu]", "]"}], "]"}], "]"}]], "Input",
  CellLabel->"In[787]:=  (21:54:26 on 5/16/01)",
  CellTags->"GA"],

Cell[BoxData[
    RowBox[{"DiracGamma", "[", 
      RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], "]"}]], "Output",
  CellLabel->"Out[787]//StandardForm=  (21:54:26 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GA", "[", 
      RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Sigma]"}], 
      "]"}]], "Input",
  CellLabel->"In[788]:=  (21:54:26 on 5/16/01)",
  CellTags->"GA"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
        SuperscriptBox["\[Gamma]", "\[Nu]"], ".", 
        SuperscriptBox["\[Gamma]", "\[Rho]"], ".", 
        SuperscriptBox["\[Gamma]", "\[Sigma]"]}], TraditionalForm]], "Output",\

  CellLabel->"Out[788]=  (21:54:26 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StandardForm", "[", 
      RowBox[{"GA", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Sigma]"}], 
        "]"}], "]"}]], "Input",
  CellLabel->"In[789]:=  (21:54:26 on 5/16/01)",
  CellTags->"GA"],

Cell[BoxData[
    RowBox[{
      RowBox[{"GA", "[", "\[Mu]", "]"}], ".", 
      RowBox[{"GA", "[", "\[Nu]", "]"}], ".", 
      RowBox[{"GA", "[", "\[Rho]", "]"}], ".", 
      RowBox[{"GA", "[", "\[Sigma]", "]"}]}]], "Output",
  CellLabel->"Out[789]//StandardForm=  (21:54:26 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"GA", "[", "\[Alpha]", "]"}], ".", 
      RowBox[{"(", 
        RowBox[{
          RowBox[{"GS", "[", "p", "]"}], "+", "m"}], ")"}], ".", 
      RowBox[{"GA", "[", "\[Beta]", "]"}]}]], "Input",
  CellLabel->"In[790]:=  (21:54:26 on 5/16/01)",
  CellTags->"GA"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", "\[Alpha]"], ".", 
        RowBox[{"(", 
          RowBox[{"m", "+", 
            RowBox[{
            "\[Gamma]", "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "p"}]}], 
          ")"}], ".", 
        SuperscriptBox["\[Gamma]", "\[Beta]"]}], TraditionalForm]], "Output",
  CellLabel->"Out[790]=  (21:54:26 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["GAD", "ObjectName",
  CellTags->"GAD"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"GAD"],

Cell[TextData[{
  "GAD[",
  Cell[BoxData[
      FormBox["\[Mu]", TraditionalForm]]],
  "] can be used as input for a D-dimensional ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox["\[Gamma]", "\[Mu]"], " "}], TraditionalForm]]],
  "and is transformed into DiracGamma[LorentzIndex[",
  Cell[BoxData[
      FormBox["\[Mu]", TraditionalForm]]],
  ",D],D] by FeynCalcInternal (=FCI).GAD[",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Mu]", ",", "\[Nu]", ",", " ", "..."}], TraditionalForm]]],
  "] is a short form for GAD[",
  Cell[BoxData[
      FormBox["\[Mu]", TraditionalForm]]],
  "].GAD[",
  Cell[BoxData[
      FormBox["\[Nu]", TraditionalForm]]],
  "]. ... ."
}], "Text",
  CellTags->"GAD"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["DiracMatrix",
    ButtonData:>"DiracMatrix",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracMatrix"],
  ", ",
  ButtonBox["GA",
    ButtonData:>"GA",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"GA"],
  ", ",
  ButtonBox["GS",
    ButtonData:>"GS",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"GS"],
  "."
}], "Text",
  CellTags->"GAD"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"GAD"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GAD", "[", "\[Mu]", "]"}]], "Input",
  CellLabel->"In[791]:=  (21:54:26 on 5/16/01)",
  CellTags->"GAD"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["\[Gamma]", "\[Mu]"], TraditionalForm]], "Output",
  CellLabel->"Out[791]=  (21:54:26 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"GAD", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], "-", 
      RowBox[{"GAD", "[", 
        RowBox[{"\[Nu]", ",", "\[Mu]"}], "]"}]}]], "Input",
  CellLabel->"In[792]:=  (21:54:26 on 5/16/01)",
  CellTags->"GAD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
          SuperscriptBox["\[Gamma]", "\[Nu]"]}], "-", 
        RowBox[{
          SuperscriptBox["\[Gamma]", "\[Nu]"], ".", 
          SuperscriptBox["\[Gamma]", "\[Mu]"]}]}], TraditionalForm]], "Output",\

  CellLabel->"Out[792]=  (21:54:27 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StandardForm", "[", 
      RowBox[{"FCI", "[", 
        RowBox[{"GAD", "[", "\[Mu]", "]"}], "]"}], "]"}]], "Input",
  CellLabel->"In[793]:=  (21:54:27 on 5/16/01)",
  CellTags->"GAD"],

Cell[BoxData[
    RowBox[{"DiracGamma", "[", 
      RowBox[{
        RowBox[{"LorentzIndex", "[", 
          RowBox[{"\[Mu]", ",", "D"}], "]"}], ",", "D"}], "]"}]], "Output",
  CellLabel->"Out[793]//StandardForm=  (21:54:27 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GAD", "[", 
      RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Sigma]"}], 
      "]"}]], "Input",
  CellLabel->"In[794]:=  (21:54:27 on 5/16/01)",
  CellTags->"GAD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
        SuperscriptBox["\[Gamma]", "\[Nu]"], ".", 
        SuperscriptBox["\[Gamma]", "\[Rho]"], ".", 
        SuperscriptBox["\[Gamma]", "\[Sigma]"]}], TraditionalForm]], "Output",\

  CellLabel->"Out[794]=  (21:54:27 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StandardForm", "[", 
      RowBox[{"GAD", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Sigma]"}], 
        "]"}], "]"}]], "Input",
  CellLabel->"In[795]:=  (21:54:27 on 5/16/01)",
  CellTags->"GAD"],

Cell[BoxData[
    RowBox[{
      RowBox[{"GAD", "[", "\[Mu]", "]"}], ".", 
      RowBox[{"GAD", "[", "\[Nu]", "]"}], ".", 
      RowBox[{"GAD", "[", "\[Rho]", "]"}], ".", 
      RowBox[{"GAD", "[", "\[Sigma]", "]"}]}]], "Output",
  CellLabel->"Out[795]//StandardForm=  (21:54:27 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"GAD", "[", "\[Alpha]", "]"}], ".", 
      RowBox[{"(", 
        RowBox[{
          RowBox[{"GSD", "[", "p", "]"}], "+", "m"}], ")"}], ".", 
      RowBox[{"GAD", "[", "\[Beta]", "]"}]}]], "Input",
  CellLabel->"In[796]:=  (21:54:27 on 5/16/01)",
  CellTags->"GAD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", "\[Alpha]"], ".", 
        RowBox[{"(", 
          RowBox[{"m", "+", 
            RowBox[{
            "\[Gamma]", "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "p"}]}], 
          ")"}], ".", 
        SuperscriptBox["\[Gamma]", "\[Beta]"]}], TraditionalForm]], "Output",
  CellLabel->"Out[796]=  (21:54:27 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["GammaEpsilon", "ObjectName",
  CellTags->"GammaEpsilon"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"GammaEpsilon"],

Cell["\<\
GammaEpsilon[exp] gives a series expansion of Gamma[exp] in Epsilon up to \
order 6 (where EulerGamma is neglected).\
\>", "Text",
  CellTags->"GammaEpsilon"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["GammaExpand",
    ButtonData:>"GammaExpand",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"GammaExpand"],
  ", ",
  ButtonBox["Series2",
    ButtonData:>"Series2",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Series2"],
  "."
}], "Text",
  CellTags->"GammaEpsilon"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"GammaEpsilon"],

Cell["\<\
If the argument is of the form (1+a Epsilon) the result is not calculated but \
tabulated.\
\>", "Text",
  CellTags->"GammaEpsilon"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GammaEpsilon", "[", 
      RowBox[{"1", "+", 
        RowBox[{"a", " ", "Epsilon"}]}], "]"}]], "Input",
  CellLabel->"In[797]:=  (21:54:27 on 5/16/01)",
  CellTags->"GammaEpsilon"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"C$749", " ", 
          SuperscriptBox[
            TagBox["\[CurlyEpsilon]",
              TraditionalForm], "6"]}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  FractionBox["1", "5"]}], " ", 
                TagBox[
                  RowBox[{"\[Zeta]", "(", 
                    TagBox["5",
                      (Editable -> True)], ")"}],
                  InterpretTemplate[ Zeta[ #]&]], " ", 
                SuperscriptBox["a", "5"]}], "-", 
              RowBox[{
                FractionBox["1", "36"], " ", 
                SuperscriptBox["\[Pi]", "2"], " ", 
                TagBox[
                  RowBox[{"\[Zeta]", "(", 
                    TagBox["3",
                      (Editable -> True)], ")"}],
                  InterpretTemplate[ Zeta[ #]&]], " ", 
                SuperscriptBox["a", "5"]}]}], ")"}], " ", 
          SuperscriptBox[
            TagBox["\[CurlyEpsilon]",
              TraditionalForm], "5"]}], "+", 
        RowBox[{
          FractionBox["1", "160"], " ", 
          SuperscriptBox["a", "4"], " ", 
          SuperscriptBox["\[Pi]", "4"], " ", 
          SuperscriptBox[
            TagBox["\[CurlyEpsilon]",
              TraditionalForm], "4"]}], "-", 
        RowBox[{
          FractionBox["1", "3"], " ", 
          SuperscriptBox["a", "3"], " ", 
          TagBox[
            RowBox[{"\[Zeta]", "(", 
              TagBox["3",
                (Editable -> True)], ")"}],
            InterpretTemplate[ Zeta[ #]&]], " ", 
          SuperscriptBox[
            TagBox["\[CurlyEpsilon]",
              TraditionalForm], "3"]}], "+", 
        RowBox[{
          FractionBox["1", "12"], " ", 
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["\[Pi]", "2"], " ", 
          SuperscriptBox[
            TagBox["\[CurlyEpsilon]",
              TraditionalForm], "2"]}], "+", "1"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[797]=  (21:54:27 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GammaEpsilon", "[", 
      RowBox[{"1", "-", 
        RowBox[{"Epsilon", "/", "2"}]}], "]"}]], "Input",
  CellLabel->"In[798]:=  (21:54:27 on 5/16/01)",
  CellTags->"GammaEpsilon"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"C$750", " ", 
          SuperscriptBox[
            TagBox["\[CurlyEpsilon]",
              TraditionalForm], "6"]}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              FractionBox[
                RowBox[{
                  SuperscriptBox["\[Pi]", "2"], " ", 
                  TagBox[
                    RowBox[{"\[Zeta]", "(", 
                      TagBox["3",
                        (Editable -> True)], ")"}],
                    InterpretTemplate[ Zeta[ #]&]]}], "1152"], "+", 
              FractionBox[
                TagBox[
                  RowBox[{"\[Zeta]", "(", 
                    TagBox["5",
                      (Editable -> True)], ")"}],
                  InterpretTemplate[ Zeta[ #]&]], "160"]}], ")"}], " ", 
          SuperscriptBox[
            TagBox["\[CurlyEpsilon]",
              TraditionalForm], "5"]}], "+", 
        FractionBox[
          RowBox[{
            SuperscriptBox["\[Pi]", "4"], " ", 
            SuperscriptBox[
              TagBox["\[CurlyEpsilon]",
                TraditionalForm], "4"]}], "2560"], "+", 
        RowBox[{
          FractionBox["1", "24"], " ", 
          TagBox[
            RowBox[{"\[Zeta]", "(", 
              TagBox["3",
                (Editable -> True)], ")"}],
            InterpretTemplate[ Zeta[ #]&]], " ", 
          SuperscriptBox[
            TagBox["\[CurlyEpsilon]",
              TraditionalForm], "3"]}], "+", 
        FractionBox[
          RowBox[{
            SuperscriptBox["\[Pi]", "2"], " ", 
            SuperscriptBox[
              TagBox["\[CurlyEpsilon]",
                TraditionalForm], "2"]}], "48"], "+", "1"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[798]=  (21:54:27 on 5/16/01)"]
}, Closed]],

Cell["For other arguments the expansion is calculated.", "Text",
  CellTags->"GammaEpsilon"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GammaEpsilon", "[", "Epsilon", "]"}]], "Input",
  CellLabel->"In[799]:=  (21:54:27 on 5/16/01)",
  CellTags->"GammaEpsilon"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"C$752", " ", 
          SuperscriptBox[
            TagBox["\[CurlyEpsilon]",
              TraditionalForm], "6"]}], "+", 
        RowBox[{
          FractionBox["1", "120"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                FractionBox["5", "3"], " ", 
                SuperscriptBox["\[Pi]", "2"], " ", 
                RowBox[{
                  SuperscriptBox[
                    TagBox["\[Psi]",
                      PolyGamma], 
                    RowBox[{"(", "2", ")"}]], "(", "1", ")"}]}], "-", 
              RowBox[{"24", " ", 
                TagBox[
                  RowBox[{"\[Zeta]", "(", 
                    TagBox["5",
                      (Editable -> True)], ")"}],
                  InterpretTemplate[ Zeta[ #]&]]}]}], ")"}], " ", 
          SuperscriptBox[
            TagBox["\[CurlyEpsilon]",
              TraditionalForm], "4"]}], "+", 
        FractionBox[
          RowBox[{
            SuperscriptBox["\[Pi]", "4"], " ", 
            SuperscriptBox[
              TagBox["\[CurlyEpsilon]",
                TraditionalForm], "3"]}], "160"], "+", 
        RowBox[{
          FractionBox["1", "6"], " ", 
          RowBox[{
            SuperscriptBox[
              TagBox["\[Psi]",
                PolyGamma], 
              RowBox[{"(", "2", ")"}]], "(", "1", ")"}], " ", 
          SuperscriptBox[
            TagBox["\[CurlyEpsilon]",
              TraditionalForm], "2"]}], "+", 
        FractionBox[
          RowBox[{
            SuperscriptBox["\[Pi]", "2"], " ", 
            TagBox["\[CurlyEpsilon]",
              TraditionalForm]}], "12"], "+", 
        FractionBox["1", 
          FormBox[
            TagBox["\[CurlyEpsilon]",
              TraditionalForm],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[799]=  (21:54:28 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GammaEpsilon", "[", "x", "]"}]], "Input",
  CellLabel->"In[800]:=  (21:54:28 on 5/16/01)",
  CellTags->"GammaEpsilon"],

Cell[BoxData[
    FormBox[
      RowBox[{"\[CapitalGamma]", "(", "x", ")"}], TraditionalForm]], "Output",\

  CellLabel->"Out[800]=  (21:54:28 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["GammaExpand", "ObjectName",
  CellTags->"GammaExpand"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"GammaExpand"],

Cell["\<\
GammaExpand[exp] rewrites Gamma[n + m] in exp (where n has Head Integer).\
\>", "Text",
  CellTags->"GammaExpand"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["GammaEpsilon",
    ButtonData:>"GammaEpsilon",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"GammaEpsilon"],
  "."
}], "Text",
  CellTags->"GammaExpand"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"GammaExpand"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GammaExpand", "[", 
      RowBox[{"Gamma", "[", 
        RowBox[{"2", " ", "+", " ", "Epsilon"}], "]"}], "]"}]], "Input",
  CellLabel->"In[801]:=  (21:54:28 on 5/16/01)",
  CellTags->"GammaExpand"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            TagBox["\[CurlyEpsilon]",
              TraditionalForm], "+", "1"}], ")"}], " ", 
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{
            TagBox["\[CurlyEpsilon]",
              TraditionalForm], "+", "1"}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[801]=  (21:54:28 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GammaExpand", "[", 
      RowBox[{"Gamma", "[", 
        RowBox[{
          RowBox[{"-", "3"}], "+", "Epsilon"}], "]"}], "]"}]], "Input",
  CellLabel->"In[802]:=  (21:54:28 on 5/16/01)",
  CellTags->"GammaExpand"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{
            TagBox["\[CurlyEpsilon]",
              TraditionalForm], "+", "1"}], ")"}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              TagBox["\[CurlyEpsilon]",
                TraditionalForm], "-", "3"}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              TagBox["\[CurlyEpsilon]",
                TraditionalForm], "-", "2"}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              TagBox["\[CurlyEpsilon]",
                TraditionalForm], "-", "1"}], ")"}], " ", 
          TagBox["\[CurlyEpsilon]",
            TraditionalForm]}]], TraditionalForm]], "Output",
  CellLabel->"Out[802]=  (21:54:28 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GammaExpand", "[", 
      RowBox[{"Gamma", "[", 
        RowBox[{"1", " ", "+", " ", "Epsilon"}], "]"}], "]"}]], "Input",
  CellLabel->"In[803]:=  (21:54:28 on 5/16/01)",
  CellTags->"GammaExpand"],

Cell[BoxData[
    FormBox[
      RowBox[{"\[CapitalGamma]", "(", 
        RowBox[{
          TagBox["\[CurlyEpsilon]",
            TraditionalForm], "+", "1"}], ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[803]=  (21:54:28 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["GhostPropagator", "ObjectName",
  CellTags->"GhostPropagator"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"GhostPropagator"],

Cell[TextData[{
  "GhostPropagator[p, a, b] gives the ghost propagator where \"a\" and \"b\" \
are the color indices. GhostPropagator[p] omits the ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox["\[Delta]", 
            RowBox[{"a", "\[NoBreak]", "b"}]], "."}], TraditionalForm]]]
}], "Text",
  CellTags->"GhostPropagator"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["GHP",
    ButtonData:>"GHP",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"GHP"],
  ", ",
  ButtonBox["GluonPropagator",
    ButtonData:>"GluonPropagator",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"GluonPropagator"],
  ", ",
  ButtonBox["GluonGhostVertex",
    ButtonData:>"GluonGhostVertex",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"GluonGhostVertex"],
  "."
}], "Text",
  CellTags->"GhostPropagator"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"GhostPropagator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GhostPropagator", "[", 
      RowBox[{"p", ",", "a", ",", "b"}], "]"}]], "Input",
  CellLabel->"In[804]:=  (21:54:28 on 5/16/01)",
  CellTags->"GhostPropagator"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["\[Delta]", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], 
        SuperscriptBox["p", "2"]], TraditionalForm]], "Output",
  CellLabel->"Out[804]=  (21:54:28 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GhostPropagator", "[", "p", "]"}]], "Input",
  CellLabel->"In[805]:=  (21:54:28 on 5/16/01)",
  CellTags->"GhostPropagator"],

Cell[BoxData[
    FormBox[
      FractionBox["\[ImaginaryI]", 
        SuperscriptBox["p", "2"]], TraditionalForm]], "Output",
  CellLabel->"Out[805]=  (21:54:29 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GhostPropagator", "[", 
      RowBox[{"p", ",", "1", ",", "2"}], "]"}]], "Input",
  CellLabel->"In[806]:=  (21:54:29 on 5/16/01)",
  CellTags->"GhostPropagator"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["\[Delta]", 
            RowBox[{
              FormBox[
                FormBox["ci1",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["ci2",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], 
        SuperscriptBox["p", "2"]], TraditionalForm]], "Output",
  CellLabel->"Out[806]=  (21:54:29 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"GhostPropagator", "[", 
          RowBox[{
            RowBox[{"-", "k"}], ",", "3", ",", "4"}], "]"}], "//", " ", 
        "FCE"}], "//", "StandardForm"}]], "Input",
  CellLabel->"In[807]:=  (21:54:29 on 5/16/01)",
  CellTags->"GhostPropagator"],

Cell[BoxData[
    RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"FAD", "[", 
        RowBox[{"-", "k"}], "]"}], " ", 
      RowBox[{"SD", "[", 
        RowBox[{"ci3", ",", "ci4"}], "]"}]}]], "Output",
  CellLabel->"Out[807]//StandardForm=  (21:54:29 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["GHP", "ObjectName",
  CellTags->"GHP"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"GHP"],

Cell[TextData[{
  "GHP[p, a, b] gives the ghost propagator where \"a\" and \"b\" are the \
color indices. GHP[p] omits the ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox["\[Delta]", 
            RowBox[{"a", "\[NoBreak]", "b"}]], "."}], TraditionalForm]]]
}], "Text",
  CellTags->"GHP"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["GhostPropagator",
    ButtonData:>"GhostPropagator",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"GhostPropagator"],
  ", ",
  ButtonBox["GluonPropagator",
    ButtonData:>"GluonPropagator",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"GluonPropagator"],
  ", ",
  ButtonBox["GluonGhostVertex",
    ButtonData:>"GluonGhostVertex",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"GluonGhostVertex"],
  "."
}], "Text",
  CellTags->"GHP"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"GHP"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GHP", "[", 
      RowBox[{"p", ",", "a", ",", "b"}], "]"}]], "Input",
  CellLabel->"In[808]:=  (21:54:29 on 5/16/01)",
  CellTags->"GHP"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["\[Delta]", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], 
        SuperscriptBox["p", "2"]], TraditionalForm]], "Output",
  CellLabel->"Out[808]=  (21:54:29 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GHP", "[", "p", "]"}]], "Input",
  CellLabel->"In[809]:=  (21:54:29 on 5/16/01)",
  CellTags->"GHP"],

Cell[BoxData[
    FormBox[
      FractionBox["\[ImaginaryI]", 
        SuperscriptBox["p", "2"]], TraditionalForm]], "Output",
  CellLabel->"Out[809]=  (21:54:29 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GHP", "[", 
      RowBox[{"p", ",", "1", ",", "2"}], "]"}]], "Input",
  CellLabel->"In[810]:=  (21:54:29 on 5/16/01)",
  CellTags->"GHP"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["\[Delta]", 
            RowBox[{
              FormBox[
                FormBox["ci1",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["ci2",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], 
        SuperscriptBox["p", "2"]], TraditionalForm]], "Output",
  CellLabel->"Out[810]=  (21:54:29 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StandardForm", "[", 
      RowBox[{"FCE", "[", 
        RowBox[{"GHP", "[", 
          RowBox[{
            RowBox[{"-", "k"}], ",", "3", ",", "4"}], "]"}], "]"}], 
      "]"}]], "Input",
  CellLabel->"In[811]:=  (21:54:29 on 5/16/01)",
  CellTags->"GHP"],

Cell[BoxData[
    RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"FAD", "[", 
        RowBox[{"-", "k"}], "]"}], " ", 
      RowBox[{"SD", "[", 
        RowBox[{"ci3", ",", "ci4"}], "]"}]}]], "Output",
  CellLabel->"Out[811]//StandardForm=  (21:54:29 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["GaugeField", "ObjectName",
  CellTags->"GluonField"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"GluonField"],

Cell["\<\
GaugeField is just a name. No functional properties are associated with it. \
GaugeField is used as default setting for the option QuantumField of \
FieldStrength.\
\>", "Text",
  CellTags->"GluonField"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["FieldStrength",
    ButtonData:>"FieldStrength",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FieldStrength"],
  ", ",
  ButtonBox["QuantumField",
    ButtonData:>"QuantumField",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"QuantumField"],
  "."
}], "Text",
  CellTags->"GluonField"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"GluonField"],

Cell[CellGroupData[{

Cell[BoxData["GaugeField"], "Input",
  CellLabel->"In[812]:=  (21:54:29 on 5/16/01)",
  CellTags->"GluonField"],

Cell[BoxData[
    FormBox["A", TraditionalForm]], "Output",
  CellLabel->"Out[812]=  (21:54:29 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"QuantumField", "[", 
      RowBox[{"GaugeField", ",", 
        RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
        RowBox[{"SUNIndex", "[", "a", "]"}]}], "]"}]], "Input",
  CellLabel->"In[813]:=  (21:54:30 on 5/16/01)",
  CellTags->"GluonField"],

Cell[BoxData[
    FormBox[
      SubsuperscriptBox[
        FormBox["A",
          "TraditionalForm"], 
        FormBox[
          FormBox["\[Mu]",
            "TraditionalForm"],
          "TraditionalForm"], 
        FormBox[
          FormBox["a",
            "TraditionalForm"],
          "TraditionalForm"]], TraditionalForm]], "Output",
  CellLabel->"Out[813]=  (21:54:30 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["GluonGhostVertex", "ObjectName",
  CellTags->"GluonGhostVertex"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"GluonGhostVertex"],

Cell["\<\
GluonGhostVertex[{p,mu,a}, {q,nu,b}, {k,rho,c}] or GluonGhostVertex[ p,mu,a , \
q,nu,b , k,rho,c ] yields the Gluon-Ghost vertex. The first argument \
represents the gluon and the third argument the outgoing ghost field (but \
incoming four-momentum). The dimension and the name of the coupling constant \
are determined by the options Dimension and CouplingConstant.\
\>", "Text",
  CellTags->"GluonGhostVertex"],

Cell[TextData[{
  "See also: ",
  ButtonBox["GhostPropagator",
    ButtonData:>"GhostPropagator",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"GhostPropagator"],
  ", ",
  ButtonBox["GluonVertex",
    ButtonData:>"GluonVertex",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"GluonVertex"],
  "."
}], "Text",
  CellTags->"GluonGhostVertex"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "GluonGhostVertex", "]"}]], "Input",
  CellLabel->"In[814]:=  (21:54:30 on 5/16/01)",
  CellTags->"GluonGhostVertex"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
          RowBox[{"CouplingConstant", "\[Rule]", 
            SubscriptBox["g", "s"]}]}], "}"}], TraditionalForm]], "Output",
  CellLabel->"Out[814]=  (21:54:30 on 5/16/01)"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"GluonGhostVertex"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GluonGhostVertex", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"q", ",", "\[Nu]", ",", "b"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"k", ",", "\[Rho]", ",", "c"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[815]:=  (21:54:30 on 5/16/01)",
  CellTags->"GluonGhostVertex"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["g", "s"], " ", 
        SuperscriptBox[
          FormBox[
            FormBox[
              TagBox[
                StyleBox["\<\"k\"\>",
                  FontSlant->"Italic"],
                (StyleForm[ #, FontSlant -> "Italic"]&)],
              "TraditionalForm"],
            "TraditionalForm"], 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]], " ", 
        SubscriptBox["f", 
          RowBox[{
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["c",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[815]=  (21:54:30 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "StandardForm"}]], "Input",
  CellLabel->"In[816]:=  (21:54:30 on 5/16/01)",
  CellTags->"GluonGhostVertex"],

Cell[BoxData[
    RowBox[{"Gstrong", " ", 
      RowBox[{"Pair", "[", 
        RowBox[{
          RowBox[{"LorentzIndex", "[", 
            RowBox[{"\[Mu]", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
            RowBox[{"k", ",", "D"}], "]"}]}], "]"}], " ", 
      RowBox[{"SUNF", "[", 
        RowBox[{
          RowBox[{"SUNIndex", "[", "a", "]"}], ",", 
          RowBox[{"SUNIndex", "[", "b", "]"}], ",", 
          RowBox[{"SUNIndex", "[", "c", "]"}]}], "]"}]}]], "Output",
  CellLabel->"Out[816]//StandardForm=  (21:54:30 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GluonGhostVertex", "[", 
      RowBox[{"p", ",", "1", ",", "q", ",", "2", ",", "k", ",", "3"}], 
      "]"}]], "Input",
  CellLabel->"In[817]:=  (21:54:30 on 5/16/01)",
  CellTags->"GluonGhostVertex"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["g", "s"], " ", 
        SuperscriptBox[
          FormBox[
            FormBox[
              TagBox[
                StyleBox["\<\"k\"\>",
                  FontSlant->"Italic"],
                (StyleForm[ #, FontSlant -> "Italic"]&)],
              "TraditionalForm"],
            "TraditionalForm"], 
          FormBox[
            FormBox["li1",
              "TraditionalForm"],
            "TraditionalForm"]], " ", 
        SubscriptBox["f", 
          RowBox[{
            FormBox[
              FormBox["ci1",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["ci2",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["ci3",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[817]=  (21:54:30 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["GluonPropagator", "ObjectName",
  CellTags->"GluonPropagator"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"GluonPropagator"],

Cell[TextData[{
  "GluonPropagator[p, {mu, a}, {nu, b}] or GluonPropagator[p, mu, a , nu, b ] \
yields the gluon propagator. GluonPropagator[p, {mu}, {nu}] or \
GluonPropagator[p, mu, nu] omits the SUNDelta. The gauge and the dimension is \
determined by the option Gauge and Dimension. The following settings of Gauge \
are possible: 1 for the Feynman gauge; ",
  Cell[BoxData[
      FormBox["\[Alpha]", TraditionalForm]]],
  " for the general covariant gauge; {Momentum[n] ,1} for the axial gauge."
}], "Text",
  CellTags->"GluonPropagator"],

Cell["GP can be used as an abbreviation of GluonPropagator.", "Text",
  CellTags->"GluonPropagator"],

Cell[CellGroupData[{

Cell[BoxData["GP"], "Input",
  CellLabel->"In[818]:=  (21:54:30 on 5/16/01)",
  CellTags->"GluonPropagator"],

Cell[BoxData[
    FormBox["GluonPropagator", TraditionalForm]], "Output",
  CellLabel->"Out[818]=  (21:54:30 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "GluonPropagator", "]"}]], "Input",
  CellLabel->"In[819]:=  (21:54:30 on 5/16/01)",
  CellTags->"GluonPropagator"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"CounterTerm", "\[Rule]", "False"}], ",", 
          RowBox[{"CouplingConstant", "\[Rule]", 
            SubscriptBox["g", "s"]}], ",", 
          RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
          RowBox[{"Gauge", "\[Rule]", "1"}], ",", 
          RowBox[{"\[CapitalKoppa]", "\[Rule]", "False"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[819]=  (21:54:30 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["GluonVertex",
    ButtonData:>"GluonVertex",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"GluonVertex"],
  ", ",
  ButtonBox["GhostPropagator",
    ButtonData:>"GhostPropagator",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"GhostPropagator"],
  ", ",
  ButtonBox["GluonGhostVertex",
    ButtonData:>"GluonGhostVertex",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"GluonGhostVertex"],
  "."
}], "Text",
  CellTags->"GluonPropagator"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData["Examples"], "Subsubsection",
  CellTags->"GluonPropagator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GluonPropagator", "[", 
      RowBox[{"p", ",", "\[Mu]", ",", "a", ",", "\[Nu]", ",", "b"}], 
      "]"}]], "Input",
  CellLabel->"In[820]:=  (21:54:30 on 5/16/01)",
  CellTags->"GluonPropagator"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        FractionBox[
          RowBox[{"\[ImaginaryI]", " ", 
            SuperscriptBox["g", 
              RowBox[{
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"], "\[NoBreak]", 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]}]], " ", 
            SubscriptBox["\[Delta]", 
              RowBox[{
                FormBox[
                  FormBox["a",
                    "TraditionalForm"],
                  "TraditionalForm"], "\[NoBreak]", 
                FormBox[
                  FormBox["b",
                    "TraditionalForm"],
                  "TraditionalForm"]}]]}], 
          SuperscriptBox["p", "2"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[820]=  (21:54:30 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GluonPropagator", "[", 
      RowBox[{"p", ",", "\[Mu]", ",", "a", ",", "\[Nu]", ",", "b", ",", 
        RowBox[{"Gauge", "\[Rule]", "\[Alpha]"}]}], "]"}]], "Input",
  CellLabel->"In[821]:=  (21:54:30 on 5/16/01)",
  CellTags->"GluonPropagator"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
            RowBox[{
              FractionBox[
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"1", "-", "\[Alpha]"}], ")"}], " ", 
                  SuperscriptBox[
                    FormBox["p",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"]], " ", 
                  SuperscriptBox[
                    FormBox["p",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"]]}], 
                SuperscriptBox["p", "2"]], "-", 
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}], ")"}], " ", 
          SubscriptBox["\[Delta]", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], 
        SuperscriptBox["p", "2"]], TraditionalForm]], "Output",
  CellLabel->"Out[821]=  (21:54:30 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GluonPropagator", "[", 
      RowBox[{"p", ",", "\[Mu]", ",", "a", ",", "\[Nu]", ",", "b", ",", 
        RowBox[{"Gauge", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"Momentum", "[", "n", "]"}], ",", "1"}], "}"}]}]}], 
      "]"}]], "Input",
  CellLabel->"In[822]:=  (21:54:31 on 5/16/01)",
  CellTags->"GluonPropagator"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                SuperscriptBox["g", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"]}]]}], "-", 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["n",
                    "TraditionalForm"], "2"]}], "+", 
              FractionBox[
                RowBox[{
                  SuperscriptBox[
                    FormBox["n",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"]], " ", 
                  SuperscriptBox[
                    FormBox["n",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"]], " ", 
                  SuperscriptBox[
                    FormBox["p",
                      "TraditionalForm"], "2"]}], 
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{
                        FormBox["n",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["p",
                          "TraditionalForm"]}],
                      "TraditionalForm"], ")"}], "2"]], "+", 
              FractionBox[
                RowBox[{
                  RowBox[{
                    SuperscriptBox[
                      FormBox["n",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"]], " ", 
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"]]}], "+", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["n",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"]], " ", 
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"]]}]}], 
                RowBox[{
                  FormBox["n",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["p",
                    "TraditionalForm"]}]]}], ")"}], " ", 
          SubscriptBox["\[Delta]", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], 
        SuperscriptBox["p", "2"]], TraditionalForm]], "Output",
  CellLabel->"Out[822]=  (21:54:31 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GluonPropagator", "[", 
      RowBox[{"p", ",", "\[Mu]", ",", "\[Nu]"}], "]"}]], "Input",
  CellLabel->"In[823]:=  (21:54:31 on 5/16/01)",
  CellTags->"GluonPropagator"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        FractionBox[
          RowBox[{"\[ImaginaryI]", " ", 
            SuperscriptBox["g", 
              RowBox[{
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"], "\[NoBreak]", 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]}]]}], 
          SuperscriptBox["p", "2"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[823]=  (21:54:31 on 5/16/01)"]
}, Closed]],

Cell["\<\
This is a convenient way to enter amplitudes by hand (GP is an abbreviation \
GluonPropagator).\
\>", "Text",
  CellTags->"GluonPropagator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GP", "[", 
      RowBox[{"p", ",", "1", ",", "2"}], "]"}]], "Input",
  CellLabel->"In[824]:=  (21:54:31 on 5/16/01)",
  CellTags->"GluonPropagator"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        FractionBox[
          RowBox[{"\[ImaginaryI]", " ", 
            SuperscriptBox["g", 
              RowBox[{
                FormBox[
                  FormBox["li1",
                    "TraditionalForm"],
                  "TraditionalForm"], "\[NoBreak]", 
                FormBox[
                  FormBox["li2",
                    "TraditionalForm"],
                  "TraditionalForm"]}]], " ", 
            SubscriptBox["\[Delta]", 
              RowBox[{
                FormBox[
                  FormBox["ci1",
                    "TraditionalForm"],
                  "TraditionalForm"], "\[NoBreak]", 
                FormBox[
                  FormBox["ci2",
                    "TraditionalForm"],
                  "TraditionalForm"]}]]}], 
          SuperscriptBox["p", "2"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[824]=  (21:54:31 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"GP", "[", 
          RowBox[{
            RowBox[{"-", "k"}], ",", "3", ",", "4"}], "]"}], "//", "FCE"}], "//",
       "StandardForm"}]], "Input",
  CellLabel->"In[825]:=  (21:54:31 on 5/16/01)",
  CellTags->"GluonPropagator"],

Cell[BoxData[
    RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", 
      RowBox[{"FAD", "[", 
        RowBox[{"-", "k"}], "]"}], " ", 
      RowBox[{"MTD", "[", 
        RowBox[{"li3", ",", "li4"}], "]"}], " ", 
      RowBox[{"SD", "[", 
        RowBox[{"ci3", ",", "ci4"}], "]"}]}]], "Output",
  CellLabel->"Out[825]//StandardForm=  (21:54:31 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GluonPropagator", "[", 
      RowBox[{"p", ",", "\[Mu]", ",", "a", ",", "\[Nu]", ",", "b", ",", 
        RowBox[{"CounterTerm", "\[Rule]", " ", "1"}]}], "]"}]], "Input",
  CellLabel->"In[826]:=  (21:54:31 on 5/16/01)",
  CellTags->"GluonPropagator"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        FractionBox[
          RowBox[{"\[ImaginaryI]", " ", 
            SubscriptBox["C", "A"], " ", 
            SubsuperscriptBox["g", "s", "2"], " ", 
            SubscriptBox["S", "n"], " ", 
            RowBox[{"(", 
              RowBox[{
                FractionBox[
                  RowBox[{"11", " ", 
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"]], " ", 
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"]]}], "3"], "-", 
                RowBox[{
                  FractionBox["19", "6"], " ", 
                  SuperscriptBox["g", 
                    RowBox[{
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"]}]], " ", 
                  SuperscriptBox[
                    FormBox["p",
                      "TraditionalForm"], "2"]}]}], ")"}], " ", 
            SubscriptBox["\[Delta]", 
              RowBox[{
                FormBox[
                  FormBox["a",
                    "TraditionalForm"],
                  "TraditionalForm"], "\[NoBreak]", 
                FormBox[
                  FormBox["b",
                    "TraditionalForm"],
                  "TraditionalForm"]}]]}], 
          TagBox["\[CurlyEpsilon]",
            TraditionalForm]]}], TraditionalForm]], "Output",
  CellLabel->"Out[826]=  (21:54:31 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GluonPropagator", "[", 
      RowBox[{"p", ",", "\[Mu]", ",", "a", ",", "\[Nu]", ",", "b", ",", 
        RowBox[{"CounterTerm", "\[Rule]", " ", "2"}]}], "]"}]], "Input",
  CellLabel->"In[827]:=  (21:54:31 on 5/16/01)",
  CellTags->"GluonPropagator"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        FractionBox[
          RowBox[{"\[ImaginaryI]", " ", 
            SubscriptBox["C", "A"], " ", 
            SubsuperscriptBox["g", "s", "2"], " ", 
            SubscriptBox["S", "n"], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"-", 
                    FractionBox["1", "3"]}], " ", 
                  SuperscriptBox[
                    FormBox["p",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"]], " ", 
                  SuperscriptBox[
                    FormBox["p",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"]]}], "-", 
                RowBox[{
                  FractionBox["1", "6"], " ", 
                  SuperscriptBox["g", 
                    RowBox[{
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"]}]], " ", 
                  SuperscriptBox[
                    FormBox["p",
                      "TraditionalForm"], "2"]}]}], ")"}], " ", 
            SubscriptBox["\[Delta]", 
              RowBox[{
                FormBox[
                  FormBox["a",
                    "TraditionalForm"],
                  "TraditionalForm"], "\[NoBreak]", 
                FormBox[
                  FormBox["b",
                    "TraditionalForm"],
                  "TraditionalForm"]}]]}], 
          TagBox["\[CurlyEpsilon]",
            TraditionalForm]]}], TraditionalForm]], "Output",
  CellLabel->"Out[827]=  (21:54:31 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GluonPropagator", "[", 
      RowBox[{"p", ",", "\[Mu]", ",", "a", ",", "\[Nu]", ",", "b", ",", 
        RowBox[{"CounterTerm", "\[Rule]", " ", "3"}]}], "]"}]], "Input",
  CellLabel->"In[828]:=  (21:54:31 on 5/16/01)",
  CellTags->"GluonPropagator"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", 
            SubsuperscriptBox["g", "s", "2"], " ", 
            SubscriptBox["S", "n"], " ", 
            SubscriptBox["T", "f"], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  FractionBox["4", "3"], " ", 
                  SuperscriptBox["g", 
                    RowBox[{
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"]}]], " ", 
                  SuperscriptBox[
                    FormBox["p",
                      "TraditionalForm"], "2"]}], "-", 
                FractionBox[
                  RowBox[{"4", " ", 
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"]], " ", 
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"]]}], "3"]}], ")"}], " ", 
            SubscriptBox["\[Delta]", 
              RowBox[{
                FormBox[
                  FormBox["a",
                    "TraditionalForm"],
                  "TraditionalForm"], "\[NoBreak]", 
                FormBox[
                  FormBox["b",
                    "TraditionalForm"],
                  "TraditionalForm"]}]]}], 
          TagBox["\[CurlyEpsilon]",
            TraditionalForm]]}], TraditionalForm]], "Output",
  CellLabel->"Out[828]=  (21:54:32 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GluonPropagator", "[", 
      RowBox[{"p", ",", "\[Mu]", ",", "a", ",", "\[Nu]", ",", "b", ",", 
        RowBox[{"CounterTerm", "\[Rule]", " ", "4"}]}], "]"}]], "Input",
  CellLabel->"In[829]:=  (21:54:32 on 5/16/01)",
  CellTags->"GluonPropagator"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        FractionBox[
          RowBox[{"\[ImaginaryI]", " ", 
            SubscriptBox["C", "A"], " ", 
            SubsuperscriptBox["g", "s", "2"], " ", 
            SubscriptBox["S", "n"], " ", 
            RowBox[{"(", 
              RowBox[{
                FractionBox[
                  RowBox[{"10", " ", 
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"]], " ", 
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"]]}], "3"], "-", 
                RowBox[{
                  FractionBox["10", "3"], " ", 
                  SuperscriptBox["g", 
                    RowBox[{
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"]}]], " ", 
                  SuperscriptBox[
                    FormBox["p",
                      "TraditionalForm"], "2"]}]}], ")"}], " ", 
            SubscriptBox["\[Delta]", 
              RowBox[{
                FormBox[
                  FormBox["a",
                    "TraditionalForm"],
                  "TraditionalForm"], "\[NoBreak]", 
                FormBox[
                  FormBox["b",
                    "TraditionalForm"],
                  "TraditionalForm"]}]]}], 
          TagBox["\[CurlyEpsilon]",
            TraditionalForm]]}], TraditionalForm]], "Output",
  CellLabel->"Out[829]=  (21:54:32 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GluonPropagator", "[", 
      RowBox[{"p", ",", "\[Mu]", ",", "a", ",", "\[Nu]", ",", "b", ",", 
        RowBox[{"CounterTerm", "\[Rule]", " ", "5"}]}], "]"}]], "Input",
  CellLabel->"In[830]:=  (21:54:32 on 5/16/01)",
  CellTags->"GluonPropagator"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{"\[ImaginaryI]", " ", 
            SubscriptBox["C", "A"], " ", 
            SubscriptBox["S", "n"], " ", 
            RowBox[{"(", 
              RowBox[{
                FractionBox[
                  RowBox[{"10", " ", 
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"]], " ", 
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"]]}], "3"], "-", 
                RowBox[{
                  FractionBox["10", "3"], " ", 
                  SuperscriptBox["g", 
                    RowBox[{
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"]}]], " ", 
                  SuperscriptBox[
                    FormBox["p",
                      "TraditionalForm"], "2"]}]}], ")"}], " ", 
            SubscriptBox["\[Delta]", 
              RowBox[{
                FormBox[
                  FormBox["a",
                    "TraditionalForm"],
                  "TraditionalForm"], "\[NoBreak]", 
                FormBox[
                  FormBox["b",
                    "TraditionalForm"],
                  "TraditionalForm"]}]], " ", 
            SubsuperscriptBox["g", "s", "2"]}], 
          TagBox["\[CurlyEpsilon]",
            TraditionalForm]], "+", 
        FractionBox[
          RowBox[{"\[ImaginaryI]", " ", 
            SubscriptBox["S", "n"], " ", 
            SubscriptBox["T", "f"], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  FractionBox["4", "3"], " ", 
                  SuperscriptBox["g", 
                    RowBox[{
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"]}]], " ", 
                  SuperscriptBox[
                    FormBox["p",
                      "TraditionalForm"], "2"]}], "-", 
                FractionBox[
                  RowBox[{"4", " ", 
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"]], " ", 
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"]]}], "3"]}], ")"}], " ", 
            SubscriptBox["\[Delta]", 
              RowBox[{
                FormBox[
                  FormBox["a",
                    "TraditionalForm"],
                  "TraditionalForm"], "\[NoBreak]", 
                FormBox[
                  FormBox["b",
                    "TraditionalForm"],
                  "TraditionalForm"]}]], " ", 
            SubsuperscriptBox["g", "s", "2"]}], 
          TagBox["\[CurlyEpsilon]",
            TraditionalForm]]}], TraditionalForm]], "Output",
  CellLabel->"Out[830]=  (21:54:32 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["GluonVertex", "ObjectName",
  CellTags->"GluonVertex"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"GluonVertex"],

Cell["Note: All momenta are flowing into the vertex.", "Text",
  CellTags->"GluonVertex"],

Cell["\<\
GluonVertex[{p,mu,a}, {q,nu,b}, {k,la,c}] or GluonVertex[p,mu,a , q,nu,b , \
k,la,c ] yields the 3-gluon vertex. GluonVertex[{p,mu}, {q,nu}, {k,la}] \
yields the 3-gluon vertex without color structure and the coupling constant. \
GluonVertex[{p,mu,a}, {q,nu,b}, {k,la,c}, {s,si,d}] or GluonVertex[{mu,a}, \
{nu,b}, {la,c}, {si,d}] or GluonVertex[p,mu,a , q,nu,b , k,la,c , s,si,d] or \
GluonVertex[ mu,a , nu,b , la,c , si,d ] yields the 4-gluon vertex. The \
dimension and the name of the coupling constant are determined by the options \
Dimension and CouplingConstant.\
\>", "Text",
  CellTags->"GluonVertex"],

Cell["GV can be used as an abbreviation of GluonVertex.", "Text",
  CellTags->"GluonVertex"],

Cell[CellGroupData[{

Cell[BoxData["GV"], "Input",
  CellLabel->"In[831]:=  (21:54:32 on 5/16/01)",
  CellTags->"GluonVertex"],

Cell[BoxData[
    FormBox["GluonVertex", TraditionalForm]], "Output",
  CellLabel->"Out[831]=  (21:54:32 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "GluonVertex", "]"}]], "Input",
  CellLabel->"In[832]:=  (21:54:32 on 5/16/01)",
  CellTags->"GluonVertex"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"CouplingConstant", "\[Rule]", 
            SubscriptBox["g", "s"]}], ",", 
          RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
          RowBox[{"Explicit", "\[Rule]", "False"}], ",", 
          RowBox[{"\[CapitalKoppa]", "\[Rule]", "False"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[832]=  (21:54:32 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["GluonGhostVertex",
    ButtonData:>"GluonGhostVertex",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"GluonGhostVertex"],
  ", ",
  ButtonBox["GluonPropagator",
    ButtonData:>"GluonPropagator",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"GluonPropagator"],
  "."
}], "Text",
  CellTags->"GluonVertex"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"GluonVertex"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GluonVertex", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"q", ",", "\[Nu]", ",", "b"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"r", ",", "\[Rho]", ",", "c"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[833]:=  (21:54:32 on 5/16/01)",
  CellTags->"GluonVertex"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["g", "s"], " ", 
        RowBox[{
          SuperscriptBox["V", 
            RowBox[{
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Rho]",
                  "TraditionalForm"],
                "TraditionalForm"]}]], "(", 
          RowBox[{
            FormBox["p",
              "TraditionalForm"], "\[NoBreak]", 
            RowBox[{",", " "}], "\[NoBreak]", 
            FormBox["q",
              "TraditionalForm"], "\[NoBreak]", 
            RowBox[{",", " "}], "\[NoBreak]", 
            FormBox["r",
              "TraditionalForm"]}], ")"}], " ", 
        SubscriptBox["f", 
          RowBox[{
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["c",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[833]=  (21:54:32 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"GluonVertex", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{"q", ",", "\[Nu]", ",", "b"}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{"r", ",", "\[Rho]", ",", "c"}], "}"}]}], "]"}], "//", 
      "Explicit"}]], "Input",
  CellLabel->"In[834]:=  (21:54:32 on 5/16/01)",
  CellTags->"GluonVertex"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["g", "s"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}], "-", 
            RowBox[{
              SuperscriptBox[
                FormBox["r",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}], "-", 
            RowBox[{
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], "+", 
            RowBox[{
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox[
                FormBox["r",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], "+", 
            RowBox[{
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Rho]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], "-", 
            RowBox[{
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Rho]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}]}], ")"}], " ", 
        SubscriptBox["f", 
          RowBox[{
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["c",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[834]=  (21:54:32 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GluonVertex", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"p", ",", "\[Mu]"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"q", ",", "\[Nu]"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"r", ",", "\[Rho]"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[835]:=  (21:54:32 on 5/16/01)",
  CellTags->"GluonVertex"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["V", 
          RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]", "\[NoBreak]", "\[Rho]"}]], 
        "(", 
        RowBox[{"p", "\[NoBreak]", 
          RowBox[{",", " "}], "\[NoBreak]", "q", "\[NoBreak]", 
          RowBox[{",", " "}], "\[NoBreak]", "r"}], ")"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[835]=  (21:54:32 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"GluonVertex", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{"p", ",", "\[Mu]"}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{"q", ",", "\[Nu]"}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{"r", ",", "\[Rho]"}], "}"}]}], "]"}], "//", 
      "Explicit"}]], "Input",
  CellLabel->"In[836]:=  (21:54:32 on 5/16/01)",
  CellTags->"GluonVertex"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            FormBox["q",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SuperscriptBox["g", 
            RowBox[{
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Rho]",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "-", 
        RowBox[{
          SuperscriptBox[
            FormBox["r",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SuperscriptBox["g", 
            RowBox[{
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Rho]",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "-", 
        RowBox[{
          SuperscriptBox["g", 
            RowBox[{
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Rho]",
                  "TraditionalForm"],
                "TraditionalForm"]}]], " ", 
          SuperscriptBox[
            FormBox["p",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"]]}], "+", 
        RowBox[{
          SuperscriptBox["g", 
            RowBox[{
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Rho]",
                  "TraditionalForm"],
                "TraditionalForm"]}]], " ", 
          SuperscriptBox[
            FormBox["r",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"]]}], "+", 
        RowBox[{
          SuperscriptBox["g", 
            RowBox[{
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"]}]], " ", 
          SuperscriptBox[
            FormBox["p",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Rho]",
                "TraditionalForm"],
              "TraditionalForm"]]}], "-", 
        RowBox[{
          SuperscriptBox["g", 
            RowBox[{
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"]}]], " ", 
          SuperscriptBox[
            FormBox["q",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Rho]",
                "TraditionalForm"],
              "TraditionalForm"]]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[836]=  (21:54:33 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GluonVertex", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"q", ",", "\[Nu]", ",", "b"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"r", ",", "\[Rho]", ",", "c"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"s", ",", "\[Sigma]", ",", "d"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[837]:=  (21:54:33 on 5/16/01)",
  CellTags->"GluonVertex"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        SubsuperscriptBox["g", "s", "2"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Rho]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Sigma]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}], "-", 
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Rho]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Sigma]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}]}], ")"}], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["a",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["d",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["u9",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["b",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["c",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["u9",
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Rho]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Sigma]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}], "-", 
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Sigma]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Rho]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}]}], ")"}], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["a",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["c",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["u9",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["b",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["d",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["u9",
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Rho]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Sigma]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}], "-", 
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Sigma]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Rho]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}]}], ")"}], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["a",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["b",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["u9",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["c",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["d",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["u9",
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[837]=  (21:54:34 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GluonVertex", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"\[Mu]", ",", "a"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"\[Nu]", ",", "b"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"\[Rho]", ",", "c"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"\[Sigma]", ",", "d"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[838]:=  (21:54:34 on 5/16/01)",
  CellTags->"GluonVertex"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        SubsuperscriptBox["g", "s", "2"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Rho]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Sigma]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}], "-", 
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Rho]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Sigma]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}]}], ")"}], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["a",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["d",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["u10",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["b",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["c",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["u10",
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Rho]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Sigma]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}], "-", 
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Sigma]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Rho]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}]}], ")"}], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["a",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["c",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["u10",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["b",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["d",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["u10",
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Rho]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Sigma]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}], "-", 
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Sigma]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Rho]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}]}], ")"}], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["a",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["b",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["u10",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["c",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["d",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["u10",
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[838]=  (21:54:34 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GluonVertex", "[", 
      RowBox[{
      "\[Mu]", ",", "a", ",", "\[Nu]", ",", "b", ",", "\[Rho]", ",", "c", ",",
         "\[Sigma]", ",", "d"}], "]"}]], "Input",
  CellLabel->"In[839]:=  (21:54:34 on 5/16/01)",
  CellTags->"GluonVertex"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        SubsuperscriptBox["g", "s", "2"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Rho]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Sigma]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}], "-", 
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Rho]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Sigma]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}]}], ")"}], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["a",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["d",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["u11",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["b",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["c",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["u11",
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Rho]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Sigma]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}], "-", 
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Sigma]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Rho]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}]}], ")"}], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["a",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["c",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["u11",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["b",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["d",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["u11",
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Rho]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Sigma]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}], "-", 
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Sigma]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Rho]",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}]}], ")"}], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["a",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["b",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["u11",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["c",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["d",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["u11",
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[839]=  (21:54:34 on 5/16/01)"]
}, Closed]],

Cell["\<\
A very convenient way to enter diagrams by hand is to label each line hitting \
a vertex by a number and put this number after the inflowing momentum.\
\>", "Text",
  CellTags->"GluonVertex"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GV", "[", 
      RowBox[{"p", ",", "1", ",", "q", ",", "2", ",", "r", ",", "3"}], 
      "]"}]], "Input",
  CellLabel->"In[840]:=  (21:54:34 on 5/16/01)",
  CellTags->"GluonVertex"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["g", "s"], " ", 
        RowBox[{
          SuperscriptBox["V", 
            RowBox[{
              FormBox[
                FormBox["li1",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["li2",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["li3",
                  "TraditionalForm"],
                "TraditionalForm"]}]], "(", 
          RowBox[{
            FormBox["p",
              "TraditionalForm"], "\[NoBreak]", 
            RowBox[{",", " "}], "\[NoBreak]", 
            FormBox["q",
              "TraditionalForm"], "\[NoBreak]", 
            RowBox[{",", " "}], "\[NoBreak]", 
            FormBox["r",
              "TraditionalForm"]}], ")"}], " ", 
        SubscriptBox["f", 
          RowBox[{
            FormBox[
              FormBox["ci1",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["ci2",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["ci3",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[840]=  (21:54:34 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GV", "[", 
      RowBox[{
      "p", ",", "1", ",", "q", ",", "2", ",", "r", ",", "3", ",", "s", ",", 
        "4"}], "]"}]], "Input",
  CellLabel->"In[841]:=  (21:54:34 on 5/16/01)",
  CellTags->"GluonVertex"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        SubsuperscriptBox["g", "s", "2"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["li1",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["li2",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["li3",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["li4",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}], "-", 
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["li1",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["li3",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["li2",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["li4",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}]}], ")"}], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["ci1",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["ci4",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["u12",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["ci2",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["ci3",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["u12",
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["li1",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["li2",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["li3",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["li4",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}], "-", 
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["li1",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["li4",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["li2",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["li3",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}]}], ")"}], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["ci1",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["ci3",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["u12",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["ci2",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["ci4",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["u12",
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["li1",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["li3",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["li2",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["li4",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}], "-", 
                  RowBox[{
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["li1",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["li4",
                            "TraditionalForm"],
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox["g", 
                      RowBox[{
                        FormBox[
                          FormBox["li2",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["li3",
                            "TraditionalForm"],
                          "TraditionalForm"]}]]}]}], ")"}], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["ci1",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["ci2",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["u12",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["ci3",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["ci4",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["u12",
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[841]=  (21:54:34 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["GSD", "ObjectName",
  CellTags->"GSD"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"GSD"],

Cell[TextData[{
  "GSD[p] can be used as input for a D-dimensional ",
  Cell[BoxData[
      FormBox[
        RowBox[{
        "p", " ", "\[NegativeMediumSpace]", "\[NegativeMediumSpace]", 
          "\[NegativeMediumSpace]", "\[NegativeMediumSpace]", "/", " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"=", 
                RowBox[{"\[Gamma]", ".", "p"}]}], " ", "=", " ", 
              RowBox[{
                SubscriptBox["\[Gamma]", "\[Mu]"], 
                SuperscriptBox["p", "\[Mu]"]}]}], ")"}]}], 
        TraditionalForm]]],
  " and is transformed into DiracGamma[Momentum[p,D],D] by FeynCalcInternal \
(=FCI). GSD[p,q, ...] is a short form for GSD[p].GSD[q]. ... ."
}], "Text",
  CellTags->"GSD"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["DiracGamma",
    ButtonData:>"DiracGamma",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracGamma"],
  ", ",
  ButtonBox["DiracSlash",
    ButtonData:>"DiracSlash",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracSlash"],
  ", ",
  ButtonBox["GA",
    ButtonData:>"GA",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"GA"],
  ", ",
  ButtonBox["GAD",
    ButtonData:>"GAD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"GAD"],
  "."
}], "Text",
  CellTags->"GSD"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"GSD"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GSD", "[", "p", "]"}]], "Input",
  CellLabel->"In[842]:=  (21:54:34 on 5/16/01)",
  CellTags->"GSD"],

Cell[BoxData[
    FormBox[
      RowBox[{"\[Gamma]", "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "p"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[842]=  (21:54:34 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"GSD", "[", "p", "]"}], "//", "FCI"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[843]:=  (21:54:35 on 5/16/01)",
  CellTags->"GSD"],

Cell[BoxData[
    RowBox[{"DiracGamma", "[", 
      RowBox[{
        RowBox[{"Momentum", "[", 
          RowBox[{"p", ",", "D"}], "]"}], ",", "D"}], "]"}]], "Output",
  CellLabel->"Out[843]//StandardForm=  (21:54:35 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GSD", "[", 
      RowBox[{"p", ",", "q", ",", "r", ",", "s"}], "]"}]], "Input",
  CellLabel->"In[844]:=  (21:54:35 on 5/16/01)",
  CellTags->"GSD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
          "\[Gamma]", "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "p"}], 
          ")"}], ".", 
        RowBox[{"(", 
          RowBox[{
          "\[Gamma]", "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "q"}], 
          ")"}], ".", 
        RowBox[{"(", 
          RowBox[{
          "\[Gamma]", "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "r"}], 
          ")"}], ".", 
        RowBox[{"(", 
          RowBox[{
          "\[Gamma]", "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "s"}], 
          ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[844]=  (21:54:35 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"GSD", "[", 
        RowBox[{"p", ",", "q", ",", "r", ",", "s"}], "]"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[845]:=  (21:54:35 on 5/16/01)",
  CellTags->"GSD"],

Cell[BoxData[
    RowBox[{
      RowBox[{"GSD", "[", "p", "]"}], ".", 
      RowBox[{"GSD", "[", "q", "]"}], ".", 
      RowBox[{"GSD", "[", "r", "]"}], ".", 
      RowBox[{"GSD", "[", "s", "]"}]}]], "Output",
  CellLabel->"Out[845]//StandardForm=  (21:54:35 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"GSD", "[", "q", "]"}], ".", 
      RowBox[{"(", 
        RowBox[{
          RowBox[{"GSD", "[", "p", "]"}], "+", "m"}], ")"}], ".", 
      RowBox[{"GSD", "[", "q", "]"}]}]], "Input",
  CellLabel->"In[846]:=  (21:54:35 on 5/16/01)",
  CellTags->"GSD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
          "\[Gamma]", "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "q"}], 
          ")"}], ".", 
        RowBox[{"(", 
          RowBox[{"m", "+", 
            RowBox[{
            "\[Gamma]", "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "p"}]}], 
          ")"}], ".", 
        RowBox[{"(", 
          RowBox[{
          "\[Gamma]", "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "q"}], 
          ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[846]=  (21:54:35 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["GS", "ObjectName",
  CellTags->"GS"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"GS"],

Cell[TextData[{
  "GS[p] can be used as input for a 4-dimensional ",
  Cell[BoxData[
      FormBox[
        RowBox[{
        "p", " ", "\[NegativeMediumSpace]", "\[NegativeMediumSpace]", 
          "\[NegativeMediumSpace]", "\[NegativeMediumSpace]", "/", " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"=", 
                RowBox[{"\[Gamma]", ".", "p"}]}], " ", "=", " ", 
              RowBox[{
                SubscriptBox["\[Gamma]", "\[Mu]"], 
                SuperscriptBox["p", "\[Mu]"]}]}], ")"}]}], 
        TraditionalForm]]],
  " and is transformed into DiracGamma[Momentum[p]] by FeynCalcInternal \
(=FCI). GS[p,q, ...] is a short form for GS[p].GS[q]. ... ."
}], "Text",
  CellTags->"GS"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["DiracGamma",
    ButtonData:>"DiracGamma",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracGamma"],
  ", ",
  ButtonBox["DiracSlash",
    ButtonData:>"DiracSlash",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracSlash"],
  ", ",
  ButtonBox["GA",
    ButtonData:>"GA",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"GA"],
  ", ",
  ButtonBox["GAD",
    ButtonData:>"GAD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"GAD"],
  "."
}], "Text",
  CellTags->"GS"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"GS"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GS", "[", "p", "]"}]], "Input",
  CellLabel->"In[847]:=  (21:54:35 on 5/16/01)",
  CellTags->"GS"],

Cell[BoxData[
    FormBox[
      RowBox[{"\[Gamma]", "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "p"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[847]=  (21:54:35 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"GS", "[", "p", "]"}], "//", "FCI"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[848]:=  (21:54:35 on 5/16/01)",
  CellTags->"GS"],

Cell[BoxData[
    RowBox[{"DiracGamma", "[", 
      RowBox[{"Momentum", "[", "p", "]"}], "]"}]], "Output",
  CellLabel->"Out[848]//StandardForm=  (21:54:35 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GS", "[", 
      RowBox[{"p", ",", "q", ",", "r", ",", "s"}], "]"}]], "Input",
  CellLabel->"In[849]:=  (21:54:35 on 5/16/01)",
  CellTags->"GS"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
          "\[Gamma]", "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "p"}], 
          ")"}], ".", 
        RowBox[{"(", 
          RowBox[{
          "\[Gamma]", "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "q"}], 
          ")"}], ".", 
        RowBox[{"(", 
          RowBox[{
          "\[Gamma]", "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "r"}], 
          ")"}], ".", 
        RowBox[{"(", 
          RowBox[{
          "\[Gamma]", "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "s"}], 
          ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[849]=  (21:54:35 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"GS", "[", 
        RowBox[{"p", ",", "q", ",", "r", ",", "s"}], "]"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[850]:=  (21:54:35 on 5/16/01)",
  CellTags->"GS"],

Cell[BoxData[
    RowBox[{
      RowBox[{"GS", "[", "p", "]"}], ".", 
      RowBox[{"GS", "[", "q", "]"}], ".", 
      RowBox[{"GS", "[", "r", "]"}], ".", 
      RowBox[{"GS", "[", "s", "]"}]}]], "Output",
  CellLabel->"Out[850]//StandardForm=  (21:54:35 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"GS", "[", "q", "]"}], ".", 
      RowBox[{"(", 
        RowBox[{
          RowBox[{"GS", "[", "p", "]"}], "+", "m"}], ")"}], ".", 
      RowBox[{"GS", "[", "q", "]"}]}]], "Input",
  CellLabel->"In[851]:=  (21:54:35 on 5/16/01)",
  CellTags->"GS"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
          "\[Gamma]", "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "q"}], 
          ")"}], ".", 
        RowBox[{"(", 
          RowBox[{"m", "+", 
            RowBox[{
            "\[Gamma]", "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "p"}]}], 
          ")"}], ".", 
        RowBox[{"(", 
          RowBox[{
          "\[Gamma]", "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "q"}], 
          ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[851]=  (21:54:35 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Gstrong", "ObjectName",
  CellTags->"Gstrong"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"Gstrong"],

Cell["Gstrong denotes the strong coupling constant.", "Text",
  CellTags->"Gstrong"],

Cell[TextData[{
  "See also: ",
  ButtonBox["CovariantD",
    ButtonData:>"CovariantD",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["FieldStrength",
    ButtonData:>"FieldStrength",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["GluonVertex",
    ButtonData:>"GluonVertex",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Text",
  CellTags->"Gstrong"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"Gstrong"],

Cell["\<\
Gstrong has no functional properties. Only a typesetting rule is defined.\
\>", "Text",
  CellTags->"Gstrong"],

Cell[CellGroupData[{

Cell[BoxData["Gstrong"], "Input",
  CellLabel->"In[852]:=  (21:54:35 on 5/16/01)",
  CellTags->"Gstrong"],

Cell[BoxData[
    FormBox[
      SubscriptBox["g", "s"], TraditionalForm]], "Output",
  CellLabel->"Out[852]=  (21:54:35 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Hill", "ObjectName",
  CellTags->"Hill"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"Hill"],

Cell["\<\
Hill[x, y] gives the Hill identity with arguments x and y. The returned \
object is 0.\
\>", "Text",
  CellTags->"Hill"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["SimplifyPolyLog",
    ButtonData:>"SimplifyPolyLog",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SimplifyPolyLog"],
  "."
}], "Text",
  CellTags->"Hill"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"Hill"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Hill", "[", 
      RowBox[{"a", ",", "b"}], "]"}]], "Input",
  CellLabel->"In[853]:=  (21:54:35 on 5/16/01)",
  CellTags->"Hill"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"log", "(", "a", ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"log", "(", 
                RowBox[{"1", "-", "a"}], ")"}], "-", 
              RowBox[{"log", "(", 
                RowBox[{"1", "-", "b"}], ")"}]}], ")"}]}], "+", 
        RowBox[{
          RowBox[{"log", "(", 
            FractionBox[
              RowBox[{"1", "-", "a"}], 
              RowBox[{"1", "-", "b"}]], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"log", "(", "a", ")"}]}], "+", 
              RowBox[{"log", "(", 
                RowBox[{"1", "-", "b"}], ")"}], "-", 
              RowBox[{"log", "(", 
                FractionBox[
                  RowBox[{"a", "-", "b"}], "a"], ")"}], "+", 
              RowBox[{"log", "(", 
                FractionBox[
                  RowBox[{"a", "-", "b"}], 
                  RowBox[{"1", "-", "b"}]], ")"}]}], ")"}]}], "-", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"log", "(", 
                RowBox[{"1", "-", "b"}], ")"}], "-", 
              RowBox[{"log", "(", 
                FractionBox[
                  RowBox[{"a", "-", "b"}], "a"], ")"}], "+", 
              RowBox[{"log", "(", 
                FractionBox[
                  RowBox[{"a", "-", "b"}], 
                  RowBox[{"a", " ", 
                    RowBox[{"(", 
                      RowBox[{"1", "-", "b"}], ")"}]}]], ")"}]}], ")"}], " ", 
          
          RowBox[{"log", "(", 
            FractionBox[
              RowBox[{
                RowBox[{"(", 
                  RowBox[{"1", "-", "a"}], ")"}], " ", "b"}], 
              RowBox[{"a", " ", 
                RowBox[{"(", 
                  RowBox[{"1", "-", "b"}], ")"}]}]], ")"}]}], "+", 
        RowBox[{
          SubscriptBox["Li", "2"], "(", "a", ")"}], "+", 
        RowBox[{
          SubscriptBox["Li", "2"], "(", 
          FractionBox[
            RowBox[{"1", "-", "a"}], 
            RowBox[{"1", "-", "b"}]], ")"}], "-", 
        RowBox[{
          SubscriptBox["Li", "2"], "(", "b", ")"}], "+", 
        RowBox[{
          SubscriptBox["Li", "2"], "(", 
          FractionBox["b", "a"], ")"}], "-", 
        RowBox[{
          SubscriptBox["Li", "2"], "(", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{"1", "-", "a"}], ")"}], " ", "b"}], 
            RowBox[{"a", " ", 
              RowBox[{"(", 
                RowBox[{"1", "-", "b"}], ")"}]}]], ")"}], "-", 
        FractionBox[
          SuperscriptBox["\[Pi]", "2"], "6"]}], TraditionalForm]], "Output",
  CellLabel->"Out[853]=  (21:54:36 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"%", " ", "/.", " ", 
          RowBox[{"a", ":>", " ", ".123"}]}], " ", "/.", " ", 
        RowBox[{"b", ":>", " ", ".656"}]}], " ", "//", " ", "Chop"}]], "Input",\

  CellLabel->"In[854]:=  (21:54:36 on 5/16/01)",
  CellTags->"Hill"],

Cell[BoxData[
    FormBox["0", TraditionalForm]], "Output",
  CellLabel->"Out[854]=  (21:54:36 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          RowBox[{"Hill", "[", 
            RowBox[{"x", ",", 
              RowBox[{"x", " ", "y"}]}], "]"}], "//", "PowerExpand"}], "//", 
        "SimplifyPolyLog"}], "//", "Expand"}]], "Input",
  CellLabel->"In[855]:=  (21:54:36 on 5/16/01)",
  CellTags->"Hill"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[Zeta]", "(", "2", ")"}], "-", 
        RowBox[{
          RowBox[{"log", "(", 
            RowBox[{"1", "-", "y"}], ")"}], " ", 
          RowBox[{"log", "(", "y", ")"}]}], "-", 
        RowBox[{
          RowBox[{"log", "(", "x", ")"}], " ", 
          RowBox[{"log", "(", 
            RowBox[{"1", "-", 
              RowBox[{"x", " ", "y"}]}], ")"}]}], "-", 
        RowBox[{
          SubscriptBox["Li", "2"], "(", 
          RowBox[{"1", "-", "x"}], ")"}], "-", 
        RowBox[{
          SubscriptBox["Li", "2"], "(", 
          RowBox[{"1", "-", "y"}], ")"}], "-", 
        RowBox[{
          SubscriptBox["Li", "2"], "(", 
          RowBox[{"x", " ", "y"}], ")"}], "+", 
        RowBox[{
          SubscriptBox["Li", "2"], "(", 
          FractionBox[
            RowBox[{"1", "-", "x"}], 
            RowBox[{"1", "-", 
              RowBox[{"x", " ", "y"}]}]], ")"}], "-", 
        RowBox[{
          SubscriptBox["Li", "2"], "(", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{"1", "-", "x"}], ")"}], " ", "y"}], 
            RowBox[{"1", "-", 
              RowBox[{"x", " ", "y"}]}]], ")"}]}], TraditionalForm]], "Output",\

  CellLabel->"Out[855]=  (21:54:36 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          RowBox[{"%", " ", "/.", " ", 
            RowBox[{"x", ":>", " ", ".34"}]}], "/.", " ", 
          RowBox[{"y", "->", " ", ".6"}]}], "//", "N"}], "//", 
      "Chop"}]], "Input",
  CellLabel->"In[856]:=  (21:54:36 on 5/16/01)",
  CellTags->"Hill"],

Cell[BoxData[
    FormBox["0", TraditionalForm]], "Output",
  CellLabel->"Out[856]=  (21:54:36 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["HypergeometricAC", "ObjectName",
  CellTags->"HypergeometricAC"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"HypergeometricAC"],

Cell["\<\
HypergeometricAC[n][exp] analytically continues Hypergeometric2F1 functions \
in exp. The second argument n refers to the equation number (n) in chapter \
2.10 of \"Higher Transcendental Functions\" by Ergelyi, Magnus, \
Oberhettinger, Tricomi. In case of eq. (6) (p.109) the last line is returned \
for HypergeometricAC[6][exp], while the first equality is given by \
HypergeometricAC[61][exp]. ((2.10.1) is identical to eq. (9.5.7) of \"Special \
Functions & their Applications\" by N.N.Lebedev).\
\>", "Text",
  CellTags->"HypergeometricAC"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "HypergeometricAC", "]"}]], "Input",
  CellLabel->"In[857]:=  (21:54:36 on 5/16/01)",
  CellTags->"HypergeometricAC"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"Collect2", "\[Rule]", "True"}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[857]=  (21:54:36 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["HypExplicit",
    ButtonData:>"HypExplicit",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"HypExplicit"],
  ", ",
  ButtonBox["HypergeometricIR",
    ButtonData:>"HypergeometricIR",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"HypergeometricIR"],
  ", ",
  ButtonBox["HypergeometricSE",
    ButtonData:>"HypergeometricSE",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"HypergeometricSE"],
  ", ",
  ButtonBox["ToHypergeometric",
    ButtonData:>"ToHypergeometric",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"ToHypergeometric"],
  "."
}], "Text",
  CellTags->"HypergeometricAC"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"HypergeometricAC"],

Cell["These are all transformation rules currently built in.", "Text",
  CellTags->"HypergeometricAC"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"HypergeometricAC", "[", "1", "]"}], "[", 
      RowBox[{"Hypergeometric2F1", "[", 
        RowBox[{"\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]", ",", "z"}], 
        "]"}], "]"}]], "Input",
  CellLabel->"In[858]:=  (21:54:36 on 5/16/01)",
  CellTags->"HypergeometricAC"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{
            RowBox[{"\[CapitalGamma]", "(", 
              RowBox[{"\[Alpha]", "+", "\[Beta]", "-", "\[Gamma]"}], ")"}], 
            " ", 
            RowBox[{"\[CapitalGamma]", "(", "\[Gamma]", ")"}], " ", 
            TagBox[
              TagBox[
                RowBox[{
                  RowBox[{
                    SubscriptBox["\[InvisiblePrefixScriptBase]", 
                      FormBox["2",
                        "TraditionalForm"]], 
                    SubscriptBox["F", 
                      FormBox["1",
                        "TraditionalForm"]]}], "\[InvisibleApplication]", 
                  RowBox[{"(", 
                    RowBox[{
                      TagBox[
                        TagBox[
                          RowBox[{
                            TagBox[
                              RowBox[{"\[Gamma]", "-", "\[Alpha]"}],
                              Hypergeometric2F1,
                              Editable->True], ",", 
                            TagBox[
                              RowBox[{"\[Gamma]", "-", "\[Beta]"}],
                              Hypergeometric2F1,
                              Editable->True]}],
                          InterpretTemplate[ {
                            SlotSequence[ 1]}&]],
                        Hypergeometric2F1,
                        Editable->False], ";", 
                      TagBox[
                        TagBox[
                          TagBox[
                            RowBox[{
                              RowBox[{"-", "\[Alpha]"}], "-", "\[Beta]", "+", 
                              "\[Gamma]", "+", "1"}],
                            Hypergeometric2F1,
                            Editable->True],
                          InterpretTemplate[ {
                            SlotSequence[ 1]}&]],
                        Hypergeometric2F1,
                        Editable->False], ";", 
                      TagBox[
                        RowBox[{"1", "-", "z"}],
                        Hypergeometric2F1,
                        Editable->True]}], ")"}]}],
                InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
                Editable->False],
              Hypergeometric2F1], " ", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"1", "-", "z"}], ")"}], 
              RowBox[{
                RowBox[{"-", "\[Alpha]"}], "-", "\[Beta]", "+", 
                "\[Gamma]"}]]}], 
          RowBox[{
            RowBox[{"\[CapitalGamma]", "(", "\[Alpha]", ")"}], " ", 
            RowBox[{"\[CapitalGamma]", "(", "\[Beta]", ")"}]}]], "+", 
        FractionBox[
          RowBox[{
            RowBox[{"\[CapitalGamma]", "(", "\[Gamma]", ")"}], " ", 
            RowBox[{"\[CapitalGamma]", "(", 
              RowBox[{
                RowBox[{"-", "\[Alpha]"}], "-", "\[Beta]", "+", "\[Gamma]"}], 
              ")"}], " ", 
            TagBox[
              TagBox[
                RowBox[{
                  RowBox[{
                    SubscriptBox["\[InvisiblePrefixScriptBase]", 
                      FormBox["2",
                        "TraditionalForm"]], 
                    SubscriptBox["F", 
                      FormBox["1",
                        "TraditionalForm"]]}], "\[InvisibleApplication]", 
                  RowBox[{"(", 
                    RowBox[{
                      TagBox[
                        TagBox[
                          RowBox[{
                            TagBox["\[Alpha]",
                              Hypergeometric2F1,
                              Editable->True], ",", 
                            TagBox["\[Beta]",
                              Hypergeometric2F1,
                              Editable->True]}],
                          InterpretTemplate[ {
                            SlotSequence[ 1]}&]],
                        Hypergeometric2F1,
                        Editable->False], ";", 
                      TagBox[
                        TagBox[
                          TagBox[
                            RowBox[{
                            "\[Alpha]", "+", "\[Beta]", "-", "\[Gamma]", "+", 
                              "1"}],
                            Hypergeometric2F1,
                            Editable->True],
                          InterpretTemplate[ {
                            SlotSequence[ 1]}&]],
                        Hypergeometric2F1,
                        Editable->False], ";", 
                      TagBox[
                        RowBox[{"1", "-", "z"}],
                        Hypergeometric2F1,
                        Editable->True]}], ")"}]}],
                InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
                Editable->False],
              Hypergeometric2F1]}], 
          RowBox[{
            RowBox[{"\[CapitalGamma]", "(", 
              RowBox[{"\[Gamma]", "-", "\[Alpha]"}], ")"}], " ", 
            RowBox[{"\[CapitalGamma]", "(", 
              RowBox[{"\[Gamma]", "-", "\[Beta]"}], ")"}]}]]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[858]=  (21:54:38 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"HypergeometricAC", "[", "2", "]"}], "[", 
      RowBox[{"Hypergeometric2F1", "[", 
        RowBox[{"\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]", ",", "z"}], 
        "]"}], "]"}]], "Input",
  CellLabel->"In[859]:=  (21:54:38 on 5/16/01)",
  CellTags->"HypergeometricAC"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{
            RowBox[{"\[CapitalGamma]", "(", 
              RowBox[{"\[Beta]", "-", "\[Alpha]"}], ")"}], " ", 
            RowBox[{"\[CapitalGamma]", "(", "\[Gamma]", ")"}], " ", 
            TagBox[
              TagBox[
                RowBox[{
                  RowBox[{
                    SubscriptBox["\[InvisiblePrefixScriptBase]", 
                      FormBox["2",
                        "TraditionalForm"]], 
                    SubscriptBox["F", 
                      FormBox["1",
                        "TraditionalForm"]]}], "\[InvisibleApplication]", 
                  RowBox[{"(", 
                    RowBox[{
                      TagBox[
                        TagBox[
                          RowBox[{
                            TagBox["\[Alpha]",
                              Hypergeometric2F1,
                              Editable->True], ",", 
                            TagBox[
                              RowBox[{"\[Alpha]", "-", "\[Gamma]", "+", "1"}],
                              
                              Hypergeometric2F1,
                              Editable->True]}],
                          InterpretTemplate[ {
                            SlotSequence[ 1]}&]],
                        Hypergeometric2F1,
                        Editable->False], ";", 
                      TagBox[
                        TagBox[
                          TagBox[
                            RowBox[{"\[Alpha]", "-", "\[Beta]", "+", "1"}],
                            Hypergeometric2F1,
                            Editable->True],
                          InterpretTemplate[ {
                            SlotSequence[ 1]}&]],
                        Hypergeometric2F1,
                        Editable->False], ";", 
                      TagBox[
                        FractionBox["1", "z"],
                        Hypergeometric2F1,
                        Editable->True]}], ")"}]}],
                InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
                Editable->False],
              Hypergeometric2F1], " ", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"-", "z"}], ")"}], 
              RowBox[{"-", "\[Alpha]"}]]}], 
          RowBox[{
            RowBox[{"\[CapitalGamma]", "(", "\[Beta]", ")"}], " ", 
            RowBox[{"\[CapitalGamma]", "(", 
              RowBox[{"\[Gamma]", "-", "\[Alpha]"}], ")"}]}]], "+", 
        FractionBox[
          RowBox[{
            RowBox[{"\[CapitalGamma]", "(", 
              RowBox[{"\[Alpha]", "-", "\[Beta]"}], ")"}], " ", 
            RowBox[{"\[CapitalGamma]", "(", "\[Gamma]", ")"}], " ", 
            TagBox[
              TagBox[
                RowBox[{
                  RowBox[{
                    SubscriptBox["\[InvisiblePrefixScriptBase]", 
                      FormBox["2",
                        "TraditionalForm"]], 
                    SubscriptBox["F", 
                      FormBox["1",
                        "TraditionalForm"]]}], "\[InvisibleApplication]", 
                  RowBox[{"(", 
                    RowBox[{
                      TagBox[
                        TagBox[
                          RowBox[{
                            TagBox["\[Beta]",
                              Hypergeometric2F1,
                              Editable->True], ",", 
                            TagBox[
                              RowBox[{"\[Beta]", "-", "\[Gamma]", "+", "1"}],
                              Hypergeometric2F1,
                              Editable->True]}],
                          InterpretTemplate[ {
                            SlotSequence[ 1]}&]],
                        Hypergeometric2F1,
                        Editable->False], ";", 
                      TagBox[
                        TagBox[
                          TagBox[
                            RowBox[{
                              RowBox[{"-", "\[Alpha]"}], "+", "\[Beta]", "+", 
                              "1"}],
                            Hypergeometric2F1,
                            Editable->True],
                          InterpretTemplate[ {
                            SlotSequence[ 1]}&]],
                        Hypergeometric2F1,
                        Editable->False], ";", 
                      TagBox[
                        FractionBox["1", "z"],
                        Hypergeometric2F1,
                        Editable->True]}], ")"}]}],
                InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
                Editable->False],
              Hypergeometric2F1], " ", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"-", "z"}], ")"}], 
              RowBox[{"-", "\[Beta]"}]]}], 
          RowBox[{
            RowBox[{"\[CapitalGamma]", "(", "\[Alpha]", ")"}], " ", 
            RowBox[{"\[CapitalGamma]", "(", 
              RowBox[{"\[Gamma]", "-", "\[Beta]"}], ")"}]}]]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[859]=  (21:54:38 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"HypergeometricAC", "[", "3", "]"}], "[", 
      RowBox[{"Hypergeometric2F1", "[", 
        RowBox[{"\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]", ",", "z"}], 
        "]"}], "]"}]], "Input",
  CellLabel->"In[860]:=  (21:54:38 on 5/16/01)",
  CellTags->"HypergeometricAC"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{
            RowBox[{"\[CapitalGamma]", "(", 
              RowBox[{"\[Beta]", "-", "\[Alpha]"}], ")"}], " ", 
            RowBox[{"\[CapitalGamma]", "(", "\[Gamma]", ")"}], " ", 
            TagBox[
              TagBox[
                RowBox[{
                  RowBox[{
                    SubscriptBox["\[InvisiblePrefixScriptBase]", 
                      FormBox["2",
                        "TraditionalForm"]], 
                    SubscriptBox["F", 
                      FormBox["1",
                        "TraditionalForm"]]}], "\[InvisibleApplication]", 
                  RowBox[{"(", 
                    RowBox[{
                      TagBox[
                        TagBox[
                          RowBox[{
                            TagBox["\[Alpha]",
                              Hypergeometric2F1,
                              Editable->True], ",", 
                            TagBox[
                              RowBox[{"\[Gamma]", "-", "\[Beta]"}],
                              Hypergeometric2F1,
                              Editable->True]}],
                          InterpretTemplate[ {
                            SlotSequence[ 1]}&]],
                        Hypergeometric2F1,
                        Editable->False], ";", 
                      TagBox[
                        TagBox[
                          TagBox[
                            RowBox[{"\[Alpha]", "-", "\[Beta]", "+", "1"}],
                            Hypergeometric2F1,
                            Editable->True],
                          InterpretTemplate[ {
                            SlotSequence[ 1]}&]],
                        Hypergeometric2F1,
                        Editable->False], ";", 
                      TagBox[
                        FractionBox["1", 
                          RowBox[{"1", "-", "z"}]],
                        Hypergeometric2F1,
                        Editable->True]}], ")"}]}],
                InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
                Editable->False],
              Hypergeometric2F1], " ", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"1", "-", "z"}], ")"}], 
              RowBox[{"-", "\[Alpha]"}]]}], 
          RowBox[{
            RowBox[{"\[CapitalGamma]", "(", "\[Beta]", ")"}], " ", 
            RowBox[{"\[CapitalGamma]", "(", 
              RowBox[{"\[Gamma]", "-", "\[Alpha]"}], ")"}]}]], "+", 
        FractionBox[
          RowBox[{
            RowBox[{"\[CapitalGamma]", "(", 
              RowBox[{"\[Alpha]", "-", "\[Beta]"}], ")"}], " ", 
            RowBox[{"\[CapitalGamma]", "(", "\[Gamma]", ")"}], " ", 
            TagBox[
              TagBox[
                RowBox[{
                  RowBox[{
                    SubscriptBox["\[InvisiblePrefixScriptBase]", 
                      FormBox["2",
                        "TraditionalForm"]], 
                    SubscriptBox["F", 
                      FormBox["1",
                        "TraditionalForm"]]}], "\[InvisibleApplication]", 
                  RowBox[{"(", 
                    RowBox[{
                      TagBox[
                        TagBox[
                          RowBox[{
                            TagBox["\[Beta]",
                              Hypergeometric2F1,
                              Editable->True], ",", 
                            TagBox[
                              RowBox[{"\[Gamma]", "-", "\[Alpha]"}],
                              Hypergeometric2F1,
                              Editable->True]}],
                          InterpretTemplate[ {
                            SlotSequence[ 1]}&]],
                        Hypergeometric2F1,
                        Editable->False], ";", 
                      TagBox[
                        TagBox[
                          TagBox[
                            RowBox[{
                              RowBox[{"-", "\[Alpha]"}], "+", "\[Beta]", "+", 
                              "1"}],
                            Hypergeometric2F1,
                            Editable->True],
                          InterpretTemplate[ {
                            SlotSequence[ 1]}&]],
                        Hypergeometric2F1,
                        Editable->False], ";", 
                      TagBox[
                        FractionBox["1", 
                          RowBox[{"1", "-", "z"}]],
                        Hypergeometric2F1,
                        Editable->True]}], ")"}]}],
                InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
                Editable->False],
              Hypergeometric2F1], " ", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"1", "-", "z"}], ")"}], 
              RowBox[{"-", "\[Beta]"}]]}], 
          RowBox[{
            RowBox[{"\[CapitalGamma]", "(", "\[Alpha]", ")"}], " ", 
            RowBox[{"\[CapitalGamma]", "(", 
              RowBox[{"\[Gamma]", "-", "\[Beta]"}], ")"}]}]]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[860]=  (21:54:38 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"HypergeometricAC", "[", "4", "]"}], "[", 
      RowBox[{"Hypergeometric2F1", "[", 
        RowBox[{"\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]", ",", "z"}], 
        "]"}], "]"}]], "Input",
  CellLabel->"In[861]:=  (21:54:38 on 5/16/01)",
  CellTags->"HypergeometricAC"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{
            RowBox[{"\[CapitalGamma]", "(", "\[Gamma]", ")"}], " ", 
            RowBox[{"\[CapitalGamma]", "(", 
              RowBox[{
                RowBox[{"-", "\[Alpha]"}], "-", "\[Beta]", "+", "\[Gamma]"}], 
              ")"}], " ", 
            TagBox[
              TagBox[
                RowBox[{
                  RowBox[{
                    SubscriptBox["\[InvisiblePrefixScriptBase]", 
                      FormBox["2",
                        "TraditionalForm"]], 
                    SubscriptBox["F", 
                      FormBox["1",
                        "TraditionalForm"]]}], "\[InvisibleApplication]", 
                  RowBox[{"(", 
                    RowBox[{
                      TagBox[
                        TagBox[
                          RowBox[{
                            TagBox["\[Alpha]",
                              Hypergeometric2F1,
                              Editable->True], ",", 
                            TagBox[
                              RowBox[{"\[Alpha]", "-", "\[Gamma]", "+", "1"}],
                              
                              Hypergeometric2F1,
                              Editable->True]}],
                          InterpretTemplate[ {
                            SlotSequence[ 1]}&]],
                        Hypergeometric2F1,
                        Editable->False], ";", 
                      TagBox[
                        TagBox[
                          TagBox[
                            RowBox[{
                            "\[Alpha]", "+", "\[Beta]", "-", "\[Gamma]", "+", 
                              "1"}],
                            Hypergeometric2F1,
                            Editable->True],
                          InterpretTemplate[ {
                            SlotSequence[ 1]}&]],
                        Hypergeometric2F1,
                        Editable->False], ";", 
                      TagBox[
                        RowBox[{"-", 
                          FractionBox[
                            RowBox[{"1", "-", "z"}], "z"]}],
                        Hypergeometric2F1,
                        Editable->True]}], ")"}]}],
                InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
                Editable->False],
              Hypergeometric2F1], " ", 
            SuperscriptBox["z", 
              RowBox[{"-", "\[Alpha]"}]]}], 
          RowBox[{
            RowBox[{"\[CapitalGamma]", "(", 
              RowBox[{"\[Gamma]", "-", "\[Alpha]"}], ")"}], " ", 
            RowBox[{"\[CapitalGamma]", "(", 
              RowBox[{"\[Gamma]", "-", "\[Beta]"}], ")"}]}]], "+", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"1", "-", "z"}], ")"}], 
              RowBox[{
                RowBox[{"-", "\[Alpha]"}], "-", "\[Beta]", "+", "\[Gamma]"}]],
             " ", 
            RowBox[{"\[CapitalGamma]", "(", 
              RowBox[{"\[Alpha]", "+", "\[Beta]", "-", "\[Gamma]"}], ")"}], 
            " ", 
            RowBox[{"\[CapitalGamma]", "(", "\[Gamma]", ")"}], " ", 
            TagBox[
              TagBox[
                RowBox[{
                  RowBox[{
                    SubscriptBox["\[InvisiblePrefixScriptBase]", 
                      FormBox["2",
                        "TraditionalForm"]], 
                    SubscriptBox["F", 
                      FormBox["1",
                        "TraditionalForm"]]}], "\[InvisibleApplication]", 
                  RowBox[{"(", 
                    RowBox[{
                      TagBox[
                        TagBox[
                          RowBox[{
                            TagBox[
                              RowBox[{"\[Gamma]", "-", "\[Alpha]"}],
                              Hypergeometric2F1,
                              Editable->True], ",", 
                            TagBox[
                              RowBox[{"1", "-", "\[Alpha]"}],
                              Hypergeometric2F1,
                              Editable->True]}],
                          InterpretTemplate[ {
                            SlotSequence[ 1]}&]],
                        Hypergeometric2F1,
                        Editable->False], ";", 
                      TagBox[
                        TagBox[
                          TagBox[
                            RowBox[{
                              RowBox[{"-", "\[Alpha]"}], "-", "\[Beta]", "+", 
                              "\[Gamma]", "+", "1"}],
                            Hypergeometric2F1,
                            Editable->True],
                          InterpretTemplate[ {
                            SlotSequence[ 1]}&]],
                        Hypergeometric2F1,
                        Editable->False], ";", 
                      TagBox[
                        RowBox[{"-", 
                          FractionBox[
                            RowBox[{"1", "-", "z"}], "z"]}],
                        Hypergeometric2F1,
                        Editable->True]}], ")"}]}],
                InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
                Editable->False],
              Hypergeometric2F1], " ", 
            SuperscriptBox["z", 
              RowBox[{"\[Alpha]", "-", "\[Gamma]"}]]}], 
          RowBox[{
            RowBox[{"\[CapitalGamma]", "(", "\[Alpha]", ")"}], " ", 
            RowBox[{"\[CapitalGamma]", "(", "\[Beta]", ")"}]}]]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[861]=  (21:54:39 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"HypergeometricAC", "[", "6", "]"}], "[", 
      RowBox[{"Hypergeometric2F1", "[", 
        RowBox[{"\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]", ",", "z"}], 
        "]"}], "]"}]], "Input",
  CellLabel->"In[862]:=  (21:54:39 on 5/16/01)",
  CellTags->"HypergeometricAC"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{"1", "-", "z"}], ")"}], 
          RowBox[{"-", "\[Beta]"}]], " ", 
        TagBox[
          TagBox[
            RowBox[{
              RowBox[{
                SubscriptBox["\[InvisiblePrefixScriptBase]", 
                  FormBox["2",
                    "TraditionalForm"]], 
                SubscriptBox["F", 
                  FormBox["1",
                    "TraditionalForm"]]}], "\[InvisibleApplication]", 
              RowBox[{"(", 
                RowBox[{
                  TagBox[
                    TagBox[
                      RowBox[{
                        TagBox["\[Beta]",
                          Hypergeometric2F1,
                          Editable->True], ",", 
                        TagBox[
                          RowBox[{"\[Gamma]", "-", "\[Alpha]"}],
                          Hypergeometric2F1,
                          Editable->True]}],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    TagBox[
                      TagBox["\[Gamma]",
                        Hypergeometric2F1,
                        Editable->True],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    RowBox[{"-", 
                      FractionBox["z", 
                        RowBox[{"1", "-", "z"}]]}],
                    Hypergeometric2F1,
                    Editable->True]}], ")"}]}],
            InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
            Editable->False],
          Hypergeometric2F1]}], TraditionalForm]], "Output",
  CellLabel->"Out[862]=  (21:54:39 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"HypergeometricAC", "[", "61", "]"}], "[", 
      RowBox[{"Hypergeometric2F1", "[", 
        RowBox[{"\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]", ",", "z"}], 
        "]"}], "]"}]], "Input",
  CellLabel->"In[863]:=  (21:54:39 on 5/16/01)",
  CellTags->"HypergeometricAC"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{"1", "-", "z"}], ")"}], 
          RowBox[{"-", "\[Alpha]"}]], " ", 
        TagBox[
          TagBox[
            RowBox[{
              RowBox[{
                SubscriptBox["\[InvisiblePrefixScriptBase]", 
                  FormBox["2",
                    "TraditionalForm"]], 
                SubscriptBox["F", 
                  FormBox["1",
                    "TraditionalForm"]]}], "\[InvisibleApplication]", 
              RowBox[{"(", 
                RowBox[{
                  TagBox[
                    TagBox[
                      RowBox[{
                        TagBox["\[Alpha]",
                          Hypergeometric2F1,
                          Editable->True], ",", 
                        TagBox[
                          RowBox[{"\[Gamma]", "-", "\[Beta]"}],
                          Hypergeometric2F1,
                          Editable->True]}],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    TagBox[
                      TagBox["\[Gamma]",
                        Hypergeometric2F1,
                        Editable->True],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    RowBox[{"-", 
                      FractionBox["z", 
                        RowBox[{"1", "-", "z"}]]}],
                    Hypergeometric2F1,
                    Editable->True]}], ")"}]}],
            InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
            Editable->False],
          Hypergeometric2F1]}], TraditionalForm]], "Output",
  CellLabel->"Out[863]=  (21:54:39 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["HypergeometricIR", "ObjectName",
  CellTags->"HypergeometricIR"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"HypergeometricIR"],

Cell["\<\
HypergeometricIR[exp, t] substitutes for all Hypergeometric2F1[a,b,c,z] in \
exp by its Euler integral reprentation. The factor Integratedx[t, 0, 1] can \
be omitted by setting the option Integratedx \[Rule] False.\
\>", "Text",
  CellTags->"HypergeometricIR"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["HypergeometricAC",
    ButtonData:>"HypergeometricAC",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"HypergeometricAC"],
  ", ",
  ButtonBox["HypergeometricSE",
    ButtonData:>"HypergeometricSE",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"HypergeometricSE"],
  ", ",
  ButtonBox["ToHypergeometric",
    ButtonData:>"ToHypergeometric",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"ToHypergeometric"],
  "."
}], "Text",
  CellTags->"HypergeometricIR"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "HypergeometricIR", "]"}]], "Input",
  CellLabel->"In[864]:=  (21:54:39 on 5/16/01)",
  CellTags->"HypergeometricIR"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"Integratedx", "\[Rule]", "False"}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[864]=  (21:54:39 on 5/16/01)"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"HypergeometricIR"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"HypergeometricIR", "[", 
      RowBox[{
        RowBox[{"Hypergeometric2F1", "[", 
          RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], ",", "t"}], 
      "]"}]], "Input",
  CellLabel->"In[865]:=  (21:54:39 on 5/16/01)",
  CellTags->"HypergeometricIR"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"1", "-", "t"}], ")"}], 
            RowBox[{
              RowBox[{"-", "b"}], "+", "c", "-", "1"}]], " ", 
          SuperscriptBox["t", 
            RowBox[{"b", "-", "1"}]], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"1", "-", 
                RowBox[{"t", " ", "z"}]}], ")"}], 
            RowBox[{"-", "a"}]], " ", 
          RowBox[{"\[CapitalGamma]", "(", "c", ")"}]}], 
        RowBox[{
          RowBox[{"\[CapitalGamma]", "(", "b", ")"}], " ", 
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"c", "-", "b"}], ")"}]}]], TraditionalForm]], "Output",
  CellLabel->"Out[865]=  (21:54:40 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ToHypergeometric", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"t", "^", "b"}], " ", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"1", "-", "t"}], ")"}], "^", "c"}], " ", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"t", " ", "z"}]}], ")"}], "^", "a"}]}], ",", "t"}], 
      "]"}]], "Input",
  CellLabel->"In[866]:=  (21:54:40 on 5/16/01)",
  CellTags->"HypergeometricIR"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"b", "+", "1"}], ")"}], " ", 
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"c", "+", "1"}], ")"}], " ", 
          TagBox[
            TagBox[
              RowBox[{
                RowBox[{
                  SubscriptBox["\[InvisiblePrefixScriptBase]", 
                    FormBox["2",
                      "TraditionalForm"]], 
                  SubscriptBox["F", 
                    FormBox["1",
                      "TraditionalForm"]]}], "\[InvisibleApplication]", 
                RowBox[{"(", 
                  RowBox[{
                    TagBox[
                      TagBox[
                        RowBox[{
                          TagBox[
                            RowBox[{"-", "a"}],
                            Hypergeometric2F1,
                            Editable->True], ",", 
                          TagBox[
                            RowBox[{"b", "+", "1"}],
                            Hypergeometric2F1,
                            Editable->True]}],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      TagBox[
                        TagBox[
                          RowBox[{"b", "+", "c", "+", "2"}],
                          Hypergeometric2F1,
                          Editable->True],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      RowBox[{"-", "z"}],
                      Hypergeometric2F1,
                      Editable->True]}], ")"}]}],
              InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
              Editable->False],
            Hypergeometric2F1]}], 
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"b", "+", "c", "+", "2"}], ")"}]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[866]=  (21:54:40 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"HypergeometricIR", "[", 
      RowBox[{"%", ",", "t"}], "]"}]], "Input",
  CellLabel->"In[867]:=  (21:54:40 on 5/16/01)",
  CellTags->"HypergeometricIR"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{"1", "-", "t"}], ")"}], "c"], " ", 
        SuperscriptBox["t", "b"], " ", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              RowBox[{"t", " ", "z"}], "+", "1"}], ")"}], "a"]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[867]=  (21:54:40 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["HypergeometricSE", "ObjectName",
  CellTags->"HypergeometricSE"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"HypergeometricSE"],

Cell[TextData[{
  "HypergeometricSE[exp, ",
  Cell[BoxData[
      FormBox["\[Nu]", TraditionalForm]]],
  "] expresses Hypergeometric functions by their series expansion in terms of \
a sum (the Sum is omitted and ",
  Cell[BoxData[
      FormBox["\[Nu]", TraditionalForm]]],
  ", running from 0 to ",
  Cell[BoxData[
      FormBox["\[Infinity]", TraditionalForm]]],
  ", is the summation index)."
}], "Text",
  CellTags->"HypergeometricSE"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "HypergeometricSE", "]"}]], "Input",
  CellLabel->"In[868]:=  (21:54:40 on 5/16/01)",
  CellTags->"HypergeometricSE"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"Simplify", "\[Rule]", "FullSimplify"}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[868]=  (21:54:40 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["HypergeometricIR",
    ButtonData:>"HypergeometricIR",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"HypergeometricIR"],
  "."
}], "Text",
  CellTags->"HypergeometricSE"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"HypergeometricSE"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"HypergeometricSE", "[", 
      RowBox[{
        RowBox[{"Hypergeometric2F1", "[", 
          RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], ",", "\[Nu]"}], 
      "]"}]], "Input",
  CellLabel->"In[869]:=  (21:54:40 on 5/16/01)",
  CellTags->"HypergeometricSE"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{
          SuperscriptBox["z", "\[Nu]"], " ", 
          RowBox[{"\[CapitalGamma]", "(", "c", ")"}], " ", 
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"a", "+", "\[Nu]"}], ")"}], " ", 
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"b", "+", "\[Nu]"}], ")"}]}], 
        RowBox[{
          RowBox[{"\[CapitalGamma]", "(", "a", ")"}], " ", 
          RowBox[{"\[CapitalGamma]", "(", "b", ")"}], " ", 
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"\[Nu]", "+", "1"}], ")"}], " ", 
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"c", "+", "\[Nu]"}], ")"}]}]], TraditionalForm]], "Output",\

  CellLabel->"Out[869]=  (21:54:41 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"HypergeometricSE", "[", 
      RowBox[{
        RowBox[{"HypergeometricPFQ", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"a", ",", "b", ",", "c"}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"d", ",", "e"}], "}"}], ",", "z"}], "]"}], ",", 
        "\[Nu]"}], "]"}]], "Input",
  CellLabel->"In[870]:=  (21:54:41 on 5/16/01)",
  CellTags->"HypergeometricSE"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{
          SuperscriptBox["z", "\[Nu]"], " ", 
          RowBox[{"\[CapitalGamma]", "(", "d", ")"}], " ", 
          RowBox[{"\[CapitalGamma]", "(", "e", ")"}], " ", 
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"a", "+", "\[Nu]"}], ")"}], " ", 
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"b", "+", "\[Nu]"}], ")"}], " ", 
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"c", "+", "\[Nu]"}], ")"}]}], 
        RowBox[{
          RowBox[{"\[CapitalGamma]", "(", "a", ")"}], " ", 
          RowBox[{"\[CapitalGamma]", "(", "b", ")"}], " ", 
          RowBox[{"\[CapitalGamma]", "(", "c", ")"}], " ", 
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"\[Nu]", "+", "1"}], ")"}], " ", 
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"d", "+", "\[Nu]"}], ")"}], " ", 
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"e", "+", "\[Nu]"}], ")"}]}]], TraditionalForm]], "Output",\

  CellLabel->"Out[870]=  (21:54:41 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["HypExplicit", "ObjectName",
  CellTags->"HypExplicit"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"HypExplicit"],

Cell[TextData[{
  "HypExplicit[exp, ",
  Cell[BoxData[
      FormBox["\[Nu]", TraditionalForm]]],
  "] expresses Hypergeometric functions in exp by their definition in terms \
of a sum (the Sum is omitted and ",
  Cell[BoxData[
      FormBox["\[Nu]", TraditionalForm]]],
  " is the summation index)."
}], "Text",
  CellTags->"HypExplicit"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["HypergeometricIR",
    ButtonData:>"HypergeometricIR",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"HypergeometricIR"],
  "."
}], "Text",
  CellTags->"HypExplicit"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"HypExplicit"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Hypergeometric2F1", "[", 
      RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}]], "Input",
  CellLabel->"In[871]:=  (21:54:41 on 5/16/01)",
  CellTags->"HypExplicit"],

Cell[BoxData[
    FormBox[
      TagBox[
        TagBox[
          RowBox[{
            RowBox[{
              SubscriptBox["\[InvisiblePrefixScriptBase]", 
                FormBox["2",
                  "TraditionalForm"]], 
              SubscriptBox["F", 
                FormBox["1",
                  "TraditionalForm"]]}], "\[InvisibleApplication]", 
            RowBox[{"(", 
              RowBox[{
                TagBox[
                  TagBox[
                    RowBox[{
                      TagBox["a",
                        Hypergeometric2F1,
                        Editable->True], ",", 
                      TagBox["b",
                        Hypergeometric2F1,
                        Editable->True]}],
                    InterpretTemplate[ {
                      SlotSequence[ 1]}&]],
                  Hypergeometric2F1,
                  Editable->False], ";", 
                TagBox[
                  TagBox[
                    TagBox["c",
                      Hypergeometric2F1,
                      Editable->True],
                    InterpretTemplate[ {
                      SlotSequence[ 1]}&]],
                  Hypergeometric2F1,
                  Editable->False], ";", 
                TagBox["z",
                  Hypergeometric2F1,
                  Editable->True]}], ")"}]}],
          InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
          Editable->False],
        Hypergeometric2F1], TraditionalForm]], "Output",
  CellLabel->"Out[871]=  (21:54:41 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"HypExplicit", "[", 
      RowBox[{"%", ",", "\[Nu]"}], "]"}]], "Input",
  CellLabel->"In[872]:=  (21:54:42 on 5/16/01)",
  CellTags->"HypExplicit"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{
          SuperscriptBox["z", "\[Nu]"], " ", 
          RowBox[{"\[CapitalGamma]", "(", "c", ")"}], " ", 
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"a", "+", "\[Nu]"}], ")"}], " ", 
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"b", "+", "\[Nu]"}], ")"}]}], 
        RowBox[{
          RowBox[{"\[CapitalGamma]", "(", "a", ")"}], " ", 
          RowBox[{"\[CapitalGamma]", "(", "b", ")"}], " ", 
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"\[Nu]", "+", "1"}], ")"}], " ", 
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"c", "+", "\[Nu]"}], ")"}]}]], TraditionalForm]], "Output",\

  CellLabel->"Out[872]=  (21:54:42 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"HypergeometricPFQ", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"a", ",", "b", ",", "c"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"d", ",", "e"}], "}"}], ",", "z"}], "]"}]], "Input",
  CellLabel->"In[873]:=  (21:54:42 on 5/16/01)",
  CellTags->"HypExplicit"],

Cell[BoxData[
    FormBox[
      TagBox[
        TagBox[
          RowBox[{
            RowBox[{
              SubscriptBox["\[InvisiblePrefixScriptBase]", 
                FormBox["3",
                  "TraditionalForm"]], 
              SubscriptBox["F", 
                FormBox["2",
                  "TraditionalForm"]]}], "\[InvisibleApplication]", 
            RowBox[{"(", 
              RowBox[{
                TagBox[
                  TagBox[
                    RowBox[{
                      TagBox["a",
                        HypergeometricPFQ,
                        Editable->True], ",", 
                      TagBox["b",
                        HypergeometricPFQ,
                        Editable->True], ",", 
                      TagBox["c",
                        HypergeometricPFQ,
                        Editable->True]}],
                    InterpretTemplate[ {
                      SlotSequence[ 1]}&]],
                  HypergeometricPFQ,
                  Editable->False], ";", 
                TagBox[
                  TagBox[
                    RowBox[{
                      TagBox["d",
                        HypergeometricPFQ,
                        Editable->True], ",", 
                      TagBox["e",
                        HypergeometricPFQ,
                        Editable->True]}],
                    InterpretTemplate[ {
                      SlotSequence[ 1]}&]],
                  HypergeometricPFQ,
                  Editable->False], ";", 
                TagBox["z",
                  HypergeometricPFQ,
                  Editable->True]}], ")"}]}],
          InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
          Editable->False],
        HypergeometricPFQ], TraditionalForm]], "Output",
  CellLabel->"Out[873]=  (21:54:42 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"HypExplicit", "[", 
      RowBox[{"%", ",", "\[Nu]"}], "]"}]], "Input",
  CellLabel->"In[874]:=  (21:54:42 on 5/16/01)",
  CellTags->"HypExplicit"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{
          SuperscriptBox["z", "\[Nu]"], " ", 
          RowBox[{"\[CapitalGamma]", "(", "d", ")"}], " ", 
          RowBox[{"\[CapitalGamma]", "(", "e", ")"}], " ", 
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"a", "+", "\[Nu]"}], ")"}], " ", 
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"b", "+", "\[Nu]"}], ")"}], " ", 
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"c", "+", "\[Nu]"}], ")"}]}], 
        RowBox[{
          RowBox[{"\[CapitalGamma]", "(", "a", ")"}], " ", 
          RowBox[{"\[CapitalGamma]", "(", "b", ")"}], " ", 
          RowBox[{"\[CapitalGamma]", "(", "c", ")"}], " ", 
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"\[Nu]", "+", "1"}], ")"}], " ", 
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"d", "+", "\[Nu]"}], ")"}], " ", 
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"e", "+", "\[Nu]"}], ")"}]}]], TraditionalForm]], "Output",\

  CellLabel->"Out[874]=  (21:54:42 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Integrate2", "ObjectName",
  CellTags->"Integrate2"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"Integrate2"],

Cell[TextData[{
  "Integrate2 is like Integrate, but : Integrate2[a_Plus, b__] := \
Map[Integrate2[#, b]&, a] ( more linear algebra and partial fraction \
decomposition is done) Integrate2[f[x] DeltaFunction[x], x] \[Rule] f[0] \
Integrate2[f[x] DeltaFunction[x0-x], x] \[Rule] f[x0]. Integrate2[f[x] \
DeltaFunction[a + b x], x] \[Rule] Integrate[f[x] (1/Abs[b]) \
DeltaFunction[a/b + x], x], where abs[b] \[Rule] b, if b is a Symbol, and if \
b = -c, then abs[-c] \[Rule] c, i.e., the variable contained in b is supposed \
to be positive. ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          SuperscriptBox["\[Pi]", "2"]}], TraditionalForm]]],
  " is replaced by 6 Zeta2. Integrate2[1/(1-y),{y,x,1}] is intepreted as \
distribution, i.e. as Integrate2[-1/(1-y)],{y, 0, x}] \[Rule] Log[1-y]. \
Integrate2[1/(1-x),{x,0,1}] \[Rule] 0."
}], "Text",
  CellTags->"Integrate2"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["DeltaFunction",
    ButtonData:>"DeltaFunction",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DeltaFunction"],
  ", ",
  ButtonBox["Integrate3",
    ButtonData:>"Integrate3",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Integrate3"],
  ", ",
  ButtonBox["SumS",
    ButtonData:>"SumS",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SumS"],
  ", ",
  ButtonBox["SumT",
    ButtonData:>"SumT",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SumT"],
  "."
}], "Text",
  CellTags->"Integrate2"],

Cell["\<\
NOTE: Since Integrate2 does do a reordering and partial fraction \
decomposition before calling the integral table of Integrate3 it will in \
general be slower compared to Integrate3 for sums of integrals. I.e., if the \
integrand has already an expanded form and if partial fraction decomposition \
is not necessary it is more effective to use Integrate3.\
\>", "Text",
  CellTags->"Integrate2"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"Integrate2"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Integrate2", "[", 
        RowBox[{
          RowBox[{
            RowBox[{"Log", "[", 
              RowBox[{"1", "+", "x"}], "]"}], 
            RowBox[{
              RowBox[{"Log", "[", "x", "]"}], "/", 
              RowBox[{"(", 
                RowBox[{"1", "-", "x"}], ")"}]}]}], ",", 
          RowBox[{"{", 
            RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}], "//", 
      "Timing"}]], "Input",
  CellLabel->"In[875]:=  (21:54:42 on 5/16/01)",
  CellTags->"Integrate2"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"0.09000000000000341`", " ", "Second"}], ",", 
          RowBox[{
            TagBox[
              RowBox[{"\[Zeta]", "(", 
                TagBox["3",
                  (Editable -> True)], ")"}],
              InterpretTemplate[ Zeta[ #]&]], "-", 
            RowBox[{
              FractionBox["3", "2"], " ", 
              RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
              RowBox[{"log", "(", "2", ")"}]}]}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[875]=  (21:54:42 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "Since Integrate2 uses table-look-up methods it is much faster than ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s Integrate."
}], "Text",
  CellTags->"Integrate2"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Integrate2", "[", 
      RowBox[{
        RowBox[{"PolyLog", "[", 
          RowBox[{"2", ",", 
            RowBox[{"x", "^", "2"}]}], "]"}], ",", 
        RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[876]:=  (21:54:42 on 5/16/01)",
  CellTags->"Integrate2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[Zeta]", "(", "2", ")"}], "+", 
        RowBox[{"4", " ", 
          RowBox[{"log", "(", "2", ")"}]}], "-", "4"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[876]=  (21:54:42 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Integrate2", "[", 
      RowBox[{
        RowBox[{"PolyLog", "[", 
          RowBox[{"3", ",", 
            RowBox[{"-", "x"}]}], "]"}], ",", 
        RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[877]:=  (21:54:42 on 5/16/01)",
  CellTags->"Integrate2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{"\[Zeta]", "(", "2", ")"}], "2"], "-", 
        FractionBox[
          RowBox[{"3", " ", 
            TagBox[
              RowBox[{"\[Zeta]", "(", 
                TagBox["3",
                  (Editable -> True)], ")"}],
              InterpretTemplate[ Zeta[ #]&]]}], "4"], "-", 
        RowBox[{"2", " ", 
          RowBox[{"log", "(", "2", ")"}]}], "+", "1"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[877]=  (21:54:43 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Integrate2", "[", 
      RowBox[{
        RowBox[{"PolyLog", "[", 
          RowBox[{"3", ",", 
            RowBox[{"1", "/", 
              RowBox[{"(", 
                RowBox[{"1", "+", "x"}], ")"}]}]}], "]"}], ",", 
        RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[878]:=  (21:54:43 on 5/16/01)",
  CellTags->"Integrate2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"-", 
            RowBox[{"log", "(", "2", ")"}]}], " ", 
          RowBox[{"\[Zeta]", "(", "2", ")"}]}], "+", 
        FractionBox[
          RowBox[{"3", " ", 
            TagBox[
              RowBox[{"\[Zeta]", "(", 
                TagBox["3",
                  (Editable -> True)], ")"}],
              InterpretTemplate[ Zeta[ #]&]]}], "4"], "+", 
        FractionBox[
          RowBox[{
            SuperscriptBox["log", "3"], "(", "2", ")"}], "3"], "-", 
        RowBox[{
          SuperscriptBox["log", "2"], "(", "2", ")"}], "+", 
        RowBox[{"2", " ", 
          RowBox[{"log", "(", "2", ")"}]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[878]=  (21:54:43 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Integrate2", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"DeltaFunction", "[", 
            RowBox[{"1", "-", "x"}], "]"}], " ", 
          RowBox[{"f", "[", "x", "]"}]}], ",", 
        RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[879]:=  (21:54:43 on 5/16/01)",
  CellTags->"Integrate2"],

Cell[BoxData[
    FormBox[
      RowBox[{"f", "(", "1", ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[879]=  (21:54:43 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "Integrate2 does integration in a Hadamard sense, i.e., ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubsuperscriptBox["\[Integral]", "0", "1"], 
          RowBox[{
            RowBox[{"f", "(", "x", ")"}], 
            RowBox[{"\[DifferentialD]", "x"}]}], " "}], TraditionalForm]]],
  " means acutally expanding the result of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubsuperscriptBox["\[Integral]", "\[Delta]", 
            RowBox[{"1", "-", "\[Delta]"}]], 
          RowBox[{
            RowBox[{"f", "(", "x", ")"}], 
            RowBox[{"\[DifferentialD]", "x"}]}], " "}], TraditionalForm]]],
  "up do ",
  Cell[BoxData[
      FormBox[
        RowBox[{"O", "(", "\[Delta]", ")"}], TraditionalForm]]],
  " and neglecting all ",
  Cell[BoxData[
      FormBox["\[Delta]", TraditionalForm]]],
  "-dependent terms. E.g. ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              SubsuperscriptBox["\[Integral]", "\[Delta]", 
                RowBox[{"1", "-", "\[Delta]"}]], 
              RowBox[{
                RowBox[{"1", "/", 
                  RowBox[{"(", 
                    RowBox[{"1", "-", "x"}], ")"}]}], 
                RowBox[{"\[DifferentialD]", "x"}]}]}], " ", "=", " ", 
            RowBox[{
              RowBox[{
                RowBox[{
                  RowBox[{"-", "log"}], 
                  RowBox[{"(", 
                    RowBox[{"1", "-", "x"}], ")"}]}], 
                SubsuperscriptBox["\[VerticalSeparator]", "\[Delta]", 
                  RowBox[{"1", "-", "\[Delta]"}]]}], "=", 
              RowBox[{
                RowBox[{
                  RowBox[{"-", 
                    RowBox[{"log", "(", "\[Delta]", ")"}]}], "+", 
                  RowBox[{"log", "(", "1", ")"}]}], "\[Implies]", "0."}]}]}], 
          " "}], TraditionalForm]]]
}], "Text",
  ZeroWidthTimes->False,
  CellTags->"Integrate2"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Integrate2", "[", 
      RowBox[{
        RowBox[{"1", "/", 
          RowBox[{"(", 
            RowBox[{"1", "-", "x"}], ")"}]}], ",", 
        RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[880]:=  (21:54:43 on 5/16/01)",
  CellTags->"Integrate2"],

Cell[BoxData[
    FormBox["0", TraditionalForm]], "Output",
  CellLabel->"Out[880]=  (21:54:43 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "In the physics literature sometimes the \"+\" notation is used. In \
FeynCalc the ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          RowBox[{"(", 
            FractionBox["1", 
              RowBox[{"1", "-", "x"}]], ")"}], "+"], TraditionalForm]]],
  " is represented by ",
  Cell[BoxData[
      FormBox[
        RowBox[{"PlusDistribution", "[", 
          RowBox[{"1", "/", 
            RowBox[{"(", 
              RowBox[{"1", "-", "x"}], ")"}]}], "]"}], TraditionalForm]]],
  " or just ",
  Cell[BoxData[
      FormBox[
        RowBox[{"1", "/", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"1", "-", "x"}], ")"}], " ", "."}]}], 
        TraditionalForm]]]
}], "Text",
  CellTags->"Integrate2"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Integrate2", "[", 
      RowBox[{
        RowBox[{"PlusDistribution", "[", 
          RowBox[{"1", "/", 
            RowBox[{"(", 
              RowBox[{"1", "-", "x"}], ")"}]}], "]"}], ",", 
        RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[881]:=  (21:54:43 on 5/16/01)",
  CellTags->"Integrate2"],

Cell[BoxData[
    FormBox["0", TraditionalForm]], "Output",
  CellLabel->"Out[881]=  (21:54:43 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Integrate2", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"PolyLog", "[", 
            RowBox[{"2", ",", 
              RowBox[{"1", "-", "x"}]}], "]"}], "/", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"1", "-", "x"}], ")"}], "^", "2"}]}], ",", 
        RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[882]:=  (21:54:43 on 5/16/01)",
  CellTags->"Integrate2"],

Cell[BoxData[
    FormBox[
      RowBox[{"2", "-", 
        RowBox[{"\[Zeta]", "(", "2", ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[882]=  (21:54:43 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Integrate2", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"Log", "[", "x", "]"}], " ", 
              RowBox[{"Log", "[", 
                RowBox[{"1", "+", "x"}], "]"}]}], ")"}], "/", 
          RowBox[{"(", 
            RowBox[{"1", "+", "x"}], ")"}]}], ",", 
        RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[883]:=  (21:54:43 on 5/16/01)",
  CellTags->"Integrate2"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        FractionBox[
          TagBox[
            RowBox[{"\[Zeta]", "(", 
              TagBox["3",
                (Editable -> True)], ")"}],
            InterpretTemplate[ Zeta[ #]&]], "8"]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[883]=  (21:54:43 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Integrate2", "[", 
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{"Log", "[", "x", "]"}], "^", "2"}], "/", 
          RowBox[{"(", 
            RowBox[{"1", "-", "x"}], ")"}]}], ",", 
        RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[884]:=  (21:54:43 on 5/16/01)",
  CellTags->"Integrate2"],

Cell[BoxData[
    FormBox[
      RowBox[{"2", " ", 
        TagBox[
          RowBox[{"\[Zeta]", "(", 
            TagBox["3",
              (Editable -> True)], ")"}],
          InterpretTemplate[ Zeta[ #]&]]}], TraditionalForm]], "Output",
  CellLabel->"Out[884]=  (21:54:43 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Integrate2", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"PolyLog", "[", 
            RowBox[{"2", ",", 
              RowBox[{"-", "x"}]}], "]"}], "/", 
          RowBox[{"(", 
            RowBox[{"1", "+", "x"}], ")"}]}], ",", 
        RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[885]:=  (21:54:44 on 5/16/01)",
  CellTags->"Integrate2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          TagBox[
            RowBox[{"\[Zeta]", "(", 
              TagBox["3",
                (Editable -> True)], ")"}],
            InterpretTemplate[ Zeta[ #]&]], "4"], "-", 
        RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
          RowBox[{"log", "(", "2", ")"}]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[885]=  (21:54:44 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Integrate2", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"Log", "[", "x", "]"}], " ", 
          RowBox[{"PolyLog", "[", 
            RowBox[{"2", ",", "x"}], "]"}]}], ",", 
        RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[886]:=  (21:54:44 on 5/16/01)",
  CellTags->"Integrate2"],

Cell[BoxData[
    FormBox[
      RowBox[{"3", "-", 
        RowBox[{"2", " ", 
          RowBox[{"\[Zeta]", "(", "2", ")"}]}]}], TraditionalForm]], "Output",\

  CellLabel->"Out[886]=  (21:54:44 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Integrate2", "[", 
      RowBox[{
        RowBox[{"x", " ", 
          RowBox[{"PolyLog", "[", 
            RowBox[{"3", ",", "x"}], "]"}]}], ",", 
        RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[887]:=  (21:54:44 on 5/16/01)",
  CellTags->"Integrate2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          FractionBox[
            RowBox[{"\[Zeta]", "(", "2", ")"}], "4"]}], "+", 
        FractionBox[
          TagBox[
            RowBox[{"\[Zeta]", "(", 
              TagBox["3",
                (Editable -> True)], ")"}],
            InterpretTemplate[ Zeta[ #]&]], "2"], "+", 
        FractionBox["3", "16"]}], TraditionalForm]], "Output",
  CellLabel->"Out[887]=  (21:54:44 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Integrate2", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"Log", "[", "x", "]"}], "^", "2"}], " ", 
              RowBox[{"Log", "[", 
                RowBox[{"1", "-", "x"}], "]"}]}], ")"}], "/", 
          RowBox[{"(", 
            RowBox[{"1", "+", "x"}], ")"}]}], ",", 
        RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[888]:=  (21:54:44 on 5/16/01)",
  CellTags->"Integrate2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            SuperscriptBox["log", "2"], "(", "2", ")"}], " ", 
          RowBox[{"\[Zeta]", "(", "2", ")"}]}], "-", 
        RowBox[{"4", " ", 
          RowBox[{
            SubscriptBox["Li", "4"], "(", 
            FractionBox["1", "2"], ")"}]}], "-", 
        FractionBox[
          RowBox[{
            SuperscriptBox["log", "4"], "(", "2", ")"}], "6"], "+", 
        FractionBox[
          SuperscriptBox["\[Pi]", "4"], "90"]}], TraditionalForm]], "Output",
  CellLabel->"Out[888]=  (21:54:44 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Integrate2", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"PolyLog", "[", 
            RowBox[{"2", ",", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{"x", " ", 
                          RowBox[{"(", 
                            RowBox[{"1", "-", "z"}], ")"}]}], "+", "z"}], 
                      ")"}], " ", 
                    RowBox[{"(", 
                      RowBox[{"1", "-", "x", "+", 
                        RowBox[{"x", " ", "z"}]}], ")"}]}], ")"}], "/", 
                "z"}]}], "]"}], "/", 
          RowBox[{"(", 
            RowBox[{"1", "-", "x", "+", 
              RowBox[{"x", " ", "z"}]}], ")"}]}], ",", 
        RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[889]:=  (21:54:44 on 5/16/01)",
  CellTags->"Integrate2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{
            SuperscriptBox["log", "3"], "(", "z", ")"}], 
          RowBox[{"6", " ", 
            RowBox[{"(", 
              RowBox[{"1", "-", "z"}], ")"}]}]], "-", 
        FractionBox[
          RowBox[{
            RowBox[{"log", "(", 
              RowBox[{"1", "-", "z"}], ")"}], " ", 
            RowBox[{
              SuperscriptBox["log", "2"], "(", "z", ")"}]}], 
          RowBox[{"1", "-", "z"}]], "-", 
        FractionBox[
          RowBox[{
            RowBox[{"log", "(", 
              RowBox[{"z", "+", "1"}], ")"}], " ", 
            RowBox[{
              SuperscriptBox["log", "2"], "(", "z", ")"}]}], 
          RowBox[{"1", "-", "z"}]], "-", 
        FractionBox[
          RowBox[{"\[ImaginaryI]", " ", "\[Pi]", " ", 
            RowBox[{
              SuperscriptBox["log", "2"], "(", "z", ")"}]}], 
          RowBox[{"2", " ", 
            RowBox[{"(", 
              RowBox[{"1", "-", "z"}], ")"}]}]], "-", 
        FractionBox[
          RowBox[{
            RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
            RowBox[{"log", "(", "z", ")"}]}], 
          RowBox[{"1", "-", "z"}]], "+", 
        FractionBox[
          RowBox[{"4", " ", 
            RowBox[{"log", "(", 
              RowBox[{"1", "-", "z"}], ")"}], " ", 
            RowBox[{"log", "(", 
              RowBox[{"z", "+", "1"}], ")"}], " ", 
            RowBox[{"log", "(", "z", ")"}]}], 
          RowBox[{"1", "-", "z"}]], "+", 
        FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]", " ", 
            RowBox[{"log", "(", 
              RowBox[{"z", "+", "1"}], ")"}], " ", 
            RowBox[{"log", "(", "z", ")"}]}], 
          RowBox[{"1", "-", "z"}]], "-", 
        FractionBox[
          RowBox[{"2", " ", 
            RowBox[{
              SubscriptBox["Li", "2"], "(", 
              RowBox[{"1", "-", "z"}], ")"}], " ", 
            RowBox[{"log", "(", "z", ")"}]}], 
          RowBox[{"1", "-", "z"}]], "-", 
        FractionBox[
          RowBox[{"2", " ", 
            RowBox[{
              SubscriptBox["Li", "2"], "(", 
              RowBox[{"-", "z"}], ")"}], " ", 
            RowBox[{"log", "(", "z", ")"}]}], 
          RowBox[{"1", "-", "z"}]], "-", 
        FractionBox[
          RowBox[{"2", " ", 
            RowBox[{
              SuperscriptBox["log", "3"], "(", 
              RowBox[{"z", "+", "1"}], ")"}]}], 
          RowBox[{"3", " ", 
            RowBox[{"(", 
              RowBox[{"1", "-", "z"}], ")"}]}]], "+", 
        FractionBox[
          RowBox[{"\[ImaginaryI]", " ", "\[Pi]", " ", 
            RowBox[{"\[Zeta]", "(", "2", ")"}]}], 
          RowBox[{"1", "-", "z"}]], "+", 
        FractionBox[
          RowBox[{"2", " ", 
            RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
            RowBox[{"log", "(", 
              RowBox[{"1", "-", "z"}], ")"}]}], 
          RowBox[{"1", "-", "z"}]], "+", 
        FractionBox[
          RowBox[{"2", " ", 
            RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
            RowBox[{"log", "(", 
              RowBox[{"z", "+", "1"}], ")"}]}], 
          RowBox[{"1", "-", "z"}]], "-", 
        FractionBox[
          RowBox[{"2", " ", 
            RowBox[{
              SubscriptBox["S", 
                RowBox[{
                  FormBox["1",
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox["2",
                    "TraditionalForm"]}]], "(", 
              FormBox[
                RowBox[{"1", "-", "z"}],
                "TraditionalForm"], ")"}]}], 
          RowBox[{"1", "-", "z"}]], "+", 
        FractionBox[
          RowBox[{"4", " ", 
            RowBox[{"log", "(", 
              RowBox[{"1", "-", "z"}], ")"}], " ", 
            RowBox[{
              SubscriptBox["Li", "2"], "(", 
              RowBox[{"-", "z"}], ")"}]}], 
          RowBox[{"1", "-", "z"}]], "+", 
        FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]", " ", 
            RowBox[{
              SubscriptBox["Li", "2"], "(", 
              RowBox[{"-", "z"}], ")"}]}], 
          RowBox[{"1", "-", "z"}]], "+", 
        FractionBox[
          RowBox[{"4", " ", 
            RowBox[{
              SubscriptBox["Li", "3"], "(", 
              RowBox[{"1", "-", "z"}], ")"}]}], 
          RowBox[{"1", "-", "z"}]], "+", 
        FractionBox[
          RowBox[{"2", " ", 
            RowBox[{
              SubscriptBox["Li", "3"], "(", 
              RowBox[{"-", "z"}], ")"}]}], 
          RowBox[{"1", "-", "z"}]], "+", 
        FractionBox[
          RowBox[{"4", " ", 
            RowBox[{
              SubscriptBox["Li", "3"], "(", 
              FractionBox["1", 
                RowBox[{"z", "+", "1"}]], ")"}]}], 
          RowBox[{"1", "-", "z"}]], "+", 
        FractionBox[
          RowBox[{"4", " ", 
            RowBox[{
              SubscriptBox["Li", "3"], "(", 
              RowBox[{"-", 
                FractionBox[
                  RowBox[{"1", "-", "z"}], 
                  RowBox[{"z", "+", "1"}]]}], ")"}]}], 
          RowBox[{"1", "-", "z"}]], "-", 
        FractionBox[
          RowBox[{"4", " ", 
            RowBox[{
              SubscriptBox["Li", "3"], "(", 
              FractionBox[
                RowBox[{"1", "-", "z"}], 
                RowBox[{"z", "+", "1"}]], ")"}]}], 
          RowBox[{"1", "-", "z"}]], "-", 
        FractionBox[
          RowBox[{"2", " ", 
            TagBox[
              RowBox[{"\[Zeta]", "(", 
                TagBox["3",
                  (Editable -> True)], ")"}],
              InterpretTemplate[ Zeta[ #]&]]}], 
          RowBox[{"1", "-", "z"}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[889]=  (21:54:45 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Apart", "[", 
      RowBox[{
        RowBox[{"Integrate2", "[", 
          RowBox[{
            RowBox[{
              RowBox[{"x", "^", 
                RowBox[{"(", 
                  RowBox[{"OPEm", "-", "1"}], ")"}]}], " ", 
              RowBox[{"PolyLog", "[", 
                RowBox[{"3", ",", 
                  RowBox[{"1", "-", "x"}]}], "]"}]}], ",", 
            RowBox[{"{", 
              RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}], ",", 
        "OPEm"}], "]"}]], "Input",
  CellLabel->"In[890]:=  (21:54:45 on 5/16/01)",
  CellTags->"Integrate2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          FractionBox[
            RowBox[{"\[Zeta]", "(", "2", ")"}], 
            RowBox[{"m", "-", "1"}]]}], "-", 
        FractionBox[
          RowBox[{"\[Zeta]", "(", "2", ")"}], 
          SuperscriptBox["m", "2"]], "+", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                RowBox[{
                  SubscriptBox["S", "1"], "(", 
                  FormBox[
                    RowBox[{"m", "-", "2"}],
                    "TraditionalForm"], ")"}]}], " ", 
              RowBox[{"\[Zeta]", "(", "2", ")"}]}], "+", 
            RowBox[{"\[Zeta]", "(", "2", ")"}], "+", 
            RowBox[{
              SubscriptBox["S", "12"], "(", 
              FormBox["m",
                "TraditionalForm"], ")"}], "+", 
            TagBox[
              RowBox[{"\[Zeta]", "(", 
                TagBox["3",
                  (Editable -> True)], ")"}],
              InterpretTemplate[ Zeta[ #]&]]}], "m"]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[890]=  (21:54:46 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Integrate2", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"x", "^", 
            RowBox[{"(", 
              RowBox[{"OPEm", "-", "1"}], ")"}]}], " ", 
          RowBox[{"Log", "[", 
            RowBox[{"1", "-", "x"}], "]"}], " ", 
          RowBox[{"Log", "[", "x", "]"}], " ", 
          FractionBox[
            RowBox[{"Log", "[", 
              RowBox[{"1", "+", "x"}], "]"}], 
            RowBox[{"1", "+", "x"}]]}], ",", 
        RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[891]:=  (21:54:46 on 5/16/01)",
  CellTags->"Integrate2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox["1", "4"], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "m"], " ", 
          RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
          RowBox[{
            SubsuperscriptBox["S", 
              RowBox[{"-", "1"}], "2"], "(", 
            FormBox[
              RowBox[{"m", "-", "1"}],
              "TraditionalForm"], ")"}]}], "+", 
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "m"], " ", 
          RowBox[{"log", "(", "2", ")"}], " ", 
          RowBox[{
            SubscriptBox["S", 
              RowBox[{"-", "2"}]], "(", 
            FormBox[
              RowBox[{"m", "-", "1"}],
              "TraditionalForm"], ")"}], " ", 
          RowBox[{
            SubscriptBox["S", 
              RowBox[{"-", "1"}]], "(", 
            FormBox[
              RowBox[{"m", "-", "1"}],
              "TraditionalForm"], ")"}]}], "-", 
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "m"], " ", 
          TagBox[
            RowBox[{"\[Zeta]", "(", 
              TagBox["3",
                (Editable -> True)], ")"}],
            InterpretTemplate[ Zeta[ #]&]], " ", 
          RowBox[{
            SubscriptBox["S", 
              RowBox[{"-", "1"}]], "(", 
            FormBox[
              RowBox[{"m", "-", "1"}],
              "TraditionalForm"], ")"}]}], "+", 
        RowBox[{
          FractionBox["3", "2"], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "m"], " ", 
          RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
          RowBox[{"log", "(", "2", ")"}], " ", 
          RowBox[{
            SubscriptBox["S", 
              RowBox[{"-", "1"}]], "(", 
            FormBox[
              RowBox[{"m", "-", "1"}],
              "TraditionalForm"], ")"}]}], "-", 
        RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "m"], " ", 
          RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
          RowBox[{
            SubscriptBox["S", 
              RowBox[{"-", "2"}]], "(", 
            FormBox[
              RowBox[{"m", "-", "1"}],
              "TraditionalForm"], ")"}]}], "+", 
        RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "m"], " ", 
          RowBox[{
            SuperscriptBox["log", "2"], "(", "2", ")"}], " ", 
          RowBox[{
            SubscriptBox["S", 
              RowBox[{"-", "2"}]], "(", 
            FormBox[
              RowBox[{"m", "-", "1"}],
              "TraditionalForm"], ")"}]}], "-", 
        RowBox[{
          FractionBox["3", "2"], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "m"], " ", 
          RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
          RowBox[{"log", "(", "2", ")"}], " ", 
          RowBox[{
            SubscriptBox["S", "1"], "(", 
            FormBox[
              RowBox[{"m", "-", "1"}],
              "TraditionalForm"], ")"}]}], "+", 
        RowBox[{
          FractionBox["3", "4"], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "m"], " ", 
          RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
          RowBox[{
            SubscriptBox["S", "2"], "(", 
            FormBox[
              RowBox[{"m", "-", "1"}],
              "TraditionalForm"], ")"}]}], "-", 
        RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "m"], " ", 
          RowBox[{
            SuperscriptBox["log", "2"], "(", "2", ")"}], " ", 
          RowBox[{
            SubscriptBox["S", "2"], "(", 
            FormBox[
              RowBox[{"m", "-", "1"}],
              "TraditionalForm"], ")"}]}], "+", 
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "m"], " ", 
          RowBox[{"log", "(", "2", ")"}], " ", 
          RowBox[{
            SubscriptBox["S", "3"], "(", 
            FormBox[
              RowBox[{"m", "-", "1"}],
              "TraditionalForm"], ")"}]}], "-", 
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "m"], " ", 
          RowBox[{"log", "(", "2", ")"}], " ", 
          RowBox[{
            SubscriptBox["S", 
              RowBox[{"-", "21"}]], "(", 
            FormBox[
              RowBox[{"m", "-", "1"}],
              "TraditionalForm"], ")"}]}], "-", 
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "m"], " ", 
          RowBox[{"log", "(", "2", ")"}], " ", 
          RowBox[{
            SubscriptBox["S", 
              RowBox[{"-", "12"}]], "(", 
            FormBox[
              RowBox[{"m", "-", "1"}],
              "TraditionalForm"], ")"}]}], "-", 
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "m"], " ", 
          RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
          RowBox[{
            SubscriptBox["S", 
              RowBox[{"1", "-", "1"}]], "(", 
            FormBox[
              RowBox[{"m", "-", "1"}],
              "TraditionalForm"], ")"}]}], "+", 
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "m"], " ", 
          RowBox[{
            SubscriptBox["S", 
              RowBox[{
                RowBox[{"-", "2"}], "-", "1", "-", "1"}]], "(", 
            FormBox[
              RowBox[{"m", "-", "1"}],
              "TraditionalForm"], ")"}]}], "+", 
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "m"], " ", 
          RowBox[{
            SubscriptBox["S", 
              RowBox[{
                RowBox[{"-", "1"}], "-", "2", "-", "1"}]], "(", 
            FormBox[
              RowBox[{"m", "-", "1"}],
              "TraditionalForm"], ")"}]}], "+", 
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "m"], " ", 
          RowBox[{
            SubscriptBox["S", 
              RowBox[{
                RowBox[{"-", "1"}], "-", "1", "-", "2"}]], "(", 
            FormBox[
              RowBox[{"m", "-", "1"}],
              "TraditionalForm"], ")"}]}], "+", 
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "m"], " ", 
          RowBox[{
            SubscriptBox["S", 
              RowBox[{"1", "-", "21"}]], "(", 
            FormBox[
              RowBox[{"m", "-", "1"}],
              "TraditionalForm"], ")"}]}], "+", 
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "m"], " ", 
          RowBox[{
            SubscriptBox["S", 
              RowBox[{"1", "-", "12"}]], "(", 
            FormBox[
              RowBox[{"m", "-", "1"}],
              "TraditionalForm"], ")"}]}], "+", 
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "m"], " ", 
          RowBox[{
            SubscriptBox["S", 
              RowBox[{"2", "-", "11"}]], "(", 
            FormBox[
              RowBox[{"m", "-", "1"}],
              "TraditionalForm"], ")"}]}], "+", 
        RowBox[{
          FractionBox["13", "8"], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "m"], " ", 
          RowBox[{
            SubscriptBox["S", "1"], "(", 
            FormBox[
              RowBox[{"m", "-", "1"}],
              "TraditionalForm"], ")"}], " ", 
          TagBox[
            RowBox[{"\[Zeta]", "(", 
              TagBox["3",
                (Editable -> True)], ")"}],
            InterpretTemplate[ Zeta[ #]&]]}], "-", 
        RowBox[{
          FractionBox["21", "8"], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "m"], " ", 
          RowBox[{"log", "(", "2", ")"}], " ", 
          TagBox[
            RowBox[{"\[Zeta]", "(", 
              TagBox["3",
                (Editable -> True)], ")"}],
            InterpretTemplate[ Zeta[ #]&]]}], "-", 
        RowBox[{"2", " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "m"], " ", 
          RowBox[{
            SubscriptBox["Li", "4"], "(", 
            FractionBox["1", "2"], ")"}]}], "-", 
        RowBox[{
          FractionBox["1", "12"], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "m"], " ", 
          RowBox[{
            SuperscriptBox["log", "4"], "(", "2", ")"}]}], "+", 
        RowBox[{
          FractionBox["5", "4"], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "m"], " ", 
          RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
          RowBox[{
            SuperscriptBox["log", "2"], "(", "2", ")"}]}], "+", 
        RowBox[{
          FractionBox["1", "45"], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "m"], " ", 
          SuperscriptBox["\[Pi]", "4"]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[891]=  (21:54:46 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", " ", "/.", " ", 
      RowBox[{"OPEm", "\[Rule]", "2"}]}]], "Input",
  CellLabel->"In[892]:=  (21:54:46 on 5/16/01)",
  CellTags->"Integrate2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox["5", "4"], " ", 
          RowBox[{
            SuperscriptBox["log", "2"], "(", "2", ")"}], " ", 
          RowBox[{"\[Zeta]", "(", "2", ")"}]}], "-", 
        RowBox[{"3", " ", 
          RowBox[{"log", "(", "2", ")"}], " ", 
          RowBox[{"\[Zeta]", "(", "2", ")"}]}], "+", 
        FractionBox[
          RowBox[{"5", " ", 
            RowBox[{"\[Zeta]", "(", "2", ")"}]}], "2"], "-", 
        RowBox[{
          FractionBox["21", "8"], " ", 
          RowBox[{"log", "(", "2", ")"}], " ", 
          TagBox[
            RowBox[{"\[Zeta]", "(", 
              TagBox["3",
                (Editable -> True)], ")"}],
            InterpretTemplate[ Zeta[ #]&]]}], "+", 
        FractionBox[
          RowBox[{"21", " ", 
            TagBox[
              RowBox[{"\[Zeta]", "(", 
                TagBox["3",
                  (Editable -> True)], ")"}],
              InterpretTemplate[ Zeta[ #]&]]}], "8"], "-", 
        RowBox[{"2", " ", 
          RowBox[{
            SubscriptBox["Li", "4"], "(", 
            FractionBox["1", "2"], ")"}]}], "-", 
        FractionBox[
          RowBox[{
            SuperscriptBox["log", "4"], "(", "2", ")"}], "12"], "-", 
        RowBox[{
          SuperscriptBox["log", "2"], "(", "2", ")"}], "+", 
        RowBox[{"4", " ", 
          RowBox[{"log", "(", "2", ")"}]}], "+", 
        FractionBox[
          SuperscriptBox["\[Pi]", "4"], "45"], "-", "6"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[892]=  (21:54:46 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"N", "[", "%", "]"}]], "Input",
  CellLabel->"In[893]:=  (21:54:47 on 5/16/01)",
  CellTags->"Integrate2"],

Cell[BoxData[
    FormBox["0.050513835402744345`", TraditionalForm]], "Output",
  CellLabel->"Out[893]=  (21:54:47 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NIntegrate", "[", 
      RowBox[{
        RowBox[{"x", " ", 
          RowBox[{"Log", "[", 
            RowBox[{"1", "-", "x"}], "]"}], " ", 
          RowBox[{"Log", "[", "x", "]"}], " ", 
          FractionBox[
            RowBox[{"Log", "[", 
              RowBox[{"1", "+", "x"}], "]"}], 
            RowBox[{"1", "+", "x"}]]}], ",", 
        RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[894]:=  (21:54:47 on 5/16/01)",
  CellTags->"Integrate2"],

Cell[BoxData[
    FormBox["0.050513835398271964`", TraditionalForm]], "Output",
  CellLabel->"Out[894]=  (21:54:47 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Integrate2", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"x", "^", 
            RowBox[{"(", 
              RowBox[{"OPEm", "-", "1"}], ")"}]}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"PolyLog", "[", 
                RowBox[{"3", ",", 
                  FractionBox[
                    RowBox[{"1", "-", "x"}], 
                    RowBox[{"1", "+", "x"}]]}], "]"}], "-", 
              RowBox[{"PolyLog", "[", 
                RowBox[{"3", ",", 
                  RowBox[{"-", 
                    FractionBox[
                      RowBox[{"1", "-", "x"}], 
                      RowBox[{"1", "+", "x"}]]}]}], "]"}]}], ")"}]}], ",", 
        RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[895]:=  (21:54:47 on 5/16/01)",
  CellTags->"Integrate2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "m"], " ", 
            RowBox[{
              SubscriptBox["S", 
                RowBox[{"-", "1"}]], "(", 
              FormBox["m",
                "TraditionalForm"], ")"}], " ", 
            RowBox[{"\[Zeta]", "(", "2", ")"}]}], "m"], "-", 
        FractionBox[
          RowBox[{
            RowBox[{
              SubscriptBox["S", 
                RowBox[{"-", "1"}]], "(", 
              FormBox["m",
                "TraditionalForm"], ")"}], " ", 
            RowBox[{"\[Zeta]", "(", "2", ")"}]}], 
          RowBox[{"2", " ", "m"}]], "+", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "m"], " ", 
            RowBox[{
              SubscriptBox["S", "1"], "(", 
              FormBox["m",
                "TraditionalForm"], ")"}], " ", 
            RowBox[{"\[Zeta]", "(", "2", ")"}]}], 
          RowBox[{"2", " ", "m"}]], "-", 
        FractionBox[
          RowBox[{
            RowBox[{
              SubscriptBox["S", "1"], "(", 
              FormBox["m",
                "TraditionalForm"], ")"}], " ", 
            RowBox[{"\[Zeta]", "(", "2", ")"}]}], "m"], "+", 
        FractionBox[
          RowBox[{"3", " ", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "m"], " ", 
            RowBox[{"log", "(", "2", ")"}], " ", 
            RowBox[{"\[Zeta]", "(", "2", ")"}]}], 
          RowBox[{"2", " ", "m"}]], "-", 
        FractionBox[
          RowBox[{"3", " ", 
            RowBox[{"log", "(", "2", ")"}], " ", 
            RowBox[{"\[Zeta]", "(", "2", ")"}]}], 
          RowBox[{"2", " ", "m"}]], "+", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "m"], " ", 
            RowBox[{
              SubscriptBox["S", 
                RowBox[{"-", "3"}]], "(", 
              FormBox["m",
                "TraditionalForm"], ")"}]}], "m"], "+", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "m"], " ", 
            RowBox[{
              SubscriptBox["S", 
                RowBox[{"-", "2"}]], "(", 
              FormBox["m",
                "TraditionalForm"], ")"}], " ", 
            RowBox[{
              SubscriptBox["S", "1"], "(", 
              FormBox["m",
                "TraditionalForm"], ")"}]}], "m"], "+", 
        FractionBox[
          RowBox[{
            RowBox[{
              SubscriptBox["S", "1"], "(", 
              FormBox["m",
                "TraditionalForm"], ")"}], " ", 
            RowBox[{
              SubscriptBox["S", "2"], "(", 
              FormBox["m",
                "TraditionalForm"], ")"}]}], "m"], "+", 
        FractionBox[
          RowBox[{
            SubscriptBox["S", "3"], "(", 
            FormBox["m",
              "TraditionalForm"], ")"}], "m"], "-", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "m"], " ", 
            RowBox[{
              SubscriptBox["S", 
                RowBox[{"-", "21"}]], "(", 
              FormBox["m",
                "TraditionalForm"], ")"}]}], "m"], "-", 
        FractionBox[
          RowBox[{
            SubscriptBox["S", 
              RowBox[{
                RowBox[{"-", "1"}], "-", "2"}]], "(", 
            FormBox["m",
              "TraditionalForm"], ")"}], "m"], "-", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "m"], " ", 
            RowBox[{
              SubscriptBox["S", 
                RowBox[{"-", "12"}]], "(", 
              FormBox["m",
                "TraditionalForm"], ")"}]}], "m"], "-", 
        FractionBox[
          RowBox[{
            SubscriptBox["S", "21"], "(", 
            FormBox["m",
              "TraditionalForm"], ")"}], "m"], "-", 
        FractionBox[
          RowBox[{"7", " ", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "m"], " ", 
            TagBox[
              RowBox[{"\[Zeta]", "(", 
                TagBox["3",
                  (Editable -> True)], ")"}],
              InterpretTemplate[ Zeta[ #]&]]}], 
          RowBox[{"8", " ", "m"}]], "+", 
        FractionBox[
          RowBox[{"21", " ", 
            TagBox[
              RowBox[{"\[Zeta]", "(", 
                TagBox["3",
                  (Editable -> True)], ")"}],
              InterpretTemplate[ Zeta[ #]&]]}], 
          RowBox[{"8", " ", "m"}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[895]=  (21:54:48 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DataType", "[", 
      RowBox[{"OPEm", ",", "PositiveInteger"}], "]"}]], "Input",
  CellLabel->"In[896]:=  (21:54:48 on 5/16/01)",
  CellTags->"Integrate2"],

Cell[BoxData[
    FormBox["True", TraditionalForm]], "Output",
  CellLabel->"Out[896]=  (21:54:48 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Integrate2", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"x", "^", 
            RowBox[{"(", 
              RowBox[{"OPEm", "-", "1"}], ")"}]}], " ", 
          RowBox[{"DeltaFunction", "[", 
            RowBox[{"1", "-", "x"}], "]"}]}], ",", 
        RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[897]:=  (21:54:48 on 5/16/01)",
  CellTags->"Integrate2"],

Cell[BoxData[
    FormBox["1", TraditionalForm]], "Output",
  CellLabel->"Out[897]=  (21:54:48 on 5/16/01)"]
}, Closed]],

Cell["\<\
This is the polarized non-singlet spin splitting function whose first moment \
vanishes.\
\>", "Text",
  CellTags->"Integrate2"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t", "=", 
      RowBox[{"SplittingFunction", "[", "PQQNS", "]"}]}]], "Input",
  CellLabel->"In[898]:=  (21:54:48 on 5/16/01)",
  CellTags->"Integrate2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"-", "4"}], " ", 
                RowBox[{"(", 
                  RowBox[{"x", "+", "1"}], ")"}], " ", 
                RowBox[{
                  SuperscriptBox["log", "2"], "(", "x", ")"}]}], "-", 
              RowBox[{"8", " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"2", " ", "x"}], "+", 
                    FractionBox["3", 
                      RowBox[{"1", "-", "x"}]]}], ")"}], " ", 
                RowBox[{"log", "(", "x", ")"}]}], "-", 
              FractionBox[
                RowBox[{"16", " ", 
                  RowBox[{"(", 
                    RowBox[{
                      SuperscriptBox["x", "2"], "+", "1"}], ")"}], " ", 
                  RowBox[{"log", "(", 
                    RowBox[{"1", "-", "x"}], ")"}], " ", 
                  RowBox[{"log", "(", "x", ")"}]}], 
                RowBox[{"1", "-", "x"}]], "-", 
              RowBox[{"40", " ", 
                RowBox[{"(", 
                  RowBox[{"1", "-", "x"}], ")"}]}], "+", 
              RowBox[{
                RowBox[{"\[Delta]", "(", 
                  FormBox[
                    RowBox[{"1", "-", "x"}],
                    "TraditionalForm"], ")"}], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      RowBox[{"-", "24"}], " ", 
                      RowBox[{"\[Zeta]", "(", "2", ")"}]}], "+", 
                    RowBox[{"48", " ", 
                      TagBox[
                        RowBox[{"\[Zeta]", "(", 
                          TagBox["3",
                            (Editable -> True)], ")"}],
                        InterpretTemplate[ Zeta[ #]&]]}], "+", "3"}], 
                  ")"}]}]}], ")"}], " ", 
          SubsuperscriptBox["C", "F", "2"]}], "+", 
        RowBox[{
          SubscriptBox["N", "f"], " ", 
          RowBox[{"(", 
            RowBox[{
              FractionBox[
                RowBox[{"88", " ", "x"}], "9"], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"-", 
                      FractionBox[
                        RowBox[{"16", " ", 
                          RowBox[{"\[Zeta]", "(", "2", ")"}]}], "3"]}], "-", 
                    FractionBox["2", "3"]}], ")"}], " ", 
                RowBox[{"\[Delta]", "(", 
                  FormBox[
                    RowBox[{"1", "-", "x"}],
                    "TraditionalForm"], ")"}]}], "-", 
              FractionBox[
                RowBox[{"8", " ", 
                  RowBox[{"(", 
                    RowBox[{
                      SuperscriptBox["x", "2"], "+", "1"}], ")"}], " ", 
                  RowBox[{"log", "(", "x", ")"}]}], 
                RowBox[{"3", " ", 
                  RowBox[{"(", 
                    RowBox[{"1", "-", "x"}], ")"}]}]], "-", 
              RowBox[{
                FractionBox["80", "9"], " ", 
                SubscriptBox[
                  RowBox[{"(", 
                    FractionBox["1", 
                      RowBox[{"1", "-", "x"}]], ")"}], "+"]}], "-", 
              FractionBox["8", "9"]}], ")"}], " ", 
          SubscriptBox["C", "F"]}], "-", 
        RowBox[{"8", " ", 
          RowBox[{"(", 
            RowBox[{
              SubscriptBox["C", "F"], "-", 
              FractionBox[
                SubscriptBox["C", "A"], "2"]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"4", " ", 
                RowBox[{"(", 
                  RowBox[{"1", "-", "x"}], ")"}]}], "+", 
              RowBox[{"2", " ", 
                RowBox[{"(", 
                  RowBox[{"x", "+", "1"}], ")"}], " ", 
                RowBox[{"log", "(", "x", ")"}]}], "+", 
              FractionBox[
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      SuperscriptBox["x", "2"], "+", "1"}], ")"}], " ", 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox["log", "2"], "(", "x", ")"}], "-", 
                      RowBox[{"4", " ", 
                        RowBox[{"log", "(", 
                          RowBox[{"x", "+", "1"}], ")"}], " ", 
                        RowBox[{"log", "(", "x", ")"}]}], "-", 
                      RowBox[{"2", " ", 
                        RowBox[{"\[Zeta]", "(", "2", ")"}]}], "-", 
                      RowBox[{"4", " ", 
                        RowBox[{
                          SubscriptBox["Li", "2"], "(", 
                          RowBox[{"-", "x"}], ")"}]}]}], ")"}]}], 
                RowBox[{"x", "+", "1"}]]}], ")"}], " ", 
          SubscriptBox["C", "F"]}], "+", 
        RowBox[{
          SubscriptBox["C", "A"], " ", 
          RowBox[{"(", 
            RowBox[{
              FractionBox[
                RowBox[{"4", " ", 
                  RowBox[{"(", 
                    RowBox[{
                      SuperscriptBox["x", "2"], "+", "1"}], ")"}], " ", 
                  RowBox[{
                    SuperscriptBox["log", "2"], "(", "x", ")"}]}], 
                RowBox[{"1", "-", "x"}]], "-", 
              RowBox[{
                FractionBox["4", "3"], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"5", " ", "x"}], "-", 
                    FractionBox["22", 
                      RowBox[{"1", "-", "x"}]], "+", "5"}], ")"}], " ", 
                RowBox[{"log", "(", "x", ")"}]}], "+", 
              RowBox[{
                FractionBox["4", "9"], " ", 
                RowBox[{"(", 
                  RowBox[{"53", "-", 
                    RowBox[{"187", " ", "x"}]}], ")"}]}], "+", 
              RowBox[{"8", " ", 
                RowBox[{"(", 
                  RowBox[{"x", "+", "1"}], ")"}], " ", 
                RowBox[{"\[Zeta]", "(", "2", ")"}]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    FractionBox["536", "9"], "-", 
                    RowBox[{"16", " ", 
                      RowBox[{"\[Zeta]", "(", "2", ")"}]}]}], ")"}], " ", 
                SubscriptBox[
                  RowBox[{"(", 
                    FractionBox["1", 
                      RowBox[{"1", "-", "x"}]], ")"}], "+"]}], "+", 
              RowBox[{
                RowBox[{"\[Delta]", "(", 
                  FormBox[
                    RowBox[{"1", "-", "x"}],
                    "TraditionalForm"], ")"}], " ", 
                RowBox[{"(", 
                  RowBox[{
                    FractionBox[
                      RowBox[{"88", " ", 
                        RowBox[{"\[Zeta]", "(", "2", ")"}]}], "3"], "-", 
                    RowBox[{"24", " ", 
                      TagBox[
                        RowBox[{"\[Zeta]", "(", 
                          TagBox["3",
                            (Editable -> True)], ")"}],
                        InterpretTemplate[ Zeta[ #]&]]}], "+", 
                    FractionBox["17", "3"]}], ")"}]}]}], ")"}], " ", 
          SubscriptBox["C", "F"]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[898]=  (21:54:49 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Integrate2", "[", 
        RowBox[{"t", ",", 
          RowBox[{"{", 
            RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}], "//", 
      "Timing"}]], "Input",
  CellLabel->"In[899]:=  (21:54:49 on 5/16/01)",
  CellTags->"Integrate2"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"1.0109999999999957`", " ", "Second"}], ",", "0"}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[899]=  (21:54:50 on 5/16/01)"]
}, Closed]],

Cell["\<\
Expanding t with respect to x yields a form already suitable for Integrate3 \
and therefore the following is faster:\
\>", "Text",
  CellTags->"Integrate2"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"Integrate3", "[", 
          RowBox[{
            RowBox[{"Expand", "[", 
              RowBox[{"t", ",", "x"}], "]"}], ",", 
            RowBox[{"{", 
              RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}], "//", 
        "Expand"}], "//", "Timing"}]], "Input",
  CellLabel->"In[900]:=  (21:54:50 on 5/16/01)",
  CellTags->"Integrate2"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"0.18999999999999773`", " ", "Second"}], ",", "0"}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[900]=  (21:54:50 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      RowBox[{"Clear", "[", "t", "]"}], ";"}]], "Input",
  CellLabel->"In[901]:=  (21:54:50 on 5/16/01)",
  CellTags->"Integrate2"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Integrate2", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"DeltaFunction", "[", 
            RowBox[{"1", "-", "x"}], "]"}], " ", 
          RowBox[{"f", "[", "x", "]"}]}], ",", 
        RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[902]:=  (21:54:56 on 5/16/01)",
  CellTags->"Integrate2"],

Cell[BoxData[
    FormBox[
      RowBox[{"f", "(", "1", ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[902]=  (21:54:56 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Integrate2", "[", 
      RowBox[{
        RowBox[{
          SuperscriptBox["x", "5"], 
          RowBox[{
            RowBox[{"Log", "[", 
              RowBox[{"1", "+", "x"}], "]"}], "^", "2"}]}], ",", 
        RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[903]:=  (21:54:56 on 5/16/01)",
  CellTags->"Integrate2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          FractionBox["6959", "10800"]}], "+", 
        FractionBox[
          RowBox[{"46", " ", 
            RowBox[{"log", "(", "2", ")"}]}], "45"]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[903]=  (21:54:56 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"N", "@", "%"}]], "Input",
  CellLabel->"In[904]:=  (21:54:56 on 5/16/01)",
  CellTags->"Integrate2"],

Cell[BoxData[
    FormBox["0.06419859938720329`", TraditionalForm]], "Output",
  CellLabel->"Out[904]=  (21:54:56 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NIntegrate", "[", 
      RowBox[{
        RowBox[{
          SuperscriptBox["x", "5"], 
          RowBox[{
            RowBox[{"Log", "[", 
              RowBox[{"1", "+", "x"}], "]"}], "^", "2"}]}], ",", 
        RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[905]:=  (21:54:56 on 5/16/01)",
  CellTags->"Integrate2"],

Cell[BoxData[
    FormBox["0.06419859938720235`", TraditionalForm]], "Output",
  CellLabel->"Out[905]=  (21:54:56 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Integrate2", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"x", "^", 
            RowBox[{"(", 
              RowBox[{"OPEm", "-", "1"}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"Log", "[", 
              RowBox[{"1", "+", "x"}], "]"}], "2"]}], ",", 
        RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[906]:=  (21:54:57 on 5/16/01)",
  CellTags->"Integrate2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          FractionBox[
            RowBox[{"2", " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"-", "1"}], ")"}], "m"], " ", 
              RowBox[{
                SubsuperscriptBox["S", "1", "2"], "(", 
                FormBox["m",
                  "TraditionalForm"], ")"}]}], "m"]}], "+", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "m"], " ", 
            RowBox[{
              SubscriptBox["S", "1"], "(", 
              FormBox[
                FractionBox[
                  RowBox[{"m", "-", "1"}], "2"],
                "TraditionalForm"], ")"}], " ", 
            RowBox[{
              SubscriptBox["S", "1"], "(", 
              FormBox["m",
                "TraditionalForm"], ")"}]}], "m"], "-", 
        FractionBox[
          RowBox[{
            RowBox[{
              SubscriptBox["S", "1"], "(", 
              FormBox[
                FractionBox[
                  RowBox[{"m", "-", "1"}], "2"],
                "TraditionalForm"], ")"}], " ", 
            RowBox[{
              SubscriptBox["S", "1"], "(", 
              FormBox["m",
                "TraditionalForm"], ")"}]}], "m"], "+", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "m"], " ", 
            RowBox[{
              SubscriptBox["S", "1"], "(", 
              FormBox[
                FractionBox["m", "2"],
                "TraditionalForm"], ")"}], " ", 
            RowBox[{
              SubscriptBox["S", "1"], "(", 
              FormBox["m",
                "TraditionalForm"], ")"}]}], "m"], "+", 
        FractionBox[
          RowBox[{
            RowBox[{
              SubscriptBox["S", "1"], "(", 
              FormBox[
                FractionBox["m", "2"],
                "TraditionalForm"], ")"}], " ", 
            RowBox[{
              SubscriptBox["S", "1"], "(", 
              FormBox["m",
                "TraditionalForm"], ")"}]}], "m"], "+", 
        FractionBox[
          RowBox[{"4", " ", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "m"], " ", 
            RowBox[{"log", "(", "2", ")"}], " ", 
            RowBox[{
              SubscriptBox["S", "1"], "(", 
              FormBox["m",
                "TraditionalForm"], ")"}]}], "m"], "-", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "m"], " ", 
            RowBox[{"log", "(", "2", ")"}], " ", 
            RowBox[{
              SubscriptBox["S", "1"], "(", 
              FormBox[
                FractionBox[
                  RowBox[{"m", "-", "1"}], "2"],
                "TraditionalForm"], ")"}]}], "m"], "+", 
        FractionBox[
          RowBox[{
            RowBox[{"log", "(", "2", ")"}], " ", 
            RowBox[{
              SubscriptBox["S", "1"], "(", 
              FormBox[
                FractionBox[
                  RowBox[{"m", "-", "1"}], "2"],
                "TraditionalForm"], ")"}]}], "m"], "-", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "m"], " ", 
            RowBox[{"log", "(", "2", ")"}], " ", 
            RowBox[{
              SubscriptBox["S", "1"], "(", 
              FormBox[
                FractionBox["m", "2"],
                "TraditionalForm"], ")"}]}], "m"], "-", 
        FractionBox[
          RowBox[{
            RowBox[{"log", "(", "2", ")"}], " ", 
            RowBox[{
              SubscriptBox["S", "1"], "(", 
              FormBox[
                FractionBox["m", "2"],
                "TraditionalForm"], ")"}]}], "m"], "+", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "m"], " ", 
            RowBox[{
              SubscriptBox["S", "2"], "(", 
              FormBox[
                FractionBox[
                  RowBox[{"m", "-", "1"}], "2"],
                "TraditionalForm"], ")"}]}], 
          RowBox[{"2", " ", "m"}]], "-", 
        FractionBox[
          RowBox[{
            SubscriptBox["S", "2"], "(", 
            FormBox[
              FractionBox[
                RowBox[{"m", "-", "1"}], "2"],
              "TraditionalForm"], ")"}], 
          RowBox[{"2", " ", "m"}]], "+", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "m"], " ", 
            RowBox[{
              SubscriptBox["S", "2"], "(", 
              FormBox[
                FractionBox["m", "2"],
                "TraditionalForm"], ")"}]}], 
          RowBox[{"2", " ", "m"}]], "+", 
        FractionBox[
          RowBox[{
            SubscriptBox["S", "2"], "(", 
            FormBox[
              FractionBox["m", "2"],
              "TraditionalForm"], ")"}], 
          RowBox[{"2", " ", "m"}]], "-", 
        FractionBox[
          RowBox[{"2", " ", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "m"], " ", 
            RowBox[{
              SubscriptBox["S", "2"], "(", 
              FormBox["m",
                "TraditionalForm"], ")"}]}], "m"], "-", 
        FractionBox[
          RowBox[{"2", " ", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "m"], " ", 
            RowBox[{
              SubscriptBox["S", 
                RowBox[{"-", "11"}]], "(", 
              FormBox["m",
                "TraditionalForm"], ")"}]}], "m"], "-", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "m"], " ", 
            RowBox[{
              SuperscriptBox["log", "2"], "(", "2", ")"}]}], "m"], "+", 
        FractionBox[
          RowBox[{
            SuperscriptBox["log", "2"], "(", "2", ")"}], "m"]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[906]=  (21:54:57 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Integrate3", "ObjectName",
  CellTags->"Integrate3"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"Integrate3"],

Cell["\<\
Integrate3 contains the integral table used by Integrate2. Integration is \
performed in a distributional sense. Integrate3 works more effectively on a \
sum of expressions if they are expanded or collected with respect to the \
integration variable. See the examples in Integrate2.\
\>", "Text",
  CellTags->"Integrate3"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["Integrate2",
    ButtonData:>"Integrate2",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Integrate2"],
  "."
}], "Text",
  CellTags->"Integrate3"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"Integrate3"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Integrate3", "[", 
      RowBox[{
        RowBox[{
          SuperscriptBox["x", "OPEm"], " ", 
          RowBox[{"Log", "[", "x", "]"}]}], ",", 
        RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[907]:=  (21:54:57 on 5/16/01)",
  CellTags->"Integrate3"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        FractionBox["1", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"m", "+", "1"}], ")"}], "2"]]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[907]=  (21:54:57 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Integrate3", "[", 
      RowBox[{
        FractionBox[
          RowBox[{
            SuperscriptBox["x", "OPEm"], " ", 
            RowBox[{"Log", "[", "x", "]"}], " ", 
            RowBox[{"Log", "[", 
              RowBox[{"1", "-", "x"}], "]"}]}], 
          RowBox[{"1", "-", "x"}]], ",", 
        RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[908]:=  (21:54:57 on 5/16/01)",
  CellTags->"Integrate3"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
          RowBox[{
            SubscriptBox["S", "1"], "(", 
            FormBox["m",
              "TraditionalForm"], ")"}]}], "-", 
        RowBox[{
          SubscriptBox["S", "12"], "(", 
          FormBox["m",
            "TraditionalForm"], ")"}], "-", 
        RowBox[{
          SubscriptBox["S", "21"], "(", 
          FormBox["m",
            "TraditionalForm"], ")"}], "+", 
        TagBox[
          RowBox[{"\[Zeta]", "(", 
            TagBox["3",
              (Editable -> True)], ")"}],
          InterpretTemplate[ Zeta[ #]&]]}], TraditionalForm]], "Output",
  CellLabel->"Out[908]=  (21:54:57 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Integrate3", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"a", 
            FractionBox[
              RowBox[{
                SuperscriptBox["x", "OPEm"], " ", 
                RowBox[{"Log", "[", "x", "]"}], " ", 
                RowBox[{"Log", "[", 
                  RowBox[{"1", "-", "x"}], "]"}]}], 
              RowBox[{"1", "-", "x"}]]}], "+", 
          RowBox[{"b", 
            FractionBox[
              RowBox[{
                SuperscriptBox["x", "OPEm"], 
                RowBox[{"PolyLog", "[", 
                  RowBox[{"3", ",", 
                    RowBox[{"-", "x"}]}], "]"}]}], 
              RowBox[{"1", "+", "x"}]]}]}], ",", 
        RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[909]:=  (21:54:57 on 5/16/01)",
  CellTags->"Integrate3"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"a", " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
                RowBox[{
                  SubscriptBox["S", "1"], "(", 
                  FormBox["m",
                    "TraditionalForm"], ")"}]}], "-", 
              RowBox[{
                SubscriptBox["S", "12"], "(", 
                FormBox["m",
                  "TraditionalForm"], ")"}], "-", 
              RowBox[{
                SubscriptBox["S", "21"], "(", 
                FormBox["m",
                  "TraditionalForm"], ")"}], "+", 
              TagBox[
                RowBox[{"\[Zeta]", "(", 
                  TagBox["3",
                    (Editable -> True)], ")"}],
                InterpretTemplate[ Zeta[ #]&]]}], ")"}]}], "+", 
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "m"], " ", "b", " ", 
          RowBox[{"(", 
            RowBox[{
              FractionBox[
                SuperscriptBox[
                  RowBox[{"\[Zeta]", "(", "2", ")"}], "2"], "8"], "+", 
              RowBox[{
                FractionBox["1", "2"], " ", 
                RowBox[{
                  SubscriptBox["S", 
                    RowBox[{"-", "2"}]], "(", 
                  FormBox["m",
                    "TraditionalForm"], ")"}], " ", 
                RowBox[{"\[Zeta]", "(", "2", ")"}]}], "+", 
              RowBox[{
                RowBox[{"log", "(", "2", ")"}], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      SubscriptBox["S", "3"], "(", 
                      FormBox["m",
                        "TraditionalForm"], ")"}], "-", 
                    RowBox[{
                      SubscriptBox["S", 
                        RowBox[{"-", "3"}]], "(", 
                      FormBox["m",
                        "TraditionalForm"], ")"}]}], ")"}]}], "+", 
              RowBox[{
                SubscriptBox["S", 
                  RowBox[{"3", "-", "1"}]], "(", 
                FormBox["m",
                  "TraditionalForm"], ")"}], "-", 
              RowBox[{
                FractionBox["3", "4"], " ", 
                RowBox[{
                  SubscriptBox["S", 
                    RowBox[{"-", "1"}]], "(", 
                  FormBox["m",
                    "TraditionalForm"], ")"}], " ", 
                TagBox[
                  RowBox[{"\[Zeta]", "(", 
                    TagBox["3",
                      (Editable -> True)], ")"}],
                  InterpretTemplate[ Zeta[ #]&]]}], "-", 
              RowBox[{
                FractionBox["3", "4"], " ", 
                RowBox[{"log", "(", "2", ")"}], " ", 
                TagBox[
                  RowBox[{"\[Zeta]", "(", 
                    TagBox["3",
                      (Editable -> True)], ")"}],
                  InterpretTemplate[ Zeta[ #]&]]}]}], ")"}]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[909]=  (21:54:57 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Integrate3", "[", 
      RowBox[{
        RowBox[{"DeltaFunctionPrime", "[", 
          RowBox[{"1", "-", "x"}], "]"}], ",", 
        RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[910]:=  (21:54:57 on 5/16/01)",
  CellTags->"Integrate3"],

Cell[BoxData[
    FormBox["0", TraditionalForm]], "Output",
  CellLabel->"Out[910]=  (21:54:57 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Integrate3", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"f", "[", "x", "]"}], " ", 
          RowBox[{"DeltaFunctionPrime", "[", 
            RowBox[{"1", "-", "x"}], "]"}]}], ",", 
        RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[911]:=  (21:54:57 on 5/16/01)",
  CellTags->"Integrate3"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["f", "\[Prime]",
          MultilineFunction->None], "(", "1", ")"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[911]=  (21:54:57 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Integrate3", "[", 
      RowBox[{
        RowBox[{"1", "/", 
          RowBox[{"(", 
            RowBox[{"1", "-", "x"}], ")"}]}], ",", 
        RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[912]:=  (21:54:57 on 5/16/01)",
  CellTags->"Integrate3"],

Cell[BoxData[
    FormBox["0", TraditionalForm]], "Output",
  CellLabel->"Out[912]=  (21:54:57 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["IntegrateByParts", "ObjectName",
  CellTags->"IntegrateByParts"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"IntegrateByParts"],

Cell["\<\
IntegrateByParts[(1-t)^(a Epsilon -1) g[t], deriv, t] does an integration by \
parts of the definite integral over t from 0 to 1.\
\>", "Text",
  CellTags->"IntegrateByParts"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "IntegrateByParts", "]"}]], "Input",
  CellLabel->"In[913]:=  (21:54:57 on 5/16/01)",
  CellTags->"IntegrateByParts"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"Hold", "\[Rule]", "False"}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[913]=  (21:54:57 on 5/16/01)"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"IntegrateByParts"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"IntegrateByParts", "[", 
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{"(", 
              RowBox[{"1", "-", "t"}], ")"}], "^", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"a", " ", "Epsilon"}], "-", "1"}], ")"}]}], " ", 
          RowBox[{"g", "[", "t", "]"}]}], ",", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "-", "t"}], ")"}], "^", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"a", " ", "Epsilon"}], "-", "1"}], ")"}]}], ",", "t"}], 
      "]"}]], "Input",
  CellLabel->"In[914]:=  (21:54:57 on 5/16/01)",
  CellTags->"IntegrateByParts"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{
            RowBox[{
              SuperscriptBox["g", "\[Prime]",
                MultilineFunction->None], "(", "t", ")"}], " ", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"1", "-", "t"}], ")"}], 
              RowBox[{"a", " ", 
                TagBox["\[CurlyEpsilon]",
                  TraditionalForm]}]]}], 
          RowBox[{"a", " ", 
            TagBox["\[CurlyEpsilon]",
              TraditionalForm]}]], "+", 
        FractionBox[
          RowBox[{"g", "(", "0", ")"}], 
          RowBox[{"a", " ", 
            TagBox["\[CurlyEpsilon]",
              TraditionalForm]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[914]=  (21:54:58 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["InverseMellin", "ObjectName",
  CellTags->"InverseMellin"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"InverseMellin"],

Cell[TextData[{
  "InverseMellin[exp, y] performs the inverse Mellin transform of polynomials \
in OPEm. The inverse transforms are not calculated but a table-lookup is \
done. WARNING: do not \"trust\" the results for the inverse Mellin transform \
involving SumT's; there is an unresolved inconsistency here (related to ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "^", "m"}], ")"}], "."}], 
        TraditionalForm]]]
}], "Text",
  CellTags->"InverseMellin"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["DeltaFunction",
    ButtonData:>"DeltaFunction",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DeltaFunction"],
  ", ",
  ButtonBox["Integrate2",
    ButtonData:>"Integrate2",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Integrate2"],
  ", ",
  ButtonBox["OPEm",
    ButtonData:>"OPEi",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SumS"],
  ", ",
  ButtonBox["SumS",
    ButtonData:>"SumS",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SumS"],
  ", ",
  ButtonBox["SumT",
    ButtonData:>"SumT",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SumT"],
  "."
}], "Text",
  CellTags->"InverseMellin"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"InverseMellin"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"InverseMellin", "[", 
      RowBox[{
        RowBox[{"1", "/", "OPEm"}], ",", "y"}], "]"}]], "Input",
  CellLabel->"In[915]:=  (21:54:58 on 5/16/01)",
  CellTags->"InverseMellin"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["y", 
        RowBox[{"m", "-", "1"}]], TraditionalForm]], "Output",
  CellLabel->"Out[915]=  (21:54:58 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"InverseMellin", "[", 
      RowBox[{
        RowBox[{"1", "/", 
          RowBox[{"(", 
            RowBox[{"OPEm", "+", "3"}], ")"}]}], ",", "y"}], "]"}]], "Input",
  CellLabel->"In[916]:=  (21:54:58 on 5/16/01)",
  CellTags->"InverseMellin"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["y", 
        RowBox[{"m", "+", "2"}]], TraditionalForm]], "Output",
  CellLabel->"Out[916]=  (21:54:58 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"InverseMellin", "[", 
      RowBox[{"1", ",", "y"}], "]"}]], "Input",
  CellLabel->"In[917]:=  (21:54:58 on 5/16/01)",
  CellTags->"InverseMellin"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["y", 
          RowBox[{"m", "-", "1"}]], " ", 
        RowBox[{"\[Delta]", "(", 
          FormBox[
            RowBox[{"1", "-", "y"}],
            "TraditionalForm"], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[917]=  (21:54:58 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"InverseMellin", "[", 
      RowBox[{
        RowBox[{"1", "/", 
          RowBox[{"OPEm", "^", "4"}]}], ",", "y"}], "]"}]], "Input",
  CellLabel->"In[918]:=  (21:54:58 on 5/16/01)",
  CellTags->"InverseMellin"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          FractionBox["1", "6"]}], " ", 
        SuperscriptBox["y", 
          RowBox[{"m", "-", "1"}]], " ", 
        RowBox[{
          SuperscriptBox["log", "3"], "(", "y", ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[918]=  (21:54:58 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"InverseMellin", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"1", "/", "OPEm"}], "+", "1"}], ",", "y"}], "]"}]], "Input",\

  CellLabel->"In[919]:=  (21:54:58 on 5/16/01)",
  CellTags->"InverseMellin"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"\[Delta]", "(", 
            FormBox[
              RowBox[{"1", "-", "y"}],
              "TraditionalForm"], ")"}], " ", 
          SuperscriptBox["y", 
            RowBox[{"m", "-", "1"}]]}], "+", 
        SuperscriptBox["y", 
          RowBox[{"m", "-", "1"}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[919]=  (21:54:58 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"InverseMellin", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"1", "/", "i"}], "+", "1"}], ",", "y", ",", "i"}], 
      "]"}]], "Input",
  CellLabel->"In[920]:=  (21:54:58 on 5/16/01)",
  CellTags->"InverseMellin"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"\[Delta]", "(", 
            FormBox[
              RowBox[{"1", "-", "y"}],
              "TraditionalForm"], ")"}], " ", 
          SuperscriptBox["y", 
            RowBox[{"i", "-", "1"}]]}], "+", 
        SuperscriptBox["y", 
          RowBox[{"i", "-", "1"}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[920]=  (21:54:58 on 5/16/01)"]
}, Closed]],

Cell["\<\
The inverse operation to InverseMellin is done by Integrate2.\
\>", "Text",
  CellTags->"InverseMellin"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Integrate2", "[", 
      RowBox[{
        RowBox[{"InverseMellin", "[", 
          RowBox[{
            RowBox[{"1", "/", "OPEm"}], ",", "y"}], "]"}], ",", 
        RowBox[{"{", 
          RowBox[{"y", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[921]:=  (21:54:58 on 5/16/01)",
  CellTags->"InverseMellin"],

Cell[BoxData[
    FormBox[
      FractionBox["1", "m"], TraditionalForm]], "Output",
  CellLabel->"Out[921]=  (21:54:59 on 5/16/01)"]
}, Closed]],

Cell["\<\
Below is a list of all built-in basic inverse Mellin transforms .\
\>", "Text",
  CellTags->"InverseMellin"],

Cell[BoxData[
    RowBox[{
      RowBox[{"list", "=", 
        RowBox[{"{", 
          RowBox[{"1", ",", 
            FractionBox["1", 
              RowBox[{"OPEm", "+", "n"}]], ",", 
            FractionBox["1", 
              RowBox[{
                RowBox[{"-", "OPEm"}], "+", "n"}]], ",", 
            RowBox[{"PolyGamma", "[", 
              RowBox[{"0", ",", "OPEm"}], "]"}], ",", 
            RowBox[{"SumS", "[", 
              RowBox[{"1", ",", 
                RowBox[{
                  RowBox[{"-", "1"}], "+", "OPEm"}]}], "]"}], ",", 
            FractionBox[
              RowBox[{"SumS", "[", 
                RowBox[{"1", ",", 
                  RowBox[{
                    RowBox[{"-", "1"}], "+", "OPEm"}]}], "]"}], 
              RowBox[{"OPEm", "-", "1"}]], ",", 
            FractionBox[
              RowBox[{"SumS", "[", 
                RowBox[{"1", ",", 
                  RowBox[{
                    RowBox[{"-", "1"}], "+", "OPEm"}]}], "]"}], 
              RowBox[{"1", "-", "OPEm"}]], ",", 
            FractionBox[
              RowBox[{"SumS", "[", 
                RowBox[{"1", ",", 
                  RowBox[{
                    RowBox[{"-", "1"}], "+", "OPEm"}]}], "]"}], 
              RowBox[{"OPEm", "+", "1"}]], ",", 
            FractionBox[
              RowBox[{"SumS", "[", 
                RowBox[{"1", ",", 
                  RowBox[{
                    RowBox[{"-", "1"}], "+", "OPEm"}]}], "]"}], 
              SuperscriptBox["OPEm", "2"]], ",", 
            FractionBox[
              RowBox[{"SumS", "[", 
                RowBox[{"1", ",", 
                  RowBox[{
                    RowBox[{"-", "1"}], "+", "OPEm"}]}], "]"}], "OPEm"], ",", 
            
            FractionBox[
              SuperscriptBox[
                RowBox[{"SumS", "[", 
                  RowBox[{"1", ",", 
                    RowBox[{
                      RowBox[{"-", "1"}], "+", "OPEm"}]}], "]"}], "2"], 
              "OPEm"], ",", 
            RowBox[{"SumS", "[", 
              RowBox[{"2", ",", 
                RowBox[{
                  RowBox[{"-", "1"}], "+", "OPEm"}]}], "]"}], ",", 
            FractionBox[
              RowBox[{"SumS", "[", 
                RowBox[{"2", ",", 
                  RowBox[{
                    RowBox[{"-", "1"}], "+", "OPEm"}]}], "]"}], "OPEm"], ",", 
            
            RowBox[{"SumS", "[", 
              RowBox[{"3", ",", 
                RowBox[{
                  RowBox[{"-", "1"}], "+", "OPEm"}]}], "]"}], ",", 
            RowBox[{"SumS", "[", 
              RowBox[{"1", ",", "1", ",", 
                RowBox[{
                  RowBox[{"-", "1"}], "+", "OPEm"}]}], "]"}], ",", 
            SuperscriptBox[
              RowBox[{"SumS", "[", 
                RowBox[{"1", ",", 
                  RowBox[{"OPEm", "-", "1"}]}], "]"}], "2"], ",", 
            RowBox[{"SumS", "[", 
              RowBox[{"1", ",", "2", ",", 
                RowBox[{
                  RowBox[{"-", "1"}], "+", "OPEm"}]}], "]"}], ",", 
            RowBox[{"SumS", "[", 
              RowBox[{"2", ",", "1", ",", 
                RowBox[{
                  RowBox[{"-", "1"}], "+", "OPEm"}]}], "]"}], ",", 
            SuperscriptBox[
              RowBox[{"SumS", "[", 
                RowBox[{"1", ",", 
                  RowBox[{
                    RowBox[{"-", "1"}], "+", "OPEm"}]}], "]"}], "3"], ",", 
            RowBox[{
              RowBox[{"SumS", "[", 
                RowBox[{"1", ",", 
                  RowBox[{
                    RowBox[{"-", "1"}], "+", "OPEm"}]}], "]"}], " ", 
              RowBox[{"SumS", "[", 
                RowBox[{"2", ",", 
                  RowBox[{
                    RowBox[{"-", "1"}], "+", "OPEm"}]}], "]"}]}], ",", 
            RowBox[{"SumS", "[", 
              RowBox[{"1", ",", "1", ",", "1", ",", 
                RowBox[{
                  RowBox[{"-", "1"}], "+", "OPEm"}]}], "]"}]}], "}"}]}], 
      ";"}]], "Input",
  CellLabel->"In[922]:=  (21:54:59 on 5/16/01)",
  CellTags->"InverseMellin"],

Cell[BoxData[
    RowBox[{
      RowBox[{"im", "[", "z_", "]"}], ":=", 
      RowBox[{"z", " ", "\[LongRightArrow]", 
        RowBox[{"InverseMellin", "[", 
          RowBox[{"z", ",", "y"}], "]"}]}]}]], "Input",
  CellLabel->"In[923]:=  (21:54:59 on 5/16/01)",
  CellTags->"InverseMellin"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"im", "[", 
      RowBox[{"OPEm", "^", 
        RowBox[{"(", 
          RowBox[{"-", "3"}], ")"}]}], "]"}]], "Input",
  CellLabel->"In[924]:=  (21:54:59 on 5/16/01)",
  CellTags->"InverseMellin"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox["1", 
          SuperscriptBox["m", "3"]], "\[LongRightArrow]", 
        RowBox[{"(", 
          RowBox[{
            FractionBox["1", "2"], " ", 
            SuperscriptBox["y", 
              RowBox[{"m", "-", "1"}]], " ", 
            RowBox[{
              SuperscriptBox["log", "2"], "(", "y", ")"}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[924]=  (21:54:59 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"im", "[", 
      RowBox[{"OPEm", "^", 
        RowBox[{"(", 
          RowBox[{"-", "2"}], ")"}]}], "]"}]], "Input",
  CellLabel->"In[925]:=  (21:54:59 on 5/16/01)",
  CellTags->"InverseMellin"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox["1", 
          SuperscriptBox["m", "2"]], "\[LongRightArrow]", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"-", 
              SuperscriptBox["y", 
                RowBox[{"m", "-", "1"}]]}], " ", 
            RowBox[{"log", "(", "y", ")"}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[925]=  (21:54:59 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"im", "[", 
      RowBox[{"PolyGamma", "[", 
        RowBox[{"0", ",", "OPEm"}], "]"}], "]"}]], "Input",
  CellLabel->"In[926]:=  (21:54:59 on 5/16/01)",
  CellTags->"InverseMellin"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            TagBox["\[Psi]",
              PolyGamma], 
            RowBox[{"(", "0", ")"}]], "(", "m", ")"}], "\[LongRightArrow]", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                TagBox["\[DoubledGamma]",
                  (EulerGamma&)]}], " ", 
              RowBox[{"\[Delta]", "(", 
                FormBox[
                  RowBox[{"1", "-", "y"}],
                  "TraditionalForm"], ")"}], " ", 
              SuperscriptBox["y", 
                RowBox[{"m", "-", "1"}]]}], "-", 
            RowBox[{
              SubscriptBox[
                RowBox[{"(", 
                  FractionBox["1", 
                    RowBox[{"1", "-", "y"}]], ")"}], "+"], " ", 
              SuperscriptBox["y", 
                RowBox[{"m", "-", "1"}]]}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[926]=  (21:54:59 on 5/16/01)"]
}, Closed]],

Cell[BoxData[" "], "Input",
  CellLabel->"In[927]:=  (21:54:59 on 5/16/01)",
  CellTags->"InverseMellin"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"im", "[", 
      RowBox[{"SumS", "[", 
        RowBox[{"1", ",", 
          RowBox[{"OPEm", "-", "1"}]}], "]"}], "]"}]], "Input",
  CellLabel->"In[928]:=  (21:55:00 on 5/16/01)",
  CellTags->"InverseMellin"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["S", "1"], "(", 
          FormBox[
            RowBox[{"m", "-", "1"}],
            "TraditionalForm"], ")"}], "\[LongRightArrow]", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"-", 
              SuperscriptBox["y", 
                RowBox[{"m", "-", "1"}]]}], " ", 
            SubscriptBox[
              RowBox[{"(", 
                FractionBox["1", 
                  RowBox[{"1", "-", "y"}]], ")"}], "+"]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[928]=  (21:55:00 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"im", "[", 
      RowBox[{
        RowBox[{"SumS", "[", 
          RowBox[{"1", ",", 
            RowBox[{"OPEm", "-", "1"}]}], "]"}], "/", 
        RowBox[{"(", 
          RowBox[{"OPEm", "-", "1"}], ")"}]}], "]"}]], "Input",
  CellLabel->"In[929]:=  (21:55:00 on 5/16/01)",
  CellTags->"InverseMellin"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{
            SubscriptBox["S", "1"], "(", 
            FormBox[
              RowBox[{"m", "-", "1"}],
              "TraditionalForm"], ")"}], 
          RowBox[{"m", "-", "1"}]], "\[LongRightArrow]", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"-", 
              SuperscriptBox["y", 
                RowBox[{"m", "-", "2"}]]}], " ", 
            RowBox[{"log", "(", 
              RowBox[{"1", "-", "y"}], ")"}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[929]=  (21:55:00 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"im", "[", 
      RowBox[{
        RowBox[{"SumS", "[", 
          RowBox[{"1", ",", 
            RowBox[{"OPEm", "-", "1"}]}], "]"}], "/", 
        RowBox[{"(", 
          RowBox[{"OPEm", "+", "1"}], ")"}]}], "]"}]], "Input",
  CellLabel->"In[930]:=  (21:55:00 on 5/16/01)",
  CellTags->"InverseMellin"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{
            SubscriptBox["S", "1"], "(", 
            FormBox[
              RowBox[{"m", "-", "1"}],
              "TraditionalForm"], ")"}], 
          RowBox[{"m", "+", "1"}]], "\[LongRightArrow]", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"-", 
              SuperscriptBox["y", 
                RowBox[{"m", "-", "1"}]]}], "-", 
            RowBox[{
              RowBox[{"log", "(", 
                RowBox[{"1", "-", "y"}], ")"}], " ", 
              SuperscriptBox["y", "m"]}], "+", 
            RowBox[{
              RowBox[{"log", "(", "y", ")"}], " ", 
              SuperscriptBox["y", "m"]}], "+", 
            SuperscriptBox["y", "m"]}], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[930]=  (21:55:00 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"im", "[", 
      RowBox[{
        RowBox[{"SumS", "[", 
          RowBox[{"1", ",", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "OPEm"}]}], "]"}], "/", 
        RowBox[{"OPEm", "^", "2"}]}], "]"}]], "Input",
  CellLabel->"In[931]:=  (21:55:00 on 5/16/01)",
  CellTags->"InverseMellin"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{
            SubscriptBox["S", "1"], "(", 
            FormBox[
              RowBox[{"m", "-", "1"}],
              "TraditionalForm"], ")"}], 
          SuperscriptBox["m", "2"]], "\[LongRightArrow]", 
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox["y", 
              RowBox[{"m", "-", "1"}]], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"-", 
                    FractionBox["1", "2"]}], " ", 
                  RowBox[{
                    SuperscriptBox["log", "2"], "(", "y", ")"}]}], "+", 
                RowBox[{"\[Zeta]", "(", "2", ")"}], "-", 
                RowBox[{
                  SubscriptBox["Li", "2"], "(", "y", ")"}]}], ")"}]}], 
          ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[931]=  (21:55:01 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"im", "[", 
      RowBox[{
        RowBox[{"SumS", "[", 
          RowBox[{"1", ",", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "OPEm"}]}], "]"}], "/", "OPEm"}], 
      "]"}]], "Input",
  CellLabel->"In[932]:=  (21:55:01 on 5/16/01)",
  CellTags->"InverseMellin"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{
            SubscriptBox["S", "1"], "(", 
            FormBox[
              RowBox[{"m", "-", "1"}],
              "TraditionalForm"], ")"}], "m"], "\[LongRightArrow]", 
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox["y", 
              RowBox[{"m", "-", "1"}]], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"log", "(", "y", ")"}], "-", 
                RowBox[{"log", "(", 
                  RowBox[{"1", "-", "y"}], ")"}]}], ")"}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[932]=  (21:55:01 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"im", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"SumS", "[", 
            RowBox[{"1", ",", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "OPEm"}]}], "]"}], "^", "2"}], "/", 
        "OPEm"}], "]"}]], "Input",
  CellLabel->"In[933]:=  (21:55:01 on 5/16/01)",
  CellTags->"InverseMellin"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{
            SubsuperscriptBox["S", "1", "2"], "(", 
            FormBox[
              RowBox[{"m", "-", "1"}],
              "TraditionalForm"], ")"}], "m"], "\[LongRightArrow]", 
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox["y", 
              RowBox[{"m", "-", "1"}]], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  SuperscriptBox["log", "2"], "(", 
                  RowBox[{"1", "-", "y"}], ")"}], "+", 
                FractionBox[
                  RowBox[{
                    SuperscriptBox["log", "2"], "(", "y", ")"}], "2"], "-", 
                RowBox[{"3", " ", 
                  RowBox[{"\[Zeta]", "(", "2", ")"}]}], "+", 
                RowBox[{
                  SubscriptBox["Li", "2"], "(", 
                  RowBox[{"1", "-", "y"}], ")"}], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    SubscriptBox["Li", "2"], "(", "y", ")"}]}]}], ")"}]}], 
          ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[933]=  (21:55:01 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"im", "[", 
      RowBox[{"SumS", "[", 
        RowBox[{"2", ",", 
          RowBox[{"OPEm", "-", "1"}]}], "]"}], "]"}]], "Input",
  CellLabel->"In[934]:=  (21:55:01 on 5/16/01)",
  CellTags->"InverseMellin"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["S", "2"], "(", 
          FormBox[
            RowBox[{"m", "-", "1"}],
            "TraditionalForm"], ")"}], "\[LongRightArrow]", 
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox["y", 
              RowBox[{"m", "-", "1"}]], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
                  RowBox[{"\[Delta]", "(", 
                    FormBox[
                      RowBox[{"1", "-", "y"}],
                      "TraditionalForm"], ")"}]}], "+", 
                FractionBox[
                  RowBox[{"log", "(", "y", ")"}], 
                  RowBox[{"1", "-", "y"}]]}], ")"}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[934]=  (21:55:01 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"im", "[", 
      RowBox[{
        RowBox[{"SumS", "[", 
          RowBox[{"2", ",", 
            RowBox[{"OPEm", "-", "1"}]}], "]"}], "/", "OPEm"}], 
      "]"}]], "Input",
  CellLabel->"In[935]:=  (21:55:01 on 5/16/01)",
  CellTags->"InverseMellin"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{
            SubscriptBox["S", "2"], "(", 
            FormBox[
              RowBox[{"m", "-", "1"}],
              "TraditionalForm"], ")"}], "m"], "\[LongRightArrow]", 
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox["y", 
              RowBox[{"m", "-", "1"}]], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"-", 
                    FractionBox["1", "2"]}], " ", 
                  RowBox[{
                    SuperscriptBox["log", "2"], "(", "y", ")"}]}], "+", 
                RowBox[{"\[Zeta]", "(", "2", ")"}], "-", 
                RowBox[{
                  SubscriptBox["Li", "2"], "(", 
                  RowBox[{"1", "-", "y"}], ")"}]}], ")"}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[935]=  (21:55:02 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"im", "[", 
      RowBox[{"SumS", "[", 
        RowBox[{"3", ",", 
          RowBox[{"OPEm", "-", "1"}]}], "]"}], "]"}]], "Input",
  CellLabel->"In[936]:=  (21:55:02 on 5/16/01)",
  CellTags->"InverseMellin"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["S", "3"], "(", 
          FormBox[
            RowBox[{"m", "-", "1"}],
            "TraditionalForm"], ")"}], "\[LongRightArrow]", 
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox["y", 
              RowBox[{"m", "-", "1"}]], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"\[Delta]", "(", 
                    FormBox[
                      RowBox[{"1", "-", "y"}],
                      "TraditionalForm"], ")"}], " ", 
                  TagBox[
                    RowBox[{"\[Zeta]", "(", 
                      TagBox["3",
                        (Editable -> True)], ")"}],
                    InterpretTemplate[ Zeta[ #]&]]}], "-", 
                FractionBox[
                  RowBox[{
                    SuperscriptBox["log", "2"], "(", "y", ")"}], 
                  RowBox[{"2", " ", 
                    RowBox[{"(", 
                      RowBox[{"1", "-", "y"}], ")"}]}]]}], ")"}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[936]=  (21:55:02 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"im", "[", 
      RowBox[{"SumS", "[", 
        RowBox[{"1", ",", "1", ",", 
          RowBox[{"OPEm", "-", "1"}]}], "]"}], "]"}]], "Input",
  CellLabel->"In[937]:=  (21:55:02 on 5/16/01)",
  CellTags->"InverseMellin"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["S", "11"], "(", 
          FormBox[
            RowBox[{"m", "-", "1"}],
            "TraditionalForm"], ")"}], "\[LongRightArrow]", 
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox["y", 
              RowBox[{"m", "-", "1"}]], " ", 
            SubscriptBox[
              RowBox[{"(", 
                FractionBox[
                  RowBox[{"log", "(", 
                    RowBox[{"1", "-", "y"}], ")"}], 
                  RowBox[{"1", "-", "y"}]], ")"}], "+"]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[937]=  (21:55:02 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{" ", 
      RowBox[{"im", "[", 
        RowBox[{"SumS", "[", 
          RowBox[{"1", ",", "2", ",", 
            RowBox[{"OPEm", "-", "1"}]}], "]"}], "]"}]}]], "Input",
  CellLabel->"In[938]:=  (21:55:02 on 5/16/01)",
  CellTags->"InverseMellin"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["S", "12"], "(", 
          FormBox[
            RowBox[{"m", "-", "1"}],
            "TraditionalForm"], ")"}], "\[LongRightArrow]", 
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox["y", 
              RowBox[{"m", "-", "1"}]], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"-", 
                    TagBox[
                      RowBox[{"\[Zeta]", "(", 
                        TagBox["3",
                          (Editable -> True)], ")"}],
                      InterpretTemplate[ Zeta[ #]&]]}], " ", 
                  RowBox[{"\[Delta]", "(", 
                    FormBox[
                      RowBox[{"1", "-", "y"}],
                      "TraditionalForm"], ")"}]}], "-", 
                RowBox[{
                  RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
                  SubscriptBox[
                    RowBox[{"(", 
                      FractionBox["1", 
                        RowBox[{"1", "-", "y"}]], ")"}], "+"]}], "+", 
                FractionBox[
                  RowBox[{
                    SubscriptBox["Li", "2"], "(", 
                    RowBox[{"1", "-", "y"}], ")"}], 
                  RowBox[{"1", "-", "y"}]]}], ")"}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[938]=  (21:55:02 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{" ", 
      RowBox[{"im", "[", 
        RowBox[{"SumS", "[", 
          RowBox[{"2", ",", "1", ",", 
            RowBox[{"OPEm", "-", "1"}]}], "]"}], "]"}]}]], "Input",
  CellLabel->"In[939]:=  (21:55:02 on 5/16/01)",
  CellTags->"InverseMellin"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["S", "21"], "(", 
          FormBox[
            RowBox[{"m", "-", "1"}],
            "TraditionalForm"], ")"}], "\[LongRightArrow]", 
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox["y", 
              RowBox[{"m", "-", "1"}]], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"2", " ", 
                  TagBox[
                    RowBox[{"\[Zeta]", "(", 
                      TagBox["3",
                        (Editable -> True)], ")"}],
                    InterpretTemplate[ Zeta[ #]&]], " ", 
                  RowBox[{"\[Delta]", "(", 
                    FormBox[
                      RowBox[{"1", "-", "y"}],
                      "TraditionalForm"], ")"}]}], "-", 
                RowBox[{
                  RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
                  SubscriptBox[
                    RowBox[{"(", 
                      FractionBox["1", 
                        RowBox[{"1", "-", "y"}]], ")"}], "+"]}], "+", 
                FractionBox[
                  RowBox[{
                    SubscriptBox["Li", "2"], "(", "y", ")"}], 
                  RowBox[{"1", "-", "y"}]]}], ")"}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[939]=  (21:55:02 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"im", "[", 
      RowBox[{"SumS", "[", 
        RowBox[{"1", ",", "1", ",", "1", ",", 
          RowBox[{"OPEm", "-", "1"}]}], "]"}], "]"}]], "Input",
  CellLabel->"In[940]:=  (21:55:02 on 5/16/01)",
  CellTags->"InverseMellin"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["S", "111"], "(", 
          FormBox[
            RowBox[{"m", "-", "1"}],
            "TraditionalForm"], ")"}], "\[LongRightArrow]", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"-", 
              FractionBox["1", "2"]}], " ", 
            SuperscriptBox["y", 
              RowBox[{"m", "-", "1"}]], " ", 
            SubscriptBox[
              RowBox[{"(", 
                FractionBox[
                  RowBox[{
                    SuperscriptBox["log", "2"], "(", 
                    RowBox[{"1", "-", "y"}], ")"}], 
                  RowBox[{"1", "-", "y"}]], ")"}], "+"]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[940]=  (21:55:02 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      RowBox[{"Clear", "[", 
        RowBox[{"im", ",", "list"}], "]"}], ";"}]], "Input",
  CellLabel->"In[941]:=  (21:55:03 on 5/16/01)",
  CellTags->"InverseMellin"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Isolate", "ObjectName",
  CellTags->"Isolate"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"Isolate"],

Cell["\<\
Isolate[expr] substitutes abbreviations KK[i] for all Plus[...] (sub-sums) in \
expr. The inserted KK[i] have head HoldForm. Isolate[expr, varlist] \
substitutes KK[i] for all subsums in expr which are free of any occurence of \
a member of the list varlist. Instead of KK any other head or a list of names \
of the abbreviations may be specified with the option IsolateNames.\
\>", "Text",
  CellTags->"Isolate"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "Isolate", "]"}]], "Input",
  CellLabel->"In[942]:=  (21:55:03 on 5/16/01)",
  CellTags->"Isolate"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"IsolateNames", "\[Rule]", "KK"}], ",", 
          RowBox[{"IsolatePrint", "\[Rule]", "False"}], ",", 
          RowBox[{"IsolateSplit", "\[Rule]", 
            InterpretationBox["\[Infinity]",
              DirectedInfinity[ 1]]}]}], "}"}], TraditionalForm]], "Output",
  CellLabel->"Out[942]=  (21:55:03 on 5/16/01)"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"Isolate"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t0", "=", 
      RowBox[{"Isolate", "[", 
        RowBox[{"a", "+", "b"}], "]"}]}]], "Input",
  CellLabel->"In[943]:=  (21:55:03 on 5/16/01)",
  CellTags->"Isolate"],

Cell[BoxData[
    FormBox[
      TagBox[
        RowBox[{"KK", "(", "1", ")"}],
        HoldForm], TraditionalForm]], "Output",
  CellLabel->"Out[943]=  (21:55:03 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t1", "=", 
      RowBox[{"Isolate", "[", 
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{"a", "+", "b"}], ")"}], " ", "f"}], " ", "+", " ", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"c", "+", "d"}], ")"}], " ", "f"}], " ", "+", " ", 
            "e"}], ",", "f"}], "]"}]}]], "Input",
  CellLabel->"In[944]:=  (21:55:03 on 5/16/01)",
  CellTags->"Isolate"],

Cell[BoxData[
    FormBox[
      RowBox[{"e", "+", 
        RowBox[{"f", " ", 
          TagBox[
            RowBox[{"KK", "(", "1", ")"}],
            HoldForm]}], "+", 
        RowBox[{"f", " ", 
          TagBox[
            RowBox[{"KK", "(", "2", ")"}],
            HoldForm]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[944]=  (21:55:03 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StandardForm", "[", "t1", "]"}]], "Input",
  CellLabel->"In[945]:=  (21:55:04 on 5/16/01)",
  CellTags->"Isolate"],

Cell[BoxData[
    RowBox[{"e", "+", 
      RowBox[{"f", " ", 
        TagBox[
          RowBox[{"KK", "[", "1", "]"}],
          HoldForm]}], "+", 
      RowBox[{"f", " ", 
        TagBox[
          RowBox[{"KK", "[", "2", "]"}],
          HoldForm]}]}]], "Output",
  CellLabel->"Out[945]//StandardForm=  (21:55:04 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"t0", ",", " ", "t1", ",", " ", 
        RowBox[{"ReleaseHold", "[", "t1", "]"}]}], "}"}]], "Input",
  CellLabel->"In[946]:=  (21:55:04 on 5/16/01)",
  CellTags->"Isolate"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          TagBox[
            RowBox[{"KK", "(", "1", ")"}],
            HoldForm], ",", 
          RowBox[{"e", "+", 
            RowBox[{"f", " ", 
              TagBox[
                RowBox[{"KK", "(", "1", ")"}],
                HoldForm]}], "+", 
            RowBox[{"f", " ", 
              TagBox[
                RowBox[{"KK", "(", "2", ")"}],
                HoldForm]}]}], ",", 
          RowBox[{"e", "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"a", "+", "b"}], ")"}], " ", "f"}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"c", "+", "d"}], ")"}], " ", "f"}]}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[946]=  (21:55:04 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Isolate", "[", 
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{"a", "[", "z", "]"}], " ", 
            RowBox[{"(", 
              RowBox[{"b", "+", 
                RowBox[{"c", " ", 
                  RowBox[{"(", 
                    RowBox[{"y", "+", "z"}], ")"}]}]}], ")"}]}], "+", 
          RowBox[{
            RowBox[{"d", "[", "z", "]"}], " ", 
            RowBox[{"(", 
              RowBox[{"y", "+", "z"}], ")"}]}]}], ",", 
        RowBox[{"{", 
          RowBox[{"a", ",", "d"}], "}"}], ",", 
        RowBox[{"IsolateNames", "\[Rule]", "F"}]}], "]"}]], "Input",
  CellLabel->"In[947]:=  (21:55:04 on 5/16/01)",
  CellTags->"Isolate"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"d", "(", "z", ")"}], " ", 
          TagBox[
            RowBox[{"F", "(", "3", ")"}],
            HoldForm]}], "+", 
        RowBox[{
          RowBox[{"a", "(", "z", ")"}], " ", 
          TagBox[
            RowBox[{"F", "(", "4", ")"}],
            HoldForm]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[947]=  (21:55:04 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"??", "F"}]], "Input",
  CellLabel->"In[948]:=  (21:55:04 on 5/16/01)",
  CellTags->"Isolate"],

Cell[BoxData[
    FormBox["\<\"F is a fermion field.\"\>", TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {GridBox[{
                  {
                    RowBox[{
                      RowBox[{"F", "(", "3", ")"}], "=", 
                      RowBox[{"y", "+", "z"}]}]},
                  {" "},
                  {
                    RowBox[{
                      RowBox[{"F", "(", "4", ")"}], "=", 
                      RowBox[{"b", "+", 
                        RowBox[{"c", " ", 
                          RowBox[{"\<\"HoldForm\"\>", "[", 
                            RowBox[{"F", "(", "3", ")"}], "]"}]}]}]}]}
                  },
                GridBaseline->{Baseline, {1, 1}},
                ColumnWidths->0.999,
                ColumnAlignments->{Left}]}
            },
          GridBaseline->{Baseline, {1, 1}},
          ColumnAlignments->{Left}],
        Definition[ F],
        Editable->False], TraditionalForm]], "Print"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Isolate", "[", 
      RowBox[{
        RowBox[{"a", "-", "b", "-", "c", "-", "d", "-", "e"}], ",", 
        RowBox[{"IsolateNames", "\[Rule]", "L"}], ",", 
        RowBox[{"IsolateSplit", "\[Rule]", "15"}]}], "]"}]], "Input",
  CellLabel->"In[949]:=  (21:55:04 on 5/16/01)",
  CellTags->"Isolate"],

Cell[BoxData[
    FormBox[
      TagBox[
        RowBox[{"L", "(", "3", ")"}],
        HoldForm], TraditionalForm]], "Output",
  CellLabel->"Out[949]=  (21:55:04 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"L", "[", "2", "]"}], ",", 
        RowBox[{"L", "[", "1", "]"}]}], "}"}]], "Input",
  CellLabel->"In[950]:=  (21:55:04 on 5/16/01)",
  CellTags->"Isolate"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"a", "-", "b"}], ",", 
          RowBox[{"L", "(", "1", ")"}]}], "}"}], TraditionalForm]], "Output",
  CellLabel->"Out[950]=  (21:55:05 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{"Clear", "[", 
      RowBox[{"t0", ",", "t1", ",", "L"}], "]"}]], "Input",
  CellLabel->"In[951]:=  (21:55:05 on 5/16/01)",
  CellTags->"Isolate"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Kummer", "ObjectName",
  CellTags->"Kummer"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"Kummer"],

Cell["\<\
Kummer[i][exp] applies Kummer relation number i (i =1, ... 24, 94,95,96) to \
all Hypergeometric2F1 in exp. i = 94 corresponds to eq. 9.131.2, i = 95 to \
eq. 9.132.1 and i = 96 to eq. 9.132.2 in Gradsteyn & Ryzhik.\
\>", "Text",
  CellTags->"Kummer"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["HypergeometricAC",
    ButtonData:>"HypergeometricAC",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"HypergeometricAC"],
  "."
}], "Text",
  CellTags->"Kummer"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"Kummer"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Hypergeometric2F1", "[", 
        RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], "==", 
      RowBox[{
        RowBox[{"Kummer", "[", "2", "]"}], "[", 
        RowBox[{"Hypergeometric2F1", "[", 
          RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], 
        "]"}]}]], "Input",
  CellLabel->"In[952]:=  (21:55:05 on 5/16/01)",
  CellTags->"Kummer"],

Cell[BoxData[
    FormBox[
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              RowBox[{
                SubscriptBox["\[InvisiblePrefixScriptBase]", 
                  FormBox["2",
                    "TraditionalForm"]], 
                SubscriptBox["F", 
                  FormBox["1",
                    "TraditionalForm"]]}], "\[InvisibleApplication]", 
              RowBox[{"(", 
                RowBox[{
                  TagBox[
                    TagBox[
                      RowBox[{
                        TagBox["a",
                          Hypergeometric2F1,
                          Editable->True], ",", 
                        TagBox["b",
                          Hypergeometric2F1,
                          Editable->True]}],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    TagBox[
                      TagBox["c",
                        Hypergeometric2F1,
                        Editable->True],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox["z",
                    Hypergeometric2F1,
                    Editable->True]}], ")"}]}],
            InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
            Editable->False],
          Hypergeometric2F1], "==", 
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"1", "-", "z"}], ")"}], 
            RowBox[{
              RowBox[{"-", "a"}], "-", "b", "+", "c"}]], " ", 
          TagBox[
            TagBox[
              RowBox[{
                RowBox[{
                  SubscriptBox["\[InvisiblePrefixScriptBase]", 
                    FormBox["2",
                      "TraditionalForm"]], 
                  SubscriptBox["F", 
                    FormBox["1",
                      "TraditionalForm"]]}], "\[InvisibleApplication]", 
                RowBox[{"(", 
                  RowBox[{
                    TagBox[
                      TagBox[
                        RowBox[{
                          TagBox[
                            RowBox[{"c", "-", "a"}],
                            Hypergeometric2F1,
                            Editable->True], ",", 
                          TagBox[
                            RowBox[{"c", "-", "b"}],
                            Hypergeometric2F1,
                            Editable->True]}],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      TagBox[
                        TagBox["c",
                          Hypergeometric2F1,
                          Editable->True],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox["z",
                      Hypergeometric2F1,
                      Editable->True]}], ")"}]}],
              InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
              Editable->False],
            Hypergeometric2F1]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[952]=  (21:55:05 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Hypergeometric2F1", "[", 
        RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], "==", 
      RowBox[{
        RowBox[{"Kummer", "[", "3", "]"}], "[", 
        RowBox[{"Hypergeometric2F1", "[", 
          RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], 
        "]"}]}]], "Input",
  CellLabel->"In[953]:=  (21:55:05 on 5/16/01)",
  CellTags->"Kummer"],

Cell[BoxData[
    FormBox[
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              RowBox[{
                SubscriptBox["\[InvisiblePrefixScriptBase]", 
                  FormBox["2",
                    "TraditionalForm"]], 
                SubscriptBox["F", 
                  FormBox["1",
                    "TraditionalForm"]]}], "\[InvisibleApplication]", 
              RowBox[{"(", 
                RowBox[{
                  TagBox[
                    TagBox[
                      RowBox[{
                        TagBox["a",
                          Hypergeometric2F1,
                          Editable->True], ",", 
                        TagBox["b",
                          Hypergeometric2F1,
                          Editable->True]}],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    TagBox[
                      TagBox["c",
                        Hypergeometric2F1,
                        Editable->True],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox["z",
                    Hypergeometric2F1,
                    Editable->True]}], ")"}]}],
            InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
            Editable->False],
          Hypergeometric2F1], "==", 
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"1", "-", "z"}], ")"}], 
            RowBox[{"-", "a"}]], " ", 
          TagBox[
            TagBox[
              RowBox[{
                RowBox[{
                  SubscriptBox["\[InvisiblePrefixScriptBase]", 
                    FormBox["2",
                      "TraditionalForm"]], 
                  SubscriptBox["F", 
                    FormBox["1",
                      "TraditionalForm"]]}], "\[InvisibleApplication]", 
                RowBox[{"(", 
                  RowBox[{
                    TagBox[
                      TagBox[
                        RowBox[{
                          TagBox["a",
                            Hypergeometric2F1,
                            Editable->True], ",", 
                          TagBox[
                            RowBox[{"c", "-", "b"}],
                            Hypergeometric2F1,
                            Editable->True]}],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      TagBox[
                        TagBox["c",
                          Hypergeometric2F1,
                          Editable->True],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      RowBox[{"-", 
                        FractionBox["z", 
                          RowBox[{"1", "-", "z"}]]}],
                      Hypergeometric2F1,
                      Editable->True]}], ")"}]}],
              InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
              Editable->False],
            Hypergeometric2F1]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[953]=  (21:55:05 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Hypergeometric2F1", "[", 
        RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], "==", 
      RowBox[{
        RowBox[{"Kummer", "[", "4", "]"}], "[", 
        RowBox[{"Hypergeometric2F1", "[", 
          RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], 
        "]"}]}]], "Input",
  CellLabel->"In[954]:=  (21:55:05 on 5/16/01)",
  CellTags->"Kummer"],

Cell[BoxData[
    FormBox[
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              RowBox[{
                SubscriptBox["\[InvisiblePrefixScriptBase]", 
                  FormBox["2",
                    "TraditionalForm"]], 
                SubscriptBox["F", 
                  FormBox["1",
                    "TraditionalForm"]]}], "\[InvisibleApplication]", 
              RowBox[{"(", 
                RowBox[{
                  TagBox[
                    TagBox[
                      RowBox[{
                        TagBox["a",
                          Hypergeometric2F1,
                          Editable->True], ",", 
                        TagBox["b",
                          Hypergeometric2F1,
                          Editable->True]}],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    TagBox[
                      TagBox["c",
                        Hypergeometric2F1,
                        Editable->True],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox["z",
                    Hypergeometric2F1,
                    Editable->True]}], ")"}]}],
            InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
            Editable->False],
          Hypergeometric2F1], "==", 
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"1", "-", "z"}], ")"}], 
            RowBox[{"-", "b"}]], " ", 
          TagBox[
            TagBox[
              RowBox[{
                RowBox[{
                  SubscriptBox["\[InvisiblePrefixScriptBase]", 
                    FormBox["2",
                      "TraditionalForm"]], 
                  SubscriptBox["F", 
                    FormBox["1",
                      "TraditionalForm"]]}], "\[InvisibleApplication]", 
                RowBox[{"(", 
                  RowBox[{
                    TagBox[
                      TagBox[
                        RowBox[{
                          TagBox[
                            RowBox[{"c", "-", "a"}],
                            Hypergeometric2F1,
                            Editable->True], ",", 
                          TagBox["b",
                            Hypergeometric2F1,
                            Editable->True]}],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      TagBox[
                        TagBox["c",
                          Hypergeometric2F1,
                          Editable->True],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      RowBox[{"-", 
                        FractionBox["z", 
                          RowBox[{"1", "-", "z"}]]}],
                      Hypergeometric2F1,
                      Editable->True]}], ")"}]}],
              InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
              Editable->False],
            Hypergeometric2F1]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[954]=  (21:55:05 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Hypergeometric2F1", "[", 
        RowBox[{"a", ",", "b", ",", "c", ",", 
          RowBox[{"1", "-", "z"}]}], "]"}], "==", 
      RowBox[{
        RowBox[{"Kummer", "[", "6", "]"}], "[", 
        RowBox[{"Hypergeometric2F1", "[", 
          RowBox[{"a", ",", "b", ",", "c", ",", 
            RowBox[{"1", "-", "z"}]}], "]"}], "]"}]}]], "Input",
  CellLabel->"In[955]:=  (21:55:05 on 5/16/01)",
  CellTags->"Kummer"],

Cell[BoxData[
    FormBox[
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              RowBox[{
                SubscriptBox["\[InvisiblePrefixScriptBase]", 
                  FormBox["2",
                    "TraditionalForm"]], 
                SubscriptBox["F", 
                  FormBox["1",
                    "TraditionalForm"]]}], "\[InvisibleApplication]", 
              RowBox[{"(", 
                RowBox[{
                  TagBox[
                    TagBox[
                      RowBox[{
                        TagBox["a",
                          Hypergeometric2F1,
                          Editable->True], ",", 
                        TagBox["b",
                          Hypergeometric2F1,
                          Editable->True]}],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    TagBox[
                      TagBox["c",
                        Hypergeometric2F1,
                        Editable->True],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    RowBox[{"1", "-", "z"}],
                    Hypergeometric2F1,
                    Editable->True]}], ")"}]}],
            InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
            Editable->False],
          Hypergeometric2F1], "==", 
        RowBox[{
          SuperscriptBox["z", 
            RowBox[{
              RowBox[{"-", "a"}], "-", "b", "+", "c"}]], " ", 
          TagBox[
            TagBox[
              RowBox[{
                RowBox[{
                  SubscriptBox["\[InvisiblePrefixScriptBase]", 
                    FormBox["2",
                      "TraditionalForm"]], 
                  SubscriptBox["F", 
                    FormBox["1",
                      "TraditionalForm"]]}], "\[InvisibleApplication]", 
                RowBox[{"(", 
                  RowBox[{
                    TagBox[
                      TagBox[
                        RowBox[{
                          TagBox[
                            RowBox[{"c", "-", "b"}],
                            Hypergeometric2F1,
                            Editable->True], ",", 
                          TagBox[
                            RowBox[{"c", "-", "a"}],
                            Hypergeometric2F1,
                            Editable->True]}],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      TagBox[
                        TagBox["c",
                          Hypergeometric2F1,
                          Editable->True],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      RowBox[{"1", "-", "z"}],
                      Hypergeometric2F1,
                      Editable->True]}], ")"}]}],
              InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
              Editable->False],
            Hypergeometric2F1]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[955]=  (21:55:05 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Hypergeometric2F1", "[", 
        RowBox[{"a", ",", "b", ",", 
          RowBox[{"a", "+", "b", "+", "1", "-", "c"}], ",", 
          RowBox[{"1", "-", "z"}]}], "]"}], "==", 
      RowBox[{
        RowBox[{"Kummer", "[", "6", "]"}], "[", 
        RowBox[{"Hypergeometric2F1", "[", 
          RowBox[{"a", ",", "b", ",", 
            RowBox[{"a", "+", "b", "+", "1", "-", "c"}], ",", 
            RowBox[{"1", "-", "z"}]}], "]"}], "]"}]}]], "Input",
  CellLabel->"In[956]:=  (21:55:05 on 5/16/01)",
  CellTags->"Kummer"],

Cell[BoxData[
    FormBox[
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              RowBox[{
                SubscriptBox["\[InvisiblePrefixScriptBase]", 
                  FormBox["2",
                    "TraditionalForm"]], 
                SubscriptBox["F", 
                  FormBox["1",
                    "TraditionalForm"]]}], "\[InvisibleApplication]", 
              RowBox[{"(", 
                RowBox[{
                  TagBox[
                    TagBox[
                      RowBox[{
                        TagBox["a",
                          Hypergeometric2F1,
                          Editable->True], ",", 
                        TagBox["b",
                          Hypergeometric2F1,
                          Editable->True]}],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    TagBox[
                      TagBox[
                        RowBox[{"a", "+", "b", "-", "c", "+", "1"}],
                        Hypergeometric2F1,
                        Editable->True],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    RowBox[{"1", "-", "z"}],
                    Hypergeometric2F1,
                    Editable->True]}], ")"}]}],
            InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
            Editable->False],
          Hypergeometric2F1], "==", 
        RowBox[{
          SuperscriptBox["z", 
            RowBox[{"1", "-", "c"}]], " ", 
          TagBox[
            TagBox[
              RowBox[{
                RowBox[{
                  SubscriptBox["\[InvisiblePrefixScriptBase]", 
                    FormBox["2",
                      "TraditionalForm"]], 
                  SubscriptBox["F", 
                    FormBox["1",
                      "TraditionalForm"]]}], "\[InvisibleApplication]", 
                RowBox[{"(", 
                  RowBox[{
                    TagBox[
                      TagBox[
                        RowBox[{
                          TagBox[
                            RowBox[{"a", "-", "c", "+", "1"}],
                            Hypergeometric2F1,
                            Editable->True], ",", 
                          TagBox[
                            RowBox[{"b", "-", "c", "+", "1"}],
                            Hypergeometric2F1,
                            Editable->True]}],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      TagBox[
                        TagBox[
                          RowBox[{"a", "+", "b", "-", "c", "+", "1"}],
                          Hypergeometric2F1,
                          Editable->True],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      RowBox[{"1", "-", "z"}],
                      Hypergeometric2F1,
                      Editable->True]}], ")"}]}],
              InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
              Editable->False],
            Hypergeometric2F1]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[956]=  (21:55:05 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Hypergeometric2F1", "[", 
        RowBox[{"a", ",", "b", ",", "c", ",", 
          RowBox[{"1", "-", "z"}]}], "]"}], "==", 
      RowBox[{
        RowBox[{"Kummer", "[", "7", "]"}], "[", 
        RowBox[{"Hypergeometric2F1", "[", 
          RowBox[{"a", ",", "b", ",", "c", ",", 
            RowBox[{"1", "-", "z"}]}], "]"}], "]"}]}]], "Input",
  CellLabel->"In[957]:=  (21:55:05 on 5/16/01)",
  CellTags->"Kummer"],

Cell[BoxData[
    FormBox[
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              RowBox[{
                SubscriptBox["\[InvisiblePrefixScriptBase]", 
                  FormBox["2",
                    "TraditionalForm"]], 
                SubscriptBox["F", 
                  FormBox["1",
                    "TraditionalForm"]]}], "\[InvisibleApplication]", 
              RowBox[{"(", 
                RowBox[{
                  TagBox[
                    TagBox[
                      RowBox[{
                        TagBox["a",
                          Hypergeometric2F1,
                          Editable->True], ",", 
                        TagBox["b",
                          Hypergeometric2F1,
                          Editable->True]}],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    TagBox[
                      TagBox["c",
                        Hypergeometric2F1,
                        Editable->True],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    RowBox[{"1", "-", "z"}],
                    Hypergeometric2F1,
                    Editable->True]}], ")"}]}],
            InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
            Editable->False],
          Hypergeometric2F1], "==", 
        RowBox[{
          SuperscriptBox["z", 
            RowBox[{"-", "a"}]], " ", 
          TagBox[
            TagBox[
              RowBox[{
                RowBox[{
                  SubscriptBox["\[InvisiblePrefixScriptBase]", 
                    FormBox["2",
                      "TraditionalForm"]], 
                  SubscriptBox["F", 
                    FormBox["1",
                      "TraditionalForm"]]}], "\[InvisibleApplication]", 
                RowBox[{"(", 
                  RowBox[{
                    TagBox[
                      TagBox[
                        RowBox[{
                          TagBox["a",
                            Hypergeometric2F1,
                            Editable->True], ",", 
                          TagBox[
                            RowBox[{"c", "-", "b"}],
                            Hypergeometric2F1,
                            Editable->True]}],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      TagBox[
                        TagBox["c",
                          Hypergeometric2F1,
                          Editable->True],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      RowBox[{"-", 
                        FractionBox[
                          RowBox[{"1", "-", "z"}], "z"]}],
                      Hypergeometric2F1,
                      Editable->True]}], ")"}]}],
              InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
              Editable->False],
            Hypergeometric2F1]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[957]=  (21:55:05 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Hypergeometric2F1", "[", 
        RowBox[{"a", ",", "b", ",", 
          RowBox[{"a", "+", "b", "+", "1", "-", "c"}], ",", 
          RowBox[{"1", "-", "z"}]}], "]"}], "==", 
      RowBox[{
        RowBox[{"Kummer", "[", "7", "]"}], "[", 
        RowBox[{"Hypergeometric2F1", "[", 
          RowBox[{"a", ",", "b", ",", 
            RowBox[{"a", "+", "b", "+", "1", "-", "c"}], ",", 
            RowBox[{"1", "-", "z"}]}], "]"}], "]"}]}]], "Input",
  CellLabel->"In[958]:=  (21:55:05 on 5/16/01)",
  CellTags->"Kummer"],

Cell[BoxData[
    FormBox[
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              RowBox[{
                SubscriptBox["\[InvisiblePrefixScriptBase]", 
                  FormBox["2",
                    "TraditionalForm"]], 
                SubscriptBox["F", 
                  FormBox["1",
                    "TraditionalForm"]]}], "\[InvisibleApplication]", 
              RowBox[{"(", 
                RowBox[{
                  TagBox[
                    TagBox[
                      RowBox[{
                        TagBox["a",
                          Hypergeometric2F1,
                          Editable->True], ",", 
                        TagBox["b",
                          Hypergeometric2F1,
                          Editable->True]}],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    TagBox[
                      TagBox[
                        RowBox[{"a", "+", "b", "-", "c", "+", "1"}],
                        Hypergeometric2F1,
                        Editable->True],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    RowBox[{"1", "-", "z"}],
                    Hypergeometric2F1,
                    Editable->True]}], ")"}]}],
            InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
            Editable->False],
          Hypergeometric2F1], "==", 
        RowBox[{
          SuperscriptBox["z", 
            RowBox[{"-", "a"}]], " ", 
          TagBox[
            TagBox[
              RowBox[{
                RowBox[{
                  SubscriptBox["\[InvisiblePrefixScriptBase]", 
                    FormBox["2",
                      "TraditionalForm"]], 
                  SubscriptBox["F", 
                    FormBox["1",
                      "TraditionalForm"]]}], "\[InvisibleApplication]", 
                RowBox[{"(", 
                  RowBox[{
                    TagBox[
                      TagBox[
                        RowBox[{
                          TagBox["a",
                            Hypergeometric2F1,
                            Editable->True], ",", 
                          TagBox[
                            RowBox[{"a", "-", "c", "+", "1"}],
                            Hypergeometric2F1,
                            Editable->True]}],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      TagBox[
                        TagBox[
                          RowBox[{"a", "+", "b", "-", "c", "+", "1"}],
                          Hypergeometric2F1,
                          Editable->True],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      RowBox[{"-", 
                        FractionBox[
                          RowBox[{"1", "-", "z"}], "z"]}],
                      Hypergeometric2F1,
                      Editable->True]}], ")"}]}],
              InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
              Editable->False],
            Hypergeometric2F1]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[958]=  (21:55:05 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Hypergeometric2F1", "[", 
        RowBox[{"a", ",", "b", ",", "c", ",", 
          RowBox[{"1", "-", "z"}]}], "]"}], "==", 
      RowBox[{
        RowBox[{"Kummer", "[", "8", "]"}], "[", 
        RowBox[{"Hypergeometric2F1", "[", 
          RowBox[{"a", ",", "b", ",", "c", ",", 
            RowBox[{"1", "-", "z"}]}], "]"}], "]"}]}]], "Input",
  CellLabel->"In[959]:=  (21:55:05 on 5/16/01)",
  CellTags->"Kummer"],

Cell[BoxData[
    FormBox[
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              RowBox[{
                SubscriptBox["\[InvisiblePrefixScriptBase]", 
                  FormBox["2",
                    "TraditionalForm"]], 
                SubscriptBox["F", 
                  FormBox["1",
                    "TraditionalForm"]]}], "\[InvisibleApplication]", 
              RowBox[{"(", 
                RowBox[{
                  TagBox[
                    TagBox[
                      RowBox[{
                        TagBox["a",
                          Hypergeometric2F1,
                          Editable->True], ",", 
                        TagBox["b",
                          Hypergeometric2F1,
                          Editable->True]}],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    TagBox[
                      TagBox["c",
                        Hypergeometric2F1,
                        Editable->True],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    RowBox[{"1", "-", "z"}],
                    Hypergeometric2F1,
                    Editable->True]}], ")"}]}],
            InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
            Editable->False],
          Hypergeometric2F1], "==", 
        RowBox[{
          SuperscriptBox["z", 
            RowBox[{"-", "b"}]], " ", 
          TagBox[
            TagBox[
              RowBox[{
                RowBox[{
                  SubscriptBox["\[InvisiblePrefixScriptBase]", 
                    FormBox["2",
                      "TraditionalForm"]], 
                  SubscriptBox["F", 
                    FormBox["1",
                      "TraditionalForm"]]}], "\[InvisibleApplication]", 
                RowBox[{"(", 
                  RowBox[{
                    TagBox[
                      TagBox[
                        RowBox[{
                          TagBox[
                            RowBox[{"c", "-", "a"}],
                            Hypergeometric2F1,
                            Editable->True], ",", 
                          TagBox["b",
                            Hypergeometric2F1,
                            Editable->True]}],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      TagBox[
                        TagBox["c",
                          Hypergeometric2F1,
                          Editable->True],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      RowBox[{"-", 
                        FractionBox[
                          RowBox[{"1", "-", "z"}], "z"]}],
                      Hypergeometric2F1,
                      Editable->True]}], ")"}]}],
              InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
              Editable->False],
            Hypergeometric2F1]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[959]=  (21:55:05 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Hypergeometric2F1", "[", 
        RowBox[{"a", ",", "b", ",", 
          RowBox[{"a", "+", "b", "+", "1", "-", "c"}], ",", 
          RowBox[{"1", "-", "z"}]}], "]"}], "==", 
      RowBox[{
        RowBox[{"Kummer", "[", "8", "]"}], "[", 
        RowBox[{"Hypergeometric2F1", "[", 
          RowBox[{"a", ",", "b", ",", 
            RowBox[{"a", "+", "b", "+", "1", "-", "c"}], ",", 
            RowBox[{"1", "-", "z"}]}], "]"}], "]"}]}]], "Input",
  CellLabel->"In[960]:=  (21:55:05 on 5/16/01)",
  CellTags->"Kummer"],

Cell[BoxData[
    FormBox[
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              RowBox[{
                SubscriptBox["\[InvisiblePrefixScriptBase]", 
                  FormBox["2",
                    "TraditionalForm"]], 
                SubscriptBox["F", 
                  FormBox["1",
                    "TraditionalForm"]]}], "\[InvisibleApplication]", 
              RowBox[{"(", 
                RowBox[{
                  TagBox[
                    TagBox[
                      RowBox[{
                        TagBox["a",
                          Hypergeometric2F1,
                          Editable->True], ",", 
                        TagBox["b",
                          Hypergeometric2F1,
                          Editable->True]}],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    TagBox[
                      TagBox[
                        RowBox[{"a", "+", "b", "-", "c", "+", "1"}],
                        Hypergeometric2F1,
                        Editable->True],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    RowBox[{"1", "-", "z"}],
                    Hypergeometric2F1,
                    Editable->True]}], ")"}]}],
            InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
            Editable->False],
          Hypergeometric2F1], "==", 
        RowBox[{
          SuperscriptBox["z", 
            RowBox[{"-", "b"}]], " ", 
          TagBox[
            TagBox[
              RowBox[{
                RowBox[{
                  SubscriptBox["\[InvisiblePrefixScriptBase]", 
                    FormBox["2",
                      "TraditionalForm"]], 
                  SubscriptBox["F", 
                    FormBox["1",
                      "TraditionalForm"]]}], "\[InvisibleApplication]", 
                RowBox[{"(", 
                  RowBox[{
                    TagBox[
                      TagBox[
                        RowBox[{
                          TagBox[
                            RowBox[{"b", "-", "c", "+", "1"}],
                            Hypergeometric2F1,
                            Editable->True], ",", 
                          TagBox["b",
                            Hypergeometric2F1,
                            Editable->True]}],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      TagBox[
                        TagBox[
                          RowBox[{"a", "+", "b", "-", "c", "+", "1"}],
                          Hypergeometric2F1,
                          Editable->True],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      RowBox[{"-", 
                        FractionBox[
                          RowBox[{"1", "-", "z"}], "z"]}],
                      Hypergeometric2F1,
                      Editable->True]}], ")"}]}],
              InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
              Editable->False],
            Hypergeometric2F1]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[960]=  (21:55:05 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Hypergeometric2F1", "[", 
        RowBox[{"a", ",", "b", ",", "c", ",", 
          RowBox[{"z", "^", 
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}]}]}], "]"}], "==", 
      RowBox[{
        RowBox[{"Kummer", "[", "10", "]"}], "[", 
        RowBox[{"Hypergeometric2F1", "[", 
          RowBox[{"a", ",", "b", ",", "c", ",", 
            RowBox[{"z", "^", 
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}]}]}], "]"}], "]"}]}]], "Input",
  CellLabel->"In[961]:=  (21:55:05 on 5/16/01)",
  CellTags->"Kummer"],

Cell[BoxData[
    FormBox[
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              RowBox[{
                SubscriptBox["\[InvisiblePrefixScriptBase]", 
                  FormBox["2",
                    "TraditionalForm"]], 
                SubscriptBox["F", 
                  FormBox["1",
                    "TraditionalForm"]]}], "\[InvisibleApplication]", 
              RowBox[{"(", 
                RowBox[{
                  TagBox[
                    TagBox[
                      RowBox[{
                        TagBox["a",
                          Hypergeometric2F1,
                          Editable->True], ",", 
                        TagBox["b",
                          Hypergeometric2F1,
                          Editable->True]}],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    TagBox[
                      TagBox["c",
                        Hypergeometric2F1,
                        Editable->True],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    FractionBox["1", "z"],
                    Hypergeometric2F1,
                    Editable->True]}], ")"}]}],
            InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
            Editable->False],
          Hypergeometric2F1], "==", 
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"1", "-", "z"}], ")"}], 
            RowBox[{
              RowBox[{"-", "a"}], "-", "b", "+", "c"}]], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "z"}], ")"}], 
            RowBox[{"a", "+", "b", "-", "c"}]], " ", 
          TagBox[
            TagBox[
              RowBox[{
                RowBox[{
                  SubscriptBox["\[InvisiblePrefixScriptBase]", 
                    FormBox["2",
                      "TraditionalForm"]], 
                  SubscriptBox["F", 
                    FormBox["1",
                      "TraditionalForm"]]}], "\[InvisibleApplication]", 
                RowBox[{"(", 
                  RowBox[{
                    TagBox[
                      TagBox[
                        RowBox[{
                          TagBox[
                            RowBox[{"c", "-", "a"}],
                            Hypergeometric2F1,
                            Editable->True], ",", 
                          TagBox[
                            RowBox[{"c", "-", "b"}],
                            Hypergeometric2F1,
                            Editable->True]}],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      TagBox[
                        TagBox["c",
                          Hypergeometric2F1,
                          Editable->True],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      FractionBox["1", "z"],
                      Hypergeometric2F1,
                      Editable->True]}], ")"}]}],
              InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
              Editable->False],
            Hypergeometric2F1]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[961]=  (21:55:05 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Hypergeometric2F1", "[", 
        RowBox[{"a", ",", 
          RowBox[{"a", "+", "1", "-", "c"}], ",", 
          RowBox[{"a", "+", "1", "-", "b"}], ",", 
          RowBox[{"z", "^", 
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}]}]}], "]"}], "==", 
      RowBox[{
        RowBox[{"Kummer", "[", "10", "]"}], "[", 
        RowBox[{"Hypergeometric2F1", "[", 
          RowBox[{"a", ",", 
            RowBox[{"a", "+", "1", "-", "c"}], ",", 
            RowBox[{"a", "+", "1", "-", "b"}], ",", 
            RowBox[{"z", "^", 
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}]}]}], "]"}], "]"}]}]], "Input",
  CellLabel->"In[962]:=  (21:55:05 on 5/16/01)",
  CellTags->"Kummer"],

Cell[BoxData[
    FormBox[
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              RowBox[{
                SubscriptBox["\[InvisiblePrefixScriptBase]", 
                  FormBox["2",
                    "TraditionalForm"]], 
                SubscriptBox["F", 
                  FormBox["1",
                    "TraditionalForm"]]}], "\[InvisibleApplication]", 
              RowBox[{"(", 
                RowBox[{
                  TagBox[
                    TagBox[
                      RowBox[{
                        TagBox["a",
                          Hypergeometric2F1,
                          Editable->True], ",", 
                        TagBox[
                          RowBox[{"a", "-", "c", "+", "1"}],
                          Hypergeometric2F1,
                          Editable->True]}],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    TagBox[
                      TagBox[
                        RowBox[{"a", "-", "b", "+", "1"}],
                        Hypergeometric2F1,
                        Editable->True],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    FractionBox["1", "z"],
                    Hypergeometric2F1,
                    Editable->True]}], ")"}]}],
            InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
            Editable->False],
          Hypergeometric2F1], "==", 
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"1", "-", "z"}], ")"}], 
            RowBox[{
              RowBox[{"-", "a"}], "-", "b", "+", "c"}]], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "z"}], ")"}], 
            RowBox[{"a", "+", "b", "-", "c"}]], " ", 
          TagBox[
            TagBox[
              RowBox[{
                RowBox[{
                  SubscriptBox["\[InvisiblePrefixScriptBase]", 
                    FormBox["2",
                      "TraditionalForm"]], 
                  SubscriptBox["F", 
                    FormBox["1",
                      "TraditionalForm"]]}], "\[InvisibleApplication]", 
                RowBox[{"(", 
                  RowBox[{
                    TagBox[
                      TagBox[
                        RowBox[{
                          TagBox[
                            RowBox[{"1", "-", "b"}],
                            Hypergeometric2F1,
                            Editable->True], ",", 
                          TagBox[
                            RowBox[{"c", "-", "b"}],
                            Hypergeometric2F1,
                            Editable->True]}],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      TagBox[
                        TagBox[
                          RowBox[{"a", "-", "b", "+", "1"}],
                          Hypergeometric2F1,
                          Editable->True],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      FractionBox["1", "z"],
                      Hypergeometric2F1,
                      Editable->True]}], ")"}]}],
              InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
              Editable->False],
            Hypergeometric2F1]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[962]=  (21:55:05 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Hypergeometric2F1", "[", 
        RowBox[{"a", ",", "b", ",", "c", ",", 
          RowBox[{"z", "^", 
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}]}]}], "]"}], "==", 
      RowBox[{
        RowBox[{"Kummer", "[", "11", "]"}], "[", 
        RowBox[{"Hypergeometric2F1", "[", 
          RowBox[{"a", ",", "b", ",", "c", ",", 
            RowBox[{"z", "^", 
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}]}]}], "]"}], "]"}]}]], "Input",
  CellLabel->"In[963]:=  (21:55:06 on 5/16/01)",
  CellTags->"Kummer"],

Cell[BoxData[
    FormBox[
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              RowBox[{
                SubscriptBox["\[InvisiblePrefixScriptBase]", 
                  FormBox["2",
                    "TraditionalForm"]], 
                SubscriptBox["F", 
                  FormBox["1",
                    "TraditionalForm"]]}], "\[InvisibleApplication]", 
              RowBox[{"(", 
                RowBox[{
                  TagBox[
                    TagBox[
                      RowBox[{
                        TagBox["a",
                          Hypergeometric2F1,
                          Editable->True], ",", 
                        TagBox["b",
                          Hypergeometric2F1,
                          Editable->True]}],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    TagBox[
                      TagBox["c",
                        Hypergeometric2F1,
                        Editable->True],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    FractionBox["1", "z"],
                    Hypergeometric2F1,
                    Editable->True]}], ")"}]}],
            InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
            Editable->False],
          Hypergeometric2F1], "==", 
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", 
                FractionBox[
                  RowBox[{"1", "-", "z"}], "z"]}], ")"}], 
            RowBox[{"-", "a"}]], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "z"}], ")"}], "a"], " ", 
          TagBox[
            TagBox[
              RowBox[{
                RowBox[{
                  SubscriptBox["\[InvisiblePrefixScriptBase]", 
                    FormBox["2",
                      "TraditionalForm"]], 
                  SubscriptBox["F", 
                    FormBox["1",
                      "TraditionalForm"]]}], "\[InvisibleApplication]", 
                RowBox[{"(", 
                  RowBox[{
                    TagBox[
                      TagBox[
                        RowBox[{
                          TagBox["a",
                            Hypergeometric2F1,
                            Editable->True], ",", 
                          TagBox[
                            RowBox[{"c", "-", "b"}],
                            Hypergeometric2F1,
                            Editable->True]}],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      TagBox[
                        TagBox["c",
                          Hypergeometric2F1,
                          Editable->True],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      FractionBox["1", 
                        RowBox[{"1", "-", "z"}]],
                      Hypergeometric2F1,
                      Editable->True]}], ")"}]}],
              InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
              Editable->False],
            Hypergeometric2F1]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[963]=  (21:55:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Hypergeometric2F1", "[", 
        RowBox[{"a", ",", 
          RowBox[{"a", "+", "1", "-", "c"}], ",", 
          RowBox[{"a", "+", "1", "-", "b"}], ",", 
          RowBox[{"z", "^", 
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}]}]}], "]"}], "==", 
      RowBox[{
        RowBox[{"Kummer", "[", "11", "]"}], "[", 
        RowBox[{"Hypergeometric2F1", "[", 
          RowBox[{"a", ",", 
            RowBox[{"a", "+", "1", "-", "c"}], ",", 
            RowBox[{"a", "+", "1", "-", "b"}], ",", 
            RowBox[{"z", "^", 
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}]}]}], "]"}], "]"}]}]], "Input",
  CellLabel->"In[964]:=  (21:55:06 on 5/16/01)",
  CellTags->"Kummer"],

Cell[BoxData[
    FormBox[
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              RowBox[{
                SubscriptBox["\[InvisiblePrefixScriptBase]", 
                  FormBox["2",
                    "TraditionalForm"]], 
                SubscriptBox["F", 
                  FormBox["1",
                    "TraditionalForm"]]}], "\[InvisibleApplication]", 
              RowBox[{"(", 
                RowBox[{
                  TagBox[
                    TagBox[
                      RowBox[{
                        TagBox["a",
                          Hypergeometric2F1,
                          Editable->True], ",", 
                        TagBox[
                          RowBox[{"a", "-", "c", "+", "1"}],
                          Hypergeometric2F1,
                          Editable->True]}],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    TagBox[
                      TagBox[
                        RowBox[{"a", "-", "b", "+", "1"}],
                        Hypergeometric2F1,
                        Editable->True],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    FractionBox["1", "z"],
                    Hypergeometric2F1,
                    Editable->True]}], ")"}]}],
            InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
            Editable->False],
          Hypergeometric2F1], "==", 
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", 
                FractionBox[
                  RowBox[{"1", "-", "z"}], "z"]}], ")"}], 
            RowBox[{"-", "a"}]], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "z"}], ")"}], "a"], " ", 
          TagBox[
            TagBox[
              RowBox[{
                RowBox[{
                  SubscriptBox["\[InvisiblePrefixScriptBase]", 
                    FormBox["2",
                      "TraditionalForm"]], 
                  SubscriptBox["F", 
                    FormBox["1",
                      "TraditionalForm"]]}], "\[InvisibleApplication]", 
                RowBox[{"(", 
                  RowBox[{
                    TagBox[
                      TagBox[
                        RowBox[{
                          TagBox["a",
                            Hypergeometric2F1,
                            Editable->True], ",", 
                          TagBox[
                            RowBox[{"c", "-", "b"}],
                            Hypergeometric2F1,
                            Editable->True]}],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      TagBox[
                        TagBox[
                          RowBox[{"a", "-", "b", "+", "1"}],
                          Hypergeometric2F1,
                          Editable->True],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      FractionBox["1", 
                        RowBox[{"1", "-", "z"}]],
                      Hypergeometric2F1,
                      Editable->True]}], ")"}]}],
              InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
              Editable->False],
            Hypergeometric2F1]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[964]=  (21:55:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Hypergeometric2F1", "[", 
        RowBox[{"a", ",", "b", ",", "c", ",", 
          RowBox[{"z", "^", 
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}]}]}], "]"}], "==", 
      RowBox[{
        RowBox[{"Kummer", "[", "12", "]"}], "[", 
        RowBox[{"Hypergeometric2F1", "[", 
          RowBox[{"a", ",", "b", ",", "c", ",", 
            RowBox[{"z", "^", 
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}]}]}], "]"}], "]"}]}]], "Input",
  CellLabel->"In[965]:=  (21:55:06 on 5/16/01)",
  CellTags->"Kummer"],

Cell[BoxData[
    FormBox[
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              RowBox[{
                SubscriptBox["\[InvisiblePrefixScriptBase]", 
                  FormBox["2",
                    "TraditionalForm"]], 
                SubscriptBox["F", 
                  FormBox["1",
                    "TraditionalForm"]]}], "\[InvisibleApplication]", 
              RowBox[{"(", 
                RowBox[{
                  TagBox[
                    TagBox[
                      RowBox[{
                        TagBox["a",
                          Hypergeometric2F1,
                          Editable->True], ",", 
                        TagBox["b",
                          Hypergeometric2F1,
                          Editable->True]}],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    TagBox[
                      TagBox["c",
                        Hypergeometric2F1,
                        Editable->True],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    FractionBox["1", "z"],
                    Hypergeometric2F1,
                    Editable->True]}], ")"}]}],
            InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
            Editable->False],
          Hypergeometric2F1], "==", 
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"1", "-", "z"}], ")"}], 
            RowBox[{"-", "b"}]], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "z"}], ")"}], 
            RowBox[{"b", "-", "a"}]], " ", 
          TagBox[
            TagBox[
              RowBox[{
                RowBox[{
                  SubscriptBox["\[InvisiblePrefixScriptBase]", 
                    FormBox["2",
                      "TraditionalForm"]], 
                  SubscriptBox["F", 
                    FormBox["1",
                      "TraditionalForm"]]}], "\[InvisibleApplication]", 
                RowBox[{"(", 
                  RowBox[{
                    TagBox[
                      TagBox[
                        RowBox[{
                          TagBox["b",
                            Hypergeometric2F1,
                            Editable->True], ",", 
                          TagBox[
                            RowBox[{"c", "-", "a"}],
                            Hypergeometric2F1,
                            Editable->True]}],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      TagBox[
                        TagBox["c",
                          Hypergeometric2F1,
                          Editable->True],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      FractionBox["1", 
                        RowBox[{"1", "-", "z"}]],
                      Hypergeometric2F1,
                      Editable->True]}], ")"}]}],
              InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
              Editable->False],
            Hypergeometric2F1]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[965]=  (21:55:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Hypergeometric2F1", "[", 
        RowBox[{"a", ",", 
          RowBox[{"a", "+", "1", "-", "c"}], ",", 
          RowBox[{"a", "+", "1", "-", "b"}], ",", 
          RowBox[{"z", "^", 
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}]}]}], "]"}], "==", 
      RowBox[{
        RowBox[{"Kummer", "[", "12", "]"}], "[", 
        RowBox[{"Hypergeometric2F1", "[", 
          RowBox[{"a", ",", 
            RowBox[{"a", "+", "1", "-", "c"}], ",", 
            RowBox[{"a", "+", "1", "-", "b"}], ",", 
            RowBox[{"z", "^", 
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}]}]}], "]"}], "]"}]}]], "Input",
  CellLabel->"In[966]:=  (21:55:06 on 5/16/01)",
  CellTags->"Kummer"],

Cell[BoxData[
    FormBox[
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              RowBox[{
                SubscriptBox["\[InvisiblePrefixScriptBase]", 
                  FormBox["2",
                    "TraditionalForm"]], 
                SubscriptBox["F", 
                  FormBox["1",
                    "TraditionalForm"]]}], "\[InvisibleApplication]", 
              RowBox[{"(", 
                RowBox[{
                  TagBox[
                    TagBox[
                      RowBox[{
                        TagBox["a",
                          Hypergeometric2F1,
                          Editable->True], ",", 
                        TagBox[
                          RowBox[{"a", "-", "c", "+", "1"}],
                          Hypergeometric2F1,
                          Editable->True]}],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    TagBox[
                      TagBox[
                        RowBox[{"a", "-", "b", "+", "1"}],
                        Hypergeometric2F1,
                        Editable->True],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    FractionBox["1", "z"],
                    Hypergeometric2F1,
                    Editable->True]}], ")"}]}],
            InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
            Editable->False],
          Hypergeometric2F1], "==", 
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"1", "-", "z"}], ")"}], 
            RowBox[{
              RowBox[{"-", "a"}], "+", "c", "-", "1"}]], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "z"}], ")"}], 
            RowBox[{"1", "-", "c"}]], " ", 
          TagBox[
            TagBox[
              RowBox[{
                RowBox[{
                  SubscriptBox["\[InvisiblePrefixScriptBase]", 
                    FormBox["2",
                      "TraditionalForm"]], 
                  SubscriptBox["F", 
                    FormBox["1",
                      "TraditionalForm"]]}], "\[InvisibleApplication]", 
                RowBox[{"(", 
                  RowBox[{
                    TagBox[
                      TagBox[
                        RowBox[{
                          TagBox[
                            RowBox[{"a", "-", "c", "+", "1"}],
                            Hypergeometric2F1,
                            Editable->True], ",", 
                          TagBox[
                            RowBox[{"1", "-", "b"}],
                            Hypergeometric2F1,
                            Editable->True]}],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      TagBox[
                        TagBox[
                          RowBox[{"a", "-", "b", "+", "1"}],
                          Hypergeometric2F1,
                          Editable->True],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      FractionBox["1", 
                        RowBox[{"1", "-", "z"}]],
                      Hypergeometric2F1,
                      Editable->True]}], ")"}]}],
              InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
              Editable->False],
            Hypergeometric2F1]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[966]=  (21:55:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Hypergeometric2F1", "[", 
        RowBox[{"a", ",", "b", ",", "c", ",", 
          RowBox[{"z", "^", 
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}]}]}], "]"}], "==", 
      RowBox[{
        RowBox[{"Kummer", "[", "14", "]"}], "[", 
        RowBox[{"Hypergeometric2F1", "[", 
          RowBox[{"a", ",", "b", ",", "c", ",", 
            RowBox[{"z", "^", 
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}]}]}], "]"}], "]"}]}]], "Input",
  CellLabel->"In[967]:=  (21:55:06 on 5/16/01)",
  CellTags->"Kummer"],

Cell[BoxData[
    FormBox[
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              RowBox[{
                SubscriptBox["\[InvisiblePrefixScriptBase]", 
                  FormBox["2",
                    "TraditionalForm"]], 
                SubscriptBox["F", 
                  FormBox["1",
                    "TraditionalForm"]]}], "\[InvisibleApplication]", 
              RowBox[{"(", 
                RowBox[{
                  TagBox[
                    TagBox[
                      RowBox[{
                        TagBox["a",
                          Hypergeometric2F1,
                          Editable->True], ",", 
                        TagBox["b",
                          Hypergeometric2F1,
                          Editable->True]}],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    TagBox[
                      TagBox["c",
                        Hypergeometric2F1,
                        Editable->True],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    FractionBox["1", "z"],
                    Hypergeometric2F1,
                    Editable->True]}], ")"}]}],
            InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
            Editable->False],
          Hypergeometric2F1], "==", 
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"1", "-", "z"}], ")"}], 
            RowBox[{
              RowBox[{"-", "a"}], "-", "b", "+", "c"}]], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "z"}], ")"}], 
            RowBox[{"a", "+", "b", "-", "c"}]], " ", 
          TagBox[
            TagBox[
              RowBox[{
                RowBox[{
                  SubscriptBox["\[InvisiblePrefixScriptBase]", 
                    FormBox["2",
                      "TraditionalForm"]], 
                  SubscriptBox["F", 
                    FormBox["1",
                      "TraditionalForm"]]}], "\[InvisibleApplication]", 
                RowBox[{"(", 
                  RowBox[{
                    TagBox[
                      TagBox[
                        RowBox[{
                          TagBox[
                            RowBox[{"c", "-", "b"}],
                            Hypergeometric2F1,
                            Editable->True], ",", 
                          TagBox[
                            RowBox[{"c", "-", "a"}],
                            Hypergeometric2F1,
                            Editable->True]}],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      TagBox[
                        TagBox["c",
                          Hypergeometric2F1,
                          Editable->True],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      FractionBox["1", "z"],
                      Hypergeometric2F1,
                      Editable->True]}], ")"}]}],
              InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
              Editable->False],
            Hypergeometric2F1]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[967]=  (21:55:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Hypergeometric2F1", "[", 
        RowBox[{
          RowBox[{"b", "+", "1", "-", "c"}], ",", "b", ",", 
          RowBox[{"b", "+", "1", "-", "a"}], ",", 
          RowBox[{"z", "^", 
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}]}]}], "]"}], "==", 
      RowBox[{
        RowBox[{"Kummer", "[", "14", "]"}], "[", 
        RowBox[{"Hypergeometric2F1", "[", 
          RowBox[{
            RowBox[{"b", "+", "1", "-", "c"}], ",", "b", ",", 
            RowBox[{"b", "+", "1", "-", "a"}], ",", 
            RowBox[{"z", "^", 
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}]}]}], "]"}], "]"}]}]], "Input",
  CellLabel->"In[968]:=  (21:55:06 on 5/16/01)",
  CellTags->"Kummer"],

Cell[BoxData[
    FormBox[
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              RowBox[{
                SubscriptBox["\[InvisiblePrefixScriptBase]", 
                  FormBox["2",
                    "TraditionalForm"]], 
                SubscriptBox["F", 
                  FormBox["1",
                    "TraditionalForm"]]}], "\[InvisibleApplication]", 
              RowBox[{"(", 
                RowBox[{
                  TagBox[
                    TagBox[
                      RowBox[{
                        TagBox[
                          RowBox[{"b", "-", "c", "+", "1"}],
                          Hypergeometric2F1,
                          Editable->True], ",", 
                        TagBox["b",
                          Hypergeometric2F1,
                          Editable->True]}],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    TagBox[
                      TagBox[
                        RowBox[{
                          RowBox[{"-", "a"}], "+", "b", "+", "1"}],
                        Hypergeometric2F1,
                        Editable->True],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    FractionBox["1", "z"],
                    Hypergeometric2F1,
                    Editable->True]}], ")"}]}],
            InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
            Editable->False],
          Hypergeometric2F1], "==", 
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"1", "-", "z"}], ")"}], 
            RowBox[{
              RowBox[{"-", "a"}], "-", "b", "+", "c"}]], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "z"}], ")"}], 
            RowBox[{"a", "+", "b", "-", "c"}]], " ", 
          TagBox[
            TagBox[
              RowBox[{
                RowBox[{
                  SubscriptBox["\[InvisiblePrefixScriptBase]", 
                    FormBox["2",
                      "TraditionalForm"]], 
                  SubscriptBox["F", 
                    FormBox["1",
                      "TraditionalForm"]]}], "\[InvisibleApplication]", 
                RowBox[{"(", 
                  RowBox[{
                    TagBox[
                      TagBox[
                        RowBox[{
                          TagBox[
                            RowBox[{"1", "-", "a"}],
                            Hypergeometric2F1,
                            Editable->True], ",", 
                          TagBox[
                            RowBox[{"c", "-", "a"}],
                            Hypergeometric2F1,
                            Editable->True]}],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      TagBox[
                        TagBox[
                          RowBox[{
                            RowBox[{"-", "a"}], "+", "b", "+", "1"}],
                          Hypergeometric2F1,
                          Editable->True],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      FractionBox["1", "z"],
                      Hypergeometric2F1,
                      Editable->True]}], ")"}]}],
              InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
              Editable->False],
            Hypergeometric2F1]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[968]=  (21:55:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Hypergeometric2F1", "[", 
        RowBox[{"a", ",", "b", ",", "c", ",", 
          RowBox[{"z", "^", 
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}]}]}], "]"}], "==", 
      RowBox[{
        RowBox[{"Kummer", "[", "15", "]"}], "[", 
        RowBox[{"Hypergeometric2F1", "[", 
          RowBox[{"a", ",", "b", ",", "c", ",", 
            RowBox[{"z", "^", 
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}]}]}], "]"}], "]"}]}]], "Input",
  CellLabel->"In[969]:=  (21:55:06 on 5/16/01)",
  CellTags->"Kummer"],

Cell[BoxData[
    FormBox[
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              RowBox[{
                SubscriptBox["\[InvisiblePrefixScriptBase]", 
                  FormBox["2",
                    "TraditionalForm"]], 
                SubscriptBox["F", 
                  FormBox["1",
                    "TraditionalForm"]]}], "\[InvisibleApplication]", 
              RowBox[{"(", 
                RowBox[{
                  TagBox[
                    TagBox[
                      RowBox[{
                        TagBox["a",
                          Hypergeometric2F1,
                          Editable->True], ",", 
                        TagBox["b",
                          Hypergeometric2F1,
                          Editable->True]}],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    TagBox[
                      TagBox["c",
                        Hypergeometric2F1,
                        Editable->True],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    FractionBox["1", "z"],
                    Hypergeometric2F1,
                    Editable->True]}], ")"}]}],
            InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
            Editable->False],
          Hypergeometric2F1], "==", 
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"1", "-", "z"}], ")"}], 
            RowBox[{"-", "b"}]], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "z"}], ")"}], "b"], " ", 
          TagBox[
            TagBox[
              RowBox[{
                RowBox[{
                  SubscriptBox["\[InvisiblePrefixScriptBase]", 
                    FormBox["2",
                      "TraditionalForm"]], 
                  SubscriptBox["F", 
                    FormBox["1",
                      "TraditionalForm"]]}], "\[InvisibleApplication]", 
                RowBox[{"(", 
                  RowBox[{
                    TagBox[
                      TagBox[
                        RowBox[{
                          TagBox["b",
                            Hypergeometric2F1,
                            Editable->True], ",", 
                          TagBox[
                            RowBox[{"c", "-", "a"}],
                            Hypergeometric2F1,
                            Editable->True]}],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      TagBox[
                        TagBox["c",
                          Hypergeometric2F1,
                          Editable->True],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      FractionBox["1", 
                        RowBox[{"1", "-", "z"}]],
                      Hypergeometric2F1,
                      Editable->True]}], ")"}]}],
              InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
              Editable->False],
            Hypergeometric2F1]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[969]=  (21:55:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Hypergeometric2F1", "[", 
        RowBox[{
          RowBox[{"b", "+", "1", "-", "c"}], ",", "b", ",", 
          RowBox[{"b", "+", "1", "-", "a"}], ",", 
          RowBox[{"z", "^", 
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}]}]}], "]"}], "==", 
      RowBox[{
        RowBox[{"Kummer", "[", "15", "]"}], "[", 
        RowBox[{"Hypergeometric2F1", "[", 
          RowBox[{
            RowBox[{"b", "+", "1", "-", "c"}], ",", "b", ",", 
            RowBox[{"b", "+", "1", "-", "a"}], ",", 
            RowBox[{"z", "^", 
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}]}]}], "]"}], "]"}]}]], "Input",
  CellLabel->"In[970]:=  (21:55:06 on 5/16/01)",
  CellTags->"Kummer"],

Cell[BoxData[
    FormBox[
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              RowBox[{
                SubscriptBox["\[InvisiblePrefixScriptBase]", 
                  FormBox["2",
                    "TraditionalForm"]], 
                SubscriptBox["F", 
                  FormBox["1",
                    "TraditionalForm"]]}], "\[InvisibleApplication]", 
              RowBox[{"(", 
                RowBox[{
                  TagBox[
                    TagBox[
                      RowBox[{
                        TagBox[
                          RowBox[{"b", "-", "c", "+", "1"}],
                          Hypergeometric2F1,
                          Editable->True], ",", 
                        TagBox["b",
                          Hypergeometric2F1,
                          Editable->True]}],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    TagBox[
                      TagBox[
                        RowBox[{
                          RowBox[{"-", "a"}], "+", "b", "+", "1"}],
                        Hypergeometric2F1,
                        Editable->True],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    FractionBox["1", "z"],
                    Hypergeometric2F1,
                    Editable->True]}], ")"}]}],
            InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
            Editable->False],
          Hypergeometric2F1], "==", 
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"1", "-", "z"}], ")"}], 
            RowBox[{"-", "b"}]], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "z"}], ")"}], "b"], " ", 
          TagBox[
            TagBox[
              RowBox[{
                RowBox[{
                  SubscriptBox["\[InvisiblePrefixScriptBase]", 
                    FormBox["2",
                      "TraditionalForm"]], 
                  SubscriptBox["F", 
                    FormBox["1",
                      "TraditionalForm"]]}], "\[InvisibleApplication]", 
                RowBox[{"(", 
                  RowBox[{
                    TagBox[
                      TagBox[
                        RowBox[{
                          TagBox["b",
                            Hypergeometric2F1,
                            Editable->True], ",", 
                          TagBox[
                            RowBox[{"c", "-", "a"}],
                            Hypergeometric2F1,
                            Editable->True]}],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      TagBox[
                        TagBox[
                          RowBox[{
                            RowBox[{"-", "a"}], "+", "b", "+", "1"}],
                          Hypergeometric2F1,
                          Editable->True],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      FractionBox["1", 
                        RowBox[{"1", "-", "z"}]],
                      Hypergeometric2F1,
                      Editable->True]}], ")"}]}],
              InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
              Editable->False],
            Hypergeometric2F1]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[970]=  (21:55:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Hypergeometric2F1", "[", 
        RowBox[{"a", ",", "b", ",", "c", ",", 
          RowBox[{"z", "^", 
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}]}]}], "]"}], "==", 
      RowBox[{
        RowBox[{"Kummer", "[", "16", "]"}], "[", 
        RowBox[{"Hypergeometric2F1", "[", 
          RowBox[{"a", ",", "b", ",", "c", ",", 
            RowBox[{"z", "^", 
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}]}]}], "]"}], "]"}]}]], "Input",
  CellLabel->"In[971]:=  (21:55:06 on 5/16/01)",
  CellTags->"Kummer"],

Cell[BoxData[
    FormBox[
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              RowBox[{
                SubscriptBox["\[InvisiblePrefixScriptBase]", 
                  FormBox["2",
                    "TraditionalForm"]], 
                SubscriptBox["F", 
                  FormBox["1",
                    "TraditionalForm"]]}], "\[InvisibleApplication]", 
              RowBox[{"(", 
                RowBox[{
                  TagBox[
                    TagBox[
                      RowBox[{
                        TagBox["a",
                          Hypergeometric2F1,
                          Editable->True], ",", 
                        TagBox["b",
                          Hypergeometric2F1,
                          Editable->True]}],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    TagBox[
                      TagBox["c",
                        Hypergeometric2F1,
                        Editable->True],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    FractionBox["1", "z"],
                    Hypergeometric2F1,
                    Editable->True]}], ")"}]}],
            InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
            Editable->False],
          Hypergeometric2F1], "==", 
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"1", "-", "z"}], ")"}], 
            RowBox[{"-", "a"}]], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "z"}], ")"}], "a"], " ", 
          TagBox[
            TagBox[
              RowBox[{
                RowBox[{
                  SubscriptBox["\[InvisiblePrefixScriptBase]", 
                    FormBox["2",
                      "TraditionalForm"]], 
                  SubscriptBox["F", 
                    FormBox["1",
                      "TraditionalForm"]]}], "\[InvisibleApplication]", 
                RowBox[{"(", 
                  RowBox[{
                    TagBox[
                      TagBox[
                        RowBox[{
                          TagBox["a",
                            Hypergeometric2F1,
                            Editable->True], ",", 
                          TagBox[
                            RowBox[{"c", "-", "b"}],
                            Hypergeometric2F1,
                            Editable->True]}],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      TagBox[
                        TagBox["c",
                          Hypergeometric2F1,
                          Editable->True],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      FractionBox["1", 
                        RowBox[{"1", "-", "z"}]],
                      Hypergeometric2F1,
                      Editable->True]}], ")"}]}],
              InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
              Editable->False],
            Hypergeometric2F1]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[971]=  (21:55:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Hypergeometric2F1", "[", 
        RowBox[{
          RowBox[{"b", "+", "1", "-", "c"}], ",", "b", ",", 
          RowBox[{"b", "+", "1", "-", "a"}], ",", 
          RowBox[{"z", "^", 
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}]}]}], "]"}], "==", 
      RowBox[{
        RowBox[{"Kummer", "[", "16", "]"}], "[", 
        RowBox[{"Hypergeometric2F1", "[", 
          RowBox[{
            RowBox[{"b", "+", "1", "-", "c"}], ",", "b", ",", 
            RowBox[{"b", "+", "1", "-", "a"}], ",", 
            RowBox[{"z", "^", 
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}]}]}], "]"}], "]"}]}]], "Input",
  CellLabel->"In[972]:=  (21:55:06 on 5/16/01)",
  CellTags->"Kummer"],

Cell[BoxData[
    FormBox[
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              RowBox[{
                SubscriptBox["\[InvisiblePrefixScriptBase]", 
                  FormBox["2",
                    "TraditionalForm"]], 
                SubscriptBox["F", 
                  FormBox["1",
                    "TraditionalForm"]]}], "\[InvisibleApplication]", 
              RowBox[{"(", 
                RowBox[{
                  TagBox[
                    TagBox[
                      RowBox[{
                        TagBox[
                          RowBox[{"b", "-", "c", "+", "1"}],
                          Hypergeometric2F1,
                          Editable->True], ",", 
                        TagBox["b",
                          Hypergeometric2F1,
                          Editable->True]}],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    TagBox[
                      TagBox[
                        RowBox[{
                          RowBox[{"-", "a"}], "+", "b", "+", "1"}],
                        Hypergeometric2F1,
                        Editable->True],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    FractionBox["1", "z"],
                    Hypergeometric2F1,
                    Editable->True]}], ")"}]}],
            InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
            Editable->False],
          Hypergeometric2F1], "==", 
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"1", "-", "z"}], ")"}], 
            RowBox[{
              RowBox[{"-", "b"}], "+", "c", "-", "1"}]], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "z"}], ")"}], 
            RowBox[{"b", "-", "c", "+", "1"}]], " ", 
          TagBox[
            TagBox[
              RowBox[{
                RowBox[{
                  SubscriptBox["\[InvisiblePrefixScriptBase]", 
                    FormBox["2",
                      "TraditionalForm"]], 
                  SubscriptBox["F", 
                    FormBox["1",
                      "TraditionalForm"]]}], "\[InvisibleApplication]", 
                RowBox[{"(", 
                  RowBox[{
                    TagBox[
                      TagBox[
                        RowBox[{
                          TagBox[
                            RowBox[{"b", "-", "c", "+", "1"}],
                            Hypergeometric2F1,
                            Editable->True], ",", 
                          TagBox[
                            RowBox[{"1", "-", "a"}],
                            Hypergeometric2F1,
                            Editable->True]}],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      TagBox[
                        TagBox[
                          RowBox[{
                            RowBox[{"-", "a"}], "+", "b", "+", "1"}],
                          Hypergeometric2F1,
                          Editable->True],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      FractionBox["1", 
                        RowBox[{"1", "-", "z"}]],
                      Hypergeometric2F1,
                      Editable->True]}], ")"}]}],
              InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
              Editable->False],
            Hypergeometric2F1]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[972]=  (21:55:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Hypergeometric2F1", "[", 
        RowBox[{
          RowBox[{"a", "+", "1", "-", "c"}], ",", 
          RowBox[{"b", "+", "1", "-", "c"}], ",", 
          RowBox[{"2", "-", "c"}], ",", "z"}], "]"}], "==", 
      RowBox[{
        RowBox[{"Kummer", "[", "18", "]"}], "[", 
        RowBox[{"Hypergeometric2F1", "[", 
          RowBox[{
            RowBox[{"a", "+", "1", "-", "c"}], ",", 
            RowBox[{"b", "+", "1", "-", "c"}], ",", 
            RowBox[{"2", "-", "c"}], ",", "z"}], "]"}], "]"}]}]], "Input",
  CellLabel->"In[973]:=  (21:55:06 on 5/16/01)",
  CellTags->"Kummer"],

Cell[BoxData[
    FormBox[
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              RowBox[{
                SubscriptBox["\[InvisiblePrefixScriptBase]", 
                  FormBox["2",
                    "TraditionalForm"]], 
                SubscriptBox["F", 
                  FormBox["1",
                    "TraditionalForm"]]}], "\[InvisibleApplication]", 
              RowBox[{"(", 
                RowBox[{
                  TagBox[
                    TagBox[
                      RowBox[{
                        TagBox[
                          RowBox[{"a", "-", "c", "+", "1"}],
                          Hypergeometric2F1,
                          Editable->True], ",", 
                        TagBox[
                          RowBox[{"b", "-", "c", "+", "1"}],
                          Hypergeometric2F1,
                          Editable->True]}],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    TagBox[
                      TagBox[
                        RowBox[{"2", "-", "c"}],
                        Hypergeometric2F1,
                        Editable->True],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox["z",
                    Hypergeometric2F1,
                    Editable->True]}], ")"}]}],
            InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
            Editable->False],
          Hypergeometric2F1], "==", 
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"1", "-", "z"}], ")"}], 
            RowBox[{
              RowBox[{"-", "a"}], "-", "b", "+", "c"}]], " ", 
          TagBox[
            TagBox[
              RowBox[{
                RowBox[{
                  SubscriptBox["\[InvisiblePrefixScriptBase]", 
                    FormBox["2",
                      "TraditionalForm"]], 
                  SubscriptBox["F", 
                    FormBox["1",
                      "TraditionalForm"]]}], "\[InvisibleApplication]", 
                RowBox[{"(", 
                  RowBox[{
                    TagBox[
                      TagBox[
                        RowBox[{
                          TagBox[
                            RowBox[{"1", "-", "a"}],
                            Hypergeometric2F1,
                            Editable->True], ",", 
                          TagBox[
                            RowBox[{"1", "-", "b"}],
                            Hypergeometric2F1,
                            Editable->True]}],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      TagBox[
                        TagBox[
                          RowBox[{"2", "-", "c"}],
                          Hypergeometric2F1,
                          Editable->True],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox["z",
                      Hypergeometric2F1,
                      Editable->True]}], ")"}]}],
              InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
              Editable->False],
            Hypergeometric2F1]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[973]=  (21:55:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Hypergeometric2F1", "[", 
        RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], "==", 
      RowBox[{
        RowBox[{"Kummer", "[", "18", "]"}], "[", 
        RowBox[{"Hypergeometric2F1", "[", 
          RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], 
        "]"}]}]], "Input",
  CellLabel->"In[974]:=  (21:55:06 on 5/16/01)",
  CellTags->"Kummer"],

Cell[BoxData[
    FormBox[
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              RowBox[{
                SubscriptBox["\[InvisiblePrefixScriptBase]", 
                  FormBox["2",
                    "TraditionalForm"]], 
                SubscriptBox["F", 
                  FormBox["1",
                    "TraditionalForm"]]}], "\[InvisibleApplication]", 
              RowBox[{"(", 
                RowBox[{
                  TagBox[
                    TagBox[
                      RowBox[{
                        TagBox["a",
                          Hypergeometric2F1,
                          Editable->True], ",", 
                        TagBox["b",
                          Hypergeometric2F1,
                          Editable->True]}],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    TagBox[
                      TagBox["c",
                        Hypergeometric2F1,
                        Editable->True],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox["z",
                    Hypergeometric2F1,
                    Editable->True]}], ")"}]}],
            InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
            Editable->False],
          Hypergeometric2F1], "==", 
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"1", "-", "z"}], ")"}], 
            RowBox[{
              RowBox[{"-", "a"}], "-", "b", "+", "c"}]], " ", 
          TagBox[
            TagBox[
              RowBox[{
                RowBox[{
                  SubscriptBox["\[InvisiblePrefixScriptBase]", 
                    FormBox["2",
                      "TraditionalForm"]], 
                  SubscriptBox["F", 
                    FormBox["1",
                      "TraditionalForm"]]}], "\[InvisibleApplication]", 
                RowBox[{"(", 
                  RowBox[{
                    TagBox[
                      TagBox[
                        RowBox[{
                          TagBox[
                            RowBox[{"c", "-", "a"}],
                            Hypergeometric2F1,
                            Editable->True], ",", 
                          TagBox[
                            RowBox[{"c", "-", "b"}],
                            Hypergeometric2F1,
                            Editable->True]}],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      TagBox[
                        TagBox["c",
                          Hypergeometric2F1,
                          Editable->True],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox["z",
                      Hypergeometric2F1,
                      Editable->True]}], ")"}]}],
              InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
              Editable->False],
            Hypergeometric2F1]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[974]=  (21:55:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Hypergeometric2F1", "[", 
        RowBox[{
          RowBox[{"a", "+", "1", "-", "c"}], ",", 
          RowBox[{"b", "+", "1", "-", "c"}], ",", 
          RowBox[{"2", "-", "c"}], ",", "z"}], "]"}], "==", 
      RowBox[{
        RowBox[{"Kummer", "[", "19", "]"}], "[", 
        RowBox[{"Hypergeometric2F1", "[", 
          RowBox[{
            RowBox[{"a", "+", "1", "-", "c"}], ",", 
            RowBox[{"b", "+", "1", "-", "c"}], ",", 
            RowBox[{"2", "-", "c"}], ",", "z"}], "]"}], "]"}]}]], "Input",
  CellLabel->"In[975]:=  (21:55:06 on 5/16/01)",
  CellTags->"Kummer"],

Cell[BoxData[
    FormBox[
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              RowBox[{
                SubscriptBox["\[InvisiblePrefixScriptBase]", 
                  FormBox["2",
                    "TraditionalForm"]], 
                SubscriptBox["F", 
                  FormBox["1",
                    "TraditionalForm"]]}], "\[InvisibleApplication]", 
              RowBox[{"(", 
                RowBox[{
                  TagBox[
                    TagBox[
                      RowBox[{
                        TagBox[
                          RowBox[{"a", "-", "c", "+", "1"}],
                          Hypergeometric2F1,
                          Editable->True], ",", 
                        TagBox[
                          RowBox[{"b", "-", "c", "+", "1"}],
                          Hypergeometric2F1,
                          Editable->True]}],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    TagBox[
                      TagBox[
                        RowBox[{"2", "-", "c"}],
                        Hypergeometric2F1,
                        Editable->True],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox["z",
                    Hypergeometric2F1,
                    Editable->True]}], ")"}]}],
            InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
            Editable->False],
          Hypergeometric2F1], "==", 
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"1", "-", "z"}], ")"}], 
            RowBox[{
              RowBox[{"-", "a"}], "+", "c", "-", "1"}]], " ", 
          TagBox[
            TagBox[
              RowBox[{
                RowBox[{
                  SubscriptBox["\[InvisiblePrefixScriptBase]", 
                    FormBox["2",
                      "TraditionalForm"]], 
                  SubscriptBox["F", 
                    FormBox["1",
                      "TraditionalForm"]]}], "\[InvisibleApplication]", 
                RowBox[{"(", 
                  RowBox[{
                    TagBox[
                      TagBox[
                        RowBox[{
                          TagBox[
                            RowBox[{"a", "-", "c", "+", "1"}],
                            Hypergeometric2F1,
                            Editable->True], ",", 
                          TagBox[
                            RowBox[{"1", "-", "b"}],
                            Hypergeometric2F1,
                            Editable->True]}],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      TagBox[
                        TagBox[
                          RowBox[{"2", "-", "c"}],
                          Hypergeometric2F1,
                          Editable->True],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      FractionBox["z", 
                        RowBox[{"z", "-", "1"}]],
                      Hypergeometric2F1,
                      Editable->True]}], ")"}]}],
              InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
              Editable->False],
            Hypergeometric2F1]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[975]=  (21:55:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Hypergeometric2F1", "[", 
        RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], "==", 
      RowBox[{
        RowBox[{"Kummer", "[", "19", "]"}], "[", 
        RowBox[{"Hypergeometric2F1", "[", 
          RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], 
        "]"}]}]], "Input",
  CellLabel->"In[976]:=  (21:55:06 on 5/16/01)",
  CellTags->"Kummer"],

Cell[BoxData[
    FormBox[
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              RowBox[{
                SubscriptBox["\[InvisiblePrefixScriptBase]", 
                  FormBox["2",
                    "TraditionalForm"]], 
                SubscriptBox["F", 
                  FormBox["1",
                    "TraditionalForm"]]}], "\[InvisibleApplication]", 
              RowBox[{"(", 
                RowBox[{
                  TagBox[
                    TagBox[
                      RowBox[{
                        TagBox["a",
                          Hypergeometric2F1,
                          Editable->True], ",", 
                        TagBox["b",
                          Hypergeometric2F1,
                          Editable->True]}],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    TagBox[
                      TagBox["c",
                        Hypergeometric2F1,
                        Editable->True],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox["z",
                    Hypergeometric2F1,
                    Editable->True]}], ")"}]}],
            InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
            Editable->False],
          Hypergeometric2F1], "==", 
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"1", "-", "z"}], ")"}], 
            RowBox[{"-", "a"}]], " ", 
          TagBox[
            TagBox[
              RowBox[{
                RowBox[{
                  SubscriptBox["\[InvisiblePrefixScriptBase]", 
                    FormBox["2",
                      "TraditionalForm"]], 
                  SubscriptBox["F", 
                    FormBox["1",
                      "TraditionalForm"]]}], "\[InvisibleApplication]", 
                RowBox[{"(", 
                  RowBox[{
                    TagBox[
                      TagBox[
                        RowBox[{
                          TagBox["a",
                            Hypergeometric2F1,
                            Editable->True], ",", 
                          TagBox[
                            RowBox[{"c", "-", "b"}],
                            Hypergeometric2F1,
                            Editable->True]}],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      TagBox[
                        TagBox["c",
                          Hypergeometric2F1,
                          Editable->True],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      FractionBox["z", 
                        RowBox[{"z", "-", "1"}]],
                      Hypergeometric2F1,
                      Editable->True]}], ")"}]}],
              InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
              Editable->False],
            Hypergeometric2F1]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[976]=  (21:55:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Hypergeometric2F1", "[", 
        RowBox[{
          RowBox[{"a", "+", "1", "-", "c"}], ",", 
          RowBox[{"b", "+", "1", "-", "c"}], ",", 
          RowBox[{"2", "-", "c"}], ",", "z"}], "]"}], "==", 
      RowBox[{
        RowBox[{"Kummer", "[", "20", "]"}], "[", 
        RowBox[{"Hypergeometric2F1", "[", 
          RowBox[{
            RowBox[{"a", "+", "1", "-", "c"}], ",", 
            RowBox[{"b", "+", "1", "-", "c"}], ",", 
            RowBox[{"2", "-", "c"}], ",", "z"}], "]"}], "]"}]}]], "Input",
  CellLabel->"In[977]:=  (21:55:07 on 5/16/01)",
  CellTags->"Kummer"],

Cell[BoxData[
    FormBox[
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              RowBox[{
                SubscriptBox["\[InvisiblePrefixScriptBase]", 
                  FormBox["2",
                    "TraditionalForm"]], 
                SubscriptBox["F", 
                  FormBox["1",
                    "TraditionalForm"]]}], "\[InvisibleApplication]", 
              RowBox[{"(", 
                RowBox[{
                  TagBox[
                    TagBox[
                      RowBox[{
                        TagBox[
                          RowBox[{"a", "-", "c", "+", "1"}],
                          Hypergeometric2F1,
                          Editable->True], ",", 
                        TagBox[
                          RowBox[{"b", "-", "c", "+", "1"}],
                          Hypergeometric2F1,
                          Editable->True]}],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    TagBox[
                      TagBox[
                        RowBox[{"2", "-", "c"}],
                        Hypergeometric2F1,
                        Editable->True],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox["z",
                    Hypergeometric2F1,
                    Editable->True]}], ")"}]}],
            InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
            Editable->False],
          Hypergeometric2F1], "==", 
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"1", "-", "z"}], ")"}], 
            RowBox[{
              RowBox[{"-", "b"}], "+", "c", "-", "1"}]], " ", 
          TagBox[
            TagBox[
              RowBox[{
                RowBox[{
                  SubscriptBox["\[InvisiblePrefixScriptBase]", 
                    FormBox["2",
                      "TraditionalForm"]], 
                  SubscriptBox["F", 
                    FormBox["1",
                      "TraditionalForm"]]}], "\[InvisibleApplication]", 
                RowBox[{"(", 
                  RowBox[{
                    TagBox[
                      TagBox[
                        RowBox[{
                          TagBox[
                            RowBox[{"b", "-", "c", "+", "1"}],
                            Hypergeometric2F1,
                            Editable->True], ",", 
                          TagBox[
                            RowBox[{"1", "-", "a"}],
                            Hypergeometric2F1,
                            Editable->True]}],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      TagBox[
                        TagBox[
                          RowBox[{"2", "-", "c"}],
                          Hypergeometric2F1,
                          Editable->True],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      FractionBox["z", 
                        RowBox[{"z", "-", "1"}]],
                      Hypergeometric2F1,
                      Editable->True]}], ")"}]}],
              InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
              Editable->False],
            Hypergeometric2F1]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[977]=  (21:55:07 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Hypergeometric2F1", "[", 
        RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], "==", 
      RowBox[{
        RowBox[{"Kummer", "[", "20", "]"}], "[", 
        RowBox[{"Hypergeometric2F1", "[", 
          RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], 
        "]"}]}]], "Input",
  CellLabel->"In[978]:=  (21:55:07 on 5/16/01)",
  CellTags->"Kummer"],

Cell[BoxData[
    FormBox[
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              RowBox[{
                SubscriptBox["\[InvisiblePrefixScriptBase]", 
                  FormBox["2",
                    "TraditionalForm"]], 
                SubscriptBox["F", 
                  FormBox["1",
                    "TraditionalForm"]]}], "\[InvisibleApplication]", 
              RowBox[{"(", 
                RowBox[{
                  TagBox[
                    TagBox[
                      RowBox[{
                        TagBox["a",
                          Hypergeometric2F1,
                          Editable->True], ",", 
                        TagBox["b",
                          Hypergeometric2F1,
                          Editable->True]}],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    TagBox[
                      TagBox["c",
                        Hypergeometric2F1,
                        Editable->True],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox["z",
                    Hypergeometric2F1,
                    Editable->True]}], ")"}]}],
            InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
            Editable->False],
          Hypergeometric2F1], "==", 
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"1", "-", "z"}], ")"}], 
            RowBox[{"-", "b"}]], " ", 
          TagBox[
            TagBox[
              RowBox[{
                RowBox[{
                  SubscriptBox["\[InvisiblePrefixScriptBase]", 
                    FormBox["2",
                      "TraditionalForm"]], 
                  SubscriptBox["F", 
                    FormBox["1",
                      "TraditionalForm"]]}], "\[InvisibleApplication]", 
                RowBox[{"(", 
                  RowBox[{
                    TagBox[
                      TagBox[
                        RowBox[{
                          TagBox["b",
                            Hypergeometric2F1,
                            Editable->True], ",", 
                          TagBox[
                            RowBox[{"c", "-", "a"}],
                            Hypergeometric2F1,
                            Editable->True]}],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      TagBox[
                        TagBox["c",
                          Hypergeometric2F1,
                          Editable->True],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      FractionBox["z", 
                        RowBox[{"z", "-", "1"}]],
                      Hypergeometric2F1,
                      Editable->True]}], ")"}]}],
              InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
              Editable->False],
            Hypergeometric2F1]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[978]=  (21:55:07 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Hypergeometric2F1", "[", 
        RowBox[{
          RowBox[{"c", "-", "a"}], ",", 
          RowBox[{"c", "-", "b"}], ",", 
          RowBox[{"c", "+", "1", "-", "a", "-", "b"}], ",", 
          RowBox[{"1", "-", "z"}]}], "]"}], "==", 
      RowBox[{
        RowBox[{"Kummer", "[", "22", "]"}], "[", 
        RowBox[{"Hypergeometric2F1", "[", 
          RowBox[{
            RowBox[{"c", "-", "a"}], ",", 
            RowBox[{"c", "-", "b"}], ",", 
            RowBox[{"c", "+", "1", "-", "a", "-", "b"}], ",", 
            RowBox[{"1", "-", "z"}]}], "]"}], "]"}]}]], "Input",
  CellLabel->"In[979]:=  (21:55:07 on 5/16/01)",
  CellTags->"Kummer"],

Cell[BoxData[
    FormBox[
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              RowBox[{
                SubscriptBox["\[InvisiblePrefixScriptBase]", 
                  FormBox["2",
                    "TraditionalForm"]], 
                SubscriptBox["F", 
                  FormBox["1",
                    "TraditionalForm"]]}], "\[InvisibleApplication]", 
              RowBox[{"(", 
                RowBox[{
                  TagBox[
                    TagBox[
                      RowBox[{
                        TagBox[
                          RowBox[{"c", "-", "a"}],
                          Hypergeometric2F1,
                          Editable->True], ",", 
                        TagBox[
                          RowBox[{"c", "-", "b"}],
                          Hypergeometric2F1,
                          Editable->True]}],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    TagBox[
                      TagBox[
                        RowBox[{
                          RowBox[{"-", "a"}], "-", "b", "+", "c", "+", "1"}],
                        Hypergeometric2F1,
                        Editable->True],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    RowBox[{"1", "-", "z"}],
                    Hypergeometric2F1,
                    Editable->True]}], ")"}]}],
            InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
            Editable->False],
          Hypergeometric2F1], "==", 
        RowBox[{
          SuperscriptBox["z", 
            RowBox[{"1", "-", "c"}]], " ", 
          TagBox[
            TagBox[
              RowBox[{
                RowBox[{
                  SubscriptBox["\[InvisiblePrefixScriptBase]", 
                    FormBox["2",
                      "TraditionalForm"]], 
                  SubscriptBox["F", 
                    FormBox["1",
                      "TraditionalForm"]]}], "\[InvisibleApplication]", 
                RowBox[{"(", 
                  RowBox[{
                    TagBox[
                      TagBox[
                        RowBox[{
                          TagBox[
                            RowBox[{"1", "-", "a"}],
                            Hypergeometric2F1,
                            Editable->True], ",", 
                          TagBox[
                            RowBox[{"1", "-", "b"}],
                            Hypergeometric2F1,
                            Editable->True]}],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      TagBox[
                        TagBox[
                          RowBox[{
                            RowBox[{"-", "a"}], "-", "b", "+", "c", "+", 
                            "1"}],
                          Hypergeometric2F1,
                          Editable->True],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      RowBox[{"1", "-", "z"}],
                      Hypergeometric2F1,
                      Editable->True]}], ")"}]}],
              InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
              Editable->False],
            Hypergeometric2F1]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[979]=  (21:55:07 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Hypergeometric2F1", "[", 
        RowBox[{"a", ",", "b", ",", "c", ",", 
          RowBox[{"1", "-", "z"}]}], "]"}], "==", 
      RowBox[{
        RowBox[{"Kummer", "[", "22", "]"}], "[", 
        RowBox[{"Hypergeometric2F1", "[", 
          RowBox[{"a", ",", "b", ",", "c", ",", 
            RowBox[{"1", "-", "z"}]}], "]"}], "]"}]}]], "Input",
  CellLabel->"In[980]:=  (21:55:07 on 5/16/01)",
  CellTags->"Kummer"],

Cell[BoxData[
    FormBox[
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              RowBox[{
                SubscriptBox["\[InvisiblePrefixScriptBase]", 
                  FormBox["2",
                    "TraditionalForm"]], 
                SubscriptBox["F", 
                  FormBox["1",
                    "TraditionalForm"]]}], "\[InvisibleApplication]", 
              RowBox[{"(", 
                RowBox[{
                  TagBox[
                    TagBox[
                      RowBox[{
                        TagBox["a",
                          Hypergeometric2F1,
                          Editable->True], ",", 
                        TagBox["b",
                          Hypergeometric2F1,
                          Editable->True]}],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    TagBox[
                      TagBox["c",
                        Hypergeometric2F1,
                        Editable->True],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    RowBox[{"1", "-", "z"}],
                    Hypergeometric2F1,
                    Editable->True]}], ")"}]}],
            InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
            Editable->False],
          Hypergeometric2F1], "==", 
        RowBox[{
          SuperscriptBox["z", 
            RowBox[{
              RowBox[{"-", "a"}], "-", "b", "+", "c"}]], " ", 
          TagBox[
            TagBox[
              RowBox[{
                RowBox[{
                  SubscriptBox["\[InvisiblePrefixScriptBase]", 
                    FormBox["2",
                      "TraditionalForm"]], 
                  SubscriptBox["F", 
                    FormBox["1",
                      "TraditionalForm"]]}], "\[InvisibleApplication]", 
                RowBox[{"(", 
                  RowBox[{
                    TagBox[
                      TagBox[
                        RowBox[{
                          TagBox[
                            RowBox[{"c", "-", "b"}],
                            Hypergeometric2F1,
                            Editable->True], ",", 
                          TagBox[
                            RowBox[{"c", "-", "a"}],
                            Hypergeometric2F1,
                            Editable->True]}],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      TagBox[
                        TagBox["c",
                          Hypergeometric2F1,
                          Editable->True],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      RowBox[{"1", "-", "z"}],
                      Hypergeometric2F1,
                      Editable->True]}], ")"}]}],
              InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
              Editable->False],
            Hypergeometric2F1]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[980]=  (21:55:07 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Hypergeometric2F1", "[", 
        RowBox[{
          RowBox[{"c", "-", "a"}], ",", 
          RowBox[{"c", "-", "b"}], ",", 
          RowBox[{"c", "+", "1", "-", "a", "-", "b"}], ",", 
          RowBox[{"1", "-", "z"}]}], "]"}], "==", 
      RowBox[{
        RowBox[{"Kummer", "[", "23", "]"}], "[", 
        RowBox[{"Hypergeometric2F1", "[", 
          RowBox[{
            RowBox[{"c", "-", "a"}], ",", 
            RowBox[{"c", "-", "b"}], ",", 
            RowBox[{"c", "+", "1", "-", "a", "-", "b"}], ",", 
            RowBox[{"1", "-", "z"}]}], "]"}], "]"}]}]], "Input",
  CellLabel->"In[981]:=  (21:55:07 on 5/16/01)",
  CellTags->"Kummer"],

Cell[BoxData[
    FormBox[
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              RowBox[{
                SubscriptBox["\[InvisiblePrefixScriptBase]", 
                  FormBox["2",
                    "TraditionalForm"]], 
                SubscriptBox["F", 
                  FormBox["1",
                    "TraditionalForm"]]}], "\[InvisibleApplication]", 
              RowBox[{"(", 
                RowBox[{
                  TagBox[
                    TagBox[
                      RowBox[{
                        TagBox[
                          RowBox[{"c", "-", "a"}],
                          Hypergeometric2F1,
                          Editable->True], ",", 
                        TagBox[
                          RowBox[{"c", "-", "b"}],
                          Hypergeometric2F1,
                          Editable->True]}],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    TagBox[
                      TagBox[
                        RowBox[{
                          RowBox[{"-", "a"}], "-", "b", "+", "c", "+", "1"}],
                        Hypergeometric2F1,
                        Editable->True],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    RowBox[{"1", "-", "z"}],
                    Hypergeometric2F1,
                    Editable->True]}], ")"}]}],
            InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
            Editable->False],
          Hypergeometric2F1], "==", 
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"1", "-", "z"}], ")"}], 
            RowBox[{"a", "-", "c"}]], " ", 
          TagBox[
            TagBox[
              RowBox[{
                RowBox[{
                  SubscriptBox["\[InvisiblePrefixScriptBase]", 
                    FormBox["2",
                      "TraditionalForm"]], 
                  SubscriptBox["F", 
                    FormBox["1",
                      "TraditionalForm"]]}], "\[InvisibleApplication]", 
                RowBox[{"(", 
                  RowBox[{
                    TagBox[
                      TagBox[
                        RowBox[{
                          TagBox[
                            RowBox[{"c", "-", "a"}],
                            Hypergeometric2F1,
                            Editable->True], ",", 
                          TagBox[
                            RowBox[{"1", "-", "a"}],
                            Hypergeometric2F1,
                            Editable->True]}],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      TagBox[
                        TagBox[
                          RowBox[{
                            RowBox[{"-", "a"}], "-", "b", "+", "c", "+", 
                            "1"}],
                          Hypergeometric2F1,
                          Editable->True],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      RowBox[{"1", "-", 
                        FractionBox["1", 
                          RowBox[{"1", "-", "z"}]]}],
                      Hypergeometric2F1,
                      Editable->True]}], ")"}]}],
              InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
              Editable->False],
            Hypergeometric2F1]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[981]=  (21:55:07 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Hypergeometric2F1", "[", 
        RowBox[{"a", ",", "b", ",", "c", ",", 
          RowBox[{"1", "-", "z"}]}], "]"}], "==", 
      RowBox[{
        RowBox[{"Kummer", "[", "23", "]"}], "[", 
        RowBox[{"Hypergeometric2F1", "[", 
          RowBox[{"a", ",", "b", ",", "c", ",", 
            RowBox[{"1", "-", "z"}]}], "]"}], "]"}]}]], "Input",
  CellLabel->"In[982]:=  (21:55:07 on 5/16/01)",
  CellTags->"Kummer"],

Cell[BoxData[
    FormBox[
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              RowBox[{
                SubscriptBox["\[InvisiblePrefixScriptBase]", 
                  FormBox["2",
                    "TraditionalForm"]], 
                SubscriptBox["F", 
                  FormBox["1",
                    "TraditionalForm"]]}], "\[InvisibleApplication]", 
              RowBox[{"(", 
                RowBox[{
                  TagBox[
                    TagBox[
                      RowBox[{
                        TagBox["a",
                          Hypergeometric2F1,
                          Editable->True], ",", 
                        TagBox["b",
                          Hypergeometric2F1,
                          Editable->True]}],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    TagBox[
                      TagBox["c",
                        Hypergeometric2F1,
                        Editable->True],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    RowBox[{"1", "-", "z"}],
                    Hypergeometric2F1,
                    Editable->True]}], ")"}]}],
            InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
            Editable->False],
          Hypergeometric2F1], "==", 
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"1", "-", "z"}], ")"}], 
            RowBox[{"-", "a"}]], " ", 
          TagBox[
            TagBox[
              RowBox[{
                RowBox[{
                  SubscriptBox["\[InvisiblePrefixScriptBase]", 
                    FormBox["2",
                      "TraditionalForm"]], 
                  SubscriptBox["F", 
                    FormBox["1",
                      "TraditionalForm"]]}], "\[InvisibleApplication]", 
                RowBox[{"(", 
                  RowBox[{
                    TagBox[
                      TagBox[
                        RowBox[{
                          TagBox["a",
                            Hypergeometric2F1,
                            Editable->True], ",", 
                          TagBox[
                            RowBox[{"c", "-", "b"}],
                            Hypergeometric2F1,
                            Editable->True]}],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      TagBox[
                        TagBox["c",
                          Hypergeometric2F1,
                          Editable->True],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      RowBox[{"1", "-", 
                        FractionBox["1", 
                          RowBox[{"1", "-", "z"}]]}],
                      Hypergeometric2F1,
                      Editable->True]}], ")"}]}],
              InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
              Editable->False],
            Hypergeometric2F1]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[982]=  (21:55:07 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Hypergeometric2F1", "[", 
        RowBox[{
          RowBox[{"c", "-", "a"}], ",", 
          RowBox[{"c", "-", "b"}], ",", 
          RowBox[{"c", "+", "1", "-", "a", "-", "b"}], ",", 
          RowBox[{"1", "-", "z"}]}], "]"}], "==", 
      RowBox[{
        RowBox[{"Kummer", "[", "24", "]"}], "[", 
        RowBox[{"Hypergeometric2F1", "[", 
          RowBox[{
            RowBox[{"c", "-", "a"}], ",", 
            RowBox[{"c", "-", "b"}], ",", 
            RowBox[{"c", "+", "1", "-", "a", "-", "b"}], ",", 
            RowBox[{"1", "-", "z"}]}], "]"}], "]"}]}]], "Input",
  CellLabel->"In[983]:=  (21:55:07 on 5/16/01)",
  CellTags->"Kummer"],

Cell[BoxData[
    FormBox[
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              RowBox[{
                SubscriptBox["\[InvisiblePrefixScriptBase]", 
                  FormBox["2",
                    "TraditionalForm"]], 
                SubscriptBox["F", 
                  FormBox["1",
                    "TraditionalForm"]]}], "\[InvisibleApplication]", 
              RowBox[{"(", 
                RowBox[{
                  TagBox[
                    TagBox[
                      RowBox[{
                        TagBox[
                          RowBox[{"c", "-", "a"}],
                          Hypergeometric2F1,
                          Editable->True], ",", 
                        TagBox[
                          RowBox[{"c", "-", "b"}],
                          Hypergeometric2F1,
                          Editable->True]}],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    TagBox[
                      TagBox[
                        RowBox[{
                          RowBox[{"-", "a"}], "-", "b", "+", "c", "+", "1"}],
                        Hypergeometric2F1,
                        Editable->True],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    RowBox[{"1", "-", "z"}],
                    Hypergeometric2F1,
                    Editable->True]}], ")"}]}],
            InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
            Editable->False],
          Hypergeometric2F1], "==", 
        RowBox[{
          SuperscriptBox["z", 
            RowBox[{"b", "-", "c"}]], " ", 
          TagBox[
            TagBox[
              RowBox[{
                RowBox[{
                  SubscriptBox["\[InvisiblePrefixScriptBase]", 
                    FormBox["2",
                      "TraditionalForm"]], 
                  SubscriptBox["F", 
                    FormBox["1",
                      "TraditionalForm"]]}], "\[InvisibleApplication]", 
                RowBox[{"(", 
                  RowBox[{
                    TagBox[
                      TagBox[
                        RowBox[{
                          TagBox[
                            RowBox[{"c", "-", "b"}],
                            Hypergeometric2F1,
                            Editable->True], ",", 
                          TagBox[
                            RowBox[{"1", "-", "b"}],
                            Hypergeometric2F1,
                            Editable->True]}],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      TagBox[
                        TagBox[
                          RowBox[{
                            RowBox[{"-", "a"}], "-", "b", "+", "c", "+", 
                            "1"}],
                          Hypergeometric2F1,
                          Editable->True],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      RowBox[{"-", 
                        FractionBox[
                          RowBox[{"1", "-", "z"}], "z"]}],
                      Hypergeometric2F1,
                      Editable->True]}], ")"}]}],
              InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
              Editable->False],
            Hypergeometric2F1]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[983]=  (21:55:07 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Hypergeometric2F1", "[", 
        RowBox[{"a", ",", "b", ",", "c", ",", 
          RowBox[{"1", "-", "z"}]}], "]"}], "==", 
      RowBox[{
        RowBox[{"Kummer", "[", "24", "]"}], "[", 
        RowBox[{"Hypergeometric2F1", "[", 
          RowBox[{"a", ",", "b", ",", "c", ",", 
            RowBox[{"1", "-", "z"}]}], "]"}], "]"}]}]], "Input",
  CellLabel->"In[984]:=  (21:55:07 on 5/16/01)",
  CellTags->"Kummer"],

Cell[BoxData[
    FormBox[
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              RowBox[{
                SubscriptBox["\[InvisiblePrefixScriptBase]", 
                  FormBox["2",
                    "TraditionalForm"]], 
                SubscriptBox["F", 
                  FormBox["1",
                    "TraditionalForm"]]}], "\[InvisibleApplication]", 
              RowBox[{"(", 
                RowBox[{
                  TagBox[
                    TagBox[
                      RowBox[{
                        TagBox["a",
                          Hypergeometric2F1,
                          Editable->True], ",", 
                        TagBox["b",
                          Hypergeometric2F1,
                          Editable->True]}],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    TagBox[
                      TagBox["c",
                        Hypergeometric2F1,
                        Editable->True],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    RowBox[{"1", "-", "z"}],
                    Hypergeometric2F1,
                    Editable->True]}], ")"}]}],
            InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
            Editable->False],
          Hypergeometric2F1], "==", 
        RowBox[{
          SuperscriptBox["z", 
            RowBox[{"-", "b"}]], " ", 
          TagBox[
            TagBox[
              RowBox[{
                RowBox[{
                  SubscriptBox["\[InvisiblePrefixScriptBase]", 
                    FormBox["2",
                      "TraditionalForm"]], 
                  SubscriptBox["F", 
                    FormBox["1",
                      "TraditionalForm"]]}], "\[InvisibleApplication]", 
                RowBox[{"(", 
                  RowBox[{
                    TagBox[
                      TagBox[
                        RowBox[{
                          TagBox["b",
                            Hypergeometric2F1,
                            Editable->True], ",", 
                          TagBox[
                            RowBox[{"c", "-", "a"}],
                            Hypergeometric2F1,
                            Editable->True]}],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      TagBox[
                        TagBox["c",
                          Hypergeometric2F1,
                          Editable->True],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      RowBox[{"-", 
                        FractionBox[
                          RowBox[{"1", "-", "z"}], "z"]}],
                      Hypergeometric2F1,
                      Editable->True]}], ")"}]}],
              InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
              Editable->False],
            Hypergeometric2F1]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[984]=  (21:55:07 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Hypergeometric2F1", "[", 
        RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], "==", 
      RowBox[{
        RowBox[{"Kummer", "[", "94", "]"}], "[", 
        RowBox[{"Hypergeometric2F1", "[", 
          RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], 
        "]"}]}]], "Input",
  CellLabel->"In[985]:=  (21:55:07 on 5/16/01)",
  CellTags->"Kummer"],

Cell[BoxData[
    FormBox[
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              RowBox[{
                SubscriptBox["\[InvisiblePrefixScriptBase]", 
                  FormBox["2",
                    "TraditionalForm"]], 
                SubscriptBox["F", 
                  FormBox["1",
                    "TraditionalForm"]]}], "\[InvisibleApplication]", 
              RowBox[{"(", 
                RowBox[{
                  TagBox[
                    TagBox[
                      RowBox[{
                        TagBox["a",
                          Hypergeometric2F1,
                          Editable->True], ",", 
                        TagBox["b",
                          Hypergeometric2F1,
                          Editable->True]}],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    TagBox[
                      TagBox["c",
                        Hypergeometric2F1,
                        Editable->True],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox["z",
                    Hypergeometric2F1,
                    Editable->True]}], ")"}]}],
            InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
            Editable->False],
          Hypergeometric2F1], "==", 
        RowBox[{
          FractionBox[
            RowBox[{
              RowBox[{"\[CapitalGamma]", "(", 
                RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
              RowBox[{"\[CapitalGamma]", "(", "c", ")"}], " ", 
              TagBox[
                TagBox[
                  RowBox[{
                    RowBox[{
                      SubscriptBox["\[InvisiblePrefixScriptBase]", 
                        FormBox["2",
                          "TraditionalForm"]], 
                      SubscriptBox["F", 
                        FormBox["1",
                          "TraditionalForm"]]}], "\[InvisibleApplication]", 
                    RowBox[{"(", 
                      RowBox[{
                        TagBox[
                          TagBox[
                            RowBox[{
                              TagBox[
                                RowBox[{"c", "-", "a"}],
                                Hypergeometric2F1,
                                Editable->True], ",", 
                              TagBox[
                                RowBox[{"c", "-", "b"}],
                                Hypergeometric2F1,
                                Editable->True]}],
                            InterpretTemplate[ {
                              SlotSequence[ 1]}&]],
                          Hypergeometric2F1,
                          Editable->False], ";", 
                        TagBox[
                          TagBox[
                            TagBox[
                              RowBox[{
                                RowBox[{"-", "a"}], "-", "b", "+", "c", "+", 
                                "1"}],
                              Hypergeometric2F1,
                              Editable->True],
                            InterpretTemplate[ {
                              SlotSequence[ 1]}&]],
                          Hypergeometric2F1,
                          Editable->False], ";", 
                        TagBox[
                          RowBox[{"1", "-", "z"}],
                          Hypergeometric2F1,
                          Editable->True]}], ")"}]}],
                  InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
                  Editable->False],
                Hypergeometric2F1], " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"1", "-", "z"}], ")"}], 
                RowBox[{
                  RowBox[{"-", "a"}], "-", "b", "+", "c"}]]}], 
            RowBox[{
              RowBox[{"\[CapitalGamma]", "(", "a", ")"}], " ", 
              RowBox[{"\[CapitalGamma]", "(", "b", ")"}]}]], "+", 
          FractionBox[
            RowBox[{
              RowBox[{"\[CapitalGamma]", "(", "c", ")"}], " ", 
              RowBox[{"\[CapitalGamma]", "(", 
                RowBox[{
                  RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}], " ", 
              TagBox[
                TagBox[
                  RowBox[{
                    RowBox[{
                      SubscriptBox["\[InvisiblePrefixScriptBase]", 
                        FormBox["2",
                          "TraditionalForm"]], 
                      SubscriptBox["F", 
                        FormBox["1",
                          "TraditionalForm"]]}], "\[InvisibleApplication]", 
                    RowBox[{"(", 
                      RowBox[{
                        TagBox[
                          TagBox[
                            RowBox[{
                              TagBox["a",
                                Hypergeometric2F1,
                                Editable->True], ",", 
                              TagBox["b",
                                Hypergeometric2F1,
                                Editable->True]}],
                            InterpretTemplate[ {
                              SlotSequence[ 1]}&]],
                          Hypergeometric2F1,
                          Editable->False], ";", 
                        TagBox[
                          TagBox[
                            TagBox[
                              RowBox[{"a", "+", "b", "-", "c", "+", "1"}],
                              Hypergeometric2F1,
                              Editable->True],
                            InterpretTemplate[ {
                              SlotSequence[ 1]}&]],
                          Hypergeometric2F1,
                          Editable->False], ";", 
                        TagBox[
                          RowBox[{"1", "-", "z"}],
                          Hypergeometric2F1,
                          Editable->True]}], ")"}]}],
                  InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
                  Editable->False],
                Hypergeometric2F1]}], 
            RowBox[{
              RowBox[{"\[CapitalGamma]", "(", 
                RowBox[{"c", "-", "a"}], ")"}], " ", 
              RowBox[{"\[CapitalGamma]", "(", 
                RowBox[{"c", "-", "b"}], ")"}]}]]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[985]=  (21:55:07 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Hypergeometric2F1", "[", 
        RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], "==", 
      RowBox[{
        RowBox[{"Kummer", "[", "95", "]"}], "[", 
        RowBox[{"Hypergeometric2F1", "[", 
          RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], 
        "]"}]}]], "Input",
  CellLabel->"In[986]:=  (21:55:07 on 5/16/01)",
  CellTags->"Kummer"],

Cell[BoxData[
    FormBox[
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              RowBox[{
                SubscriptBox["\[InvisiblePrefixScriptBase]", 
                  FormBox["2",
                    "TraditionalForm"]], 
                SubscriptBox["F", 
                  FormBox["1",
                    "TraditionalForm"]]}], "\[InvisibleApplication]", 
              RowBox[{"(", 
                RowBox[{
                  TagBox[
                    TagBox[
                      RowBox[{
                        TagBox["a",
                          Hypergeometric2F1,
                          Editable->True], ",", 
                        TagBox["b",
                          Hypergeometric2F1,
                          Editable->True]}],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    TagBox[
                      TagBox["c",
                        Hypergeometric2F1,
                        Editable->True],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox["z",
                    Hypergeometric2F1,
                    Editable->True]}], ")"}]}],
            InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
            Editable->False],
          Hypergeometric2F1], "==", 
        RowBox[{
          FractionBox[
            RowBox[{
              RowBox[{"\[CapitalGamma]", "(", 
                RowBox[{"b", "-", "a"}], ")"}], " ", 
              RowBox[{"\[CapitalGamma]", "(", "c", ")"}], " ", 
              TagBox[
                TagBox[
                  RowBox[{
                    RowBox[{
                      SubscriptBox["\[InvisiblePrefixScriptBase]", 
                        FormBox["2",
                          "TraditionalForm"]], 
                      SubscriptBox["F", 
                        FormBox["1",
                          "TraditionalForm"]]}], "\[InvisibleApplication]", 
                    RowBox[{"(", 
                      RowBox[{
                        TagBox[
                          TagBox[
                            RowBox[{
                              TagBox["a",
                                Hypergeometric2F1,
                                Editable->True], ",", 
                              TagBox[
                                RowBox[{"c", "-", "b"}],
                                Hypergeometric2F1,
                                Editable->True]}],
                            InterpretTemplate[ {
                              SlotSequence[ 1]}&]],
                          Hypergeometric2F1,
                          Editable->False], ";", 
                        TagBox[
                          TagBox[
                            TagBox[
                              RowBox[{"a", "-", "b", "+", "1"}],
                              Hypergeometric2F1,
                              Editable->True],
                            InterpretTemplate[ {
                              SlotSequence[ 1]}&]],
                          Hypergeometric2F1,
                          Editable->False], ";", 
                        TagBox[
                          FractionBox["1", 
                            RowBox[{"1", "-", "z"}]],
                          Hypergeometric2F1,
                          Editable->True]}], ")"}]}],
                  InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
                  Editable->False],
                Hypergeometric2F1], " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"1", "-", "z"}], ")"}], 
                RowBox[{"-", "a"}]]}], 
            RowBox[{
              RowBox[{"\[CapitalGamma]", "(", "b", ")"}], " ", 
              RowBox[{"\[CapitalGamma]", "(", 
                RowBox[{"c", "-", "a"}], ")"}]}]], "+", 
          FractionBox[
            RowBox[{
              RowBox[{"\[CapitalGamma]", "(", 
                RowBox[{"a", "-", "b"}], ")"}], " ", 
              RowBox[{"\[CapitalGamma]", "(", "c", ")"}], " ", 
              TagBox[
                TagBox[
                  RowBox[{
                    RowBox[{
                      SubscriptBox["\[InvisiblePrefixScriptBase]", 
                        FormBox["2",
                          "TraditionalForm"]], 
                      SubscriptBox["F", 
                        FormBox["1",
                          "TraditionalForm"]]}], "\[InvisibleApplication]", 
                    RowBox[{"(", 
                      RowBox[{
                        TagBox[
                          TagBox[
                            RowBox[{
                              TagBox["b",
                                Hypergeometric2F1,
                                Editable->True], ",", 
                              TagBox[
                                RowBox[{"c", "-", "a"}],
                                Hypergeometric2F1,
                                Editable->True]}],
                            InterpretTemplate[ {
                              SlotSequence[ 1]}&]],
                          Hypergeometric2F1,
                          Editable->False], ";", 
                        TagBox[
                          TagBox[
                            TagBox[
                              RowBox[{
                                RowBox[{"-", "a"}], "+", "b", "+", "1"}],
                              Hypergeometric2F1,
                              Editable->True],
                            InterpretTemplate[ {
                              SlotSequence[ 1]}&]],
                          Hypergeometric2F1,
                          Editable->False], ";", 
                        TagBox[
                          FractionBox["1", 
                            RowBox[{"1", "-", "z"}]],
                          Hypergeometric2F1,
                          Editable->True]}], ")"}]}],
                  InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
                  Editable->False],
                Hypergeometric2F1], " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"1", "-", "z"}], ")"}], 
                RowBox[{"-", "b"}]]}], 
            RowBox[{
              RowBox[{"\[CapitalGamma]", "(", "a", ")"}], " ", 
              RowBox[{"\[CapitalGamma]", "(", 
                RowBox[{"c", "-", "b"}], ")"}]}]]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[986]=  (21:55:07 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Hypergeometric2F1", "[", 
        RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], "==", 
      RowBox[{
        RowBox[{"Kummer", "[", "96", "]"}], "[", 
        RowBox[{"Hypergeometric2F1", "[", 
          RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], 
        "]"}]}]], "Input",
  CellLabel->"In[987]:=  (21:55:07 on 5/16/01)",
  CellTags->"Kummer"],

Cell[BoxData[
    FormBox[
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{
              RowBox[{
                SubscriptBox["\[InvisiblePrefixScriptBase]", 
                  FormBox["2",
                    "TraditionalForm"]], 
                SubscriptBox["F", 
                  FormBox["1",
                    "TraditionalForm"]]}], "\[InvisibleApplication]", 
              RowBox[{"(", 
                RowBox[{
                  TagBox[
                    TagBox[
                      RowBox[{
                        TagBox["a",
                          Hypergeometric2F1,
                          Editable->True], ",", 
                        TagBox["b",
                          Hypergeometric2F1,
                          Editable->True]}],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox[
                    TagBox[
                      TagBox["c",
                        Hypergeometric2F1,
                        Editable->True],
                      InterpretTemplate[ {
                        SlotSequence[ 1]}&]],
                    Hypergeometric2F1,
                    Editable->False], ";", 
                  TagBox["z",
                    Hypergeometric2F1,
                    Editable->True]}], ")"}]}],
            InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
            Editable->False],
          Hypergeometric2F1], "==", 
        RowBox[{
          FractionBox[
            RowBox[{
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"-", "1"}], ")"}], "a"], " ", 
              RowBox[{"\[CapitalGamma]", "(", 
                RowBox[{"b", "-", "a"}], ")"}], " ", 
              RowBox[{"\[CapitalGamma]", "(", "c", ")"}], " ", 
              TagBox[
                TagBox[
                  RowBox[{
                    RowBox[{
                      SubscriptBox["\[InvisiblePrefixScriptBase]", 
                        FormBox["2",
                          "TraditionalForm"]], 
                      SubscriptBox["F", 
                        FormBox["1",
                          "TraditionalForm"]]}], "\[InvisibleApplication]", 
                    RowBox[{"(", 
                      RowBox[{
                        TagBox[
                          TagBox[
                            RowBox[{
                              TagBox["a",
                                Hypergeometric2F1,
                                Editable->True], ",", 
                              TagBox[
                                RowBox[{"a", "-", "c", "+", "1"}],
                                Hypergeometric2F1,
                                Editable->True]}],
                            InterpretTemplate[ {
                              SlotSequence[ 1]}&]],
                          Hypergeometric2F1,
                          Editable->False], ";", 
                        TagBox[
                          TagBox[
                            TagBox[
                              RowBox[{"a", "-", "b", "+", "1"}],
                              Hypergeometric2F1,
                              Editable->True],
                            InterpretTemplate[ {
                              SlotSequence[ 1]}&]],
                          Hypergeometric2F1,
                          Editable->False], ";", 
                        TagBox[
                          FractionBox["1", "z"],
                          Hypergeometric2F1,
                          Editable->True]}], ")"}]}],
                  InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
                  Editable->False],
                Hypergeometric2F1], " ", 
              SuperscriptBox["z", 
                RowBox[{"-", "a"}]]}], 
            RowBox[{
              RowBox[{"\[CapitalGamma]", "(", "b", ")"}], " ", 
              RowBox[{"\[CapitalGamma]", "(", 
                RowBox[{"c", "-", "a"}], ")"}]}]], "+", 
          FractionBox[
            RowBox[{
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"-", "1"}], ")"}], "b"], " ", 
              RowBox[{"\[CapitalGamma]", "(", 
                RowBox[{"a", "-", "b"}], ")"}], " ", 
              RowBox[{"\[CapitalGamma]", "(", "c", ")"}], " ", 
              TagBox[
                TagBox[
                  RowBox[{
                    RowBox[{
                      SubscriptBox["\[InvisiblePrefixScriptBase]", 
                        FormBox["2",
                          "TraditionalForm"]], 
                      SubscriptBox["F", 
                        FormBox["1",
                          "TraditionalForm"]]}], "\[InvisibleApplication]", 
                    RowBox[{"(", 
                      RowBox[{
                        TagBox[
                          TagBox[
                            RowBox[{
                              TagBox["b",
                                Hypergeometric2F1,
                                Editable->True], ",", 
                              TagBox[
                                RowBox[{"b", "-", "c", "+", "1"}],
                                Hypergeometric2F1,
                                Editable->True]}],
                            InterpretTemplate[ {
                              SlotSequence[ 1]}&]],
                          Hypergeometric2F1,
                          Editable->False], ";", 
                        TagBox[
                          TagBox[
                            TagBox[
                              RowBox[{
                                RowBox[{"-", "a"}], "+", "b", "+", "1"}],
                              Hypergeometric2F1,
                              Editable->True],
                            InterpretTemplate[ {
                              SlotSequence[ 1]}&]],
                          Hypergeometric2F1,
                          Editable->False], ";", 
                        TagBox[
                          FractionBox["1", "z"],
                          Hypergeometric2F1,
                          Editable->True]}], ")"}]}],
                  InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
                  Editable->False],
                Hypergeometric2F1], " ", 
              SuperscriptBox["z", 
                RowBox[{"-", "b"}]]}], 
            RowBox[{
              RowBox[{"\[CapitalGamma]", "(", "a", ")"}], " ", 
              RowBox[{"\[CapitalGamma]", "(", 
                RowBox[{"c", "-", "b"}], ")"}]}]]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[987]=  (21:55:07 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Lagrangian", "ObjectName",
  CellTags->"Lagrangian"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"Lagrangian"],

Cell["\<\
Lagrangian[oqu] gives the unpolarized quark operator. Lagrangian[oqp] gives \
the polarized quark operator. Lagrangian[\"QCD\"] gives part of the QCD \
Lagrangian.\
\>", "Text",
  CellTags->"Lagrangian"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["FeynRule",
    ButtonData:>"FeynRule",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FeynRule"],
  "."
}], "Text",
  CellTags->"Lagrangian"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"Lagrangian"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Lagrangian", "[", "\"\<QCD\>\"", "]"}]], "Input",
  CellLabel->"In[988]:=  (21:55:07 on 5/16/01)",
  CellTags->"Lagrangian"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          FractionBox["1", "4"]}], " ", 
        RowBox[{
          SubsuperscriptBox["F", 
            RowBox[{"\[Alpha]", "\[NoBreak]", "\[Beta]"}], "a"], ".", 
          SubsuperscriptBox["F", 
            RowBox[{"\[Alpha]", "\[NoBreak]", "\[Beta]"}], "a"]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[988]=  (21:55:07 on 5/16/01)"]
}, Closed]],

Cell["Twist-2 operator product expansion operators", "Text",
  CellTags->"Lagrangian"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Lagrangian", "[", "\"\<ogu\>\"", "]"}]], "Input",
  CellLabel->"In[989]:=  (21:55:07 on 5/16/01)",
  CellTags->"Lagrangian"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox["\[ImaginaryI]", 
          RowBox[{"m", "-", "1"}]], " ", 
        RowBox[{
          SubsuperscriptBox["F", 
            RowBox[{"\[Alpha]", "\[NoBreak]", 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"]}], "a"], ".", 
          SuperscriptBox[
            RowBox[{"(", 
              SubsuperscriptBox["D", 
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], 
                RowBox[{"a", "\[NoBreak]", "b"}]], ")"}], 
            RowBox[{"m", "-", "2"}]], ".", 
          SubsuperscriptBox["F", 
            RowBox[{"\[Alpha]", "\[NoBreak]", 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"]}], "b"]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[989]=  (21:55:07 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Lagrangian", "[", "\"\<ogp\>\"", "]"}]], "Input",
  CellLabel->"In[990]:=  (21:55:07 on 5/16/01)",
  CellTags->"Lagrangian"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox["\[ImaginaryI]", "m"], " ", 
        RowBox[{
          SuperscriptBox["\[Epsilon]", 
            RowBox[{
              FormBox[
                FormBox["\[Alpha]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Beta]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["\[Gamma]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"]}]], ".", 
          SubsuperscriptBox["F", 
            RowBox[{"\[Beta]", "\[NoBreak]", "\[Gamma]"}], "a"], ".", 
          SuperscriptBox[
            RowBox[{"(", 
              SubsuperscriptBox["D", 
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], 
                RowBox[{"a", "\[NoBreak]", "b"}]], ")"}], 
            RowBox[{"m", "-", "2"}]], ".", 
          SubsuperscriptBox["F", 
            RowBox[{"\[Alpha]", "\[NoBreak]", 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"]}], "b"]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[990]=  (21:55:07 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Lagrangian", "[", "\"\<oqu\>\"", "]"}]], "Input",
  CellLabel->"In[991]:=  (21:55:07 on 5/16/01)",
  CellTags->"Lagrangian"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[ImaginaryI]", "m"], " ", 
        RowBox[{
          FormBox[
            OverscriptBox["\[Psi]", "_"],
            "TraditionalForm"], ".", 
          RowBox[{"(", 
            RowBox[{
              FormBox["\<\"\[Gamma]\"\>",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"]}], ")"}], ".", 
          SuperscriptBox[
            SubscriptBox["D", 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"]], 
            RowBox[{"m", "-", "1"}]], ".", 
          FormBox["\[Psi]",
            "TraditionalForm"]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[991]=  (21:55:07 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Lagrangian", "[", "\"\<oqp\>\"", "]"}]], "Input",
  CellLabel->"In[992]:=  (21:55:07 on 5/16/01)",
  CellTags->"Lagrangian"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[ImaginaryI]", "m"], " ", 
        RowBox[{
          FormBox[
            OverscriptBox["\[Psi]", "_"],
            "TraditionalForm"], ".", 
          SuperscriptBox["\[Gamma]", "5"], ".", 
          RowBox[{"(", 
            RowBox[{
              FormBox["\<\"\[Gamma]\"\>",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"]}], ")"}], ".", 
          SuperscriptBox[
            SubscriptBox["D", 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"]], 
            RowBox[{"m", "-", "1"}]], ".", 
          FormBox["\[Psi]",
            "TraditionalForm"]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[992]=  (21:55:07 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["LC", "ObjectName",
  CellTags->"LC"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"LC"],

Cell["\<\
LC[m,n,r,s] evaluates to 4-dimensional LeviCivita[m,n,r,s] by virtue of \
applying FeynCalcInternal. LC[m,...][p, ...] evaluates to 4-dimensional \
LeviCivita[m,...][p,...] applying FeynCalcInternal.\
\>", "Text",
  CellTags->"LC"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["LeviCivita",
    ButtonData:>"LeviCivita",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"LeviCivita"],
  ", ",
  ButtonBox["LCD",
    ButtonData:>"LCD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"LCD"],
  "."
}], "Text",
  CellTags->"LC"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"LC"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"LC", "[", 
      RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Sigma]"}], 
      "]"}]], "Input",
  CellLabel->"In[993]:=  (21:55:08 on 5/16/01)",
  CellTags->"LC"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["\[Epsilon]", 
        RowBox[{
        "\[Mu]", "\[NoBreak]", "\[Nu]", "\[NoBreak]", "\[Rho]", "\[NoBreak]", 
          "\[Sigma]"}]], TraditionalForm]], "Output",
  CellLabel->"Out[993]=  (21:55:08 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "FCI"}]], "Input",
  CellLabel->"In[994]:=  (21:55:08 on 5/16/01)",
  CellTags->"LC"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["\[Epsilon]", 
        RowBox[{
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", 
          FormBox[
            FormBox["\[Nu]",
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", 
          FormBox[
            FormBox["\[Rho]",
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", 
          FormBox[
            FormBox["\[Sigma]",
              "TraditionalForm"],
            "TraditionalForm"]}]], TraditionalForm]], "Output",
  CellLabel->"Out[994]=  (21:55:08 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "StandardForm"}]], "Input",
  CellLabel->"In[995]:=  (21:55:08 on 5/16/01)",
  CellTags->"LC"],

Cell[BoxData[
    RowBox[{"Eps", "[", 
      RowBox[{
        RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
        RowBox[{"LorentzIndex", "[", "\[Nu]", "]"}], ",", 
        RowBox[{"LorentzIndex", "[", "\[Rho]", "]"}], ",", 
        RowBox[{"LorentzIndex", "[", "\[Sigma]", "]"}]}], "]"}]], "Output",
  CellLabel->"Out[995]//StandardForm=  (21:55:08 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"LC", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], "[", 
      RowBox[{"p", ",", "q"}], "]"}]], "Input",
  CellLabel->"In[996]:=  (21:55:08 on 5/16/01)",
  CellTags->"LC"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["\[Epsilon]", 
        RowBox[{
        "\[Mu]", "\[NoBreak]", "\[Nu]", "\[NoBreak]", "p", "\[NoBreak]", 
          "q"}]], TraditionalForm]], "Output",
  CellLabel->"Out[996]=  (21:55:08 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"%", "//", "FCI"}], "//", "StandardForm"}]], "Input",
  CellLabel->"In[997]:=  (21:55:08 on 5/16/01)",
  CellTags->"LC"],

Cell[BoxData[
    RowBox[{"Eps", "[", 
      RowBox[{
        RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
        RowBox[{"LorentzIndex", "[", "\[Nu]", "]"}], ",", 
        RowBox[{"Momentum", "[", 
          RowBox[{"p", ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
          RowBox[{"q", ",", "D"}], "]"}]}], "]"}]], "Output",
  CellLabel->"Out[997]//StandardForm=  (21:55:08 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Contract", "[", 
        RowBox[{
          RowBox[{
            RowBox[{"LC", "[", 
              RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]"}], "]"}], "[", "p",
             "]"}], " ", 
          RowBox[{
            RowBox[{"LC", "[", 
              RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]"}], "]"}], "[", "q",
             "]"}]}], "]"}], " "}]], "Input",
  CellLabel->"In[998]:=  (21:55:08 on 5/16/01)",
  CellTags->"LC"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"18", " ", 
          RowBox[{
            FormBox["p",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["q",
              "TraditionalForm"]}]}], "-", 
        RowBox[{"24", " ", 
          RowBox[{
            FormBox["p",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["q",
              "TraditionalForm"]}]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[998]=  (21:55:08 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["LCD", "ObjectName",
  CellTags->"LCD"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"LCD"],

Cell["\<\
LCD[m,n,r,s] evaluates to D-dimensional LeviCivita[m,n,r,s] by virtue of \
FeynCalcInternal. LCD[m,...][p, ...] evaluates to D-dimensional \
LeviCivita[m,...][p,...] applying FeynCalcInternal.\
\>", "Text",
  CellTags->"LCD"],

Cell["\<\
You need to do SetOptions[Eps, Dimension->D] before LCD can be used as \
D-dimensional Levi-Civita input function.\
\>", "Text",
  CellTags->"LCD"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["LeviCivita",
    ButtonData:>"LeviCivita",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"LeviCivita"],
  ", ",
  ButtonBox["LC",
    ButtonData:>"LC",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"LC"],
  "."
}], "Text",
  CellTags->"LCD"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"LCD"],

Cell[BoxData[
    RowBox[{
      RowBox[{"SetOptions", "[", 
        RowBox[{"Eps", ",", 
          RowBox[{"Dimension", "\[Rule]", "D"}]}], "]"}], ";"}]], "Input",
  CellLabel->"In[999]:=  (21:55:08 on 5/16/01)",
  CellTags->"LCD"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"LCD", "[", 
      RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Sigma]"}], 
      "]"}]], "Input",
  CellLabel->"In[1000]:=  (21:55:08 on 5/16/01)",
  CellTags->"LCD"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["\[Epsilon]", 
        RowBox[{
        "\[Mu]", "\[NoBreak]", "\[Nu]", "\[NoBreak]", "\[Rho]", "\[NoBreak]", 
          "\[Sigma]"}]], TraditionalForm]], "Output",
  CellLabel->"Out[1000]=  (21:55:08 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "FCI"}]], "Input",
  CellLabel->"In[1001]:=  (21:55:08 on 5/16/01)",
  CellTags->"LCD"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["\[Epsilon]", 
        RowBox[{
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", 
          FormBox[
            FormBox["\[Nu]",
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", 
          FormBox[
            FormBox["\[Rho]",
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", 
          FormBox[
            FormBox["\[Sigma]",
              "TraditionalForm"],
            "TraditionalForm"]}]], TraditionalForm]], "Output",
  CellLabel->"Out[1001]=  (21:55:08 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "StandardForm"}]], "Input",
  CellLabel->"In[1002]:=  (21:55:08 on 5/16/01)",
  CellTags->"LCD"],

Cell[BoxData[
    RowBox[{"Eps", "[", 
      RowBox[{
        RowBox[{"LorentzIndex", "[", 
          RowBox[{"\[Mu]", ",", "D"}], "]"}], ",", 
        RowBox[{"LorentzIndex", "[", 
          RowBox[{"\[Nu]", ",", "D"}], "]"}], ",", 
        RowBox[{"LorentzIndex", "[", 
          RowBox[{"\[Rho]", ",", "D"}], "]"}], ",", 
        RowBox[{"LorentzIndex", "[", 
          RowBox[{"\[Sigma]", ",", "D"}], "]"}]}], "]"}]], "Output",
  CellLabel->"Out[1002]//StandardForm=  (21:55:08 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"LCD", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], "[", 
      RowBox[{"p", ",", "q"}], "]"}]], "Input",
  CellLabel->"In[1003]:=  (21:55:08 on 5/16/01)",
  CellTags->"LCD"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["\[Epsilon]", 
        RowBox[{
        "\[Mu]", "\[NoBreak]", "\[Nu]", "\[NoBreak]", "p", "\[NoBreak]", 
          "q"}]], TraditionalForm]], "Output",
  CellLabel->"Out[1003]=  (21:55:08 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"%", "//", "FCI"}], "//", "StandardForm"}]], "Input",
  CellLabel->"In[1004]:=  (21:55:08 on 5/16/01)",
  CellTags->"LCD"],

Cell[BoxData[
    RowBox[{"Eps", "[", 
      RowBox[{
        RowBox[{"LorentzIndex", "[", 
          RowBox[{"\[Mu]", ",", "D"}], "]"}], ",", 
        RowBox[{"LorentzIndex", "[", 
          RowBox[{"\[Nu]", ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
          RowBox[{"p", ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
          RowBox[{"q", ",", "D"}], "]"}]}], "]"}]], "Output",
  CellLabel->"Out[1004]//StandardForm=  (21:55:08 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Factor2", "[", 
      RowBox[{"Contract", "[", 
        RowBox[{
          RowBox[{
            RowBox[{"LCD", "[", 
              RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]"}], "]"}], "[", "p",
             "]"}], " ", 
          RowBox[{
            RowBox[{"LCD", "[", 
              RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]"}], "]"}], "[", "q",
             "]"}]}], "]"}], "]"}]], "Input",
  CellLabel->"In[1005]:=  (21:55:08 on 5/16/01)",
  CellTags->"LCD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"(", 
          RowBox[{"1", "-", "D"}], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{"2", "-", "D"}], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{"3", "-", "D"}], ")"}], " ", 
        RowBox[{
          FormBox["p",
            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
          FormBox["q",
            "TraditionalForm"]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1005]=  (21:55:08 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SetOptions", "[", 
      RowBox[{"Eps", ",", 
        RowBox[{"Dimension", "\[Rule]", "4"}]}], "]"}]], "Input",
  CellLabel->"In[1006]:=  (21:55:08 on 5/16/01)",
  CellTags->"LCD"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"Dimension", "\[Rule]", "4"}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1006]=  (21:55:08 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["LeftPartialD", "ObjectName",
  CellTags->"LeftPartialD"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"LeftPartialD"],

Cell[TextData[{
  "LeftPartialD[\[Mu]] denotes ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]], TraditionalForm]]],
  "acting to the left."
}], "Text",
  CellTags->"LeftPartialD"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["ExpandPartialD",
    ButtonData:>"ExpandPartialD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"ExpandPartialD"],
  ", ",
  ButtonBox["PartialD",
    ButtonData:>"PartialD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"PartialD"],
  ", ",
  ButtonBox["LeftRightPartialD",
    ButtonData:>"LeftRightPartialD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"LeftRightPartialD"],
  ", ",
  ButtonBox["RightPartialD",
    ButtonData:>"RightPartialD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"RightPartialD"],
  "."
}], "Text",
  CellTags->"LeftPartialD"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData["Examples"], "Subsubsection",
  CellTags->"LeftPartialD"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"QuantumField", "[", 
        RowBox[{"A", ",", 
          RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}]}], "]"}], ".", 
      RowBox[{"LeftPartialD", "[", "\[Nu]", "]"}]}]], "Input",
  CellLabel->"In[1007]:=  (21:55:08 on 5/16/01)",
  CellTags->"LeftPartialD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["A", "\[Mu]"], ".", 
        SubscriptBox[
          OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
          FormBox[
            FormBox["\[Nu]",
              "TraditionalForm"],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1007]=  (21:55:08 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ExpandPartialD", "[", "%", "]"}]], "Input",
  CellLabel->"In[1008]:=  (21:55:08 on 5/16/01)",
  CellTags->"LeftPartialD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox[
          OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
          FormBox[
            FormBox["\[Nu]",
              "TraditionalForm"],
            "TraditionalForm"]], " ", 
        SubscriptBox["A", "\[Mu]"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1008]=  (21:55:08 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StandardForm", "[", "%", "]"}]], "Input",
  CellLabel->"In[1009]:=  (21:55:08 on 5/16/01)",
  CellTags->"LeftPartialD"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LeftPartialD", "[", 
        RowBox[{"LorentzIndex", "[", "\[Nu]", "]"}], "]"}], " ", 
      RowBox[{"QuantumField", "[", 
        RowBox[{"A", ",", 
          RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}]}], "]"}]}]], "Output",
  CellLabel->"Out[1009]//StandardForm=  (21:55:08 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StandardForm", "[", 
      RowBox[{"LeftPartialD", "[", "\[Mu]", "]"}], "]"}]], "Input",
  CellLabel->"In[1010]:=  (21:55:08 on 5/16/01)",
  CellTags->"LeftPartialD"],

Cell[BoxData[
    RowBox[{"LeftPartialD", "[", 
      RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], "]"}]], "Output",
  CellLabel->"Out[1010]//StandardForm=  (21:55:08 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"QuantumField", "[", 
        RowBox[{"A", ",", 
          RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}]}], "]"}], ".", 
      RowBox[{"QuantumField", "[", 
        RowBox[{"A", ",", 
          RowBox[{"LorentzIndex", "[", "\[Nu]", "]"}]}], "]"}], ".", 
      RowBox[{"LeftPartialD", "[", "\[Rho]", "]"}]}]], "Input",
  CellLabel->"In[1011]:=  (21:55:08 on 5/16/01)",
  CellTags->"LeftPartialD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["A", "\[Mu]"], ".", 
        SubscriptBox["A", "\[Nu]"], ".", 
        SubscriptBox[
          OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
          FormBox[
            FormBox["\[Rho]",
              "TraditionalForm"],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1011]=  (21:55:08 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ExpandPartialD", "[", "%", "]"}]], "Input",
  CellLabel->"In[1012]:=  (21:55:08 on 5/16/01)",
  CellTags->"LeftPartialD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["A", "\[Mu]"], ".", 
          SubscriptBox["A", "\[Nu]"]}], " ", 
        SubscriptBox[
          OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
          FormBox[
            FormBox["\[Rho]",
              "TraditionalForm"],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1012]=  (21:55:09 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StandardForm", "[", "%", "]"}]], "Input",
  CellLabel->"In[1013]:=  (21:55:09 on 5/16/01)",
  CellTags->"LeftPartialD"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"QuantumField", "[", 
          RowBox[{"A", ",", 
            RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}]}], "]"}], ".", 
        RowBox[{"QuantumField", "[", 
          RowBox[{"A", ",", 
            RowBox[{"LorentzIndex", "[", "\[Nu]", "]"}]}], "]"}]}], " ", 
      RowBox[{"LeftPartialD", "[", 
        RowBox[{"LorentzIndex", "[", "\[Rho]", "]"}], "]"}]}]], "Output",
  CellLabel->"Out[1013]//StandardForm=  (21:55:09 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["LeftRightPartialD", "ObjectName",
  CellTags->"LeftRightPartialD"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"LeftRightPartialD"],

Cell[TextData[{
  "LeftRightPartialD[mu] denotes ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          OverscriptBox["\[PartialD]", "\[LeftRightArrow]"], 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]], TraditionalForm]]],
  ", acting to the left and right. ExplitPartialD[LeftRightPartialD[",
  Cell[BoxData[
      FormBox["\[Mu]", TraditionalForm]]],
  "]] gives 1/2 (RightPartialD[",
  Cell[BoxData[
      FormBox["\[Mu]", TraditionalForm]]],
  "] - LeftPartialD[",
  Cell[BoxData[
      FormBox["\[Mu]", TraditionalForm]]],
  "])."
}], "Text",
  CellTags->"LeftRightPartialD"],

Cell[TextData[{
  "See also: ",
  ButtonBox["ExplicitPartialD",
    ButtonData:>"ExplicitPartialD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"ExplicitPartialD"],
  ", ",
  ButtonBox["ExpandPartialD",
    ButtonData:>"ExpandPartialD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"ExpandPartialD"],
  ", ",
  ButtonBox["PartialD",
    ButtonData:>"PartialD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"PartialD"],
  ", ",
  ButtonBox["LeftPartialD",
    ButtonData:>"LeftPartialD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"LeftPartialD"],
  ", ",
  ButtonBox["LeftRightPartialD2",
    ButtonData:>"LeftRightPartialD2",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"LeftRightPartialD2"],
  ", ",
  ButtonBox["RightPartialD",
    ButtonData:>"RightPartialD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"RightPartialD"],
  "."
}], "Text",
  CellTags->"LeftRightPartialD"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"LeftRightPartialD"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"LeftRightPartialD", "[", "\[Mu]", "]"}]], "Input",
  CellLabel->"In[1014]:=  (21:55:09 on 5/16/01)",
  CellTags->"LeftRightPartialD"],

Cell[BoxData[
    FormBox[
      SubscriptBox[
        OverscriptBox["\[PartialD]", "\[LeftRightArrow]"], 
        FormBox[
          FormBox["\[Mu]",
            "TraditionalForm"],
          "TraditionalForm"]], TraditionalForm]], "Output",
  CellLabel->"Out[1014]=  (21:55:09 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ExplicitPartialD", "[", "%", "]"}]], "Input",
  CellLabel->"In[1015]:=  (21:55:09 on 5/16/01)",
  CellTags->"LeftRightPartialD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
          RowBox[{
            SubscriptBox[
              OverscriptBox["\[PartialD]", "\[RightArrow]"], 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"]], "-", 
            SubscriptBox[
              OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"]]}], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1015]=  (21:55:09 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"LeftRightPartialD", "[", "\[Mu]", "]"}], ".", 
      RowBox[{"QuantumField", "[", 
        RowBox[{"A", ",", 
          RowBox[{"LorentzIndex", "[", "\[Nu]", "]"}]}], "]"}]}]], "Input",
  CellLabel->"In[1016]:=  (21:55:09 on 5/16/01)",
  CellTags->"LeftRightPartialD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox[
          OverscriptBox["\[PartialD]", "\[LeftRightArrow]"], 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        SubscriptBox["A", "\[Nu]"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1016]=  (21:55:09 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ExpandPartialD", "[", "%", "]"}]], "Input",
  CellLabel->"In[1017]:=  (21:55:09 on 5/16/01)",
  CellTags->"LeftRightPartialD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{
            SubscriptBox["\[PartialD]", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"]], 
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[Null]"]}], "2"], "-", 
        RowBox[{
          FractionBox["1", "2"], " ", 
          SubscriptBox[
            OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubscriptBox["A", "\[Nu]"]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1017]=  (21:55:09 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"QuantumField", "[", 
        RowBox[{"A", ",", 
          RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}]}], "]"}], ".", 
      RowBox[{"LeftRightPartialD", "[", "\[Nu]", "]"}], ".", 
      RowBox[{"QuantumField", "[", 
        RowBox[{"A", ",", 
          RowBox[{"LorentzIndex", "[", "\[Rho]", "]"}]}], "]"}]}]], "Input",
  CellLabel->"In[1018]:=  (21:55:09 on 5/16/01)",
  CellTags->"LeftRightPartialD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["A", "\[Mu]"], ".", 
        SubscriptBox[
          OverscriptBox["\[PartialD]", "\[LeftRightArrow]"], 
          FormBox[
            FormBox["\[Nu]",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        SubscriptBox["A", "\[Rho]"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1018]=  (21:55:09 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ExpandPartialD", "[", "%", "]"}]], "Input",
  CellLabel->"In[1019]:=  (21:55:09 on 5/16/01)",
  CellTags->"LeftRightPartialD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{
            SubscriptBox["A", "\[Mu]"], ".", 
            RowBox[{
              SubscriptBox["\[PartialD]", 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], 
              SubsuperscriptBox["A", 
                FormBox[
                  FormBox["\[Rho]",
                    "TraditionalForm"],
                  "TraditionalForm"], "\[Null]"]}]}]}], "-", 
        RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{
            SubscriptBox["A", "\[Mu]"], ".", 
            SubscriptBox["A", "\[Rho]"]}], " ", 
          SubscriptBox[
            OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"]]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1019]=  (21:55:09 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["LeftRightPartialD2", "ObjectName",
  CellTags->"LeftRightPartialD2"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"LeftRightPartialD2"],

Cell[TextData[{
  "LeftRightPartialD2[mu] denotes ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          OverscriptBox["\[PartialD]", "\[LeftRightArrow]"], 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]], TraditionalForm]]],
  ", acting to the left and right. ExplitPartialD[LeftRightPartialD2[",
  Cell[BoxData[
      FormBox["\[Mu]", TraditionalForm]]],
  "]] gives (RightPartialD[",
  Cell[BoxData[
      FormBox["\[Mu]", TraditionalForm]]],
  "] + LeftPartialD[",
  Cell[BoxData[
      FormBox["\[Mu]", TraditionalForm]]],
  "])."
}], "Text",
  CellTags->"LeftRightPartialD2"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["ExplicitPartialD",
    ButtonData:>"ExplicitPartialD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"ExplicitPartialD"],
  ", ",
  ButtonBox["ExpandPartialD",
    ButtonData:>"ExpandPartialD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"ExpandPartialD"],
  ", ",
  ButtonBox["PartialD",
    ButtonData:>"PartialD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"PartialD"],
  ", ",
  ButtonBox["LeftPartialD",
    ButtonData:>"LeftPartialD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"LeftPartialD"],
  ", ",
  ButtonBox["RightPartialD",
    ButtonData:>"RightPartialD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"RightPartialD"],
  "."
}], "Text",
  CellTags->"LeftRightPartialD2"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"LeftRightPartialD2"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"LeftRightPartialD2", "[", "\[Mu]", "]"}]], "Input",
  CellLabel->"In[1020]:=  (21:55:09 on 5/16/01)",
  CellTags->"LeftRightPartialD2"],

Cell[BoxData[
    FormBox[
      SubscriptBox[
        OverscriptBox["\[PartialD]", "\[LeftRightArrow]"], 
        FormBox[
          FormBox["\[Mu]",
            "TraditionalForm"],
          "TraditionalForm"]], TraditionalForm]], "Output",
  CellLabel->"Out[1020]=  (21:55:09 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ExplicitPartialD", "[", "%", "]"}]], "Input",
  CellLabel->"In[1021]:=  (21:55:09 on 5/16/01)",
  CellTags->"LeftRightPartialD2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox[
          OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]], "+", 
        SubscriptBox[
          OverscriptBox["\[PartialD]", "\[RightArrow]"], 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1021]=  (21:55:09 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"LeftRightPartialD2", "[", "\[Mu]", "]"}], ".", 
      RowBox[{"QuantumField", "[", 
        RowBox[{"A", ",", 
          RowBox[{"LorentzIndex", "[", "\[Nu]", "]"}]}], "]"}]}]], "Input",
  CellLabel->"In[1022]:=  (21:55:09 on 5/16/01)",
  CellTags->"LeftRightPartialD2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox[
          OverscriptBox["\[PartialD]", "\[LeftRightArrow]"], 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        SubscriptBox["A", "\[Nu]"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1022]=  (21:55:09 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ExpandPartialD", "[", "%", "]"}]], "Input",
  CellLabel->"In[1023]:=  (21:55:09 on 5/16/01)",
  CellTags->"LeftRightPartialD2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox[
            OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SubscriptBox["A", "\[Nu]"]}], "+", 
        RowBox[{
          SubscriptBox["\[PartialD]", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], 
          SubsuperscriptBox["A", 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"], "\[Null]"]}]}], TraditionalForm]], "Output",\

  CellLabel->"Out[1023]=  (21:55:09 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"QuantumField", "[", 
        RowBox[{"A", ",", 
          RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}]}], "]"}], ".", 
      RowBox[{"LeftRightPartialD2", "[", "\[Nu]", "]"}], ".", 
      RowBox[{"QuantumField", "[", 
        RowBox[{"A", ",", 
          RowBox[{"LorentzIndex", "[", "\[Rho]", "]"}]}], "]"}]}]], "Input",
  CellLabel->"In[1024]:=  (21:55:10 on 5/16/01)",
  CellTags->"LeftRightPartialD2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["A", "\[Mu]"], ".", 
        SubscriptBox[
          OverscriptBox["\[PartialD]", "\[LeftRightArrow]"], 
          FormBox[
            FormBox["\[Nu]",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        SubscriptBox["A", "\[Rho]"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1024]=  (21:55:11 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ExpandPartialD", "[", "%", "]"}]], "Input",
  CellLabel->"In[1025]:=  (21:55:11 on 5/16/01)",
  CellTags->"LeftRightPartialD2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["A", "\[Mu]"], ".", 
          RowBox[{
            SubscriptBox["\[PartialD]", 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"]], 
            SubsuperscriptBox["A", 
              FormBox[
                FormBox["\[Rho]",
                  "TraditionalForm"],
                "TraditionalForm"], "\[Null]"]}]}], "+", 
        RowBox[{
          RowBox[{
            SubscriptBox["A", "\[Mu]"], ".", 
            SubscriptBox["A", "\[Rho]"]}], " ", 
          SubscriptBox[
            OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"]]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1025]=  (21:55:11 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["LeviCivita ", "ObjectName",
  CellTags->"LeviCivita"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"LeviCivita"],

Cell[TextData[{
  "LeviCivita[",
  Cell[BoxData[
      FormBox[
        RowBox[{
        "\[Mu]", ",", " ", "\[Nu]", ",", " ", "\[Rho]", ",", " ", 
          "\[Sigma]"}], TraditionalForm]]],
  "] is an input function for the totally antisymmetric Levi-Civita tensor. \
It evaluates automatically to the internal representation Eps[LorentzIndex[",
  Cell[BoxData[
      FormBox["\[Mu]", TraditionalForm]]],
  "], LorentzIndex[",
  Cell[BoxData[
      FormBox["\[Nu]", TraditionalForm]]],
  "], LorentzIndex[",
  Cell[BoxData[
      FormBox[
        FormBox["\[Rho]",
          "TraditionalForm"], TraditionalForm]]],
  "], LorentzIndex[\[Sigma]]] (or with a second argument in LorentzIndex for \
the Dimension, if the option Dimension of LeviCivita is changed). \
LeviCivita[",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Mu]", ",", " ", 
          RowBox[{"\[Nu]", " ", "..."}]}], TraditionalForm]]],
  "][ ",
  Cell[BoxData[
      FormBox[
        RowBox[{"p", ",", " ", ".."}], TraditionalForm]]],
  ".] evaluates to Eps[LorentzIndex[",
  Cell[BoxData[
      FormBox["\[Mu]", TraditionalForm]]],
  "], LorentzIndex[",
  Cell[BoxData[
      FormBox["\[Nu]", TraditionalForm]]],
  "], ..., Momentum[",
  Cell[BoxData[
      FormBox["p", TraditionalForm]]],
  "], ...]."
}], "Text",
  CellTags->"LeviCivita"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "LeviCivita", "]"}]], "Input",
  CellLabel->"In[1026]:=  (21:55:11 on 5/16/01)",
  CellTags->"LeviCivita"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"Dimension", "\[Rule]", "D"}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1026]=  (21:55:11 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["LC",
    ButtonData:>"LC",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"LC"],
  ", ",
  ButtonBox["LCD",
    ButtonData:>"LCD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"LCD"],
  "."
}], "Text",
  CellTags->"LeviCivita"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"LeviCivita"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"LeviCivita", "[", 
      RowBox[{"\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]", ",", "\[Delta]"}], 
      "]"}]], "Input",
  CellLabel->"In[1027]:=  (21:55:11 on 5/16/01)",
  CellTags->"LeviCivita"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["\[Epsilon]", 
        RowBox[{
          FormBox[
            FormBox["\[Alpha]",
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", 
          FormBox[
            FormBox["\[Beta]",
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", 
          FormBox[
            FormBox["\[Gamma]",
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", 
          FormBox[
            FormBox["\[Delta]",
              "TraditionalForm"],
            "TraditionalForm"]}]], TraditionalForm]], "Output",
  CellLabel->"Out[1027]=  (21:55:11 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"LeviCivita", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], "[", 
      RowBox[{"OPEDelta", ",", "p"}], "]"}]], "Input",
  CellLabel->"In[1028]:=  (21:55:12 on 5/16/01)",
  CellTags->"LeviCivita"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["\[Epsilon]", 
        RowBox[{
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", 
          FormBox[
            FormBox["\[Nu]",
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", 
          FormBox["\[CapitalDelta]",
            "TraditionalForm"], "\[NoBreak]", 
          FormBox["p",
            "TraditionalForm"]}]], TraditionalForm]], "Output",
  CellLabel->"Out[1028]=  (21:55:12 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"LeviCivita", "[", "]"}], "[", 
      RowBox[{"p", ",", "q", ",", "r", ",", "s"}], "]"}]], "Input",
  CellLabel->"In[1029]:=  (21:55:12 on 5/16/01)",
  CellTags->"LeviCivita"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["\[Epsilon]", 
        RowBox[{
          FormBox["p",
            "TraditionalForm"], "\[NoBreak]", 
          FormBox["q",
            "TraditionalForm"], "\[NoBreak]", 
          FormBox["r",
            "TraditionalForm"], "\[NoBreak]", 
          FormBox["s",
            "TraditionalForm"]}]], TraditionalForm]], "Output",
  CellLabel->"Out[1029]=  (21:55:12 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"LeviCivita", "[", 
      RowBox[{"\[Alpha]", ",", "\[Beta]", ",", "\[Beta]", ",", "\[Delta]"}], 
      "]"}]], "Input",
  CellLabel->"In[1030]:=  (21:55:12 on 5/16/01)",
  CellTags->"LeviCivita"],

Cell[BoxData[
    FormBox["0", TraditionalForm]], "Output",
  CellLabel->"Out[1030]=  (21:55:12 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"LeviCivita", "[", 
          RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], "[", 
        RowBox[{"OPEDelta", ",", "p"}], "]"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[1031]:=  (21:55:12 on 5/16/01)",
  CellTags->"LeviCivita"],

Cell[BoxData[
    RowBox[{"Eps", "[", 
      RowBox[{
        RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
        RowBox[{"LorentzIndex", "[", "\[Nu]", "]"}], ",", 
        RowBox[{"Momentum", "[", "OPEDelta", "]"}], ",", 
        RowBox[{"Momentum", "[", "p", "]"}]}], "]"}]], "Output",
  CellLabel->"Out[1031]//StandardForm=  (21:55:12 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"t1", " ", "=", " ", 
        RowBox[{
          RowBox[{"LeviCivita", "[", 
            RowBox[{
            "\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]", ",", "\[Rho]"}], 
            "]"}], ".", 
          RowBox[{"LeviCivita", "[", 
            RowBox[{
            "\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]", ",", "\[Rho]"}], 
            "]"}]}]}], " "}]], "Input",
  CellLabel->"In[1032]:=  (21:55:12 on 5/16/01)",
  CellTags->"LeviCivita"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Epsilon]", 
          RowBox[{
            FormBox[
              FormBox["\[Alpha]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["\[Beta]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["\[Gamma]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["\[Rho]",
                "TraditionalForm"],
              "TraditionalForm"]}]], ".", 
        SuperscriptBox["\[Epsilon]", 
          RowBox[{
            FormBox[
              FormBox["\[Alpha]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["\[Beta]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["\[Gamma]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["\[Rho]",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1032]=  (21:55:12 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Contract", "[", "t1", "]"}]], "Input",
  CellLabel->"In[1033]:=  (21:55:12 on 5/16/01)",
  CellTags->"LeviCivita"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", "24"}], TraditionalForm]], "Output",
  CellLabel->"Out[1033]=  (21:55:12 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      RowBox[{"SetOptions", "[", 
        RowBox[{"LeviCivita", ",", 
          RowBox[{"Dimension", "\[Rule]", "D"}]}], "]"}], ";", 
      RowBox[{"SetOptions", "[", 
        RowBox[{"Eps", ",", 
          RowBox[{"Dimension", "\[Rule]", "D"}]}], "]"}], ";"}]], "Input",
  CellLabel->"In[1034]:=  (21:55:12 on 5/16/01)",
  CellTags->"LeviCivita"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Contract", "[", " ", 
        RowBox[{
          RowBox[{"LeviCivita", "[", 
            RowBox[{
            "\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]", ",", "\[Rho]"}], 
            "]"}], ".", 
          RowBox[{"LeviCivita", "[", 
            RowBox[{
            "\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]", ",", "\[Rho]"}], 
            "]"}]}], "]"}], "//", "Factor2"}]], "Input",
  CellLabel->"In[1035]:=  (21:55:12 on 5/16/01)",
  CellTags->"LeviCivita"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"(", 
          RowBox[{"1", "-", "D"}], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{"2", "-", "D"}], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{"3", "-", "D"}], ")"}], " ", "D"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1035]=  (21:55:12 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      RowBox[{"SetOptions", "[", 
        RowBox[{"LeviCivita", ",", 
          RowBox[{"Dimension", "\[Rule]", "4"}]}], "]"}], ";", 
      RowBox[{"SetOptions", "[", 
        RowBox[{"Eps", ",", 
          RowBox[{"Dimension", "\[Rule]", "4"}]}], "]"}], ";"}]], "Input",
  CellLabel->"In[1036]:=  (21:55:12 on 5/16/01)",
  CellTags->"LeviCivita"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"LC", "[", 
      RowBox[{"\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]", ",", "\[Delta]"}], 
      "]"}]], "Input",
  CellLabel->"In[1037]:=  (21:55:13 on 5/16/01)",
  CellTags->"LeviCivita"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["\[Epsilon]", 
        RowBox[{
        "\[Alpha]", "\[NoBreak]", "\[Beta]", "\[NoBreak]", "\[Gamma]", 
          "\[NoBreak]", "\[Delta]"}]], TraditionalForm]], "Output",
  CellLabel->"Out[1037]=  (21:55:13 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{"Clear", "[", "t1", "]"}]], "Input",
  CellLabel->"In[1038]:=  (21:55:13 on 5/16/01)",
  CellTags->"LeviCivita"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Li2 ", "ObjectName",
  CellTags->"Li2"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"Li2"],

Cell["\<\
 Li2 is an abbreviation for the dilog function, i.e., Li2 = PolyLog[2, #]&.\
\>", "Text",
  CellTags->"Li2"],

Cell[TextData[{
  "See also: ",
  ButtonBox["Li3",
    ButtonData:>"Li3",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Li3"],
  "."
}], "Text",
  CellTags->"Li2"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"Li2"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Li2", "[", "x", "]"}]], "Input",
  CellLabel->"In[1039]:=  (21:55:13 on 5/16/01)",
  CellTags->"Li2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["Li", "2"], "(", "x", ")"}], TraditionalForm]], "Output",\

  CellLabel->"Out[1039]=  (21:55:13 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Li2", "//", "StandardForm"}]], "Input",
  CellLabel->"In[1040]:=  (21:55:13 on 5/16/01)",
  CellTags->"Li2"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PolyLog", "[", 
        RowBox[{"2", ",", "#1"}], "]"}], "&"}]], "Output",
  CellLabel->"Out[1040]//StandardForm=  (21:55:13 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"-", 
      RowBox[{"\[Integral]", 
        RowBox[{
          FractionBox[
            RowBox[{"Log", "[", 
              RowBox[{"1", "-", "x"}], "]"}], "x"], 
          RowBox[{"\[DifferentialD]", "x"}]}]}]}]], "Input",
  CellLabel->"In[1041]:=  (21:55:13 on 5/16/01)",
  CellTags->"Li2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["Li", "2"], "(", "x", ")"}], TraditionalForm]], "Output",\

  CellLabel->"Out[1041]=  (21:55:14 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Li3 ", "ObjectName",
  CellTags->"Li3"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"Li3"],

Cell["\<\
 Li3 is an abbreviation for the trilog function, i.e., Li3 = PolyLog[3, \
#]&.\
\>", "Text",
  CellTags->"Li3"],

Cell[TextData[{
  "See also: ",
  ButtonBox["Li2",
    ButtonData:>"Li2",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Li2"],
  "."
}], "Text",
  CellTags->"Li3"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"Li3"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Li3", "[", "x", "]"}]], "Input",
  CellLabel->"In[1042]:=  (21:55:14 on 5/16/01)",
  CellTags->"Li3"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["Li", "3"], "(", "x", ")"}], TraditionalForm]], "Output",\

  CellLabel->"Out[1042]=  (21:55:14 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Li3", "//", "StandardForm"}]], "Input",
  CellLabel->"In[1043]:=  (21:55:14 on 5/16/01)",
  CellTags->"Li3"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PolyLog", "[", 
        RowBox[{"3", ",", "#1"}], "]"}], "&"}]], "Output",
  CellLabel->"Out[1043]//StandardForm=  (21:55:14 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"D", "[", 
      RowBox[{
        RowBox[{"Li3", "[", "x", "]"}], ",", "x"}], "]"}]], "Input",
  CellLabel->"In[1044]:=  (21:55:14 on 5/16/01)",
  CellTags->"Li3"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{
          SubscriptBox["Li", "2"], "(", "x", ")"}], "x"], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1044]=  (21:55:15 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"\[Integral]", 
      RowBox[{
        FractionBox[
          RowBox[{"Li2", "[", "x", "]"}], "x"], 
        RowBox[{"\[DifferentialD]", "x"}]}]}]], "Input",
  CellLabel->"In[1045]:=  (21:55:15 on 5/16/01)",
  CellTags->"Li3"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["Li", "3"], "(", "x", ")"}], TraditionalForm]], "Output",\

  CellLabel->"Out[1045]=  (21:55:15 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["LorentzIndex", "ObjectName",
  CellTags->"LorentzIndex"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"LorentzIndex"],

Cell["\<\
LorentzIndex[mu] denotes a four dimensional Lorentz index. For other than \
four dimensions: LorentzIndex[mu, D] or LorentzIndex[mu], etc. \
LorentzIndex[mu, 4] simplifies to LorentzIndex[mu].\
\>", "Text",
  CellTags->"LorentzIndex"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["ChangeDimension",
    ButtonData:>"ChangeDimension",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"ChangeDimension"],
  ", ",
  ButtonBox["Momentum",
    ButtonData:>"Momentum",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Momentum"],
  "."
}], "Text",
  CellTags->"LorentzIndex"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"LorentzIndex"],

Cell["This denotes a four-dimensional Lorentz index.", "Text",
  CellTags->"LorentzIndex"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"LorentzIndex", "[", "\[Alpha]", "]"}]], "Input",
  CellLabel->"In[1046]:=  (21:55:15 on 5/16/01)",
  CellTags->"LorentzIndex"],

Cell[BoxData[
    FormBox["\[Alpha]", TraditionalForm]], "Output",
  CellLabel->"Out[1046]=  (21:55:15 on 5/16/01)"]
}, Closed]],

Cell["\<\
An optional second argument can be given for a dimension different from 4.\
\>", "Text",
  CellTags->"LorentzIndex"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"LorentzIndex", "[", 
      RowBox[{"\[Alpha]", ",", "n"}], "]"}]], "Input",
  CellLabel->"In[1047]:=  (21:55:15 on 5/16/01)",
  CellTags->"LorentzIndex"],

Cell[BoxData[
    FormBox["\[Alpha]", TraditionalForm]], "Output",
  CellLabel->"Out[1047]=  (21:55:15 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell["LorentzIndex[ComplexIndex[\[Alpha]]]", "Input",
  CellLabel->"In[1048]:=  (21:55:16 on 5/16/01)",
  CellTags->"LorentzIndex"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["\[Alpha]", "*"], TraditionalForm]], "Output",
  CellLabel->"Out[1048]=  (21:55:16 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ComplexConjugate", "[", 
      RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], "]"}]], "Input",
  CellLabel->"In[1049]:=  (21:55:16 on 5/16/01)",
  CellTags->"LorentzIndex"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["\[Mu]", "*"], TraditionalForm]], "Output",
  CellLabel->"Out[1049]=  (21:55:16 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ComplexConjugate", "[", 
      RowBox[{"LorentzIndex", "[", 
        RowBox[{"ComplexIndex", "[", "\[Beta]", "]"}], "]"}], "]"}]], "Input",\

  CellLabel->"In[1050]:=  (21:55:16 on 5/16/01)",
  CellTags->"LorentzIndex"],

Cell[BoxData[
    FormBox["\[Beta]", TraditionalForm]], "Output",
  CellLabel->"Out[1050]=  (21:55:16 on 5/16/01)"]
}, Closed]],

Cell["\<\
Setting $LorentzIndices=True displays the dimension (if different from 4) as \
a subindex.\
\>", "Text",
  CellTags->"LorentzIndex"],

Cell[BoxData[
    RowBox[{
      RowBox[{"$LorentzIndices", "=", "True"}], ";"}]], "Input",
  CellLabel->"In[1051]:=  (21:55:16 on 5/16/01)",
  CellTags->"LorentzIndex"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"LorentzIndex", "[", 
          RowBox[{"\[Alpha]", ",", "D"}], "]"}], ",", 
        RowBox[{"LorentzIndex", "[", 
          RowBox[{"\[Nu]", ",", "n"}], "]"}], ",", 
        RowBox[{"LorentzIndex", "[", 
          RowBox[{"\[Beta]", ",", "4"}], "]"}]}], "}"}]], "Input",
  CellLabel->"In[1052]:=  (21:55:16 on 5/16/01)",
  CellTags->"LorentzIndex"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          SubscriptBox[
            FormBox["\[Alpha]",
              "TraditionalForm"], 
            FormBox["D",
              "TraditionalForm"]], ",", 
          SubscriptBox[
            FormBox["\[Nu]",
              "TraditionalForm"], 
            FormBox["n",
              "TraditionalForm"]], ",", "\[Beta]"}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1052]=  (21:55:16 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      RowBox[{"$LorentzIndices", " ", "=", " ", "False"}], ";"}]], "Input",
  CellLabel->"In[1053]:=  (21:55:16 on 5/16/01)",
  CellTags->"LorentzIndex"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Map2", "ObjectName",
  CellTags->"Map2"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"Map2"],

Cell["\<\
Map2[f, exp] is equivalent to Map if Nterms[exp] > 0, otherwise Map2[f, exp] \
gives f[exp].\
\>", "Text",
  CellTags->"Map2"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["NTerms",
    ButtonData:>"NTerms",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"NTerms"],
  "."
}], "Text",
  CellTags->"Map2"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"Map2"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Map2", "[", 
      RowBox[{"f", ",", 
        RowBox[{"a", "-", "b"}]}], "]"}]], "Input",
  CellLabel->"In[1054]:=  (21:55:17 on 5/16/01)",
  CellTags->"Map2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"f", "(", "a", ")"}], "+", 
        RowBox[{"f", "(", 
          RowBox[{"-", "b"}], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1054]=  (21:55:17 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Map2", "[", 
      RowBox[{"f", ",", "x"}], "]"}]], "Input",
  CellLabel->"In[1055]:=  (21:55:17 on 5/16/01)",
  CellTags->"Map2"],

Cell[BoxData[
    FormBox[
      RowBox[{"f", "(", "x", ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[1055]=  (21:55:17 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Map2", "[", 
      RowBox[{"f", ",", 
        RowBox[{"{", 
          RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[1056]:=  (21:55:17 on 5/16/01)",
  CellTags->"Map2"],

Cell[BoxData[
    FormBox[
      RowBox[{"f", "(", 
        RowBox[{"{", 
          RowBox[{"a", ",", "b", ",", "c"}], "}"}], ")"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1056]=  (21:55:17 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Map2", "[", 
      RowBox[{"f", ",", "1"}], "]"}]], "Input",
  CellLabel->"In[1057]:=  (21:55:17 on 5/16/01)",
  CellTags->"Map2"],

Cell[BoxData[
    FormBox[
      RowBox[{"f", "(", "1", ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[1057]=  (21:55:17 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["MetricTensor", "ObjectName",
  CellTags->"MetricTensor"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"MetricTensor"],

Cell[TextData[{
  "MetricTensor[",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Mu]", ",", " ", "\[Nu]"}], TraditionalForm]]],
  "] is the metric tensor. The default dimension is 4."
}], "Text",
  CellTags->"MetricTensor"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["FeynCalcExternal",
    ButtonData:>"FeynCalcExternal",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FeynCalcExternal"],
  ", ",
  ButtonBox["FCE",
    ButtonData:>"FCE",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FCE"],
  ", ",
  ButtonBox["FCI",
    ButtonData:>"FCI",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FCI"],
  ", ",
  ButtonBox["MT",
    ButtonData:>"MT",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"MT"],
  ", ",
  ButtonBox["MTD",
    ButtonData:>"MTD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"MTD"],
  "."
}], "Text",
  CellTags->"MetricTensor"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"MetricTensor"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"MetricTensor", "[", 
      RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}]], "Input",
  CellLabel->"In[1058]:=  (21:55:17 on 5/16/01)",
  CellTags->"MetricTensor"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["g", 
        RowBox[{"\[Alpha]", "\[NoBreak]", "\[Beta]"}]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1058]=  (21:55:17 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Contract", "[", 
      RowBox[{"%", " ", "%"}], "]"}]], "Input",
  CellLabel->"In[1059]:=  (21:55:18 on 5/16/01)",
  CellTags->"MetricTensor"],

Cell[BoxData[
    FormBox["4", TraditionalForm]], "Output",
  CellLabel->"Out[1059]=  (21:55:18 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"MetricTensor", "[", 
      RowBox[{"\[Alpha]", ",", "\[Beta]", ",", 
        RowBox[{"Dimension", "\[Rule]", "n"}]}], "]"}]], "Input",
  CellLabel->"In[1060]:=  (21:55:18 on 5/16/01)",
  CellTags->"MetricTensor"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["g", 
        RowBox[{
          FormBox[
            FormBox["\[Alpha]",
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", 
          FormBox[
            FormBox["\[Beta]",
              "TraditionalForm"],
            "TraditionalForm"]}]], TraditionalForm]], "Output",
  CellLabel->"Out[1060]=  (21:55:18 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Contract", "[", 
      RowBox[{"%", " ", "%"}], "]"}]], "Input",
  CellLabel->"In[1061]:=  (21:55:18 on 5/16/01)",
  CellTags->"MetricTensor"],

Cell[BoxData[
    FormBox["n", TraditionalForm]], "Output",
  CellLabel->"Out[1061]=  (21:55:18 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StandardForm", "[", 
      RowBox[{"MetricTensor", "[", 
        RowBox[{"a", ",", "b"}], "]"}], "]"}]], "Input",
  CellLabel->"In[1062]:=  (21:55:18 on 5/16/01)",
  CellTags->"MetricTensor"],

Cell[BoxData[
    RowBox[{"Pair", "[", 
      RowBox[{
        RowBox[{"LorentzIndex", "[", "a", "]"}], ",", 
        RowBox[{"LorentzIndex", "[", "b", "]"}]}], "]"}]], "Output",
  CellLabel->"Out[1062]//StandardForm=  (21:55:18 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StandardForm", "[", 
      RowBox[{"MetricTensor", "[", 
        RowBox[{"a", ",", "b", ",", 
          RowBox[{"Dimension", "\[Rule]", "D"}]}], "]"}], "]"}]], "Input",
  CellLabel->"In[1063]:=  (21:55:18 on 5/16/01)",
  CellTags->"MetricTensor"],

Cell[BoxData[
    RowBox[{"Pair", "[", 
      RowBox[{
        RowBox[{"LorentzIndex", "[", 
          RowBox[{"a", ",", "D"}], "]"}], ",", 
        RowBox[{"LorentzIndex", "[", 
          RowBox[{"b", ",", "D"}], "]"}]}], "]"}]], "Output",
  CellLabel->"Out[1063]//StandardForm=  (21:55:18 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StandardForm", "[", 
      RowBox[{"FCE", "[", 
        RowBox[{"MetricTensor", "[", 
          RowBox[{"a", ",", "b"}], "]"}], "]"}], "]"}]], "Input",
  CellLabel->"In[1064]:=  (21:55:18 on 5/16/01)",
  CellTags->"MetricTensor"],

Cell[BoxData[
    RowBox[{"MT", "[", 
      RowBox[{"a", ",", "b"}], "]"}]], "Output",
  CellLabel->"Out[1064]//StandardForm=  (21:55:18 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StandardForm", "[", 
      RowBox[{"FCE", "[", 
        RowBox[{"MetricTensor", "[", 
          RowBox[{"a", ",", "b", ",", 
            RowBox[{"Dimension", "\[Rule]", "D"}]}], "]"}], "]"}], 
      "]"}]], "Input",
  CellLabel->"In[1065]:=  (21:55:18 on 5/16/01)",
  CellTags->"MetricTensor"],

Cell[BoxData[
    RowBox[{"MTD", "[", 
      RowBox[{"a", ",", "b"}], "]"}]], "Output",
  CellLabel->"Out[1065]//StandardForm=  (21:55:18 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["MomentumCombine", "ObjectName",
  CellTags->"MomentumCombine"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"MomentumCombine"],

Cell["\<\
MomentumCombine[expr] is the inverse operation to MomentumExpand and \
ExpandScalarProduct. MomentumCombine combines also Pair`s.\
\>", "Text",
  CellTags->"MomentumCombine"],

Cell[TextData[{
  "See also: ",
  ButtonBox["ExpandScalarProduct",
    ButtonData:>"ExpandScalarProduct",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"ExpandScalarProduct"],
  ", ",
  ButtonBox["Momentum",
    ButtonData:>"Momentum",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Momentum"],
  ", ",
  ButtonBox["MomentumExpand",
    ButtonData:>"MomentumExpand",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"MomentumExpand"],
  "."
}], "Text",
  CellTags->"MomentumCombine"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"MomentumCombine"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{"Momentum", "[", "p", "]"}], "-", 
            RowBox[{"2", " ", 
              RowBox[{"Momentum", "[", "q", "]"}]}]}], " "}], "//", " ", 
        "MomentumCombine"}], " ", "//", " ", "StandardForm"}]], "Input",
  CellLabel->"In[1066]:=  (21:55:19 on 5/16/01)",
  CellTags->"MomentumCombine"],

Cell[BoxData[
    RowBox[{"Momentum", "[", 
      RowBox[{"p", "-", 
        RowBox[{"2", " ", "q"}]}], "]"}]], "Output",
  CellLabel->"Out[1066]//StandardForm=  (21:55:19 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t1", "=", 
      RowBox[{
        RowBox[{
          RowBox[{"FV", "[", 
            RowBox[{"p", ",", "\[Mu]"}], "]"}], " ", "+", " ", 
          RowBox[{"2", " ", 
            RowBox[{"FV", "[", 
              RowBox[{"q", ",", "\[Mu]"}], "]"}]}]}], " "}]}]], "Input",
  CellLabel->"In[1067]:=  (21:55:19 on 5/16/01)",
  CellTags->"MomentumCombine"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["p", "\[Mu]"], "+", 
        RowBox[{"2", " ", 
          SuperscriptBox["q", "\[Mu]"]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1067]=  (21:55:19 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"MomentumCombine", "[", "t1", "]"}]], "Input",
  CellLabel->"In[1068]:=  (21:55:19 on 5/16/01)",
  CellTags->"MomentumCombine"],

Cell[BoxData[
    FormBox[
      SuperscriptBox[
        RowBox[{"(", 
          FormBox[
            RowBox[{"p", "+", 
              RowBox[{"2", " ", "q"}]}],
            "TraditionalForm"], ")"}], 
        FormBox[
          FormBox["\[Mu]",
            "TraditionalForm"],
          "TraditionalForm"]], TraditionalForm]], "Output",
  CellLabel->"Out[1068]=  (21:55:19 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"MomentumCombine", "[", "t1", "]"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[1069]:=  (21:55:19 on 5/16/01)",
  CellTags->"MomentumCombine"],

Cell[BoxData[
    RowBox[{"Pair", "[", 
      RowBox[{
        RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
        RowBox[{"Momentum", "[", 
          RowBox[{"p", "+", 
            RowBox[{"2", " ", "q"}]}], "]"}]}], "]"}]], "Output",
  CellLabel->"Out[1069]//StandardForm=  (21:55:19 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"MomentumCombine", "[", "t1", "]"}], "//", 
      "ExpandScalarProduct"}]], "Input",
  CellLabel->"In[1070]:=  (21:55:19 on 5/16/01)",
  CellTags->"MomentumCombine"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox[
          FormBox["p",
            "TraditionalForm"], 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]], "+", 
        RowBox[{"2", " ", 
          SuperscriptBox[
            FormBox["q",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1070]=  (21:55:19 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StandardForm", "[", "%", "]"}]], "Input",
  CellLabel->"In[1071]:=  (21:55:19 on 5/16/01)",
  CellTags->"MomentumCombine"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Pair", "[", 
        RowBox[{
          RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
          RowBox[{"Momentum", "[", "p", "]"}]}], "]"}], "+", 
      RowBox[{"2", " ", 
        RowBox[{"Pair", "[", 
          RowBox[{
            RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
            RowBox[{"Momentum", "[", "q", "]"}]}], "]"}]}]}]], "Output",
  CellLabel->"Out[1071]//StandardForm=  (21:55:19 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{"Clear", "[", "t1", "]"}]], "Input",
  CellLabel->"In[1072]:=  (21:55:19 on 5/16/01)",
  CellTags->"MomentumCombine"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["MomentumExpand", "ObjectName",
  CellTags->"MomentumExpand"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"MomentumExpand"],

Cell["\<\
MomentumExpand[expr] expands Momentum[a+b+ ...] in expr into Momentum[a] + \
Momentum[b] + ... .\
\>", "Text",
  CellTags->"MomentumExpand"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["ExpandScalarProduct",
    ButtonData:>"ExpandScalarProduct",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"ExpandScalarProduct"],
  ", ",
  ButtonBox["MomentumCombine",
    ButtonData:>"MomentumCombine",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"MomentumCombine"],
  "."
}], "Text",
  CellTags->"MomentumExpand"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"MomentumExpand"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"MomentumExpand", "[", 
        RowBox[{"Momentum", "[", 
          RowBox[{"p", "+", "q"}], "]"}], "]"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[1073]:=  (21:55:19 on 5/16/01)",
  CellTags->"MomentumExpand"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Momentum", "[", "p", "]"}], "+", 
      RowBox[{"Momentum", "[", "q", "]"}]}]], "Output",
  CellLabel->"Out[1073]//StandardForm=  (21:55:19 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ScalarProduct", "[", 
      RowBox[{
        RowBox[{"p", "+", "q"}], ",", "r"}], "]"}]], "Input",
  CellLabel->"In[1074]:=  (21:55:19 on 5/16/01)",
  CellTags->"MomentumExpand"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", 
        FormBox[
          RowBox[{"p", "+", "q"}],
          "TraditionalForm"], "\[NoBreak]", ")", "\[NoBreak]", "\[CenterDot]",
         "\[NoBreak]", 
        FormBox["r",
          "TraditionalForm"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1074]=  (21:55:19 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "StandardForm"}]], "Input",
  CellLabel->"In[1075]:=  (21:55:20 on 5/16/01)",
  CellTags->"MomentumExpand"],

Cell[BoxData[
    RowBox[{"Pair", "[", 
      RowBox[{
        RowBox[{"Momentum", "[", 
          RowBox[{"p", "+", "q"}], "]"}], ",", 
        RowBox[{"Momentum", "[", "r", "]"}]}], "]"}]], "Output",
  CellLabel->"Out[1075]//StandardForm=  (21:55:20 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"MomentumExpand", "[", 
      RowBox[{"ScalarProduct", "[", 
        RowBox[{
          RowBox[{"p", "+", "q"}], ",", "r"}], "]"}], "]"}]], "Input",
  CellLabel->"In[1076]:=  (21:55:20 on 5/16/01)",
  CellTags->"MomentumExpand"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", 
        TagBox[
          FormBox[
            RowBox[{"p", "+", "q"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ")", ".", "(", 
        TagBox[
          FormBox["r",
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[1076]=  (21:55:20 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "StandardForm"}]], "Input",
  CellLabel->"In[1077]:=  (21:55:20 on 5/16/01)",
  CellTags->"MomentumExpand"],

Cell[BoxData[
    RowBox[{"Pair", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"Momentum", "[", "p", "]"}], "+", 
          RowBox[{"Momentum", "[", "q", "]"}]}], ",", 
        RowBox[{"Momentum", "[", "r", "]"}]}], "]"}]], "Output",
  CellLabel->"Out[1077]//StandardForm=  (21:55:20 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"MomentumExpand", "[", 
      RowBox[{"ScalarProduct", "[", 
        RowBox[{
          RowBox[{"p", "+", "q"}], ",", 
          RowBox[{"r", "-", "p"}]}], "]"}], "]"}]], "Input",
  CellLabel->"In[1078]:=  (21:55:20 on 5/16/01)",
  CellTags->"MomentumExpand"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", 
        TagBox[
          FormBox[
            RowBox[{"p", "+", "q"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ")", ".", "(", 
        TagBox[
          FormBox[
            RowBox[{"r", "-", "p"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[1078]=  (21:55:20 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "StandardForm"}]], "Input",
  CellLabel->"In[1079]:=  (21:55:20 on 5/16/01)",
  CellTags->"MomentumExpand"],

Cell[BoxData[
    RowBox[{"Pair", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"Momentum", "[", "p", "]"}], "+", 
          RowBox[{"Momentum", "[", "q", "]"}]}], ",", 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"Momentum", "[", "p", "]"}]}], "+", 
          RowBox[{"Momentum", "[", "r", "]"}]}]}], "]"}]], "Output",
  CellLabel->"Out[1079]//StandardForm=  (21:55:20 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Calc", "[", "%", "]"}]], "Input",
  CellLabel->"In[1080]:=  (21:55:20 on 5/16/01)",
  CellTags->"MomentumExpand"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          SuperscriptBox[
            FormBox["p",
              "TraditionalForm"], "2"]}], "-", 
        RowBox[{
          FormBox["p",
            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
          FormBox["q",
            "TraditionalForm"]}], "+", 
        RowBox[{
          FormBox["p",
            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
          FormBox["r",
            "TraditionalForm"]}], "+", 
        RowBox[{
          FormBox["q",
            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
          FormBox["r",
            "TraditionalForm"]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1080]=  (21:55:20 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Momentum", "ObjectName",
  CellTags->"Momentum"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"Momentum"],

Cell["\<\
Momentum[p] is the head of a four momentum (p). The internal representation \
of a four-dimensional p is Momentum[p]. For other than four dimensions: \
Momentum[p, dim]. Momentum[p, 4] simplifies to Momentum[p].\
\>", "Text",
  CellTags->"Momentum"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["DiracGamma",
    ButtonData:>"DiracGamma",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracGamma"],
  ", ",
  ButtonBox["Eps",
    ButtonData:>"Eps",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Eps"],
  ", ",
  ButtonBox["LorentzIndex",
    ButtonData:>"LorentzIndex",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"LorentzIndex"],
  ", ",
  ButtonBox["MomentumExpand",
    ButtonData:>"MomentumExpand",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"MomentumExpand"],
  "."
}], "Text",
  CellTags->"Momentum"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"Momentum"],

Cell["This is a four dimensional momentum.", "Text",
  CellTags->"Momentum"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Momentum", "[", "p", "]"}]], "Input",
  CellLabel->"In[1081]:=  (21:55:20 on 5/16/01)",
  CellTags->"Momentum"],

Cell[BoxData[
    FormBox["p", TraditionalForm]], "Output",
  CellLabel->"Out[1081]=  (21:55:20 on 5/16/01)"]
}, Closed]],

Cell["\<\
As an optional second argument the dimension must be specified if it is \
different from 4.\
\>", "Text",
  CellTags->"Momentum"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Momentum", "[", 
      RowBox[{"p", ",", "D"}], "]"}]], "Input",
  CellLabel->"In[1082]:=  (21:55:20 on 5/16/01)",
  CellTags->"Momentum"],

Cell[BoxData[
    FormBox["p", TraditionalForm]], "Output",
  CellLabel->"Out[1082]=  (21:55:20 on 5/16/01)"]
}, Closed]],

Cell["The dimension index is supressed in the output.", "Text",
  CellTags->"Momentum"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Momentum", "[", 
        RowBox[{"p", ",", "d"}], "]"}], "//", "StandardForm"}]], "Input",
  CellLabel->"In[1083]:=  (21:55:20 on 5/16/01)",
  CellTags->"Momentum"],

Cell[BoxData[
    RowBox[{"Momentum", "[", 
      RowBox[{"p", ",", "d"}], "]"}]], "Output",
  CellLabel->"Out[1083]//StandardForm=  (21:55:21 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"a1", "=", 
      RowBox[{"Momentum", "[", 
        RowBox[{"-", "q"}], "]"}]}]], "Input",
  CellLabel->"In[1084]:=  (21:55:21 on 5/16/01)",
  CellTags->"Momentum"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", "q"}], TraditionalForm]], "Output",
  CellLabel->"Out[1084]=  (21:55:21 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"a1", "//", "StandardForm"}]], "Input",
  CellLabel->"In[1085]:=  (21:55:21 on 5/16/01)",
  CellTags->"Momentum"],

Cell[BoxData[
    RowBox[{"-", 
      RowBox[{"Momentum", "[", "q", "]"}]}]], "Output",
  CellLabel->"Out[1085]//StandardForm=  (21:55:21 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"a2", " ", "=", " ", 
      RowBox[{
        RowBox[{"Momentum", "[", 
          RowBox[{"p", "-", "q"}], "]"}], " ", "+", " ", 
        RowBox[{"Momentum", "[", 
          RowBox[{"2", "q"}], "]"}]}]}]], "Input",
  CellLabel->"In[1086]:=  (21:55:21 on 5/16/01)",
  CellTags->"Momentum"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"(", 
          RowBox[{"p", "-", "q"}], ")"}], "+", 
        RowBox[{"2", " ", "q"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1086]=  (21:55:21 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"a2", "//", "StandardForm"}]], "Input",
  CellLabel->"In[1087]:=  (21:55:21 on 5/16/01)",
  CellTags->"Momentum"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Momentum", "[", 
        RowBox[{"p", "-", "q"}], "]"}], "+", 
      RowBox[{"2", " ", 
        RowBox[{"Momentum", "[", "q", "]"}]}]}]], "Output",
  CellLabel->"Out[1087]//StandardForm=  (21:55:21 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"a2", "//", "MomentumExpand"}], "//", "StandardForm"}]], "Input",\

  CellLabel->"In[1088]:=  (21:55:21 on 5/16/01)",
  CellTags->"Momentum"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Momentum", "[", "p", "]"}], "+", 
      RowBox[{"Momentum", "[", "q", "]"}]}]], "Output",
  CellLabel->"Out[1088]//StandardForm=  (21:55:21 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"a2", "//", "MomentumCombine"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[1089]:=  (21:55:21 on 5/16/01)",
  CellTags->"Momentum"],

Cell[BoxData[
    RowBox[{"Momentum", "[", 
      RowBox[{"p", "+", "q"}], "]"}]], "Output",
  CellLabel->"Out[1089]//StandardForm=  (21:55:21 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"ChangeDimension", "[", 
        RowBox[{
          RowBox[{"Momentum", "[", "p", "]"}], ",", "d"}], "]"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[1090]:=  (21:55:21 on 5/16/01)",
  CellTags->"Momentum"],

Cell[BoxData[
    RowBox[{"Momentum", "[", 
      RowBox[{"p", ",", "d"}], "]"}]], "Output",
  CellLabel->"Out[1090]//StandardForm=  (21:55:21 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{"Clear", "[", 
      RowBox[{"a1", ",", "a2"}], "]"}]], "Input",
  CellLabel->"In[1091]:=  (21:55:21 on 5/16/01)",
  CellTags->"Momentum"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["MT", "ObjectName",
  CellTags->"MT"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"MT"],

Cell[TextData[{
  "MT[",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Mu]", ",", " ", "\[Nu]"}], TraditionalForm]]],
  "] is the metric tensor in 4 dimensions."
}], "Text",
  CellTags->"MT"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["FeynCalcExternal",
    ButtonData:>"FeynCalcExternal",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FeynCalcExternal"],
  ", ",
  ButtonBox["FCE",
    ButtonData:>"FCE",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FCE"],
  ", ",
  ButtonBox["FCI",
    ButtonData:>"FCI",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FCI"],
  ", ",
  ButtonBox["MetricTensor",
    ButtonData:>"MetricTensor",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"MetricTensor"],
  ", ",
  ButtonBox["MTD",
    ButtonData:>"MTD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"MTD"],
  "."
}], "Text",
  CellTags->"MT"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"MT"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"MT", "[", 
      RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}]], "Input",
  CellLabel->"In[1092]:=  (21:55:21 on 5/16/01)",
  CellTags->"MT"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["g", 
        RowBox[{"\[Alpha]", "\[NoBreak]", "\[Beta]"}]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1092]=  (21:55:21 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Contract", "[", 
      RowBox[{
        RowBox[{"MT", "[", 
          RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], " ", 
        RowBox[{"MT", "[", 
          RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}]}], "]"}]], "Input",
  CellLabel->"In[1093]:=  (21:55:22 on 5/16/01)",
  CellTags->"MT"],

Cell[BoxData[
    FormBox["4", TraditionalForm]], "Output",
  CellLabel->"Out[1093]=  (21:55:22 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"MT", "[", 
        RowBox[{"a", ",", "b"}], "]"}], "//", "StandardForm"}]], "Input",
  CellLabel->"In[1094]:=  (21:55:22 on 5/16/01)",
  CellTags->"MT"],

Cell[BoxData[
    RowBox[{"MT", "[", 
      RowBox[{"a", ",", "b"}], "]"}]], "Output",
  CellLabel->"Out[1094]//StandardForm=  (21:55:22 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"FCI", "[", 
        RowBox[{"MT", "[", 
          RowBox[{"a", ",", "b"}], "]"}], "]"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[1095]:=  (21:55:22 on 5/16/01)",
  CellTags->"MT"],

Cell[BoxData[
    RowBox[{"Pair", "[", 
      RowBox[{
        RowBox[{"LorentzIndex", "[", "a", "]"}], ",", 
        RowBox[{"LorentzIndex", "[", "b", "]"}]}], "]"}]], "Output",
  CellLabel->"Out[1095]//StandardForm=  (21:55:22 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"FCE", "[", 
        RowBox[{"FCI", "[", 
          RowBox[{"MT", "[", 
            RowBox[{"a", ",", "b"}], "]"}], "]"}], "]"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[1096]:=  (21:55:22 on 5/16/01)",
  CellTags->"MT"],

Cell[BoxData[
    RowBox[{"MT", "[", 
      RowBox[{"a", ",", "b"}], "]"}]], "Output",
  CellLabel->"Out[1096]//StandardForm=  (21:55:22 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["MTD", "ObjectName",
  CellTags->"MTD"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"MTD"],

Cell[TextData[{
  "MTD[",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Mu]", ",", " ", "\[Nu]"}], TraditionalForm]]],
  "] is the metric tensor in D dimensions."
}], "Text",
  CellTags->"MTD"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["FeynCalcExternal",
    ButtonData:>"FeynCalcExternal",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FeynCalcExternal"],
  ", ",
  ButtonBox["FCE",
    ButtonData:>"FCE",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FCE"],
  ", ",
  ButtonBox["FCI",
    ButtonData:>"FCI",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FCI"],
  ", ",
  ButtonBox["MetricTensor",
    ButtonData:>"MetricTensor",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"MetricTensor"],
  ", ",
  ButtonBox["MT",
    ButtonData:>"MT",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"MT"],
  "."
}], "Text",
  CellTags->"MTD"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"MTD"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"MTD", "[", 
      RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}]], "Input",
  CellLabel->"In[1097]:=  (21:55:22 on 5/16/01)",
  CellTags->"MTD"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["g", 
        RowBox[{"\[Alpha]", "\[NoBreak]", "\[Beta]"}]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1097]=  (21:55:22 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Contract", "[", 
      RowBox[{
        RowBox[{"MTD", "[", 
          RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], " ", 
        RowBox[{"MTD", "[", 
          RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}]}], "]"}]], "Input",
  CellLabel->"In[1098]:=  (21:55:22 on 5/16/01)",
  CellTags->"MTD"],

Cell[BoxData[
    FormBox["D", TraditionalForm]], "Output",
  CellLabel->"Out[1098]=  (21:55:22 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"MTD", "[", 
        RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[1099]:=  (21:55:22 on 5/16/01)",
  CellTags->"MTD"],

Cell[BoxData[
    RowBox[{"MTD", "[", 
      RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}]], "Output",
  CellLabel->"Out[1099]//StandardForm=  (21:55:23 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"FCI", "[", 
        RowBox[{"MTD", "[", 
          RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], "]"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[1100]:=  (21:55:23 on 5/16/01)",
  CellTags->"MTD"],

Cell[BoxData[
    RowBox[{"Pair", "[", 
      RowBox[{
        RowBox[{"LorentzIndex", "[", 
          RowBox[{"\[Alpha]", ",", "D"}], "]"}], ",", 
        RowBox[{"LorentzIndex", "[", 
          RowBox[{"\[Beta]", ",", "D"}], "]"}]}], "]"}]], "Output",
  CellLabel->"Out[1100]//StandardForm=  (21:55:23 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"FCE", "[", 
        RowBox[{"FCI", "[", 
          RowBox[{"MTD", "[", 
            RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], "]"}], "]"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[1101]:=  (21:55:23 on 5/16/01)",
  CellTags->"MTD"],

Cell[BoxData[
    RowBox[{"MTD", "[", 
      RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}]], "Output",
  CellLabel->"Out[1101]//StandardForm=  (21:55:23 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Nielsen", "ObjectName",
  CellTags->"Nielsen"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"Nielsen"],

Cell["Nielsen[i,j, x] denotes Nielsen's polylogarithm.", "Text",
  CellTags->"Nielsen"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "Nielsen", "]"}]], "Input",
  CellLabel->"In[1102]:=  (21:55:23 on 5/16/01)",
  CellTags->"Nielsen"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"PolyLog", "\[Rule]", "False"}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1102]=  (21:55:23 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["SimplifyPolyLog",
    ButtonData:>"SimplifyPolyLog",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SimplifyPolyLog"],
  "."
}], "Text",
  CellTags->"Nielsen"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"Nielsen"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Nielsen", "[", 
      RowBox[{"1", ",", "2", ",", "x"}], "]"}]], "Input",
  CellLabel->"In[1103]:=  (21:55:23 on 5/16/01)",
  CellTags->"Nielsen"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["S", 
          RowBox[{
            FormBox["1",
              "TraditionalForm"], "\[NoBreak]", 
            FormBox["2",
              "TraditionalForm"]}]], "(", "x", ")"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1103]=  (21:55:23 on 5/16/01)"]
}, Closed]],

Cell["\<\
Numerical evaluation is done via N[Nielsen[n_,p_,x_]] := \
(-1)^(n+p-1)/(n-1)!/p! NIntegrate[Log[1-x t]^p Log[t]^(n-1)/t,{t,0,1}];\
\>", "Text",
  CellTags->"Nielsen"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"N", "[", 
      RowBox[{"Nielsen", "[", 
        RowBox[{"1", ",", "2", ",", ".45"}], "]"}], "]"}]], "Input",
  CellLabel->"In[1104]:=  (21:55:23 on 5/16/01)",
  CellTags->"Nielsen"],

Cell[BoxData[
    FormBox["0.07287162612104647`", TraditionalForm]], "Output",
  CellLabel->"Out[1104]=  (21:55:23 on 5/16/01)"]
}, Closed]],

Cell["Some special values are built in.", "Text",
  CellTags->"Nielsen"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"Nielsen", "[", 
          RowBox[{"1", ",", "2", ",", "0"}], "]"}], ",", 
        RowBox[{"Nielsen", "[", 
          RowBox[{"1", ",", "2", ",", 
            RowBox[{"-", "1"}]}], "]"}], ",", 
        RowBox[{"Nielsen", "[", 
          RowBox[{"1", ",", "2", ",", 
            RowBox[{"1", "/", "2"}]}], "]"}], ",", 
        RowBox[{"Nielsen", "[", 
          RowBox[{"1", ",", "2", ",", "1"}], "]"}]}], "}"}]], "Input",
  CellLabel->"In[1105]:=  (21:55:23 on 5/16/01)",
  CellTags->"Nielsen"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"0", ",", 
          FractionBox[
            TagBox[
              RowBox[{"\[Zeta]", "(", 
                TagBox["3",
                  (Editable -> True)], ")"}],
              InterpretTemplate[ Zeta[ #]&]], "8"], ",", 
          FractionBox[
            TagBox[
              RowBox[{"\[Zeta]", "(", 
                TagBox["3",
                  (Editable -> True)], ")"}],
              InterpretTemplate[ Zeta[ #]&]], "8"], ",", 
          TagBox[
            RowBox[{"\[Zeta]", "(", 
              TagBox["3",
                (Editable -> True)], ")"}],
            InterpretTemplate[ Zeta[ #]&]]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1105]=  (21:55:23 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Nielsen", "[", 
      RowBox[{"1", ",", "2", ",", "x", ",", 
        RowBox[{"PolyLog", "\[Rule]", "True"}]}], "]"}]], "Input",
  CellLabel->"In[1106]:=  (21:55:23 on 5/16/01)",
  CellTags->"Nielsen"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"log", "(", "x", ")"}], " ", 
          RowBox[{
            SuperscriptBox["log", "2"], "(", 
            RowBox[{"1", "-", "x"}], ")"}]}], "+", 
        RowBox[{
          RowBox[{
            SubscriptBox["Li", "2"], "(", 
            RowBox[{"1", "-", "x"}], ")"}], " ", 
          RowBox[{"log", "(", 
            RowBox[{"1", "-", "x"}], ")"}]}], "-", 
        RowBox[{
          SubscriptBox["Li", "3"], "(", 
          RowBox[{"1", "-", "x"}], ")"}], "+", 
        TagBox[
          RowBox[{"\[Zeta]", "(", 
            TagBox["3",
              (Editable -> True)], ")"}],
          InterpretTemplate[ Zeta[ #]&]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1106]=  (21:55:23 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Nielsen", "[", 
      RowBox[{"1", ",", "3", ",", "x", ",", 
        RowBox[{"PolyLog", "\[Rule]", "True"}]}], "]"}]], "Input",
  CellLabel->"In[1107]:=  (21:55:23 on 5/16/01)",
  CellTags->"Nielsen"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"-", 
            FractionBox["1", "6"]}], " ", 
          RowBox[{"log", "(", "x", ")"}], " ", 
          RowBox[{
            SuperscriptBox["log", "3"], "(", 
            RowBox[{"1", "-", "x"}], ")"}]}], "-", 
        RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{
            SubscriptBox["Li", "2"], "(", 
            RowBox[{"1", "-", "x"}], ")"}], " ", 
          RowBox[{
            SuperscriptBox["log", "2"], "(", 
            RowBox[{"1", "-", "x"}], ")"}]}], "+", 
        RowBox[{
          RowBox[{
            SubscriptBox["Li", "3"], "(", 
            RowBox[{"1", "-", "x"}], ")"}], " ", 
          RowBox[{"log", "(", 
            RowBox[{"1", "-", "x"}], ")"}]}], "-", 
        RowBox[{
          SubscriptBox["Li", "4"], "(", 
          RowBox[{"1", "-", "x"}], ")"}], "+", 
        FractionBox[
          SuperscriptBox["\[Pi]", "4"], "90"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1107]=  (21:55:24 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Nielsen", "[", 
      RowBox[{"3", ",", "1", ",", "x", ",", 
        RowBox[{"PolyLog", "\[Rule]", "True"}]}], "]"}]], "Input",
  CellLabel->"In[1108]:=  (21:55:24 on 5/16/01)",
  CellTags->"Nielsen"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["Li", "4"], "(", "x", ")"}], TraditionalForm]], "Output",\

  CellLabel->"Out[1108]=  (21:55:24 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["NTerms", "ObjectName",
  CellTags->"NTerms"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"NTerms"],

Cell["\<\
NTerms[x] is equivalent to Length if x is a sum; otherwise NTerms[x] returns \
1, except NTerms[0] -> 0.\
\>", "Text",
  CellTags->"NTerms"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"NTerms"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NTerms", "[", 
      RowBox[{"a", "-", "b"}], "]"}]], "Input",
  CellLabel->"In[1109]:=  (21:55:24 on 5/16/01)",
  CellTags->"NTerms"],

Cell[BoxData[
    FormBox["2", TraditionalForm]], "Output",
  CellLabel->"Out[1109]=  (21:55:24 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NTerms", "[", 
      RowBox[{"a", " ", "b", " ", "c"}], "]"}]], "Input",
  CellLabel->"In[1110]:=  (21:55:24 on 5/16/01)",
  CellTags->"NTerms"],

Cell[BoxData[
    FormBox["1", TraditionalForm]], "Output",
  CellLabel->"Out[1110]=  (21:55:24 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NTerms", "[", "9", "]"}]], "Input",
  CellLabel->"In[1111]:=  (21:55:24 on 5/16/01)",
  CellTags->"NTerms"],

Cell[BoxData[
    FormBox["1", TraditionalForm]], "Output",
  CellLabel->"Out[1111]=  (21:55:24 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NTerms", "[", "0", "]"}]], "Input",
  CellLabel->"In[1112]:=  (21:55:24 on 5/16/01)",
  CellTags->"NTerms"],

Cell[BoxData[
    FormBox["0", TraditionalForm]], "Output",
  CellLabel->"Out[1112]=  (21:55:24 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["OneLoop", "ObjectName",
  CellTags->"OneLoop"],

Cell[TextData[{
  "Documentation unfinished ....; see also the old FeynCalc documentation at \
",
  ButtonBox["http://www.mertig.com/oldfc",
    ButtonData:>{
      URL[ "http://www.mertig.com/oldfc"], None},
    ButtonStyle->"Hyperlink"],
  ". NOTICE: While OneLoop is restricted to 't Hooft Feynman gauge the \
function ",
  ButtonBox["OneLoopSimplify",
    ButtonData:>"OneLoopSimplify",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"OneLoopSimplify"],
  " does not have this restriction (but is usually slower). OneLoop handles \
selfenergies, vertex and box-graphs (those only up to 3rd rank tensor in the \
integration variable)."
}], "Text",
  CellTags->"OneLoop"],

Cell["WARNING: If you encounter anomalies:", "Text",
  CellTags->"OneLoop"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
          "The", " ", "default", " ", "setting", " ", "of", " ", "$West", " ",
             "is", " ", "True"}], ",", " ", 
          RowBox[{"i", ".", "e", "."}], ",", " ", 
          RowBox[{"the", " ", "way", " ", 
            RowBox[{"tr", "(", 
              RowBox[{
                SuperscriptBox["\[Gamma]", "\[Mu]"], 
                SuperscriptBox["\[Gamma]", "\[Nu]"], 
                SuperscriptBox["\[Gamma]", "\[Rho]"], 
                SuperscriptBox["\[Gamma]", "\[Sigma]"], 
                SuperscriptBox["\[Gamma]", "\[Tau]"], 
                SuperscriptBox["\[Gamma]", "\[Lambda]"], 
                SuperscriptBox["\[Gamma]", "5"]}], ")"}]}]}], 
        TraditionalForm]]],
  " ",
  "is calculated in D dimensions has changed compared to the old FeynCalc \
version. Please keep in mind that the issue of ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox["\[Gamma]", "5"], TraditionalForm]]],
  "schemes is inherintly tricky."
}], "Text",
  CellTags->"OneLoop"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"OneLoop"],

Cell["\<\
OneLoop[q, amplitude] calculates the one-loop Feynman diagram amplitude \
(n-point, where n<=4 and the highest tensor rank of the integration momenta \
(after cancellation of scalar products) may be 3; unless OneLoopSimplify is \
used).\
\>", "Text",
  CellTags->"OneLoop"],

Cell["\<\
The argument q denotes the integration variable, i.e., the loop momentum. \
OneLoop[name, q, amplitude] has as first argument a name of the amplitude. If \
the second argument has head FeynAmp then OneLoop[q, FeynAmp[name, k, expr]] \
and OneLoop[FeynAmp[name, k, expr]] tranform to OneLoop[name, k, expr].\
\>", "Text",
  CellTags->"OneLoop"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "OneLoop", "]"}]], "Input",
  CellLabel->"In[1113]:=  (21:55:24 on 5/16/01)",
  CellTags->"OneLoop"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"Apart2", "\[Rule]", "True"}], ",", 
          RowBox[{"CancelQP", "\[Rule]", "True"}], ",", 
          RowBox[{"DenominatorOrder", "\[Rule]", "False"}], ",", 
          RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
          RowBox[{"FinalSubstitutions", "\[Rule]", 
            RowBox[{"{", "}"}]}], ",", 
          RowBox[{"Factoring", "\[Rule]", "False"}], ",", 
          RowBox[{"FormatType", "\[Rule]", "InputForm"}], ",", 
          RowBox[{"InitialSubstitutions", "\[Rule]", 
            RowBox[{"{", "}"}]}], ",", 
          RowBox[{"IntermediateSubstitutions", "\[Rule]", 
            RowBox[{"{", "}"}]}], ",", 
          RowBox[{"IsolateHead", "\[Rule]", "False"}], ",", 
          RowBox[{"Mandelstam", "\[Rule]", 
            RowBox[{"{", "}"}]}], ",", 
          RowBox[{"OneLoopSimplify", "\[Rule]", "False"}], ",", 
          RowBox[{"Prefactor", "\[Rule]", "1"}], ",", 
          RowBox[{"ReduceGamma", "\[Rule]", "False"}], ",", 
          RowBox[{"ReduceToScalars", "\[Rule]", "False"}], ",", 
          RowBox[{"SmallVariables", "\[Rule]", 
            RowBox[{"{", "}"}]}], ",", 
          RowBox[{"WriteOut", "\[Rule]", "False"}], ",", 
          RowBox[{"WriteOutPaVe", "\[Rule]", "False"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1113]=  (21:55:24 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["B0",
    ButtonData:>"B0",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"B0"],
  ", ",
  ButtonBox["C0",
    ButtonData:>"C0",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"C0"],
  ", ",
  ButtonBox["D0",
    ButtonData:>"D0",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"D0"],
  ", ",
  ButtonBox["OneLoopSimplify",
    ButtonData:>"OneLoopSimplify",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"OneLoopSimplify"],
  ", ",
  ButtonBox["TID",
    ButtonData:>"TID",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"TID"],
  ", ",
  ButtonBox["TIDL",
    ButtonData:>"TIDL",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"TIDL"],
  "."
}], "Text",
  CellTags->"OneLoop"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"OneLoop"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          RowBox[{"-", "I"}], "/", 
          RowBox[{"Pi", "^", "2"}]}], " ", 
        RowBox[{"FAD", "[", 
          RowBox[{"{", 
            RowBox[{"q", ",", "m"}], "}"}], "]"}]}], "//", "FCI"}]], "Input",
  CellLabel->"In[1114]:=  (21:55:24 on 5/16/01)",
  CellTags->"OneLoop"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        FractionBox["\[ImaginaryI]", 
          RowBox[{
            SuperscriptBox["\[Pi]", "2"], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox["q", "2"], "-", 
                SuperscriptBox["m", "2"]}], ")"}]}]]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1114]=  (21:55:24 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"OneLoop", "[", 
      RowBox[{"q", ",", "%"}], "]"}]], "Input",
  CellLabel->"In[1115]:=  (21:55:24 on 5/16/01)",
  CellTags->"OneLoop"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            SubscriptBox["B", "0"], "(", "0", ",", 
            SuperscriptBox["m", "2"], ",", 
            SuperscriptBox["m", "2"], ")"}], " ", 
          SuperscriptBox["m", "2"]}], "+", 
        SuperscriptBox["m", "2"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1115]=  (21:55:35 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      RowBox[{"mf", "/:", 
        RowBox[{"MakeBoxes", "[", 
          RowBox[{"mf", ",", "TraditionalForm"}], "]"}], "=", 
        RowBox[{"InterpretationBox", "[", 
          RowBox[{
            RowBox[{"SubscriptBox", "[", 
              RowBox[{"\"\<m\>\"", ",", "\"\<f\>\""}], "]"}], ",", "mf"}], 
          "]"}]}], ";"}]], "Input",
  CellLabel->"In[1116]:=  (21:55:35 on 5/16/01)",
  CellTags->"OneLoop"],

Cell[TextData[{
  "Remember that FAD[{q,mf},{q-k,mf}] is a fast possibility to enter ",
  Cell[BoxData[
      FormBox[
        RowBox[{"1", "/", 
          RowBox[{
            RowBox[{"(", " ", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox["q", "2"], "-", 
                    SuperscriptBox["mf", "2"]}], ")"}], " ", 
                RowBox[{"(", " ", 
                  RowBox[{
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{"q", "-", "k"}], ")"}], "2"], "-", 
                    SuperscriptBox["mf", "2"]}], ")"}]}], " ", ")"}], "."}]}],
         TraditionalForm]]]
}], "Text",
  CellTags->"OneLoop"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t", "=", 
      RowBox[{
        RowBox[{"I", " ", 
          FractionBox[
            SuperscriptBox["el", "2"], 
            RowBox[{"16", " ", 
              SuperscriptBox["Pi", "4"], 
              RowBox[{"(", 
                RowBox[{"1", "-", "D"}], ")"}]}]], 
          RowBox[{"FAD", "[", 
            RowBox[{
              RowBox[{"{", 
                RowBox[{"q", ",", "mf"}], "}"}], ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"q", "-", "k"}], ",", "mf"}], "}"}]}], "]"}], 
          RowBox[{"DiracTrace", "[", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"mf", "+", 
                  RowBox[{"GS", "[", 
                    RowBox[{"q", "-", "k"}], "]"}]}], ")"}], ".", 
              RowBox[{"GA", "[", "\[Mu]", "]"}], ".", 
              RowBox[{"(", 
                RowBox[{"mf", "+", 
                  RowBox[{"GS", "[", "q", "]"}]}], ")"}], ".", 
              RowBox[{"GA", "[", "\[Mu]", "]"}]}], "]"}]}], " ", "//", " ", 
        "FCI"}]}]], "Input",
  CellLabel->"In[1117]:=  (21:55:35 on 5/16/01)",
  CellTags->"OneLoop"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
          SuperscriptBox["el", "2"], " ", 
          RowBox[{"tr", "(", 
            FormBox[
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    InterpretationBox[
                      SubscriptBox["m", "f"],
                      mf], "+", 
                    RowBox[{
                      FormBox["\<\"\[Gamma]\"\>",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", "(", "\[NoBreak]", 
                      FormBox[
                        RowBox[{"q", "-", 
                          FormBox[
                            TagBox[
                              StyleBox["\<\"k\"\>",
                                FontSlant->"Italic"],
                              (StyleForm[ #, FontSlant -> "Italic"]&)],
                            "TraditionalForm"]}],
                        "TraditionalForm"], "\[NoBreak]", ")"}]}], ")"}], ".",
                 
                SuperscriptBox["\[Gamma]", 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], ".", 
                RowBox[{"(", 
                  RowBox[{
                    InterpretationBox[
                      SubscriptBox["m", "f"],
                      mf], "+", 
                    RowBox[{
                      FormBox["\<\"\[Gamma]\"\>",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["q",
                        "TraditionalForm"]}]}], ")"}], ".", 
                SuperscriptBox["\[Gamma]", 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}],
              "TraditionalForm"], ")"}]}], 
        RowBox[{"16", " ", 
          RowBox[{"(", 
            RowBox[{"1", "-", "D"}], ")"}], " ", 
          SuperscriptBox["\[Pi]", "4"], " ", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox["q", "2"], "-", 
                SuperscriptBox[
                  InterpretationBox[
                    SubscriptBox["m", "f"],
                    mf], "2"]}], ")"}], ".", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"q", "-", 
                      FormBox[
                        TagBox[
                          StyleBox["\<\"k\"\>",
                            FontSlant->"Italic"],
                          (StyleForm[ #, FontSlant -> "Italic"]&)],
                        "TraditionalForm"]}], ")"}], "2"], "-", 
                SuperscriptBox[
                  InterpretationBox[
                    SubscriptBox["m", "f"],
                    mf], "2"]}], ")"}]}]}]], TraditionalForm]], "Output",
  CellLabel->"Out[1117]=  (21:55:35 on 5/16/01)"]
}, Closed]],

Cell["\<\
The input to OneLoop may be in 4 dimensions, since the function changes the \
dimension of the objects automatically to the setting of the Dimension option \
(D by default).\
\>", "Text",
  CellTags->"OneLoop"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"OneLoop", "[", 
      RowBox[{"q", ",", "t"}], "]"}]], "Input",
  CellLabel->"In[1118]:=  (21:55:35 on 5/16/01)",
  CellTags->"OneLoop"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            SuperscriptBox["el", "2"], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  FractionBox["8", "3"], " ", 
                  RowBox[{
                    SubscriptBox["B", "0"], "(", "0", ",", 
                    SuperscriptBox[
                      InterpretationBox[
                        SubscriptBox["m", "f"],
                        mf], "2"], ",", 
                    SuperscriptBox[
                      InterpretationBox[
                        SubscriptBox["m", "f"],
                        mf], "2"], ")"}], " ", 
                  SuperscriptBox[
                    InterpretationBox[
                      SubscriptBox["m", "f"],
                      mf], "2"]}], "-", 
                RowBox[{
                  FractionBox["8", "3"], " ", 
                  RowBox[{
                    SubscriptBox["B", "0"], "(", 
                    SuperscriptBox[
                      FormBox[
                        FormBox[
                          TagBox[
                            StyleBox["\<\"k\"\>",
                              FontSlant->"Italic"],
                            (StyleForm[ #, FontSlant -> "Italic"]&)],
                          "TraditionalForm"],
                        "TraditionalForm"], "2"], ",", 
                    SuperscriptBox[
                      InterpretationBox[
                        SubscriptBox["m", "f"],
                        mf], "2"], ",", 
                    SuperscriptBox[
                      InterpretationBox[
                        SubscriptBox["m", "f"],
                        mf], "2"], ")"}], " ", 
                  SuperscriptBox[
                    InterpretationBox[
                      SubscriptBox["m", "f"],
                      mf], "2"]}], "-", 
                RowBox[{
                  FractionBox["4", "3"], " ", 
                  RowBox[{
                    SubscriptBox["B", "0"], "(", 
                    SuperscriptBox[
                      FormBox[
                        FormBox[
                          TagBox[
                            StyleBox["\<\"k\"\>",
                              FontSlant->"Italic"],
                            (StyleForm[ #, FontSlant -> "Italic"]&)],
                          "TraditionalForm"],
                        "TraditionalForm"], "2"], ",", 
                    SuperscriptBox[
                      InterpretationBox[
                        SubscriptBox["m", "f"],
                        mf], "2"], ",", 
                    SuperscriptBox[
                      InterpretationBox[
                        SubscriptBox["m", "f"],
                        mf], "2"], ")"}], " ", 
                  SuperscriptBox[
                    FormBox[
                      FormBox[
                        TagBox[
                          StyleBox["\<\"k\"\>",
                            FontSlant->"Italic"],
                          (StyleForm[ #, FontSlant -> "Italic"]&)],
                        "TraditionalForm"],
                      "TraditionalForm"], "2"]}], "+", 
                FractionBox[
                  RowBox[{"4", " ", 
                    SuperscriptBox[
                      FormBox[
                        FormBox[
                          TagBox[
                            StyleBox["\<\"k\"\>",
                              FontSlant->"Italic"],
                            (StyleForm[ #, FontSlant -> "Italic"]&)],
                          "TraditionalForm"],
                        "TraditionalForm"], "2"]}], "9"]}], ")"}]}], 
          RowBox[{"16", " ", 
            SuperscriptBox["\[Pi]", "2"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1118]=  (21:55:46 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FullSimplify", "[", "%", "]"}]], "Input",
  CellLabel->"In[1119]:=  (21:55:46 on 5/16/01)",
  CellTags->"OneLoop"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            SuperscriptBox["el", "2"], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"6", " ", 
                  RowBox[{
                    SubscriptBox["B", "0"], "(", "0", ",", 
                    SuperscriptBox[
                      InterpretationBox[
                        SubscriptBox["m", "f"],
                        mf], "2"], ",", 
                    SuperscriptBox[
                      InterpretationBox[
                        SubscriptBox["m", "f"],
                        mf], "2"], ")"}], " ", 
                  SuperscriptBox[
                    InterpretationBox[
                      SubscriptBox["m", "f"],
                      mf], "2"]}], "+", 
                SuperscriptBox[
                  FormBox[
                    FormBox[
                      TagBox[
                        StyleBox["\<\"k\"\>",
                          FontSlant->"Italic"],
                        (StyleForm[ #, FontSlant -> "Italic"]&)],
                      "TraditionalForm"],
                    "TraditionalForm"], "2"], "-", 
                RowBox[{"3", " ", 
                  RowBox[{
                    SubscriptBox["B", "0"], "(", 
                    SuperscriptBox[
                      FormBox[
                        FormBox[
                          TagBox[
                            StyleBox["\<\"k\"\>",
                              FontSlant->"Italic"],
                            (StyleForm[ #, FontSlant -> "Italic"]&)],
                          "TraditionalForm"],
                        "TraditionalForm"], "2"], ",", 
                    SuperscriptBox[
                      InterpretationBox[
                        SubscriptBox["m", "f"],
                        mf], "2"], ",", 
                    SuperscriptBox[
                      InterpretationBox[
                        SubscriptBox["m", "f"],
                        mf], "2"], ")"}], " ", 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"2", " ", 
                        SuperscriptBox[
                          InterpretationBox[
                            SubscriptBox["m", "f"],
                            mf], "2"]}], "+", 
                      SuperscriptBox[
                        FormBox[
                          FormBox[
                            TagBox[
                              StyleBox["\<\"k\"\>",
                                FontSlant->"Italic"],
                              (StyleForm[ #, FontSlant -> "Italic"]&)],
                            "TraditionalForm"],
                          "TraditionalForm"], "2"]}], ")"}]}]}], ")"}]}], 
          RowBox[{"36", " ", 
            SuperscriptBox["\[Pi]", "2"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1119]=  (21:55:47 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"SP", "[", 
          RowBox[{"k", ",", "r"}], "]"}], " ", 
        RowBox[{"FAD", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"k", ",", "m"}], "}"}], " ", ",", " ", 
            RowBox[{"k", " ", "-", " ", "p"}]}], "]"}]}], "//", 
      "FCI"}]], "Input",
  CellLabel->"In[1120]:=  (21:55:47 on 5/16/01)",
  CellTags->"OneLoop"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{
          FormBox[
            FormBox[
              TagBox[
                StyleBox["\<\"k\"\>",
                  FontSlant->"Italic"],
                (StyleForm[ #, FontSlant -> "Italic"]&)],
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
          FormBox["r",
            "TraditionalForm"]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"], "2"], "-", 
              SuperscriptBox["m", "2"]}], ")"}], ".", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"], "-", "p"}], ")"}], "2"]}]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1120]=  (21:55:47 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"OneLoop", "[", 
      RowBox[{"k", ",", "%"}], "]"}]], "Input",
  CellLabel->"In[1121]:=  (21:55:47 on 5/16/01)",
  CellTags->"OneLoop"],

Cell[BoxData[
    FormBox[
      RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Pi]", "2"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"-", 
              FractionBox[
                RowBox[{
                  RowBox[{
                    SubscriptBox["B", "0"], "(", "0", ",", 
                    SuperscriptBox["m", "2"], ",", 
                    SuperscriptBox["m", "2"], ")"}], " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["r",
                      "TraditionalForm"]}], " ", 
                  SuperscriptBox["m", "2"]}], 
                RowBox[{"2", " ", 
                  SuperscriptBox[
                    FormBox["p",
                      "TraditionalForm"], "2"]}]]}], "+", 
            FractionBox[
              RowBox[{
                RowBox[{
                  SubscriptBox["B", "0"], "(", 
                  SuperscriptBox[
                    FormBox["p",
                      "TraditionalForm"], "2"], ",", "0", ",", 
                  SuperscriptBox["m", "2"], ")"}], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["r",
                    "TraditionalForm"]}], " ", 
                SuperscriptBox["m", "2"]}], 
              RowBox[{"2", " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["r",
                    "TraditionalForm"]}], " ", 
                SuperscriptBox["m", "2"]}], 
              RowBox[{"2", " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"]}]], "+", 
            RowBox[{
              FractionBox["1", "2"], " ", 
              RowBox[{
                SubscriptBox["B", "0"], "(", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], ",", "0", ",", 
                SuperscriptBox["m", "2"], ")"}], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["r",
                  "TraditionalForm"]}]}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1121]=  (21:55:56 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{"Clear", "[", "t", "]"}]], "Input",
  CellLabel->"In[1122]:=  (21:55:56 on 5/16/01)",
  CellTags->"OneLoop"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["OneLoopSimplify", "ObjectName",
  CellTags->"OneLoopSimplify"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"OneLoopSimplify"],

Cell["\<\
OneLoopSimplify[amp, q] simplifies the one-loop amplitude amp. The second \
argument denotes the integration momentum.\
\>", "Text",
  CellTags->"OneLoopSimplify"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "OneLoopSimplify", "]"}]], "Input",
  CellLabel->"In[1123]:=  (21:55:56 on 5/16/01)",
  CellTags->"OneLoopSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"Collecting", "\[Rule]", "False"}], ",", 
          RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
          RowBox[{"DimensionalReduction", "\[Rule]", "False"}], ",", 
          RowBox[{"DiracSimplify", "\[Rule]", "True"}], ",", 
          RowBox[{"FinalSubstitutions", "\[Rule]", 
            RowBox[{"{", "}"}]}], ",", 
          RowBox[{"IntegralTable", "\[Rule]", 
            RowBox[{"{", "}"}]}], ",", 
          RowBox[{"OPE1Loop", "\[Rule]", "False"}], ",", 
          RowBox[{"ScalarProductCancel", "\[Rule]", "True"}], ",", 
          RowBox[{"SUNNToCACF", "\[Rule]", "True"}], ",", 
          RowBox[{"SUNTrace", "\[Rule]", "False"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1123]=  (21:55:56 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["OneLoop",
    ButtonData:>"OneLoop",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"OneLoop"],
  ", ",
  ButtonBox["TID",
    ButtonData:>"TID",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"TID"],
  ", ",
  ButtonBox["TIDL",
    ButtonData:>"TIDL",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"TIDL"],
  "."
}], "Text",
  CellTags->"OneLoopSimplify"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"OneLoopSimplify"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"SP", "[", 
          RowBox[{"k", ",", "r"}], "]"}], " ", 
        RowBox[{"FAD", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"k", ",", "m"}], "}"}], " ", ",", " ", 
            RowBox[{"k", " ", "-", " ", "p"}]}], "]"}]}], "//", 
      "FCI"}]], "Input",
  CellLabel->"In[1124]:=  (21:55:56 on 5/16/01)",
  CellTags->"OneLoopSimplify"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{
          FormBox[
            FormBox[
              TagBox[
                StyleBox["\<\"k\"\>",
                  FontSlant->"Italic"],
                (StyleForm[ #, FontSlant -> "Italic"]&)],
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
          FormBox["r",
            "TraditionalForm"]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"], "2"], "-", 
              SuperscriptBox["m", "2"]}], ")"}], ".", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"], "-", "p"}], ")"}], "2"]}]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1124]=  (21:55:56 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"OneLoopSimplify", "[", 
      RowBox[{"%", ",", "k"}], "]"}]], "Input",
  CellLabel->"In[1125]:=  (21:55:56 on 5/16/01)",
  CellTags->"OneLoopSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox["m", "2"], "+", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"]}], ")"}], " ", 
            RowBox[{
              FormBox["p",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox["r",
                "TraditionalForm"]}]}], 
          RowBox[{"2", " ", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    FormBox[
                      TagBox[
                        StyleBox["\<\"k\"\>",
                          FontSlant->"Italic"],
                        (StyleForm[ #, FontSlant -> "Italic"]&)],
                      "TraditionalForm"], "2"], "-", 
                  SuperscriptBox["m", "2"]}], ")"}], ".", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    FormBox[
                      TagBox[
                        StyleBox["\<\"k\"\>",
                          FontSlant->"Italic"],
                        (StyleForm[ #, FontSlant -> "Italic"]&)],
                      "TraditionalForm"], "-", "p"}], ")"}], "2"]}], " ", 
            SuperscriptBox[
              FormBox["p",
                "TraditionalForm"], "2"]}]], "-", 
        FractionBox[
          RowBox[{
            FormBox["p",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["r",
              "TraditionalForm"]}], 
          RowBox[{"2", " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  FormBox[
                    TagBox[
                      StyleBox["\<\"k\"\>",
                        FontSlant->"Italic"],
                      (StyleForm[ #, FontSlant -> "Italic"]&)],
                    "TraditionalForm"], "2"], "-", 
                SuperscriptBox["m", "2"]}], ")"}], " ", 
            SuperscriptBox[
              FormBox["p",
                "TraditionalForm"], "2"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1125]=  (21:55:56 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"OneLoopSimplify", "[", 
      RowBox[{
        RowBox[{"%", "/.", 
          RowBox[{"m", "\[Rule]", "0"}]}], ",", "k"}], "]"}]], "Input",
  CellLabel->"In[1126]:=  (21:55:56 on 5/16/01)",
  CellTags->"OneLoopSimplify"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{
          FormBox["p",
            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
          FormBox["r",
            "TraditionalForm"]}], 
        RowBox[{"2", " ", 
          RowBox[{
            SuperscriptBox[
              FormBox[
                TagBox[
                  StyleBox["\<\"k\"\>",
                    FontSlant->"Italic"],
                  (StyleForm[ #, FontSlant -> "Italic"]&)],
                "TraditionalForm"], "2"], ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  FormBox[
                    TagBox[
                      StyleBox["\<\"k\"\>",
                        FontSlant->"Italic"],
                      (StyleForm[ #, FontSlant -> "Italic"]&)],
                    "TraditionalForm"], "-", "p"}], ")"}], "2"]}]}]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1126]=  (21:55:57 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"FAD", "[", 
          RowBox[{"k", ",", "k", ",", " ", 
            RowBox[{"k", " ", "-", " ", 
              SubscriptBox["p", "1"]}], ",", " ", 
            RowBox[{"k", " ", "-", " ", 
              SubscriptBox["p", "2"]}]}], "]"}], " ", 
        RowBox[{"FVD", "[", 
          RowBox[{"k", ",", "\[Mu]"}], "]"}]}], "//", "FCI"}]], "Input",
  CellLabel->"In[1127]:=  (21:55:57 on 5/16/01)",
  CellTags->"OneLoopSimplify"],

Cell[BoxData[
    FormBox[
      FractionBox[
        SuperscriptBox[
          FormBox[
            FormBox[
              TagBox[
                StyleBox["\<\"k\"\>",
                  FontSlant->"Italic"],
                (StyleForm[ #, FontSlant -> "Italic"]&)],
              "TraditionalForm"],
            "TraditionalForm"], 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]], 
        RowBox[{
          SuperscriptBox[
            FormBox[
              TagBox[
                StyleBox["\<\"k\"\>",
                  FontSlant->"Italic"],
                (StyleForm[ #, FontSlant -> "Italic"]&)],
              "TraditionalForm"], "2"], ".", 
          SuperscriptBox[
            FormBox[
              TagBox[
                StyleBox["\<\"k\"\>",
                  FontSlant->"Italic"],
                (StyleForm[ #, FontSlant -> "Italic"]&)],
              "TraditionalForm"], "2"], ".", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"], "-", 
                SubscriptBox["p", "1"]}], ")"}], "2"], ".", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"], "-", 
                SubscriptBox["p", "2"]}], ")"}], "2"]}]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1127]=  (21:55:57 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"OneLoopSimplify", "[", " ", 
      RowBox[{"%", ",", "k"}], "]"}]], "Input",
  CellLabel->"In[1128]:=  (21:55:57 on 5/16/01)",
  CellTags->"OneLoopSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{
            RowBox[{
              SubsuperscriptBox["p", 
                FormBox["2",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SubsuperscriptBox["p", "1", "2"]}], "-", 
            RowBox[{
              SubsuperscriptBox["p", 
                FormBox["1",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox[
                  SubscriptBox["p", "1"],
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox[
                  SubscriptBox["p", "2"],
                  "TraditionalForm"]}]}]}], 
          RowBox[{"2", " ", 
            RowBox[{
              SuperscriptBox[
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"], "2"], ".", 
              SuperscriptBox[
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"], "2"], ".", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    FormBox[
                      TagBox[
                        StyleBox["\<\"k\"\>",
                          FontSlant->"Italic"],
                        (StyleForm[ #, FontSlant -> "Italic"]&)],
                      "TraditionalForm"], "-", 
                    SubscriptBox["p", "1"]}], ")"}], "2"]}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{
                        FormBox[
                          SubscriptBox["p", "1"],
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox[
                          SubscriptBox["p", "2"],
                          "TraditionalForm"]}],
                      "TraditionalForm"], ")"}], "2"], "-", 
                RowBox[{
                  SubsuperscriptBox["p", "1", "2"], " ", 
                  SubsuperscriptBox["p", "2", "2"]}]}], ")"}]}]], "+", 
        FractionBox[
          RowBox[{
            RowBox[{
              SubsuperscriptBox["p", 
                FormBox["2",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SubsuperscriptBox["p", "1", "2"], " ", 
              RowBox[{
                FormBox[
                  SubscriptBox["p", "1"],
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox[
                  SubscriptBox["p", "2"],
                  "TraditionalForm"]}]}], "+", 
            RowBox[{
              SubsuperscriptBox["p", 
                FormBox["1",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SubsuperscriptBox["p", "2", "2"], " ", 
              RowBox[{
                FormBox[
                  SubscriptBox["p", "1"],
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox[
                  SubscriptBox["p", "2"],
                  "TraditionalForm"]}]}], "-", 
            RowBox[{
              SubsuperscriptBox["p", 
                FormBox["1",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SubsuperscriptBox["p", "1", "2"], " ", 
              SubsuperscriptBox["p", "2", "2"]}], "-", 
            RowBox[{
              SubsuperscriptBox["p", 
                FormBox["2",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SubsuperscriptBox["p", "1", "2"], " ", 
              SubsuperscriptBox["p", "2", "2"]}]}], 
          RowBox[{"2", " ", 
            RowBox[{
              SuperscriptBox[
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"], "2"], ".", 
              SuperscriptBox[
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"], "2"], ".", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    FormBox[
                      TagBox[
                        StyleBox["\<\"k\"\>",
                          FontSlant->"Italic"],
                        (StyleForm[ #, FontSlant -> "Italic"]&)],
                      "TraditionalForm"], "-", 
                    SubscriptBox["p", "1"]}], ")"}], "2"], ".", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    FormBox[
                      TagBox[
                        StyleBox["\<\"k\"\>",
                          FontSlant->"Italic"],
                        (StyleForm[ #, FontSlant -> "Italic"]&)],
                      "TraditionalForm"], "-", 
                    SubscriptBox["p", "2"]}], ")"}], "2"]}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{
                        FormBox[
                          SubscriptBox["p", "1"],
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox[
                          SubscriptBox["p", "2"],
                          "TraditionalForm"]}],
                      "TraditionalForm"], ")"}], "2"], "-", 
                RowBox[{
                  SubsuperscriptBox["p", "1", "2"], " ", 
                  SubsuperscriptBox["p", "2", "2"]}]}], ")"}]}]], "-", 
        FractionBox[
          RowBox[{
            RowBox[{
              SubsuperscriptBox["p", 
                FormBox["2",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox[
                  SubscriptBox["p", "1"],
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox[
                  SubscriptBox["p", "2"],
                  "TraditionalForm"]}]}], "-", 
            RowBox[{
              SubsuperscriptBox["p", 
                FormBox["1",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SubsuperscriptBox["p", "2", "2"]}]}], 
          RowBox[{"2", " ", 
            RowBox[{
              SuperscriptBox[
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"], "2"], ".", 
              SuperscriptBox[
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"], "2"], ".", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    FormBox[
                      TagBox[
                        StyleBox["\<\"k\"\>",
                          FontSlant->"Italic"],
                        (StyleForm[ #, FontSlant -> "Italic"]&)],
                      "TraditionalForm"], "-", 
                    SubscriptBox["p", "2"]}], ")"}], "2"]}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{
                        FormBox[
                          SubscriptBox["p", "1"],
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox[
                          SubscriptBox["p", "2"],
                          "TraditionalForm"]}],
                      "TraditionalForm"], ")"}], "2"], "-", 
                RowBox[{
                  SubsuperscriptBox["p", "1", "2"], " ", 
                  SubsuperscriptBox["p", "2", "2"]}]}], ")"}]}]], "-", 
        FractionBox[
          RowBox[{
            RowBox[{
              SubsuperscriptBox["p", 
                FormBox["2",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SubsuperscriptBox["p", "1", "2"]}], "-", 
            RowBox[{
              SubsuperscriptBox["p", 
                FormBox["1",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox[
                  SubscriptBox["p", "1"],
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox[
                  SubscriptBox["p", "2"],
                  "TraditionalForm"]}]}], "-", 
            RowBox[{
              SubsuperscriptBox["p", 
                FormBox["2",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox[
                  SubscriptBox["p", "1"],
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox[
                  SubscriptBox["p", "2"],
                  "TraditionalForm"]}]}], "+", 
            RowBox[{
              SubsuperscriptBox["p", 
                FormBox["1",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SubsuperscriptBox["p", "2", "2"]}]}], 
          RowBox[{"2", " ", 
            RowBox[{
              SuperscriptBox[
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"], "2"], ".", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    FormBox[
                      TagBox[
                        StyleBox["\<\"k\"\>",
                          FontSlant->"Italic"],
                        (StyleForm[ #, FontSlant -> "Italic"]&)],
                      "TraditionalForm"], "-", 
                    SubscriptBox["p", "1"]}], ")"}], "2"], ".", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    FormBox[
                      TagBox[
                        StyleBox["\<\"k\"\>",
                          FontSlant->"Italic"],
                        (StyleForm[ #, FontSlant -> "Italic"]&)],
                      "TraditionalForm"], "-", 
                    SubscriptBox["p", "2"]}], ")"}], "2"]}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{
                        FormBox[
                          SubscriptBox["p", "1"],
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox[
                          SubscriptBox["p", "2"],
                          "TraditionalForm"]}],
                      "TraditionalForm"], ")"}], "2"], "-", 
                RowBox[{
                  SubsuperscriptBox["p", "1", "2"], " ", 
                  SubsuperscriptBox["p", "2", "2"]}]}], ")"}]}]]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1128]=  (21:55:58 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"FCE", "[", "%", "]"}], "/.", 
        RowBox[{
          RowBox[{"SPD", "[", 
            SubscriptBox["p", "1"], "]"}], "\[Rule]", "0"}]}], "//", 
      "FCI"}]], "Input",
  CellLabel->"In[1129]:=  (21:55:58 on 5/16/01)",
  CellTags->"OneLoopSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{
            SubsuperscriptBox["p", 
              FormBox["1",
                "TraditionalForm"], 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"]], " ", 
            SubsuperscriptBox["p", "2", "2"]}], 
          RowBox[{"2", " ", 
            RowBox[{
              SuperscriptBox[
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"], "2"], ".", 
              SuperscriptBox[
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"], "2"], ".", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    FormBox[
                      TagBox[
                        StyleBox["\<\"k\"\>",
                          FontSlant->"Italic"],
                        (StyleForm[ #, FontSlant -> "Italic"]&)],
                      "TraditionalForm"], "-", 
                    SubscriptBox["p", "1"]}], ")"}], "2"], ".", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    FormBox[
                      TagBox[
                        StyleBox["\<\"k\"\>",
                          FontSlant->"Italic"],
                        (StyleForm[ #, FontSlant -> "Italic"]&)],
                      "TraditionalForm"], "-", 
                    SubscriptBox["p", "2"]}], ")"}], "2"]}], " ", 
            RowBox[{
              FormBox[
                SubscriptBox["p", "1"],
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox[
                SubscriptBox["p", "2"],
                "TraditionalForm"]}]}]], "-", 
        FractionBox[
          SubsuperscriptBox["p", 
            FormBox["1",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], 
          RowBox[{"2", " ", 
            RowBox[{
              SuperscriptBox[
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"], "2"], ".", 
              SuperscriptBox[
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"], "2"], ".", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    FormBox[
                      TagBox[
                        StyleBox["\<\"k\"\>",
                          FontSlant->"Italic"],
                        (StyleForm[ #, FontSlant -> "Italic"]&)],
                      "TraditionalForm"], "-", 
                    SubscriptBox["p", "1"]}], ")"}], "2"]}], " ", 
            RowBox[{
              FormBox[
                SubscriptBox["p", "1"],
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox[
                SubscriptBox["p", "2"],
                "TraditionalForm"]}]}]], "-", 
        FractionBox[
          RowBox[{
            RowBox[{
              SubsuperscriptBox["p", 
                FormBox["2",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox[
                  SubscriptBox["p", "1"],
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox[
                  SubscriptBox["p", "2"],
                  "TraditionalForm"]}]}], "-", 
            RowBox[{
              SubsuperscriptBox["p", 
                FormBox["1",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SubsuperscriptBox["p", "2", "2"]}]}], 
          RowBox[{"2", " ", 
            RowBox[{
              SuperscriptBox[
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"], "2"], ".", 
              SuperscriptBox[
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"], "2"], ".", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    FormBox[
                      TagBox[
                        StyleBox["\<\"k\"\>",
                          FontSlant->"Italic"],
                        (StyleForm[ #, FontSlant -> "Italic"]&)],
                      "TraditionalForm"], "-", 
                    SubscriptBox["p", "2"]}], ")"}], "2"]}], " ", 
            SuperscriptBox[
              RowBox[{"(", 
                FormBox[
                  RowBox[{
                    FormBox[
                      SubscriptBox["p", "1"],
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox[
                      SubscriptBox["p", "2"],
                      "TraditionalForm"]}],
                  "TraditionalForm"], ")"}], "2"]}]], "-", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                SubsuperscriptBox["p", 
                  FormBox["1",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], " ", 
              RowBox[{
                FormBox[
                  SubscriptBox["p", "1"],
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox[
                  SubscriptBox["p", "2"],
                  "TraditionalForm"]}]}], "-", 
            RowBox[{
              SubsuperscriptBox["p", 
                FormBox["2",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox[
                  SubscriptBox["p", "1"],
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox[
                  SubscriptBox["p", "2"],
                  "TraditionalForm"]}]}], "+", 
            RowBox[{
              SubsuperscriptBox["p", 
                FormBox["1",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SubsuperscriptBox["p", "2", "2"]}]}], 
          RowBox[{"2", " ", 
            RowBox[{
              SuperscriptBox[
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"], "2"], ".", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    FormBox[
                      TagBox[
                        StyleBox["\<\"k\"\>",
                          FontSlant->"Italic"],
                        (StyleForm[ #, FontSlant -> "Italic"]&)],
                      "TraditionalForm"], "-", 
                    SubscriptBox["p", "1"]}], ")"}], "2"], ".", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    FormBox[
                      TagBox[
                        StyleBox["\<\"k\"\>",
                          FontSlant->"Italic"],
                        (StyleForm[ #, FontSlant -> "Italic"]&)],
                      "TraditionalForm"], "-", 
                    SubscriptBox["p", "2"]}], ")"}], "2"]}], " ", 
            SuperscriptBox[
              RowBox[{"(", 
                FormBox[
                  RowBox[{
                    FormBox[
                      SubscriptBox["p", "1"],
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox[
                      SubscriptBox["p", "2"],
                      "TraditionalForm"]}],
                  "TraditionalForm"], ")"}], "2"]}]]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1129]=  (21:55:58 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"OneLoopSimplify", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"FAD", "[", 
            RowBox[{
              RowBox[{"k", "-", 
                SubscriptBox["p", "1"]}], ",", 
              RowBox[{"k", "-", 
                SubscriptBox["p", "2"]}]}], "]"}], " ", 
          RowBox[{
            RowBox[{"SP", "[", 
              RowBox[{"k", ",", "l"}], "]"}], "^", "2"}]}], ",", "k"}], 
      "]"}]], "Input",
  CellLabel->"In[1130]:=  (21:55:58 on 5/16/01)",
  CellTags->"OneLoopSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"D", " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  FormBox[
                    RowBox[{
                      FormBox["l",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"]}],
                    "TraditionalForm"], ")"}], "2"]}], "+", 
            RowBox[{"2", " ", "D", " ", 
              RowBox[{
                FormBox["l",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox[
                  SubscriptBox["p", "2"],
                  "TraditionalForm"]}], " ", 
              RowBox[{
                FormBox["l",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox[
                  SubscriptBox["p", "1"],
                  "TraditionalForm"]}]}], "-", 
            RowBox[{"4", " ", 
              RowBox[{
                FormBox["l",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox[
                  SubscriptBox["p", "2"],
                  "TraditionalForm"]}], " ", 
              RowBox[{
                FormBox["l",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox[
                  SubscriptBox["p", "1"],
                  "TraditionalForm"]}]}], "+", 
            RowBox[{"D", " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  FormBox[
                    RowBox[{
                      FormBox["l",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"]}],
                    "TraditionalForm"], ")"}], "2"]}], "-", 
            RowBox[{
              SuperscriptBox[
                FormBox["l",
                  "TraditionalForm"], "2"], " ", 
              SubsuperscriptBox["p", "1", "2"]}], "+", 
            RowBox[{"2", " ", 
              SuperscriptBox[
                FormBox["l",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{
                FormBox[
                  SubscriptBox["p", "1"],
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox[
                  SubscriptBox["p", "2"],
                  "TraditionalForm"]}]}], "-", 
            RowBox[{
              SuperscriptBox[
                FormBox["l",
                  "TraditionalForm"], "2"], " ", 
              SubsuperscriptBox["p", "2", "2"]}]}], 
          RowBox[{"4", " ", 
            RowBox[{"(", 
              RowBox[{"1", "-", "D"}], ")"}], " ", 
            RowBox[{
              SuperscriptBox[
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"], "2"], ".", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    FormBox[
                      TagBox[
                        StyleBox["\<\"k\"\>",
                          FontSlant->"Italic"],
                        (StyleForm[ #, FontSlant -> "Italic"]&)],
                      "TraditionalForm"], "-", 
                    SubscriptBox["p", "1"], "+", 
                    SubscriptBox["p", "2"]}], ")"}], "2"]}]}]]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1130]=  (21:56:00 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["OPEDelta", "ObjectName",
  CellTags->"OPEDelta"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"OPEDelta"],

Cell["\<\
OPEDelta is a lightlike axial vector as used e.g. in the operator product \
expansion in QCD.\
\>", "Text",
  CellTags->"OPEDelta"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["Twist2QuarkOperator",
    ButtonData:>"Twist2QuarkOperator",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Twist2QuarkOperator"],
  "."
}], "Text",
  CellTags->"OPEDelta"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"OPEDelta"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FourVector", "[", 
      RowBox[{"OPEDelta", ",", "\[Mu]"}], "]"}]], "Input",
  CellLabel->"In[1131]:=  (21:56:00 on 5/16/01)",
  CellTags->"OPEDelta"],

Cell[BoxData[
    FormBox[
      SubscriptBox[
        FormBox["\[CapitalDelta]",
          "TraditionalForm"], "\[Mu]"], TraditionalForm]], "Output",
  CellLabel->"Out[1131]=  (21:56:00 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Contract", "[", 
      RowBox[{"%", " ", "%"}], "]"}]], "Input",
  CellLabel->"In[1132]:=  (21:56:00 on 5/16/01)",
  CellTags->"OPEDelta"],

Cell[BoxData[
    FormBox["0", TraditionalForm]], "Output",
  CellLabel->"Out[1132]=  (21:56:00 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SP", "[", 
      RowBox[{"OPEDelta", ",", "OPEDelta"}], "]"}]], "Input",
  CellLabel->"In[1133]:=  (21:56:00 on 5/16/01)",
  CellTags->"OPEDelta"],

Cell[BoxData[
    FormBox["0", TraditionalForm]], "Output",
  CellLabel->"Out[1133]=  (21:56:00 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["OPEi, OPEj, OPEk, OPEl, OPEm, OPEn, OPEo", "ObjectName",
  CellTags->"OPEi"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"OPEi"],

Cell["\<\
OPEi, etc. are variables with DataType PositiveInteger which are used in \
functions relating to the operator product expansion.\
\>", "Text",
  CellTags->"OPEi"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"OPEi"],

Cell[CellGroupData[{

Cell[BoxData["OPEi"], "Input",
  CellLabel->"In[1134]:=  (21:56:00 on 5/16/01)",
  CellTags->"OPEi"],

Cell[BoxData[
    FormBox["i", TraditionalForm]], "Output",
  CellLabel->"Out[1134]=  (21:56:00 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DataType", "[", 
      RowBox[{
      "OPEi", ",", " ", "OPEj", ",", "OPEk", ",", "OPEl", ",", " ", "OPEm", 
        ",", " ", "OPEn", ",", " ", "OPEo", ",", " ", "PositiveInteger"}], 
      "]"}]], "Input",
  CellLabel->"In[1135]:=  (21:56:00 on 5/16/01)",
  CellTags->"OPEi"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
        "True", ",", "True", ",", "True", ",", "True", ",", "True", ",", 
          "True", ",", "True"}], "}"}], TraditionalForm]], "Output",
  CellLabel->"Out[1135]=  (21:56:00 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"PowerSimplify", "[", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "^", 
            RowBox[{"(", 
              RowBox[{"2", "OPEi"}], ")"}]}], ",", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "^", 
            RowBox[{"(", 
              RowBox[{"2", "OPEj"}], ")"}]}], ",", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "^", 
            RowBox[{"(", 
              RowBox[{"2", "OPEk"}], ")"}]}], ",", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "^", 
            RowBox[{"(", 
              RowBox[{"2", "OPEl"}], ")"}]}], ",", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "^", 
            RowBox[{"(", 
              RowBox[{"2", "OPEm"}], ")"}]}], ",", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "^", 
            RowBox[{"(", 
              RowBox[{"2", "OPEn"}], ")"}]}], ",", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "^", 
            RowBox[{"(", 
              RowBox[{"2", "OPEo"}], ")"}]}]}], "}"}], "]"}]], "Input",
  CellLabel->"In[1136]:=  (21:56:00 on 5/16/01)",
  CellTags->"OPEi"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
        "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1"}], 
        "}"}], TraditionalForm]], "Output",
  CellLabel->"Out[1136]=  (21:56:00 on 5/16/01)"]
}, Closed]],

Cell["Re has been changed:", "Text",
  CellTags->"OPEi"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{"Re", "[", "OPEi", "]"}], ">", 
          RowBox[{"-", "3"}]}], ",", " ", 
        RowBox[{
          RowBox[{"Re", "[", "OPEi", "]"}], ">", 
          RowBox[{"-", "2"}]}], ",", " ", 
        RowBox[{
          RowBox[{"Re", "[", "OPEi", "]"}], ">", 
          RowBox[{"-", "1"}]}], ",", " ", " ", " ", 
        RowBox[{
          RowBox[{"Re", "[", "OPEi", "]"}], ">", "0"}], ",", " ", 
        RowBox[{
          RowBox[{"Re", "[", "OPEi", "]"}], ">", "1"}]}], "}"}]], "Input",
  CellLabel->"In[1137]:=  (21:56:00 on 5/16/01)",
  CellTags->"OPEi"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"True", ",", "True", ",", "True", ",", "True", ",", "True"}], 
        "}"}], TraditionalForm]], "Output",
  CellLabel->"Out[1137]=  (21:56:00 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{"Re", "[", 
            RowBox[{
              RowBox[{"-", "OPEi"}], " ", "+", " ", "OPEm"}], "]"}], " ", ">",
           " ", "0"}], ",", " ", 
        RowBox[{
          RowBox[{"Re", "[", 
            RowBox[{
              RowBox[{"-", "OPEi"}], " ", "+", " ", "OPEm"}], "]"}], " ", ">",
           " ", "1"}], ",", 
        RowBox[{
          RowBox[{"Re", "[", 
            RowBox[{
              RowBox[{"-", "OPEi"}], " ", "+", " ", "OPEm"}], "]"}], " ", ">",
           " ", "2"}]}], "}"}]], "Input",
  CellLabel->"In[1138]:=  (21:56:00 on 5/16/01)",
  CellTags->"OPEi"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"True", ",", "True", ",", "True"}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1138]=  (21:56:00 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{"Re", "[", "OPEm", "]"}], ">", 
          RowBox[{"-", "3"}]}], ",", " ", 
        RowBox[{
          RowBox[{"Re", "[", "OPEm", "]"}], ">", 
          RowBox[{"-", "2"}]}], ",", " ", 
        RowBox[{
          RowBox[{"Re", "[", "OPEm", "]"}], ">", 
          RowBox[{"-", "1"}]}], ",", " ", " ", " ", 
        RowBox[{
          RowBox[{"Re", "[", "OPEm", "]"}], ">", "0"}], ",", " ", 
        RowBox[{
          RowBox[{"Re", "[", "OPEm", "]"}], ">", "1"}]}], "}"}]], "Input",
  CellLabel->"In[1139]:=  (21:56:00 on 5/16/01)",
  CellTags->"OPEi"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"True", ",", "True", ",", "True", ",", "True", ",", "True"}], 
        "}"}], TraditionalForm]], "Output",
  CellLabel->"Out[1139]=  (21:56:00 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["OPESumExplicit", "ObjectName",
  CellTags->"OPESumExplicit"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"OPESumExplicit"],

Cell["OPESumExplicit[exp] calculates OPESum's.", "Text",
  CellTags->"OPESumExplicit"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["OPESum",
    ButtonData:>"OPESum",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"OPESum"],
  ", ",
  ButtonBox["OPESumSimplify",
    ButtonData:>"OPESumSimplify",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"OPESumSimplify"],
  "."
}], "Text",
  CellTags->"OPESumExplicit"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"OPESumExplicit"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t1", "=", 
      RowBox[{"OPESum", "[", 
        RowBox[{
          RowBox[{
            RowBox[{"A", "^", "i"}], 
            RowBox[{"B", "^", 
              RowBox[{"(", 
                RowBox[{"m", "-", "i", "-", "3"}], ")"}]}]}], ",", 
          RowBox[{"{", 
            RowBox[{"i", ",", "0", ",", 
              RowBox[{"m", "-", "3"}]}], "}"}]}], "]"}]}]], "Input",
  CellLabel->"In[1140]:=  (21:56:00 on 5/16/01)",
  CellTags->"OPESumExplicit"],

Cell[BoxData[
    FormBox[
      TagBox[
        RowBox[{
          UnderoverscriptBox["\[Sum]", 
            RowBox[{"i", "=", "0"}], 
            RowBox[{"m", "-", "3"}]], 
          RowBox[{
            SuperscriptBox["A", "i"], " ", 
            SuperscriptBox["B", 
              RowBox[{
                RowBox[{"-", "i"}], "+", "m", "-", "3"}]]}]}],
        HoldForm], TraditionalForm]], "Output",
  CellLabel->"Out[1140]=  (21:56:00 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"OPESumExplicit", "[", "t1", "]"}]], "Input",
  CellLabel->"In[1141]:=  (21:56:00 on 5/16/01)",
  CellTags->"OPESumExplicit"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          FormBox[
            SuperscriptBox["A", 
              RowBox[{"m", "-", "2"}]],
            "TraditionalForm"], 
          RowBox[{"A", "-", "B"}]], "-", 
        FractionBox[
          FormBox[
            SuperscriptBox["B", 
              RowBox[{"m", "-", "2"}]],
            "TraditionalForm"], 
          RowBox[{"A", "-", "B"}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1141]=  (21:56:01 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t2", " ", "=", " ", 
      RowBox[{"OPESum", "[", 
        RowBox[{
          RowBox[{
            RowBox[{"a", "^", "i"}], 
            RowBox[{"b", "^", 
              RowBox[{"(", 
                RowBox[{"j", "-", "i"}], ")"}]}], 
            RowBox[{"c", "^", 
              RowBox[{"(", 
                RowBox[{"m", "-", "j", "-", "4"}], ")"}]}]}], ",", 
          RowBox[{"{", 
            RowBox[{"i", ",", "0", ",", "j"}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{"j", ",", "0", ",", 
              RowBox[{"m", "-", "4"}]}], "}"}]}], "]"}]}]], "Input",
  CellLabel->"In[1142]:=  (21:56:01 on 5/16/01)",
  CellTags->"OPESumExplicit"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", 
                RowBox[{"j", "=", "0"}], 
                RowBox[{"m", "-", "4"}]], "\<\"\"\>"}],
            HoldForm],
          "TraditionalForm"], "\[NoBreak]", 
        FormBox[
          RowBox[{
            UnderoverscriptBox["\[Sum]", 
              RowBox[{"i", "=", "0"}], "j"], "\<\"\"\>"}],
          "TraditionalForm"], "\[NoBreak]", 
        FormBox[
          RowBox[{
            SuperscriptBox["a", "i"], " ", 
            SuperscriptBox["b", 
              RowBox[{"j", "-", "i"}]], " ", 
            SuperscriptBox["c", 
              RowBox[{
                RowBox[{"-", "j"}], "+", "m", "-", "4"}]]}],
          "TraditionalForm"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1142]=  (21:56:01 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"OPESumExplicit", "[", "t2", "]"}]], "Input",
  CellLabel->"In[1143]:=  (21:56:01 on 5/16/01)",
  CellTags->"OPESumExplicit"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          FractionBox[
            RowBox[{"c", " ", 
              FormBox[
                SuperscriptBox["a", 
                  RowBox[{"m", "-", "2"}]],
                "TraditionalForm"]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"a", "-", "b"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{"a", "-", "c"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{"b", "-", "c"}], ")"}]}]]}], "+", 
        FractionBox[
          RowBox[{"b", " ", 
            FormBox[
              SuperscriptBox["a", 
                RowBox[{"m", "-", "2"}]],
              "TraditionalForm"]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"a", "-", "b"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"a", "-", "c"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"b", "-", "c"}], ")"}]}]], "+", 
        FractionBox[
          RowBox[{"c", " ", 
            FormBox[
              SuperscriptBox["b", 
                RowBox[{"m", "-", "2"}]],
              "TraditionalForm"]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"a", "-", "b"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"a", "-", "c"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"b", "-", "c"}], ")"}]}]], "-", 
        FractionBox[
          RowBox[{"a", " ", 
            FormBox[
              SuperscriptBox["b", 
                RowBox[{"m", "-", "2"}]],
              "TraditionalForm"]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"a", "-", "b"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"a", "-", "c"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"b", "-", "c"}], ")"}]}]], "-", 
        FractionBox[
          RowBox[{"b", " ", 
            FormBox[
              SuperscriptBox["c", 
                RowBox[{"m", "-", "2"}]],
              "TraditionalForm"]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"a", "-", "b"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"a", "-", "c"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"b", "-", "c"}], ")"}]}]], "+", 
        FractionBox[
          RowBox[{"a", " ", 
            FormBox[
              SuperscriptBox["c", 
                RowBox[{"m", "-", "2"}]],
              "TraditionalForm"]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"a", "-", "b"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"a", "-", "c"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"b", "-", "c"}], ")"}]}]]}], TraditionalForm]], "Output",\

  CellLabel->"Out[1143]=  (21:56:01 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      RowBox[{"Clear", "[", 
        RowBox[{"t1", ",", "t2"}], "]"}], ";"}]], "Input",
  CellLabel->"In[1144]:=  (21:56:01 on 5/16/01)",
  CellTags->"OPESumExplicit"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["OPESum", "ObjectName",
  CellTags->"OPESum"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"OPESum"],

Cell["\<\
OPESum[exp, {i, 0, m}] denotes a symbolic sum.The syntax is the same as for \
Sum.\
\>", "Text",
  CellTags->"OPESum"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["OPESumExplicit",
    ButtonData:>"OPESumExplicit",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"OPESumExplicit"],
  ", ",
  ButtonBox["OPESumSimplify",
    ButtonData:>"OPESumSimplify",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"OPESumSimplify"],
  "."
}], "Text",
  CellTags->"OPESum"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"OPESum"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t1", "=", 
      RowBox[{"OPESum", "[", 
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{"SO", "[", "p", "]"}], "^", "OPEi"}], 
            RowBox[{
              RowBox[{"SO", "[", "k", "]"}], "^", 
              RowBox[{"(", 
                RowBox[{"OPEm", "-", "OPEi", "-", "3"}], ")"}]}]}], ",", 
          RowBox[{"{", 
            RowBox[{"OPEi", ",", "0", ",", 
              RowBox[{"OPEm", "-", "3"}]}], "}"}]}], "]"}]}]], "Input",
  CellLabel->"In[1145]:=  (21:56:01 on 5/16/01)",
  CellTags->"OPESum"],

Cell[BoxData[
    FormBox[
      TagBox[
        RowBox[{
          UnderoverscriptBox["\[Sum]", 
            RowBox[{"i", "=", "0"}], 
            RowBox[{"m", "-", "3"}]], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  FormBox["\<\"\[CapitalDelta]\"\>",
                    "TraditionalForm"], 
                  FormBox["\<\"\[CenterDot]\"\>",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox[
                      TagBox[
                        StyleBox["\<\"k\"\>",
                          FontSlant->"Italic"],
                        (StyleForm[ #, FontSlant -> "Italic"]&)],
                      "TraditionalForm"],
                    "TraditionalForm"]}], ")"}], 
              RowBox[{
                RowBox[{"-", "i"}], "+", "m", "-", "3"}]], " ", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  FormBox["\<\"\[CapitalDelta]\"\>",
                    "TraditionalForm"], 
                  FormBox["\<\"\[CenterDot]\"\>",
                    "TraditionalForm"], 
                  FormBox["p",
                    "TraditionalForm"]}], ")"}], "i"]}]}],
        HoldForm], TraditionalForm]], "Output",
  CellLabel->"Out[1145]=  (21:56:01 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"OPESumExplicit", "[", "t1", "]"}]], "Input",
  CellLabel->"In[1146]:=  (21:56:01 on 5/16/01)",
  CellTags->"OPESum"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          FormBox[
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  FormBox["\<\"\[CapitalDelta]\"\>",
                    "TraditionalForm"], 
                  FormBox["\<\"\[CenterDot]\"\>",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox[
                      TagBox[
                        StyleBox["\<\"k\"\>",
                          FontSlant->"Italic"],
                        (StyleForm[ #, FontSlant -> "Italic"]&)],
                      "TraditionalForm"],
                    "TraditionalForm"]}], ")"}], 
              RowBox[{"m", "-", "2"}]],
            "TraditionalForm"], 
          RowBox[{
            RowBox[{
              FormBox["\<\"\[CapitalDelta]\"\>",
                "TraditionalForm"], 
              FormBox["\<\"\[CenterDot]\"\>",
                "TraditionalForm"], 
              FormBox[
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"],
                "TraditionalForm"]}], "-", 
            RowBox[{
              FormBox["\<\"\[CapitalDelta]\"\>",
                "TraditionalForm"], 
              FormBox["\<\"\[CenterDot]\"\>",
                "TraditionalForm"], 
              FormBox["p",
                "TraditionalForm"]}]}]], "-", 
        FractionBox[
          FormBox[
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  FormBox["\<\"\[CapitalDelta]\"\>",
                    "TraditionalForm"], 
                  FormBox["\<\"\[CenterDot]\"\>",
                    "TraditionalForm"], 
                  FormBox["p",
                    "TraditionalForm"]}], ")"}], 
              RowBox[{"m", "-", "2"}]],
            "TraditionalForm"], 
          RowBox[{
            RowBox[{
              FormBox["\<\"\[CapitalDelta]\"\>",
                "TraditionalForm"], 
              FormBox["\<\"\[CenterDot]\"\>",
                "TraditionalForm"], 
              FormBox[
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"],
                "TraditionalForm"]}], "-", 
            RowBox[{
              FormBox["\<\"\[CapitalDelta]\"\>",
                "TraditionalForm"], 
              FormBox["\<\"\[CenterDot]\"\>",
                "TraditionalForm"], 
              FormBox["p",
                "TraditionalForm"]}]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1146]=  (21:56:01 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t2", " ", "=", " ", 
      RowBox[{"OPESum", "[", 
        RowBox[{
          RowBox[{
            RowBox[{"a", "^", "i"}], 
            RowBox[{"b", "^", 
              RowBox[{"(", 
                RowBox[{"j", "-", "i"}], ")"}]}], 
            RowBox[{"c", "^", 
              RowBox[{"(", 
                RowBox[{"m", "-", "j", "-", "4"}], ")"}]}]}], ",", 
          RowBox[{"{", 
            RowBox[{"i", ",", "0", ",", "j"}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{"j", ",", "0", ",", 
              RowBox[{"m", "-", "4"}]}], "}"}]}], "]"}]}]], "Input",
  CellLabel->"In[1147]:=  (21:56:02 on 5/16/01)",
  CellTags->"OPESum"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", 
                RowBox[{"j", "=", "0"}], 
                RowBox[{"m", "-", "4"}]], "\<\"\"\>"}],
            HoldForm],
          "TraditionalForm"], "\[NoBreak]", 
        FormBox[
          RowBox[{
            UnderoverscriptBox["\[Sum]", 
              RowBox[{"i", "=", "0"}], "j"], "\<\"\"\>"}],
          "TraditionalForm"], "\[NoBreak]", 
        FormBox[
          RowBox[{
            SuperscriptBox["a", "i"], " ", 
            SuperscriptBox["b", 
              RowBox[{"j", "-", "i"}]], " ", 
            SuperscriptBox["c", 
              RowBox[{
                RowBox[{"-", "j"}], "+", "m", "-", "4"}]]}],
          "TraditionalForm"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1147]=  (21:56:02 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"OPESumExplicit", "[", "t2", "]"}]], "Input",
  CellLabel->"In[1148]:=  (21:56:02 on 5/16/01)",
  CellTags->"OPESum"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          FractionBox[
            RowBox[{"c", " ", 
              FormBox[
                SuperscriptBox["a", 
                  RowBox[{"m", "-", "2"}]],
                "TraditionalForm"]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"a", "-", "b"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{"a", "-", "c"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{"b", "-", "c"}], ")"}]}]]}], "+", 
        FractionBox[
          RowBox[{"b", " ", 
            FormBox[
              SuperscriptBox["a", 
                RowBox[{"m", "-", "2"}]],
              "TraditionalForm"]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"a", "-", "b"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"a", "-", "c"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"b", "-", "c"}], ")"}]}]], "+", 
        FractionBox[
          RowBox[{"c", " ", 
            FormBox[
              SuperscriptBox["b", 
                RowBox[{"m", "-", "2"}]],
              "TraditionalForm"]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"a", "-", "b"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"a", "-", "c"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"b", "-", "c"}], ")"}]}]], "-", 
        FractionBox[
          RowBox[{"a", " ", 
            FormBox[
              SuperscriptBox["b", 
                RowBox[{"m", "-", "2"}]],
              "TraditionalForm"]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"a", "-", "b"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"a", "-", "c"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"b", "-", "c"}], ")"}]}]], "-", 
        FractionBox[
          RowBox[{"b", " ", 
            FormBox[
              SuperscriptBox["c", 
                RowBox[{"m", "-", "2"}]],
              "TraditionalForm"]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"a", "-", "b"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"a", "-", "c"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"b", "-", "c"}], ")"}]}]], "+", 
        FractionBox[
          RowBox[{"a", " ", 
            FormBox[
              SuperscriptBox["c", 
                RowBox[{"m", "-", "2"}]],
              "TraditionalForm"]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"a", "-", "b"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"a", "-", "c"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"b", "-", "c"}], ")"}]}]]}], TraditionalForm]], "Output",\

  CellLabel->"Out[1148]=  (21:56:02 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{" ", 
      RowBox[{"Clear", "[", 
        RowBox[{"t1", ",", "t2"}], "]"}]}]], "Input",
  CellLabel->"In[1149]:=  (21:56:02 on 5/16/01)",
  CellTags->"OPESum"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["OPESumSimplify", "ObjectName",
  CellTags->"OPESumSimplify"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"OPESumSimplify"],

Cell["OPESumSimplify[exp] simplifies OPESum's in exp.", "Text",
  CellTags->"OPESumSimplify"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["OPESum",
    ButtonData:>"OPESum",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"OPESum"],
  ", ",
  ButtonBox["OPESumExplicit",
    ButtonData:>"OPESumExplicit",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"OPESumExplicit"],
  "."
}], "Text",
  CellTags->"OPESumSimplify"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"OPESumSimplify"],

Cell[CellGroupData[{

Cell["\<\
OPESum[(-SOD[p])^(OPEi+1) SOD[p-q]^(OPEm-OPEi-2),{OPEi,0,OPEm}]\
\>", "Input",
  CellLabel->"In[1150]:=  (21:56:02 on 5/16/01)",
  CellTags->"OPESumSimplify"],

Cell[BoxData[
    FormBox[
      TagBox[
        RowBox[{
          UnderoverscriptBox["\[Sum]", 
            RowBox[{"i", "=", "0"}], "m"], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"-", 
                  RowBox[{"(", 
                    RowBox[{
                      FormBox["\<\"\[CapitalDelta]\"\>",
                        "TraditionalForm"], 
                      FormBox["\<\"\[CenterDot]\"\>",
                        "TraditionalForm"], 
                      FormBox["p",
                        "TraditionalForm"]}], ")"}]}], ")"}], 
              RowBox[{"i", "+", "1"}]], " ", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  FormBox["\<\"\[CapitalDelta]\"\>",
                    "TraditionalForm"], 
                  FormBox["\<\"\[CenterDot]\"\>",
                    "TraditionalForm"], 
                  FormBox["\<\"(\"\>",
                    "TraditionalForm"], 
                  FormBox[
                    RowBox[{"p", "-", "q"}],
                    "TraditionalForm"], 
                  FormBox["\<\")\"\>",
                    "TraditionalForm"]}], ")"}], 
              RowBox[{
                RowBox[{"-", "i"}], "+", "m", "-", "2"}]]}]}],
        HoldForm], TraditionalForm]], "Output",
  CellLabel->"Out[1150]=  (21:56:02 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell["OPESumSimplify[%]", "Input",
  CellLabel->"In[1151]:=  (21:56:02 on 5/16/01)",
  CellTags->"OPESumSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", 
                  RowBox[{"i", "=", "0"}], "m"], 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{"-", "1"}], ")"}], "i"], " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["p",
                          "TraditionalForm"]}], ")"}], "i"], " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", "(", "\[NoBreak]", 
                        FormBox[
                          RowBox[{"p", "-", "q"}],
                          "TraditionalForm"], "\[NoBreak]", ")"}], ")"}], 
                    RowBox[{
                      RowBox[{"-", "i"}], "+", "m", "-", "2"}]]}]}],
              HoldForm],
            "TraditionalForm"]}], " ", 
        RowBox[{
          FormBox["\[CapitalDelta]",
            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
          FormBox["p",
            "TraditionalForm"]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1151]=  (21:56:02 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"OPESumSimplify", "[", 
      RowBox[{
        RowBox[{"OPESum", "[", 
          RowBox[{"{", 
            RowBox[{"OPEi", ",", "0", ",", "OPEm"}], "}"}], "]"}], " ", 
        RowBox[{"a", "^", "OPEi"}]}], "]"}]], "Input",
  CellLabel->"In[1152]:=  (21:56:02 on 5/16/01)",
  CellTags->"OPESumSimplify"],

Cell[BoxData[
    FormBox[
      TagBox[
        RowBox[{
          UnderoverscriptBox["\[Sum]", 
            RowBox[{"i", "=", "0"}], "m"], 
          FormBox[
            SuperscriptBox["a", "i"],
            "TraditionalForm"]}],
        HoldForm], TraditionalForm]], "Output",
  CellLabel->"Out[1152]=  (21:56:02 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"OPESumSimplify", "[", 
      RowBox[{
        RowBox[{"OPESum", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"j", ",", "0", ",", "i"}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"i", ",", "0", ",", "m"}], "}"}]}], "]"}], " ", 
        RowBox[{"a", "^", 
          RowBox[{"(", 
            RowBox[{"j", "-", "i"}], ")"}]}], " ", 
        RowBox[{"b", "^", "i"}]}], "]"}]], "Input",
  CellLabel->"In[1153]:=  (21:56:02 on 5/16/01)",
  CellTags->"OPESumSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", 
                RowBox[{"i", "=", "0"}], "m"], "\<\"\"\>"}],
            HoldForm],
          "TraditionalForm"], "\[NoBreak]", 
        FormBox[
          RowBox[{
            UnderoverscriptBox["\[Sum]", 
              RowBox[{"j", "=", "0"}], "i"], "\<\"\"\>"}],
          "TraditionalForm"], "\[NoBreak]", 
        FormBox[
          RowBox[{
            SuperscriptBox["a", 
              RowBox[{"j", "-", "i"}]], " ", 
            SuperscriptBox["b", "i"]}],
          "TraditionalForm"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1153]=  (21:56:02 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "StandardForm"}]], "Input",
  CellLabel->"In[1154]:=  (21:56:02 on 5/16/01)",
  CellTags->"OPESumSimplify"],

Cell[BoxData[
    RowBox[{"OPESum", "[", 
      RowBox[{
        RowBox[{
          SuperscriptBox["a", 
            RowBox[{
              RowBox[{"-", "i"}], "+", "j"}]], " ", 
          SuperscriptBox["b", "i"]}], ",", 
        RowBox[{"{", 
          RowBox[{"i", ",", "0", ",", "m"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"j", ",", "0", ",", "i"}], "}"}]}], "]"}]], "Output",
  CellLabel->"Out[1154]//StandardForm=  (21:56:02 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Pair", "ObjectName",
  CellTags->"Pair"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"Pair"],

Cell[TextData[{
  "Pair[x, y] is the head of a special pairing used in the internal \
representation: x and y may have heads LorentzIndex or Momentum. If both x \
and y have head LorentzIndex, the metric tensor is understood. If x and y \
have head Momentum, a scalar product is meant. If one of x and y has head \
LorentzIndex and the other Momentum, a Lorentz vector ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox["p", "\[Mu]"], TraditionalForm]]],
  " is understood."
}], "Text",
  CellTags->"Pair"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["FourVector",
    ButtonData:>"FourVector",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FourVector"],
  ", ",
  ButtonBox["FV",
    ButtonData:>"FV",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FV"],
  ", ",
  ButtonBox["FVD",
    ButtonData:>"FVD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FVD"],
  ", ",
  ButtonBox["MetricTensor",
    ButtonData:>"MetricTensor",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"MetricTensor"],
  ", ",
  ButtonBox["MT",
    ButtonData:>"MT",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"MT"],
  ", ",
  ButtonBox["MTD",
    ButtonData:>"MTD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"MTD"],
  ", ",
  ButtonBox["ScalarProduct",
    ButtonData:>"ScalarProduct",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"ScalarProduct"],
  ", ",
  ButtonBox["SP",
    ButtonData:>"SP",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SP"],
  ", ",
  ButtonBox["SPD",
    ButtonData:>"SPD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SPD"],
  "."
}], "Text",
  CellTags->"Pair"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"Pair"],

Cell["This represents a four-dimensional metric tensor.", "Text",
  CellTags->"Pair"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Pair", "[", 
      RowBox[{
        RowBox[{"LorentzIndex", "[", "\[Alpha]", "]"}], ",", 
        RowBox[{"LorentzIndex", "[", "\[Beta]", "]"}]}], "]"}]], "Input",
  CellLabel->"In[1155]:=  (21:56:02 on 5/16/01)",
  CellTags->"Pair"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["g", 
        RowBox[{"\[Alpha]", "\[NoBreak]", "\[Beta]"}]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1155]=  (21:56:02 on 5/16/01)"]
}, Closed]],

Cell["This is a D-dimensional metric tensor.", "Text",
  CellTags->"Pair"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Pair", "[", 
      RowBox[{
        RowBox[{"LorentzIndex", "[", 
          RowBox[{"\[Alpha]", ",", "D"}], "]"}], ",", 
        RowBox[{"LorentzIndex", "[", 
          RowBox[{"\[Beta]", ",", "D"}], "]"}]}], "]"}]], "Input",
  CellLabel->"In[1156]:=  (21:56:02 on 5/16/01)",
  CellTags->"Pair"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["g", 
        RowBox[{
          FormBox[
            FormBox["\[Alpha]",
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", 
          FormBox[
            FormBox["\[Beta]",
              "TraditionalForm"],
            "TraditionalForm"]}]], TraditionalForm]], "Output",
  CellLabel->"Out[1156]=  (21:56:02 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Pair", "[", 
      RowBox[{
        RowBox[{"LorentzIndex", "[", "\[Alpha]", "]"}], ",", 
        RowBox[{"Momentum", "[", "p", "]"}]}], "]"}]], "Input",
  CellLabel->"In[1157]:=  (21:56:02 on 5/16/01)",
  CellTags->"Pair"],

Cell[BoxData[
    FormBox[
      SuperscriptBox[
        FormBox["p",
          "TraditionalForm"], 
        FormBox[
          FormBox["\[Alpha]",
            "TraditionalForm"],
          "TraditionalForm"]], TraditionalForm]], "Output",
  CellLabel->"Out[1157]=  (21:56:02 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Pair", "[", 
      RowBox[{
        RowBox[{"Momentum", "[", "q", "]"}], ",", 
        RowBox[{"Momentum", "[", "p", "]"}]}], "]"}]], "Input",
  CellLabel->"In[1158]:=  (21:56:02 on 5/16/01)",
  CellTags->"Pair"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox["p",
          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
        FormBox["q",
          "TraditionalForm"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1158]=  (21:56:02 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Pair", "[", 
      RowBox[{
        RowBox[{"Momentum", "[", "p", "]"}], ",", 
        RowBox[{"Momentum", "[", "p", "]"}]}], "]"}]], "Input",
  CellLabel->"In[1159]:=  (21:56:02 on 5/16/01)",
  CellTags->"Pair"],

Cell[BoxData[
    FormBox[
      SuperscriptBox[
        FormBox["p",
          "TraditionalForm"], "2"], TraditionalForm]], "Output",
  CellLabel->"Out[1159]=  (21:56:02 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Pair", "[", 
      RowBox[{
        RowBox[{"Momentum", "[", 
          RowBox[{"p", "-", "q"}], "]"}], ",", 
        RowBox[{"Momentum", "[", "p", "]"}]}], "]"}]], "Input",
  CellLabel->"In[1160]:=  (21:56:02 on 5/16/01)",
  CellTags->"Pair"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox["p",
          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "(",
         "\[NoBreak]", 
        FormBox[
          RowBox[{"p", "-", "q"}],
          "TraditionalForm"], "\[NoBreak]", ")"}], TraditionalForm]], "Output",\

  CellLabel->"Out[1160]=  (21:56:02 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Pair", "[", 
        RowBox[{
          RowBox[{"Momentum", "[", "p", "]"}], ",", 
          RowBox[{"Momentum", "[", "p", "]"}]}], "]"}], "^", "2"}]], "Input",
  CellLabel->"In[1161]:=  (21:56:02 on 5/16/01)",
  CellTags->"Pair"],

Cell[BoxData[
    FormBox[
      SuperscriptBox[
        FormBox["p",
          "TraditionalForm"], "4"], TraditionalForm]], "Output",
  CellLabel->"Out[1161]=  (21:56:02 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Pair", "[", 
        RowBox[{
          RowBox[{"Momentum", "[", "p", "]"}], ",", 
          RowBox[{"Momentum", "[", "p", "]"}]}], "]"}], "^", "3"}]], "Input",
  CellLabel->"In[1162]:=  (21:56:02 on 5/16/01)",
  CellTags->"Pair"],

Cell[BoxData[
    FormBox[
      SuperscriptBox[
        FormBox["p",
          "TraditionalForm"], "6"], TraditionalForm]], "Output",
  CellLabel->"Out[1162]=  (21:56:02 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Pair", "[", 
        RowBox[{
          RowBox[{"LorentzIndex", "[", 
            RowBox[{"\[Alpha]", ",", 
              RowBox[{"n", "-", "4"}]}], "]"}], ",", 
          RowBox[{"LorentzIndex", "[", "\[Beta]", "]"}]}], "]"}], "//", 
      "Contract"}]], "Input",
  CellLabel->"In[1163]:=  (21:56:03 on 5/16/01)",
  CellTags->"Pair"],

Cell[BoxData[
    FormBox["0", TraditionalForm]], "Output",
  CellLabel->"Out[1163]=  (21:56:03 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ExpandScalarProduct", "[", 
      RowBox[{"Pair", "[", 
        RowBox[{
          RowBox[{"Momentum", "[", 
            RowBox[{"p", "-", "q"}], "]"}], ",", 
          RowBox[{"Momentum", "[", "p", "]"}]}], "]"}], "]"}]], "Input",
  CellLabel->"In[1164]:=  (21:56:03 on 5/16/01)",
  CellTags->"Pair"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox[
          FormBox["p",
            "TraditionalForm"], "2"], "-", 
        RowBox[{
          FormBox["p",
            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
          FormBox["q",
            "TraditionalForm"]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1164]=  (21:56:03 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Pair", "[", 
        RowBox[{
          RowBox[{"Momentum", "[", 
            RowBox[{"-", "q"}], "]"}], ",", 
          RowBox[{"Momentum", "[", "p", "]"}]}], "]"}], " ", "+", " ", 
      RowBox[{"Pair", "[", 
        RowBox[{
          RowBox[{"Momentum", "[", "q", "]"}], ",", 
          RowBox[{"Momentum", "[", "p", "]"}]}], "]"}]}]], "Input",
  CellLabel->"In[1165]:=  (21:56:03 on 5/16/01)",
  CellTags->"Pair"],

Cell[BoxData[
    FormBox["0", TraditionalForm]], "Output",
  CellLabel->"Out[1165]=  (21:56:03 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["PartialD", "ObjectName",
  CellTags->"PartialD"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"PartialD"],

Cell[TextData[{
  "PartialD[",
  Cell[BoxData[
      FormBox["\[Mu]", TraditionalForm]]],
  "] denotes the four-dimensional ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox["\[PartialD]", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], "."}], TraditionalForm]]],
  " PartialD is used to denote derivative fields. PartialD[LorentzIndex[",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Mu]", ",", "D"}], TraditionalForm]]],
  "]] denotes the ",
  Cell[BoxData[
      FormBox["D", TraditionalForm]]],
  "-dimensional ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox["\[PartialD]", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], "."}], TraditionalForm]]]
}], "Text",
  ZeroWidthTimes->True,
  CellTags->"PartialD"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["ExpandPartialD",
    ButtonData:>"ExpandPartialD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"ExpandPartialD"],
  ", ",
  ButtonBox["LeftRightPartialD",
    ButtonData:>"LeftRightPartialD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"LeftRightPartialD"],
  ", ",
  ButtonBox["RightPartialD",
    ButtonData:>"RightPartialD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"RightPartialD"],
  "."
}], "Text",
  CellTags->"PartialD"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData["Examples"], "Subsubsection",
  CellTags->"PartialD"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"QuantumField", "[", 
        RowBox[{"A", ",", 
          RowBox[{"{", "\[Mu]", "}"}]}], "]"}], ".", 
      RowBox[{"LeftPartialD", "[", "\[Nu]", "]"}]}]], "Input",
  CellLabel->"In[1166]:=  (21:56:03 on 5/16/01)",
  CellTags->"PartialD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["A", "\[Mu]"], ".", 
        SubscriptBox[
          OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
          FormBox[
            FormBox["\[Nu]",
              "TraditionalForm"],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1166]=  (21:56:03 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ExpandPartialD", "[", "%", "]"}]], "Input",
  CellLabel->"In[1167]:=  (21:56:03 on 5/16/01)",
  CellTags->"PartialD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox[
          OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
          FormBox[
            FormBox["\[Nu]",
              "TraditionalForm"],
            "TraditionalForm"]], " ", 
        SubscriptBox["A", "\[Mu]"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1167]=  (21:56:03 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StandardForm", "[", "%", "]"}]], "Input",
  CellLabel->"In[1168]:=  (21:56:03 on 5/16/01)",
  CellTags->"PartialD"],

Cell[BoxData[
    RowBox[{
      RowBox[{"LeftPartialD", "[", 
        RowBox[{"LorentzIndex", "[", "\[Nu]", "]"}], "]"}], " ", 
      RowBox[{"QuantumField", "[", 
        RowBox[{"A", ",", 
          RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}]}], "]"}]}]], "Output",
  CellLabel->"Out[1168]//StandardForm=  (21:56:03 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["PaVe", "ObjectName",
  CellTags->"PaVe"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"PaVe"],

Cell["\<\
 PaVe[ i,j,... {p10,p12,...},{m1^2, mw^2, ...} ] denotes the invariant (and \
scalar) Passarino-Veltman integrals, i.e. the coefficient functions of the \
tensor integral decomposition. Joining plist and mlist gives the same \
conventions as for A0, B0, C0, D0. Automatic simlifications are performed for \
the coefficient functions of two-point integrals and for the scalar \
integrals.\
\>", "Text",
  CellTags->"PaVe"],

Cell[TextData[{
  "For a more detailed description see the manual (no changes from there \
basically): ",
  ButtonBox["http://www.mertig.com/oldfc",
    ButtonData:>{
      URL[ "http://www.mertig.com/oldfc"], None},
    ButtonStyle->"Hyperlink"]
}], "Text",
  CellTags->"PaVe"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["PaVeReduce",
    ButtonData:>"PaVeReduce",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"PaVeReduce"],
  "."
}], "Text",
  CellTags->"PaVe"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"PaVe"],

Cell["Some of the PaVe's reduce to special cases.", "Text",
  CellTags->"PaVe"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"PaVe", "[", 
      RowBox[{"0", ",", 
        RowBox[{"{", 
          RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f"}], 
          "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"m1", ",", "m2", ",", "m3", ",", "m4"}], "}"}]}], 
      "]"}]], "Input",
  CellLabel->"In[1169]:=  (21:56:03 on 5/16/01)",
  CellTags->"PaVe"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          SubscriptBox["\<\"D\"\>", "\<\"0\"\>"],
          "TraditionalForm"], "\[NoBreak]", "(", "\[NoBreak]", "a", 
        "\[NoBreak]", ",", "\[NoBreak]", "b", "\[NoBreak]", ",", "\[NoBreak]",
         "c", "\[NoBreak]", ",", "\[NoBreak]", "d", "\[NoBreak]", ",", 
        "\[NoBreak]", "e", "\[NoBreak]", ",", "\[NoBreak]", "f", "\[NoBreak]",
         ",", "\[NoBreak]", "m1", "\[NoBreak]", ",", "\[NoBreak]", "m2", 
        "\[NoBreak]", ",", "\[NoBreak]", "m3", "\[NoBreak]", ",", 
        "\[NoBreak]", "m4", "\[NoBreak]", ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[1169]=  (21:56:03 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"PaVe", "[", 
      RowBox[{"0", ",", "0", ",", 
        RowBox[{"{", "pp", "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"m", "^", "2"}], ",", 
            RowBox[{"M", "^", "2"}]}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[1170]:=  (21:56:03 on 5/16/01)",
  CellTags->"PaVe"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{
            SubscriptBox["B", "0"], "(", "pp", ",", 
            SuperscriptBox["m", "2"], ",", 
            SuperscriptBox["M", "2"], ")"}], " ", 
          SuperscriptBox["m", "2"]}], "+", 
        RowBox[{
          FractionBox["1", "18"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"3", " ", 
                SuperscriptBox["m", "2"]}], "+", 
              RowBox[{"3", " ", 
                SuperscriptBox["M", "2"]}], "-", "pp"}], ")"}]}], "+", 
        RowBox[{
          FractionBox["1", "6"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{
                  SubscriptBox["B", "0"], "(", "0", ",", 
                  SuperscriptBox["M", "2"], ",", 
                  SuperscriptBox["M", "2"], ")"}], " ", 
                SuperscriptBox["M", "2"]}], "+", 
              SuperscriptBox["M", "2"], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox["m", "2"], "-", 
                    SuperscriptBox["M", "2"], "+", "pp"}], ")"}], " ", 
                RowBox[{"(", 
                  RowBox[{
                    FractionBox[
                      RowBox[{
                        RowBox[{"(", 
                          RowBox[{
                            SuperscriptBox["M", "2"], "-", 
                            SuperscriptBox["m", "2"]}], ")"}], " ", 
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              SubscriptBox["B", "0"], "(", "pp", ",", 
                              SuperscriptBox["m", "2"], ",", 
                              SuperscriptBox["M", "2"], ")"}], "-", 
                            RowBox[{
                              SubscriptBox["B", "0"], "(", "0", ",", 
                              SuperscriptBox["m", "2"], ",", 
                              SuperscriptBox["M", "2"], ")"}]}], ")"}]}], 
                      RowBox[{"2", " ", "pp"}]], "-", 
                    RowBox[{
                      FractionBox["1", "2"], " ", 
                      RowBox[{
                        SubscriptBox["B", "0"], "(", "pp", ",", 
                        SuperscriptBox["m", "2"], ",", 
                        SuperscriptBox["M", "2"], ")"}]}]}], ")"}]}]}], 
            ")"}]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1170]=  (21:56:03 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["PaVeOrder", "ObjectName",
  CellTags->"PaVeOrder"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"PaVeOrder"],

Cell["\<\
PaVeOrder[expr] orders the arguments of all D0 in expr in a standard way. \
PaVeOrder[expr, PaVeOrderList -> { {..., s, u, ...}, {... m1^2, m2^2, ...}, \
...}] orders the arguments of all D0 in expr according to the specified \
ordering lists. The lists may contain only a subsequence of the D0-variables.\
\
\>", "Text",
  CellTags->"PaVeOrder"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["PaVeReduce",
    ButtonData:>"PaVeReduce",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"PaVeReduce"],
  "."
}], "Text",
  CellTags->"PaVeOrder"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"PaVeOrder"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"PaVeOrder", "[", 
      RowBox[{
        RowBox[{"D0", "[", 
          RowBox[{
          "me2", ",", "me2", ",", "mw2", ",", "mw2", ",", "t", ",", "s", ",", 
            "me2", ",", "0", ",", "me2", ",", "0"}], "]"}], ",", 
        RowBox[{"PaVeOrderList", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{"me2", ",", "me2", ",", "0", ",", "0"}], "}"}]}]}], 
      "]"}]], "Input",
  CellLabel->"In[1171]:=  (21:56:03 on 5/16/01)",
  CellTags->"PaVeOrder"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          SubscriptBox["\<\"D\"\>", "\<\"0\"\>"],
          "TraditionalForm"], "\[NoBreak]", "(", "\[NoBreak]", "me2", 
        "\[NoBreak]", ",", "\[NoBreak]", "s", "\[NoBreak]", ",", "\[NoBreak]",
         "mw2", "\[NoBreak]", ",", "\[NoBreak]", "t", "\[NoBreak]", ",", 
        "\[NoBreak]", "mw2", "\[NoBreak]", ",", "\[NoBreak]", "me2", 
        "\[NoBreak]", ",", "\[NoBreak]", "me2", "\[NoBreak]", ",", 
        "\[NoBreak]", 
        FormBox["0",
          "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
        FormBox["0",
          "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", "me2", 
        "\[NoBreak]", ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[1171]=  (21:56:03 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"PaVeOrder", "[", 
      RowBox[{
        RowBox[{"D0", "[", 
          RowBox[{
          "me2", ",", "me2", ",", "mw2", ",", "mw2", ",", "t", ",", "s", ",", 
            "me2", ",", "0", ",", "me2", ",", "0"}], "]"}], ",", 
        RowBox[{"PaVeOrderList", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{"me2", ",", "me2", ",", "0", ",", "0"}], "}"}]}]}], 
      "]"}]], "Input",
  CellLabel->"In[1172]:=  (21:56:03 on 5/16/01)",
  CellTags->"PaVeOrder"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          SubscriptBox["\<\"D\"\>", "\<\"0\"\>"],
          "TraditionalForm"], "\[NoBreak]", "(", "\[NoBreak]", "me2", 
        "\[NoBreak]", ",", "\[NoBreak]", "s", "\[NoBreak]", ",", "\[NoBreak]",
         "mw2", "\[NoBreak]", ",", "\[NoBreak]", "t", "\[NoBreak]", ",", 
        "\[NoBreak]", "mw2", "\[NoBreak]", ",", "\[NoBreak]", "me2", 
        "\[NoBreak]", ",", "\[NoBreak]", "me2", "\[NoBreak]", ",", 
        "\[NoBreak]", 
        FormBox["0",
          "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
        FormBox["0",
          "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", "me2", 
        "\[NoBreak]", ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[1172]=  (21:56:03 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"PaVeOrder", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"D0", "[", 
            RowBox[{
            "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "m12",
               ",", "m22", ",", "m32", ",", "m42"}], "]"}], "+", 
          RowBox[{"D0", "[", 
            RowBox[{
            "me2", ",", "me2", ",", "mw2", ",", "mw2", ",", "t", ",", "s", 
              ",", "me2", ",", "0", ",", "me2", ",", "0"}], "]"}]}], ",", 
        RowBox[{"PaVeOrderList", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"{", 
                RowBox[{"me2", ",", "me2", ",", "0", ",", "0"}], "}"}], ",", 
              RowBox[{"{", 
                RowBox[{"f", ",", "e"}], "}"}]}], "}"}]}]}], "]"}]], "Input",
  CellLabel->"In[1173]:=  (21:56:03 on 5/16/01)",
  CellTags->"PaVeOrder"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FormBox[
            SubscriptBox["\<\"D\"\>", "\<\"0\"\>"],
            "TraditionalForm"], "\[NoBreak]", "(", "\[NoBreak]", "a", 
          "\[NoBreak]", ",", "\[NoBreak]", "d", "\[NoBreak]", ",", 
          "\[NoBreak]", "c", "\[NoBreak]", ",", "\[NoBreak]", "b", 
          "\[NoBreak]", ",", "\[NoBreak]", "f", "\[NoBreak]", ",", 
          "\[NoBreak]", "e", "\[NoBreak]", ",", "\[NoBreak]", "m22", 
          "\[NoBreak]", ",", "\[NoBreak]", "m12", "\[NoBreak]", ",", 
          "\[NoBreak]", "m42", "\[NoBreak]", ",", "\[NoBreak]", "m32", 
          "\[NoBreak]", ")"}], "+", 
        RowBox[{
          FormBox[
            SubscriptBox["\<\"D\"\>", "\<\"0\"\>"],
            "TraditionalForm"], "\[NoBreak]", "(", "\[NoBreak]", "me2", 
          "\[NoBreak]", ",", "\[NoBreak]", "s", "\[NoBreak]", ",", 
          "\[NoBreak]", "mw2", "\[NoBreak]", ",", "\[NoBreak]", "t", 
          "\[NoBreak]", ",", "\[NoBreak]", "mw2", "\[NoBreak]", ",", 
          "\[NoBreak]", "me2", "\[NoBreak]", ",", "\[NoBreak]", "me2", 
          "\[NoBreak]", ",", "\[NoBreak]", 
          FormBox["0",
            "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
          FormBox["0",
            "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", "me2", 
          "\[NoBreak]", ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1173]=  (21:56:03 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["PaVeReduce", "ObjectName",
  CellTags->"PaVeReduce"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"PaVeReduce"],

Cell["\<\
PaVeReduce[expr] reduces all Passarino-Veltman integrals (i.e. all PaVe's) in \
expr down to scalar A0, B0, C0 and D0.\
\>", "Text",
  CellTags->"PaVeReduce"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "PaVeReduce", "]"}]], "Input",
  CellLabel->"In[1174]:=  (21:56:03 on 5/16/01)",
  CellTags->"PaVeReduce"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"Dimension", "\[Rule]", "True"}], ",", 
          RowBox[{"IsolateNames", "\[Rule]", "False"}], ",", 
          RowBox[{"Mandelstam", "\[Rule]", 
            RowBox[{"{", "}"}]}], ",", 
          RowBox[{"PaVeOrderList", "\[Rule]", 
            RowBox[{"{", "}"}]}], ",", 
          RowBox[{"WriteOutPaVe", "\[Rule]", "False"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1174]=  (21:56:03 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"?", "WriteOutPaVe"}]], "Input",
  CellLabel->"In[1175]:=  (21:56:03 on 5/16/01)",
  CellTags->"PaVeReduce"],

Cell[BoxData[
    FormBox["\<\"WriteOutPaVe is an option for PaVeReduce and OneLoopSum. If \
set to a string, the results of all Passarino-Veltman PaVe's are stored in \
files with names generated from this string and the arguments of PaVe.\"\>", 
      TraditionalForm]], "Print"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["FRH",
    ButtonData:>"FRH",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FRH"],
  ", ",
  ButtonBox["PaVeOrder",
    ButtonData:>"PaVeOrder",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"PaVeOrder"],
  "."
}], "Text",
  CellTags->"PaVeReduce"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"PaVeReduce"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"PaVeReduce", "[", 
      RowBox[{
        RowBox[{"PaVe", "[", 
          RowBox[{"1", ",", "2", ",", 
            RowBox[{"{", 
              RowBox[{"s", ",", 
                RowBox[{"m", "^", "2"}], ",", 
                RowBox[{"m", "^", "2"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{"m", "^", "2"}], ",", 
                RowBox[{"m", "^", "2"}], ",", 
                RowBox[{"M", "^", "2"}]}], "}"}]}], "]"}], ",", 
        RowBox[{"IsolateHead", "\[Rule]", "L"}]}], "]"}]], "Input",
  CellLabel->"In[1176]:=  (21:56:03 on 5/16/01)",
  CellTags->"PaVeReduce"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"8", " ", 
                  SuperscriptBox["m", "2"]}], "-", 
                RowBox[{"3", " ", 
                  SuperscriptBox["M", "2"]}], "-", 
                RowBox[{"2", " ", "s"}]}], ")"}], " ", 
            RowBox[{
              FormBox[
                SubscriptBox["\<\"C\"\>", "\<\"0\"\>"],
                "TraditionalForm"], "\[NoBreak]", "(", "\[NoBreak]", 
              FormBox[
                SuperscriptBox["m", "2"],
                "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
              FormBox[
                SuperscriptBox["m", "2"],
                "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", "s", 
              "\[NoBreak]", ",", "\[NoBreak]", 
              FormBox[
                SuperscriptBox["m", "2"],
                "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
              FormBox[
                SuperscriptBox["M", "2"],
                "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
              FormBox[
                SuperscriptBox["m", "2"],
                "TraditionalForm"], "\[NoBreak]", ")"}], " ", 
            SuperscriptBox["M", "2"]}], 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                RowBox[{"4", " ", 
                  SuperscriptBox["m", "2"]}], "-", "s"}], ")"}], "2"]], "+", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox["m", "2"], "-", 
                SuperscriptBox["M", "2"]}], ")"}], " ", 
            RowBox[{
              SubscriptBox["B", "0"], "(", "0", ",", 
              SuperscriptBox["m", "2"], ",", 
              SuperscriptBox["M", "2"], ")"}]}], 
          RowBox[{"2", " ", 
            SuperscriptBox["m", "2"], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"4", " ", 
                  SuperscriptBox["m", "2"]}], "-", "s"}], ")"}]}]], "-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"8", " ", 
                  SuperscriptBox["m", "4"]}], "-", 
                RowBox[{"10", " ", 
                  SuperscriptBox["M", "2"], " ", 
                  SuperscriptBox["m", "2"]}], "-", 
                RowBox[{"2", " ", "s", " ", 
                  SuperscriptBox["m", "2"]}], "+", 
                RowBox[{
                  SuperscriptBox["M", "2"], " ", "s"}]}], ")"}], " ", 
            RowBox[{
              SubscriptBox["B", "0"], "(", 
              SuperscriptBox["m", "2"], ",", 
              SuperscriptBox["m", "2"], ",", 
              SuperscriptBox["M", "2"], ")"}]}], 
          RowBox[{"2", " ", 
            SuperscriptBox["m", "2"], " ", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"4", " ", 
                    SuperscriptBox["m", "2"]}], "-", "s"}], ")"}], "2"]}]], 
        "+", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"4", " ", 
                  SuperscriptBox["m", "2"]}], "-", 
                RowBox[{"6", " ", 
                  SuperscriptBox["M", "2"]}], "-", "s"}], ")"}], " ", 
            RowBox[{
              SubscriptBox["B", "0"], "(", "s", ",", 
              SuperscriptBox["m", "2"], ",", 
              SuperscriptBox["m", "2"], ")"}]}], 
          RowBox[{"2", " ", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"4", " ", 
                    SuperscriptBox["m", "2"]}], "-", "s"}], ")"}], "2"]}]], 
        "+", 
        FractionBox["1", 
          RowBox[{"2", " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"4", " ", 
                  SuperscriptBox["m", "2"]}], "-", "s"}], ")"}]}]]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1176]=  (21:56:03 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"L", "[", "10", "]"}]], "Input",
  CellLabel->"In[1177]:=  (21:56:04 on 5/16/01)",
  CellTags->"PaVeReduce"],

Cell[BoxData[
    FormBox[
      RowBox[{"L", "(", "10", ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[1177]=  (21:56:04 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FRH", "[", "%", "]"}]], "Input",
  CellLabel->"In[1178]:=  (21:56:04 on 5/16/01)",
  CellTags->"PaVeReduce"],

Cell[BoxData[
    FormBox[
      RowBox[{"L", "(", "10", ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[1178]=  (21:56:04 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"PaVeReduce", "[", 
      RowBox[{
        RowBox[{"PaVe", "[", 
          RowBox[{"2", ",", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{"SmallVariable", "[", "me2", "]"}], ",", "mw2", ",", 
                "t"}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{"SmallVariable", "[", "me2", "]"}], ",", "0", ",", 
                "mw2"}], "}"}]}], "]"}], ",", 
        RowBox[{"WriteOutPaVe", "\[Rule]", "\"\<p\>\""}]}], "]"}]], "Input",
  CellLabel->"In[1179]:=  (21:56:04 on 5/16/01)",
  CellTags->"PaVeReduce"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{
            SubscriptBox["B", "0"], "(", "0", ",", "mw2", ",", "mw2", ")"}], 
          RowBox[{"mw2", "-", "t"}]], "-", 
        FractionBox[
          RowBox[{
            SubscriptBox["B", "0"], "(", "t", ",", "mw2", ",", "me2", ")"}], 
          RowBox[{"mw2", "-", "t"}]], "+", 
        FractionBox["2", 
          RowBox[{"mw2", "-", "t"}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1179]=  (21:56:04 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"TableForm", "[", 
      RowBox[{"ReadList", "[", 
        RowBox[{
          RowBox[{
            RowBox[{"If", "[", 
              RowBox[{
                RowBox[{"$OperatingSystem", "===", "\"\<MacOS\>\""}], ",", 
                "\"\<:\>\"", ",", "\"\<\>\""}], "]"}], "<>", 
            "\"\<pPaVe2Csmame2mw2tCsmame20mw2.s\>\""}], ",", "String"}], 
        "]"}], "]"}]], "Input",
  CellLabel->"In[1180]:=  (21:56:04 on 5/16/01)",
  CellTags->"PaVeReduce"],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {"\<\"( 2/(mw2 - t) + B0[0, mw2, mw2]/(mw2 - t) - B0[t, mw2, \
SmallVariable[me2]]/\"\>"},
            {"\<\"  (mw2 - t)\"\>"},
            {"\<\"  ) \"\>"}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        TableForm[ {
          "( 2/(mw2 - t) + B0[0, mw2, mw2]/(mw2 - t) - B0[t, mw2, \
SmallVariable[me2]]/", "  (mw2 - t)", "  ) "}]], TraditionalForm]], "Output",
  CellLabel->"Out[1180]//TableForm=  (21:56:04 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      RowBox[{"DeleteFile", "/@", 
        RowBox[{
        "FileNames", "[", "\"\<pPaVe2Csmame2mw2tCsmame20mw2.s\>\"", "]"}]}], 
      ";"}]], "Input",
  CellLabel->"In[1181]:=  (21:56:04 on 5/16/01)",
  CellTags->"PaVeReduce"],

Cell[BoxData[
    RowBox[{
      RowBox[{"se", "=", 
        RowBox[{"SmallVariable", "[", "ME2", "]"}]}], ";"}]], "Input",
  CellLabel->"In[1182]:=  (21:56:04 on 5/16/01)",
  CellTags->"PaVeReduce"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"d122", "=", 
      RowBox[{"PaVeReduce", "[", 
        RowBox[{
          RowBox[{"PaVe", "[", 
            RowBox[{"1", ",", "2", ",", "2", ",", 
              RowBox[{"{", 
                RowBox[{
                "se", ",", "MW2", ",", "MW2", ",", "se", ",", "S", ",", "T"}],
                 "}"}], ",", 
              RowBox[{"{", 
                RowBox[{"0", ",", "se", ",", "0", ",", "se"}], "}"}]}], "]"}],
           ",", 
          RowBox[{"Mandelstam", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{"S", ",", "T", ",", "U", ",", 
                RowBox[{"2", " ", "MW2"}]}], "}"}]}], ",", 
          RowBox[{"IsolateHead", "\[Rule]", "F"}]}], "]"}]}]], "Input",
  CellLabel->"In[1183]:=  (21:56:04 on 5/16/01)",
  CellTags->"PaVeReduce"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"MW2", "-", "S"}], ")"}], " ", 
            SuperscriptBox["T", "2"], " ", 
            RowBox[{
              FormBox[
                SubscriptBox["\<\"D\"\>", "\<\"0\"\>"],
                "TraditionalForm"], "\[NoBreak]", "(", "\[NoBreak]", "MW2", 
              "\[NoBreak]", ",", "\[NoBreak]", "MW2", "\[NoBreak]", ",", 
              "\[NoBreak]", 
              FormBox["ME2",
                "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
              FormBox["ME2",
                "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", "T", 
              "\[NoBreak]", ",", "\[NoBreak]", "S", "\[NoBreak]", ",", 
              "\[NoBreak]", 
              FormBox["ME2",
                "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
              FormBox["0",
                "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
              FormBox["ME2",
                "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
              FormBox["0",
                "TraditionalForm"], "\[NoBreak]", ")"}], " ", 
            SuperscriptBox["S", "3"]}], 
          RowBox[{"2", " ", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox["MW2", "2"], "-", 
                  RowBox[{"S", " ", "U"}]}], ")"}], "3"]}]], "+", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"MW2", "-", "S"}], ")"}], "2"], " ", "T", " ", 
            RowBox[{
              FormBox[
                SubscriptBox["\<\"C\"\>", "\<\"0\"\>"],
                "TraditionalForm"], "\[NoBreak]", "(", "\[NoBreak]", "MW2", 
              "\[NoBreak]", ",", "\[NoBreak]", "S", "\[NoBreak]", ",", 
              "\[NoBreak]", 
              FormBox["ME2",
                "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
              FormBox["ME2",
                "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
              FormBox["0",
                "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
              FormBox["0",
                "TraditionalForm"], "\[NoBreak]", ")"}], " ", 
            SuperscriptBox["S", "2"]}], 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox["MW2", "2"], "-", 
                RowBox[{"S", " ", "U"}]}], ")"}], "3"]], "-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"MW2", "-", "S"}], ")"}], " ", 
            SuperscriptBox["T", "2"], " ", 
            RowBox[{
              FormBox[
                SubscriptBox["\<\"C\"\>", "\<\"0\"\>"],
                "TraditionalForm"], "\[NoBreak]", "(", "\[NoBreak]", "T", 
              "\[NoBreak]", ",", "\[NoBreak]", 
              FormBox["ME2",
                "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
              FormBox["ME2",
                "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
              FormBox["ME2",
                "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
              FormBox["ME2",
                "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
              FormBox["0",
                "TraditionalForm"], "\[NoBreak]", ")"}], " ", 
            SuperscriptBox["S", "2"]}], 
          RowBox[{"2", " ", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox["MW2", "2"], "-", 
                  RowBox[{"S", " ", "U"}]}], ")"}], "3"]}]], "+", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox["MW2", "2"], "-", 
                RowBox[{"4", " ", "S", " ", "MW2"}], "+", 
                RowBox[{"2", " ", 
                  SuperscriptBox["S", "2"]}], "+", 
                RowBox[{"S", " ", "U"}]}], ")"}], " ", 
            RowBox[{
              SubscriptBox["B", "0"], "(", "S", ",", "0", ",", "0", ")"}], 
            " ", "S"}], 
          RowBox[{"2", " ", 
            RowBox[{"(", 
              RowBox[{"MW2", "-", "S"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox["MW2", "2"], "-", 
                  RowBox[{"S", " ", "U"}]}], ")"}], "2"]}]], "-", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"4", " ", 
                    SuperscriptBox["MW2", "5"]}], "-", 
                  RowBox[{"5", " ", "S", " ", 
                    SuperscriptBox["MW2", "4"]}], "-", 
                  RowBox[{"U", " ", 
                    SuperscriptBox["MW2", "4"]}], "-", 
                  RowBox[{"16", " ", 
                    SuperscriptBox["S", "2"], " ", 
                    SuperscriptBox["MW2", "3"]}], "+", 
                  RowBox[{"4", " ", 
                    SuperscriptBox["S", "3"], " ", 
                    SuperscriptBox["MW2", "2"]}], "+", 
                  RowBox[{"4", " ", "S", " ", 
                    SuperscriptBox["U", "2"], " ", 
                    SuperscriptBox["MW2", "2"]}], "-", 
                  RowBox[{"4", " ", 
                    SuperscriptBox["S", "2"], " ", "U", " ", 
                    SuperscriptBox["MW2", "2"]}], "+", 
                  RowBox[{"4", " ", 
                    SuperscriptBox["S", "4"], " ", "MW2"}], "+", 
                  RowBox[{"8", " ", 
                    SuperscriptBox["S", "3"], " ", "U", " ", "MW2"}], "+", 
                  RowBox[{
                    SuperscriptBox["S", "2"], " ", 
                    SuperscriptBox["U", "3"]}], "+", 
                  RowBox[{
                    SuperscriptBox["S", "3"], " ", 
                    SuperscriptBox["U", "2"]}]}], ")"}], " ", 
              RowBox[{
                SubscriptBox["B", "0"], "(", "MW2", ",", "0", ",", "ME2", 
                ")"}]}], ")"}], "/", 
          RowBox[{"(", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                RowBox[{"MW2", "-", "S"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"4", " ", "MW2"}], "-", "T"}], ")"}], "2"], " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox["MW2", "2"], "-", 
                    RowBox[{"S", " ", "U"}]}], ")"}], "2"]}], ")"}]}], "+", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"MW2", "+", "S"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"4", " ", 
                  SuperscriptBox["MW2", "3"]}], "-", 
                RowBox[{"9", " ", "S", " ", 
                  SuperscriptBox["MW2", "2"]}], "-", 
                RowBox[{"U", " ", 
                  SuperscriptBox["MW2", "2"]}], "-", 
                RowBox[{"4", " ", "S", " ", "U", " ", "MW2"}], "+", 
                RowBox[{"2", " ", 
                  SuperscriptBox["S", "3"]}], "+", 
                RowBox[{"3", " ", "S", " ", 
                  SuperscriptBox["U", "2"]}], "+", 
                RowBox[{"5", " ", 
                  SuperscriptBox["S", "2"], " ", "U"}]}], ")"}], " ", 
            RowBox[{
              SubscriptBox["B", "0"], "(", "T", ",", "ME2", ",", "ME2", 
              ")"}]}], 
          RowBox[{"2", " ", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"4", " ", "MW2"}], "-", "T"}], ")"}], "2"], " ", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox["MW2", "2"], "-", 
                  RowBox[{"S", " ", "U"}]}], ")"}], "2"]}]], "-", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"MW2", "+", "S"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"2", " ", 
                    SuperscriptBox["MW2", "6"]}], "-", 
                  RowBox[{"8", " ", "S", " ", 
                    SuperscriptBox["MW2", "5"]}], "-", 
                  RowBox[{"2", " ", "T", " ", 
                    SuperscriptBox["MW2", "5"]}], "+", 
                  RowBox[{"12", " ", 
                    SuperscriptBox["S", "2"], " ", 
                    SuperscriptBox["MW2", "4"]}], "+", 
                  RowBox[{"20", " ", "S", " ", "T", " ", 
                    SuperscriptBox["MW2", "4"]}], "-", 
                  RowBox[{"8", " ", 
                    SuperscriptBox["S", "3"], " ", 
                    SuperscriptBox["MW2", "3"]}], "-", 
                  RowBox[{"6", " ", "S", " ", 
                    SuperscriptBox["T", "2"], " ", 
                    SuperscriptBox["MW2", "3"]}], "-", 
                  RowBox[{"36", " ", 
                    SuperscriptBox["S", "2"], " ", "T", " ", 
                    SuperscriptBox["MW2", "3"]}], "+", 
                  RowBox[{"2", " ", 
                    SuperscriptBox["S", "4"], " ", 
                    SuperscriptBox["MW2", "2"]}], "+", 
                  RowBox[{"6", " ", 
                    SuperscriptBox["S", "2"], " ", 
                    SuperscriptBox["T", "2"], " ", 
                    SuperscriptBox["MW2", "2"]}], "+", 
                  RowBox[{"20", " ", 
                    SuperscriptBox["S", "3"], " ", "T", " ", 
                    SuperscriptBox["MW2", "2"]}], "+", 
                  RowBox[{"4", " ", 
                    SuperscriptBox["S", "2"], " ", 
                    SuperscriptBox["T", "3"], " ", "MW2"}], "-", 
                  RowBox[{"6", " ", 
                    SuperscriptBox["S", "3"], " ", 
                    SuperscriptBox["T", "2"], " ", "MW2"}], "-", 
                  RowBox[{"2", " ", 
                    SuperscriptBox["S", "4"], " ", "T", " ", "MW2"}], "-", 
                  RowBox[{
                    SuperscriptBox["S", "2"], " ", 
                    SuperscriptBox["T", "4"]}]}], ")"}], " ", 
              RowBox[{
                FormBox[
                  SubscriptBox["\<\"C\"\>", "\<\"0\"\>"],
                  "TraditionalForm"], "\[NoBreak]", "(", "\[NoBreak]", "MW2", 
                "\[NoBreak]", ",", "\[NoBreak]", "MW2", "\[NoBreak]", ",", 
                "\[NoBreak]", "T", "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox["ME2",
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox["0",
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox["ME2",
                  "TraditionalForm"], "\[NoBreak]", ")"}]}], ")"}], "/", 
          RowBox[{"(", 
            RowBox[{"2", " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"4", " ", "MW2"}], "-", "T"}], ")"}], "2"], " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox["MW2", "2"], "-", 
                    RowBox[{"S", " ", "U"}]}], ")"}], "3"]}], ")"}]}], "-", 
        FractionBox[
          RowBox[{"MW2", "+", "S"}], 
          RowBox[{"2", " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"4", " ", "MW2"}], "-", "T"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox["MW2", "2"], "-", 
                RowBox[{"S", " ", "U"}]}], ")"}]}]]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1183]=  (21:56:06 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      RowBox[{"Write2", "[", 
        RowBox[{"\"\<fctd122.for\>\"", ",", 
          RowBox[{"d122res", "==", "d122"}], ",", 
          RowBox[{"FormatType", "\[Rule]", "FortranForm"}]}], "]"}], 
      ";"}]], "Input",
  CellLabel->"In[1184]:=  (21:56:06 on 5/16/01)",
  CellTags->"PaVeReduce"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"TableForm", "[", 
      RowBox[{"ReadList", "[", 
        RowBox[{
          RowBox[{
            RowBox[{"If", "[", 
              RowBox[{
                RowBox[{"$OperatingSystem", "===", "\"\<MacOS\>\""}], ",", 
                "\"\<:\>\"", ",", "\"\<\>\""}], "]"}], "<>", 
            "\"\<fctd122.for\>\""}], ",", "String"}], "]"}], "]"}]], "Input",
  CellLabel->"In[1185]:=  (21:56:06 on 5/16/01)",
  CellTags->"PaVeReduce"],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {"\<\"        d122res = -(MW2 + S)/(2D0*(4*MW2 - T)*(MW2**2 - \
S*U)) - \"\>"},
            {"\<\"     &  ((4*MW2**5 - 5*MW2**4*S - 16*MW2**3*S**2 + \"\>"},
            {"\<\"     &       4*MW2**2*S**3 + 4*MW2*S**4 - MW2**4*U - \
\"\>"},
            {"\<\"     &       4*MW2**2*S**2*U + 8*MW2*S**3*U + \"\>"},
            {"\<\"     &       4*MW2**2*S*U**2 + S**3*U**2 + \
S**2*U**3)*\"\>"},
            {"\<\"     &     B0(MW2,ME2,Null))/\"\>"},
            {"\<\"     &   (2D0*(MW2 - S)*(4*MW2 - T)**2*(MW2**2 - S*U)**2) + \
\"\>"},
            {"\<\"     &  (S*(MW2**2 - 4*MW2*S + 2*S**2 + \
S*U)*B0(S,Null,Null))/\"\>"},
            {"\<\"     &   (2D0*(MW2 - S)*(MW2**2 - S*U)**2) + \"\>"},
            {"\<\"     &  ((MW2 + S)*(4*MW2**3 - 9*MW2**2*S + 2*S**3 - \
\"\>"},
            {"\<\"     &       MW2**2*U - 4*MW2*S*U + 5*S**2*U + 3*S*U**2)*\"\
\>"},
            {"\<\"     &     B0(T,ME2,ME2))/\"\>"},
            {"\<\"     &   (2D0*(4*MW2 - T)**2*(MW2**2 - S*U)**2) - \"\>"},
            {"\<\"     &  ((MW2 + S)*(2*MW2**6 - 8*MW2**5*S + 12*MW2**4*S**2 \
- \"\>"},
            {"\<\"     &       8*MW2**3*S**3 + 2*MW2**2*S**4 - 2*MW2**5*T + \
\"\>"},
            {"\<\"     &       20*MW2**4*S*T - 36*MW2**3*S**2*T + \"\>"},
            {"\<\"     &       20*MW2**2*S**3*T - 2*MW2*S**4*T - \"\>"},
            {"\<\"     &       6*MW2**3*S*T**2 + 6*MW2**2*S**2*T**2 - \"\>"},
            {"\<\"     &       6*MW2*S**3*T**2 + 4*MW2*S**2*T**3 - \
S**2*T**4)*\"\>"},
            {"\<\"     &     C0(MW2,MW2,T,ME2,Null,ME2))/\"\>"},
            {"\<\"     &   (2D0*(4*MW2 - T)**2*(MW2**2 - S*U)**3) + \"\>"},
            {"\<\"     &  ((MW2 - \
S)**2*S**2*T*C0(MW2,S,ME2,ME2,Null,Null))/\"\>"},
            {"\<\"     &   (MW2**2 - S*U)**3 - \"\>"},
            {"\<\"     &  ((MW2 - S)*S**2*T**2*C0(T,ME2,ME2,ME2,ME2,Null))/\"\
\>"},
            {"\<\"     &   (2D0*(MW2**2 - S*U)**3) + \"\>"},
            {"\<\"     &  ((MW2 - S)*S**3*T**2*\"\>"},
            {"\<\"     &     \
D0(MW2,MW2,ME2,ME2,T,S,ME2,Null,ME2,Null))/\"\>"},
            {"\<\"     &   (2D0*(MW2**2 - S*U)**3)\"\>"}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        TableForm[ {
          "        d122res = -(MW2 + S)/(2D0*(4*MW2 - T)*(MW2**2 - S*U)) - ", 
          "     &  ((4*MW2**5 - 5*MW2**4*S - 16*MW2**3*S**2 + ", 
          "     &       4*MW2**2*S**3 + 4*MW2*S**4 - MW2**4*U - ", 
          "     &       4*MW2**2*S**2*U + 8*MW2*S**3*U + ", 
          "     &       4*MW2**2*S*U**2 + S**3*U**2 + S**2*U**3)*", 
          "     &     B0(MW2,ME2,Null))/", 
          "     &   (2D0*(MW2 - S)*(4*MW2 - T)**2*(MW2**2 - S*U)**2) + ", 
          "     &  (S*(MW2**2 - 4*MW2*S + 2*S**2 + S*U)*B0(S,Null,Null))/", 
          "     &   (2D0*(MW2 - S)*(MW2**2 - S*U)**2) + ", 
          "     &  ((MW2 + S)*(4*MW2**3 - 9*MW2**2*S + 2*S**3 - ", 
          "     &       MW2**2*U - 4*MW2*S*U + 5*S**2*U + 3*S*U**2)*", 
          "     &     B0(T,ME2,ME2))/", 
          "     &   (2D0*(4*MW2 - T)**2*(MW2**2 - S*U)**2) - ", 
          "     &  ((MW2 + S)*(2*MW2**6 - 8*MW2**5*S + 12*MW2**4*S**2 - ", 
          "     &       8*MW2**3*S**3 + 2*MW2**2*S**4 - 2*MW2**5*T + ", 
          "     &       20*MW2**4*S*T - 36*MW2**3*S**2*T + ", 
          "     &       20*MW2**2*S**3*T - 2*MW2*S**4*T - ", 
          "     &       6*MW2**3*S*T**2 + 6*MW2**2*S**2*T**2 - ", 
          "     &       6*MW2*S**3*T**2 + 4*MW2*S**2*T**3 - S**2*T**4)*", 
          "     &     C0(MW2,MW2,T,ME2,Null,ME2))/", 
          "     &   (2D0*(4*MW2 - T)**2*(MW2**2 - S*U)**3) + ", 
          "     &  ((MW2 - S)**2*S**2*T*C0(MW2,S,ME2,ME2,Null,Null))/", 
          "     &   (MW2**2 - S*U)**3 - ", 
          "     &  ((MW2 - S)*S**2*T**2*C0(T,ME2,ME2,ME2,ME2,Null))/", 
          "     &   (2D0*(MW2**2 - S*U)**3) + ", 
          "     &  ((MW2 - S)*S**3*T**2*", 
          "     &     D0(MW2,MW2,ME2,ME2,T,S,ME2,Null,ME2,Null))/", 
          "     &   (2D0*(MW2**2 - S*U)**3)"}]], TraditionalForm]], "Output",
  CellLabel->"Out[1185]//TableForm=  (21:56:06 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      RowBox[{"DeleteFile", "/@", 
        RowBox[{"FileNames", "[", "\"\<fctd122.for\>\"", "]"}]}], ";", 
      RowBox[{"Clear", "[", 
        RowBox[{"d122", ",", "se"}], "]"}], ";"}]], "Input",
  CellLabel->"In[1186]:=  (21:56:06 on 5/16/01)",
  CellTags->"PaVeReduce"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["PlusDistribution", "ObjectName",
  CellTags->"PlusDistribution"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"PlusDistribution"],

Cell["\<\
PlusDistribution[1/(1-x)] denotes a distribution (in the sense of the \"+\" \
prescription).\
\>", "Text",
  CellTags->"PlusDistribution"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["Integrate2",
    ButtonData:>"Integrate2",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Integrate2"],
  "."
}], "Text",
  CellTags->"PlusDistribution"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"PlusDistribution"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"PlusDistribution", "[", 
      RowBox[{"1", "/", 
        RowBox[{"(", 
          RowBox[{"1", "-", "x"}], ")"}]}], "]"}]], "Input",
  CellLabel->"In[1187]:=  (21:56:06 on 5/16/01)",
  CellTags->"PlusDistribution"],

Cell[BoxData[
    FormBox[
      SubscriptBox[
        RowBox[{"(", 
          FractionBox["1", 
            RowBox[{"1", "-", "x"}]], ")"}], "+"], TraditionalForm]], "Output",\

  CellLabel->"Out[1187]=  (21:56:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"PlusDistribution", "[", 
      RowBox[{
        RowBox[{"Log", "[", 
          RowBox[{"1", "-", "x"}], "]"}], "/", 
        RowBox[{"(", 
          RowBox[{"1", "-", "x"}], ")"}]}], "]"}]], "Input",
  CellLabel->"In[1188]:=  (21:56:06 on 5/16/01)",
  CellTags->"PlusDistribution"],

Cell[BoxData[
    FormBox[
      SubscriptBox[
        RowBox[{"(", 
          FractionBox[
            RowBox[{"log", "(", 
              RowBox[{"1", "-", "x"}], ")"}], 
            RowBox[{"1", "-", "x"}]], ")"}], "+"], TraditionalForm]], "Output",\

  CellLabel->"Out[1188]=  (21:56:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Integrate2", "[", 
      RowBox[{
        RowBox[{"PlusDistribution", "[", 
          RowBox[{"1", "/", 
            RowBox[{"(", 
              RowBox[{"1", "-", "x"}], ")"}]}], "]"}], ",", " ", 
        RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[1189]:=  (21:56:06 on 5/16/01)",
  CellTags->"PlusDistribution"],

Cell[BoxData[
    FormBox["0", TraditionalForm]], "Output",
  CellLabel->"Out[1189]=  (21:56:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Integrate2", "[", 
      RowBox[{
        RowBox[{"PlusDistribution", "[", 
          RowBox[{
            RowBox[{"Log", "[", 
              RowBox[{"1", "-", "x"}], "]"}], "/", 
            RowBox[{"(", 
              RowBox[{"1", "-", "x"}], ")"}]}], "]"}], ",", " ", 
        RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[1190]:=  (21:56:06 on 5/16/01)",
  CellTags->"PlusDistribution"],

Cell[BoxData[
    FormBox["0", TraditionalForm]], "Output",
  CellLabel->"Out[1190]=  (21:56:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Integrate2", "[", 
      RowBox[{
        RowBox[{"PlusDistribution", "[", 
          RowBox[{
            RowBox[{
              RowBox[{"Log", "[", 
                RowBox[{"1", "-", "x"}], "]"}], "^", "2"}], "/", 
            RowBox[{"(", 
              RowBox[{"1", "-", "x"}], ")"}]}], "]"}], ",", " ", 
        RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[1191]:=  (21:56:06 on 5/16/01)",
  CellTags->"PlusDistribution"],

Cell[BoxData[
    FormBox["0", TraditionalForm]], "Output",
  CellLabel->"Out[1191]=  (21:56:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"PlusDistribution", "[", 
      RowBox[{
        RowBox[{"Log", "[", 
          RowBox[{"x", " ", 
            RowBox[{"(", 
              RowBox[{"1", "-", "x"}], ")"}]}], "]"}], "/", 
        RowBox[{"(", 
          RowBox[{"1", "-", "x"}], ")"}]}], "]"}]], "Input",
  CellLabel->"In[1192]:=  (21:56:06 on 5/16/01)",
  CellTags->"PlusDistribution"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{"log", "(", "x", ")"}], 
          RowBox[{"1", "-", "x"}]], "+", 
        SubscriptBox[
          RowBox[{"(", 
            FractionBox[
              RowBox[{"log", "(", 
                RowBox[{"1", "-", "x"}], ")"}], 
              RowBox[{"1", "-", "x"}]], ")"}], "+"]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1192]=  (21:56:06 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Polarization", "ObjectName",
  CellTags->"Polarization"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"Polarization"],

Cell["\<\
Polarization[k] = Polarization[k, I] is the head of a polarization momentum \
with (incoming) momentum k. A slashed polarization vector (e1(k) slash) has \
to be entered as DiracSlash[Polarization[k]]. The internal representation for \
a polarization vector e1 corresponding to a boson with four momentum k is: \
Momentum[ Polarization[ k, I ] ]. With this notation transversality of \
polarization vectors is provided, i.e. , Pair[ Momentum[k], Momentum[ \
Polarization[k, I] ] ] yields 0. Polarization[k,-I] denotes the complex \
conjugate polarization. Polarization is also an option of various functions \
related to the operator product expansion. The setting 0 denotes the \
unpolarized and 1 the polarized case.\
\>", "Text",
  CellTags->"Polarization"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["PolarizationVector",
    ButtonData:>"PolarizationVector",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"PolarizationVector"],
  "."
}], "Text",
  CellTags->"Polarization"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"Polarization"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Polarization", "[", "k", "]"}]], "Input",
  CellLabel->"In[1193]:=  (21:56:06 on 5/16/01)",
  CellTags->"Polarization"],

Cell[BoxData[
    FormBox[
      RowBox[{"\[CurlyEpsilon]", "\[NoBreak]", "(", "\[NoBreak]", 
        FormBox[
          FormBox[
            TagBox[
              StyleBox["\<\"k\"\>",
                FontSlant->"Italic"],
              (StyleForm[ #, FontSlant -> "Italic"]&)],
            "TraditionalForm"],
          "TraditionalForm"], "\[NoBreak]", ")"}], TraditionalForm]], "Output",\

  CellLabel->"Out[1193]=  (21:56:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Polarization", "[", "k", "]"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[1194]:=  (21:56:06 on 5/16/01)",
  CellTags->"Polarization"],

Cell[BoxData[
    RowBox[{"Polarization", "[", 
      RowBox[{"k", ",", "\[ImaginaryI]"}], "]"}]], "Output",
  CellLabel->"Out[1194]//StandardForm=  (21:56:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Polarization", "[", "k", "]"}], "//", 
      "ComplexConjugate"}]], "Input",
  CellLabel->"In[1195]:=  (21:56:06 on 5/16/01)",
  CellTags->"Polarization"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          InterpretationBox[
            SuperscriptBox["\<\"\[CurlyEpsilon]\"\>", "\<\"*\"\>"],
            Superscript[ "\[CurlyEpsilon]", "*"],
            Editable->False],
          "TraditionalForm"], "\[NoBreak]", "(", "\[NoBreak]", 
        FormBox[
          FormBox[
            TagBox[
              StyleBox["\<\"k\"\>",
                FontSlant->"Italic"],
              (StyleForm[ #, FontSlant -> "Italic"]&)],
            "TraditionalForm"],
          "TraditionalForm"], "\[NoBreak]", ")"}], TraditionalForm]], "Output",\

  CellLabel->"Out[1195]=  (21:56:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"Polarization", "[", "k", "]"}], "//", "ComplexConjugate"}], "//",
       "StandardForm"}]], "Input",
  CellLabel->"In[1196]:=  (21:56:06 on 5/16/01)",
  CellTags->"Polarization"],

Cell[BoxData[
    RowBox[{"Polarization", "[", 
      RowBox[{"k", ",", 
        RowBox[{"-", "\[ImaginaryI]"}]}], "]"}]], "Output",
  CellLabel->"Out[1196]//StandardForm=  (21:56:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracSlash", "[", 
      RowBox[{"Polarization", "[", "k", "]"}], "]"}]], "Input",
  CellLabel->"In[1197]:=  (21:56:07 on 5/16/01)",
  CellTags->"Polarization"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox["\<\"\[Gamma]\"\>",
          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
        FormBox[
          RowBox[{"\[CurlyEpsilon]", "\[NoBreak]", "(", "\[NoBreak]", 
            FormBox[
              FormBox[
                TagBox[
                  StyleBox["\<\"k\"\>",
                    FontSlant->"Italic"],
                  (StyleForm[ #, FontSlant -> "Italic"]&)],
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", ")"}],
          "TraditionalForm"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1197]=  (21:56:07 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"DiracSlash", "[", 
        RowBox[{"Polarization", "[", "k", "]"}], "]"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[1198]:=  (21:56:07 on 5/16/01)",
  CellTags->"Polarization"],

Cell[BoxData[
    RowBox[{"DiracGamma", "[", 
      RowBox[{"Momentum", "[", 
        RowBox[{"Polarization", "[", 
          RowBox[{"k", ",", "\[ImaginaryI]"}], "]"}], "]"}], "]"}]], "Output",\

  CellLabel->"Out[1198]//StandardForm=  (21:56:07 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Pair", "[", " ", 
      RowBox[{
        RowBox[{"Momentum", "[", "k", "]"}], ",", " ", 
        RowBox[{"Momentum", "[", " ", 
          RowBox[{"Polarization", "[", 
            RowBox[{"k", ",", " ", "I"}], "]"}], " ", "]"}]}], " ", 
      "]"}]], "Input",
  CellLabel->"In[1199]:=  (21:56:07 on 5/16/01)",
  CellTags->"Polarization"],

Cell[BoxData[
    FormBox["0", TraditionalForm]], "Output",
  CellLabel->"Out[1199]=  (21:56:07 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["PolarizationSum", "ObjectName",
  CellTags->"PolarizationSum"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"PolarizationSum"],

Cell["\<\
PolarizationSum[ mu,nu, ... ] defines (as abbreviations) several polarization \
sums. The first two arguments are the interpreted as Lorentz indices, all \
further ones are momenta. PolarizationSum performs no calculations.\
\>", "Text",
  CellTags->"PolarizationSum"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "PolarizationSum", "]"}]], "Input",
  CellLabel->"In[1200]:=  (21:56:07 on 5/16/01)",
  CellTags->"PolarizationSum"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"Dimension", "\[Rule]", "4"}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1200]=  (21:56:07 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["Polarization",
    ButtonData:>"Polarization",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Polarization"],
  "."
}], "Text",
  CellTags->"PolarizationSum"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"PolarizationSum"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"PolarizationSum", "[", 
      RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}]], "Input",
  CellLabel->"In[1201]:=  (21:56:07 on 5/16/01)",
  CellTags->"PolarizationSum"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        SuperscriptBox["g", 
          RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1201]=  (21:56:07 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"PolarizationSum", "[", 
      RowBox[{"\[Mu]", ",", "\[Nu]", ",", "k"}], "]"}]], "Input",
  CellLabel->"In[1202]:=  (21:56:07 on 5/16/01)",
  CellTags->"PolarizationSum"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{
            SuperscriptBox[
              FormBox[
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"]], " ", 
            SuperscriptBox[
              FormBox[
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"]]}], 
          SuperscriptBox[
            FormBox[
              FormBox[
                TagBox[
                  StyleBox["\<\"k\"\>",
                    FontSlant->"Italic"],
                  (StyleForm[ #, FontSlant -> "Italic"]&)],
                "TraditionalForm"],
              "TraditionalForm"], "2"]], "-", 
        SuperscriptBox["g", 
          RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1202]=  (21:56:07 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"PolarizationSum", "[", 
      RowBox[{"\[Mu]", ",", "\[Nu]", ",", "k", ",", "n"}], "]"}]], "Input",
  CellLabel->"In[1203]:=  (21:56:07 on 5/16/01)",
  CellTags->"PolarizationSum"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]]}], "-", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              FormBox[
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"]], " ", 
            SuperscriptBox[
              FormBox[
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"]], " ", 
            SuperscriptBox[
              FormBox["n",
                "TraditionalForm"], "2"]}], 
          SuperscriptBox[
            RowBox[{"(", 
              FormBox[
                RowBox[{
                  FormBox[
                    FormBox[
                      TagBox[
                        StyleBox["\<\"k\"\>",
                          FontSlant->"Italic"],
                        (StyleForm[ #, FontSlant -> "Italic"]&)],
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["n",
                    "TraditionalForm"]}],
                "TraditionalForm"], ")"}], "2"]], "+", 
        FractionBox[
          RowBox[{
            RowBox[{
              SuperscriptBox[
                FormBox["n",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox[
                  FormBox[
                    TagBox[
                      StyleBox["\<\"k\"\>",
                        FontSlant->"Italic"],
                      (StyleForm[ #, FontSlant -> "Italic"]&)],
                    "TraditionalForm"],
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], "+", 
            RowBox[{
              SuperscriptBox[
                FormBox[
                  FormBox[
                    TagBox[
                      StyleBox["\<\"k\"\>",
                        FontSlant->"Italic"],
                      (StyleForm[ #, FontSlant -> "Italic"]&)],
                    "TraditionalForm"],
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["n",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}]}], 
          RowBox[{
            FormBox[
              FormBox[
                TagBox[
                  StyleBox["\<\"k\"\>",
                    FontSlant->"Italic"],
                  (StyleForm[ #, FontSlant -> "Italic"]&)],
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["n",
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1203]=  (21:56:07 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"PolarizationSum", "[", 
      RowBox[{"\[Mu]", ",", "\[Nu]", ",", "k", ",", 
        RowBox[{
          SubscriptBox["p", "1"], "-", 
          SubscriptBox["p", "2"]}]}], "]"}]], "Input",
  CellLabel->"In[1204]:=  (21:56:07 on 5/16/01)",
  CellTags->"PolarizationSum"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]]}], "-", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              FormBox[
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"]], " ", 
            SuperscriptBox[
              FormBox[
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"]], " ", 
            SubsuperscriptBox["p", "1", "2"]}], 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  FormBox[
                    FormBox[
                      TagBox[
                        StyleBox["\<\"k\"\>",
                          FontSlant->"Italic"],
                        (StyleForm[ #, FontSlant -> "Italic"]&)],
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox[
                    SubscriptBox["p", "1"],
                    "TraditionalForm"]}], "-", 
                RowBox[{
                  FormBox[
                    FormBox[
                      TagBox[
                        StyleBox["\<\"k\"\>",
                          FontSlant->"Italic"],
                        (StyleForm[ #, FontSlant -> "Italic"]&)],
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox[
                    SubscriptBox["p", "2"],
                    "TraditionalForm"]}]}], ")"}], "2"]], "+", 
        FractionBox[
          RowBox[{"2", " ", 
            SuperscriptBox[
              FormBox[
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"]], " ", 
            SuperscriptBox[
              FormBox[
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"]], " ", 
            RowBox[{
              FormBox[
                SubscriptBox["p", "1"],
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox[
                SubscriptBox["p", "2"],
                "TraditionalForm"]}]}], 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  FormBox[
                    FormBox[
                      TagBox[
                        StyleBox["\<\"k\"\>",
                          FontSlant->"Italic"],
                        (StyleForm[ #, FontSlant -> "Italic"]&)],
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox[
                    SubscriptBox["p", "1"],
                    "TraditionalForm"]}], "-", 
                RowBox[{
                  FormBox[
                    FormBox[
                      TagBox[
                        StyleBox["\<\"k\"\>",
                          FontSlant->"Italic"],
                        (StyleForm[ #, FontSlant -> "Italic"]&)],
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox[
                    SubscriptBox["p", "2"],
                    "TraditionalForm"]}]}], ")"}], "2"]], "-", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              FormBox[
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"]], " ", 
            SuperscriptBox[
              FormBox[
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"],
                "TraditionalForm"], 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"]], " ", 
            SubsuperscriptBox["p", "2", "2"]}], 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  FormBox[
                    FormBox[
                      TagBox[
                        StyleBox["\<\"k\"\>",
                          FontSlant->"Italic"],
                        (StyleForm[ #, FontSlant -> "Italic"]&)],
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox[
                    SubscriptBox["p", "1"],
                    "TraditionalForm"]}], "-", 
                RowBox[{
                  FormBox[
                    FormBox[
                      TagBox[
                        StyleBox["\<\"k\"\>",
                          FontSlant->"Italic"],
                        (StyleForm[ #, FontSlant -> "Italic"]&)],
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox[
                    SubscriptBox["p", "2"],
                    "TraditionalForm"]}]}], ")"}], "2"]], "+", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{
                        SubscriptBox["p", "1"], "-", 
                        SubscriptBox["p", "2"]}],
                      "TraditionalForm"], ")"}], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], ")"}], " ", 
              SuperscriptBox[
                FormBox[
                  FormBox[
                    TagBox[
                      StyleBox["\<\"k\"\>",
                        FontSlant->"Italic"],
                      (StyleForm[ #, FontSlant -> "Italic"]&)],
                    "TraditionalForm"],
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], "+", 
            RowBox[{
              SuperscriptBox[
                FormBox[
                  FormBox[
                    TagBox[
                      StyleBox["\<\"k\"\>",
                        FontSlant->"Italic"],
                      (StyleForm[ #, FontSlant -> "Italic"]&)],
                    "TraditionalForm"],
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{"(", 
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{
                        SubscriptBox["p", "1"], "-", 
                        SubscriptBox["p", "2"]}],
                      "TraditionalForm"], ")"}], 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], ")"}]}]}], 
          RowBox[{
            RowBox[{
              FormBox[
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox[
                SubscriptBox["p", "1"],
                "TraditionalForm"]}], "-", 
            RowBox[{
              FormBox[
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox[
                SubscriptBox["p", "2"],
                "TraditionalForm"]}]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1204]=  (21:56:07 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["PolarizationVector", "ObjectName",
  CellTags->"PolarizationVector"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"PolarizationVector"],

Cell["PolarizationVector[p, mu] gives a polarization vector.", "Text",
  CellTags->"PolarizationVector"],

Cell[TextData[{
  "See also: ",
  ButtonBox["FourVector",
    ButtonData:>"FourVector",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FourVector"],
  ", ",
  ButtonBox["Pair",
    ButtonData:>"Pair",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Pair"],
  ", ",
  ButtonBox["Polarization",
    ButtonData:>"Polarization",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Polarization"],
  "."
}], "Text",
  CellTags->"PolarizationVector"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"PolarizationVector"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"PolarizationVector", "[", 
      RowBox[{"k", ",", "\[Mu]"}], "]"}]], "Input",
  CellLabel->"In[1205]:=  (21:56:07 on 5/16/01)",
  CellTags->"PolarizationVector"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["\[CurlyEpsilon]", "\[Mu]"], "(", 
        FormBox[
          FormBox[
            TagBox[
              StyleBox["\<\"k\"\>",
                FontSlant->"Italic"],
              (StyleForm[ #, FontSlant -> "Italic"]&)],
            "TraditionalForm"],
          "TraditionalForm"], ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[1205]=  (21:56:07 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Conjugate", "[", 
      RowBox[{"PolarizationVector", "[", 
        RowBox[{"k", ",", "\[Mu]"}], "]"}], "]"}]], "Input",
  CellLabel->"In[1206]:=  (21:56:07 on 5/16/01)",
  CellTags->"PolarizationVector"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubsuperscriptBox["\[CurlyEpsilon]", "\[Mu]", "*"], "(", 
        FormBox[
          FormBox[
            TagBox[
              StyleBox["\<\"k\"\>",
                FontSlant->"Italic"],
              (StyleForm[ #, FontSlant -> "Italic"]&)],
            "TraditionalForm"],
          "TraditionalForm"], ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[1206]=  (21:56:07 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "A polarization vector ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox["\[CurlyEpsilon]", "\[Mu]"], "(", "k", ")"}], 
        TraditionalForm]]],
  "is a special four-vector."
}], "Text",
  CellTags->"PolarizationVector"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"PolarizationVector", "[", 
        RowBox[{"k", ",", "mu"}], "]"}], "//", "StandardForm"}]], "Input",
  CellLabel->"In[1207]:=  (21:56:07 on 5/16/01)",
  CellTags->"PolarizationVector"],

Cell[BoxData[
    RowBox[{"Pair", "[", 
      RowBox[{
        RowBox[{"LorentzIndex", "[", "mu", "]"}], ",", 
        RowBox[{"Momentum", "[", 
          RowBox[{"Polarization", "[", 
            RowBox[{"k", ",", "\[ImaginaryI]"}], "]"}], "]"}]}], 
      "]"}]], "Output",
  CellLabel->"Out[1207]//StandardForm=  (21:56:07 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "The transverality property ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SuperscriptBox[
              FormBox["k",
                "TraditionalForm"], 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"]], " ", 
            RowBox[{
              SubscriptBox["\[CurlyEpsilon]", "\[Mu]"], "(", "k", ")"}]}], 
          "=", "0"}], TraditionalForm]]],
  " is built in."
}], "Text",
  CellTags->"PolarizationVector"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"a1", " ", "=", " ", 
      RowBox[{
        RowBox[{"PolarizationVector", "[", 
          RowBox[{"k", ",", "\[Mu]"}], "]"}], " ", 
        RowBox[{"FourVector", "[", 
          RowBox[{"k", ",", "\[Mu]"}], "]"}]}]}]], "Input",
  CellLabel->"In[1208]:=  (21:56:07 on 5/16/01)",
  CellTags->"PolarizationVector"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox[
          FormBox[
            FormBox[
              TagBox[
                StyleBox["\<\"k\"\>",
                  FontSlant->"Italic"],
                (StyleForm[ #, FontSlant -> "Italic"]&)],
              "TraditionalForm"],
            "TraditionalForm"], "\[Mu]"], " ", 
        RowBox[{
          SubscriptBox["\[CurlyEpsilon]", "\[Mu]"], "(", 
          FormBox[
            FormBox[
              TagBox[
                StyleBox["\<\"k\"\>",
                  FontSlant->"Italic"],
                (StyleForm[ #, FontSlant -> "Italic"]&)],
              "TraditionalForm"],
            "TraditionalForm"], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1208]=  (21:56:07 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Contract", "[", "a1", "]"}]], "Input",
  CellLabel->"In[1209]:=  (21:56:07 on 5/16/01)",
  CellTags->"PolarizationVector"],

Cell[BoxData[
    FormBox["0", TraditionalForm]], "Output",
  CellLabel->"Out[1209]=  (21:56:07 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"a2", " ", "=", " ", 
      RowBox[{
        RowBox[{"PolarizationVector", "[", 
          RowBox[{
            RowBox[{"k", "-", "p"}], ",", "\[Mu]"}], "]"}], " ", 
        RowBox[{"FourVector", "[", 
          RowBox[{"k", ",", "\[Mu]"}], "]"}]}]}]], "Input",
  CellLabel->"In[1210]:=  (21:56:07 on 5/16/01)",
  CellTags->"PolarizationVector"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox[
          FormBox[
            FormBox[
              TagBox[
                StyleBox["\<\"k\"\>",
                  FontSlant->"Italic"],
                (StyleForm[ #, FontSlant -> "Italic"]&)],
              "TraditionalForm"],
            "TraditionalForm"], "\[Mu]"], " ", 
        RowBox[{
          SubscriptBox["\[CurlyEpsilon]", "\[Mu]"], "(", 
          FormBox[
            RowBox[{
              FormBox[
                TagBox[
                  StyleBox["\<\"k\"\>",
                    FontSlant->"Italic"],
                  (StyleForm[ #, FontSlant -> "Italic"]&)],
                "TraditionalForm"], "-", "p"}],
            "TraditionalForm"], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1210]=  (21:56:07 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Contract", "[", "a2", "]"}]], "Input",
  CellLabel->"In[1211]:=  (21:56:07 on 5/16/01)",
  CellTags->"PolarizationVector"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          FormBox[
            TagBox[
              StyleBox["\<\"k\"\>",
                FontSlant->"Italic"],
              (StyleForm[ #, FontSlant -> "Italic"]&)],
            "TraditionalForm"],
          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "(",
         "\[NoBreak]", 
        FormBox[
          RowBox[{"\[CurlyEpsilon]", "\[NoBreak]", "(", "\[NoBreak]", 
            FormBox[
              RowBox[{
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"], "-", "p"}],
              "TraditionalForm"], "\[NoBreak]", ")"}],
          "TraditionalForm"], "\[NoBreak]", ")"}], TraditionalForm]], "Output",\

  CellLabel->"Out[1211]=  (21:56:07 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "Depending on the alphabetical ordering of the momenta simplifcations are \
done, e.g., ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SuperscriptBox[
              FormBox["p",
                "TraditionalForm"], 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"]], " ", 
            RowBox[{
              SubscriptBox["\[CurlyEpsilon]", "\[Mu]"], "(", 
              FormBox[
                RowBox[{"k", "-", "p"}],
                "TraditionalForm"], ")"}]}], "=", 
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"k", "-", "p", "-", "k"}], ")"}], "\[Mu]"]}], 
              RowBox[{
                SubscriptBox["\[CurlyEpsilon]", "\[Mu]"], "(", 
                FormBox[
                  RowBox[{"k", "-", "p"}],
                  "TraditionalForm"], ")"}]}], "=", 
            RowBox[{
              RowBox[{
                SuperscriptBox["k", "\[Mu]"], 
                RowBox[{
                  SubscriptBox["\[CurlyEpsilon]", "\[Mu]"], "(", 
                  FormBox[
                    RowBox[{"k", "-", "p"}],
                    "TraditionalForm"], ")"}]}], "=", 
              RowBox[{
                FormBox["k",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                RowBox[{
                  RowBox[{"(", "\[NoBreak]", 
                    FormBox[
                      RowBox[{
                      "\[CurlyEpsilon]", "\[NoBreak]", "(", "\[NoBreak]", 
                        FormBox[
                          RowBox[{"k", "-", "p"}],
                          "TraditionalForm"], "\[NoBreak]", ")"}],
                      "TraditionalForm"], "\[NoBreak]", ")"}], "."}]}]}]}]}], 
        TraditionalForm]]]
}], "Text",
  CellTags->"PolarizationVector"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"a3", " ", "=", " ", 
      RowBox[{
        RowBox[{"PolarizationVector", "[", 
          RowBox[{
            RowBox[{"k", "-", "p"}], ",", "\[Mu]"}], "]"}], " ", 
        RowBox[{"FourVector", "[", 
          RowBox[{"p", ",", "\[Mu]"}], "]"}]}]}]], "Input",
  CellLabel->"In[1212]:=  (21:56:07 on 5/16/01)",
  CellTags->"PolarizationVector"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["p", "\[Mu]"], " ", 
        RowBox[{
          SubscriptBox["\[CurlyEpsilon]", "\[Mu]"], "(", 
          FormBox[
            RowBox[{
              FormBox[
                TagBox[
                  StyleBox["\<\"k\"\>",
                    FontSlant->"Italic"],
                  (StyleForm[ #, FontSlant -> "Italic"]&)],
                "TraditionalForm"], "-", "p"}],
            "TraditionalForm"], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1212]=  (21:56:07 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Contract", "[", "a3", "]"}]], "Input",
  CellLabel->"In[1213]:=  (21:56:07 on 5/16/01)",
  CellTags->"PolarizationVector"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          FormBox[
            TagBox[
              StyleBox["\<\"k\"\>",
                FontSlant->"Italic"],
              (StyleForm[ #, FontSlant -> "Italic"]&)],
            "TraditionalForm"],
          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", "(",
         "\[NoBreak]", 
        FormBox[
          RowBox[{"\[CurlyEpsilon]", "\[NoBreak]", "(", "\[NoBreak]", 
            FormBox[
              RowBox[{
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"], "-", "p"}],
              "TraditionalForm"], "\[NoBreak]", ")"}],
          "TraditionalForm"], "\[NoBreak]", ")"}], TraditionalForm]], "Output",\

  CellLabel->"Out[1213]=  (21:56:08 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{"Clear", "[", 
      RowBox[{"a1", ",", "a2", ",", "a3"}], "]"}]], "Input",
  CellLabel->"In[1214]:=  (21:56:08 on 5/16/01)",
  CellTags->"PolarizationVector"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["PowerSimplify", "ObjectName",
  CellTags->"PowerSimplify"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"PowerSimplify"],

Cell["\<\
PowerSimplify[exp] simplifies (-x)^a to (-1)^a x^a and (y-x)^n to (-1)^n \
(x-y)^n; thus assuming that the exponent is an integer (even if it is \
symbolic). Furthermore (-1)^(a+n) and I^(a+n) are expanded and (I)^(2 m) -> \
(-1)^m and (-1)^(n_Integer?EvenQ m) -> 1 and (-1)^(n_Integer?OddQ m) -> \
(-1)^m and (-1)^(-n) -> (-1)^n and Exp[I m Pi] -> (-1)^m.\
\>", "Text",
  CellTags->"PowerSimplify"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["DataType",
    ButtonData:>"DataType",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DataType"],
  ", ",
  "OPEm",
  "."
}], "Text",
  CellTags->"PowerSimplify"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"PowerSimplify"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"PowerSimplify", "[", 
      RowBox[{
        RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "^", 
        RowBox[{"(", 
          RowBox[{"2", "OPEm"}], ")"}]}], "]"}]], "Input",
  CellLabel->"In[1215]:=  (21:56:08 on 5/16/01)",
  CellTags->"PowerSimplify"],

Cell[BoxData[
    FormBox["1", TraditionalForm]], "Output",
  CellLabel->"Out[1215]=  (21:56:08 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"PowerSimplify", "[", 
      RowBox[{
        RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "^", 
        RowBox[{"(", 
          RowBox[{"OPEm", "+", "2"}], ")"}]}], "]"}]], "Input",
  CellLabel->"In[1216]:=  (21:56:08 on 5/16/01)",
  CellTags->"PowerSimplify"],

Cell[BoxData[
    FormBox[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "m"], TraditionalForm]], "Output",
  CellLabel->"Out[1216]=  (21:56:08 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"PowerSimplify", "[", 
      RowBox[{
        RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "^", 
        RowBox[{"(", 
          RowBox[{"OPEm", "-", "2"}], ")"}]}], "]"}]], "Input",
  CellLabel->"In[1217]:=  (21:56:08 on 5/16/01)",
  CellTags->"PowerSimplify"],

Cell[BoxData[
    FormBox[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "m"], TraditionalForm]], "Output",
  CellLabel->"Out[1217]=  (21:56:08 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"PowerSimplify", "[", 
      RowBox[{"I", "^", 
        RowBox[{"(", 
          RowBox[{"2", "OPEm"}], ")"}]}], "]"}]], "Input",
  CellLabel->"In[1218]:=  (21:56:08 on 5/16/01)",
  CellTags->"PowerSimplify"],

Cell[BoxData[
    FormBox[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "m"], TraditionalForm]], "Output",
  CellLabel->"Out[1218]=  (21:56:08 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["PropagatorDenominatorExplicit", "ObjectName",
  CellTags->"PropagatorDenominatorExplicit"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"PropagatorDenominatorExplicit"],

Cell["\<\
PropagatorDenominatorExplicit[exp] changes each occurence of \
PropagatorDenominator[a,b] in exp into 1/(ScalarProduct[a,a]-b^2) and \
replaces FeynAmpDenominator by Identity.\
\>", "Text",
  CellTags->"PropagatorDenominatorExplicit"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["FeynAmpDenominator",
    ButtonData:>"FeynAmpDenominator",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FeynAmpDenominator"],
  ", ",
  ButtonBox["PropagatorDenominator",
    ButtonData:>"PropagatorDenominator",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"PropagatorDenominator"],
  "."
}], "Text",
  CellTags->"PropagatorDenominatorExplicit"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"PropagatorDenominatorExplicit"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"FAD", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{"q", ",", "m"}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"q", "-", "p"}], ",", "0"}], "}"}]}], "]"}], "//", 
      "FCI"}]], "Input",
  CellLabel->"In[1219]:=  (21:56:08 on 5/16/01)",
  CellTags->"PropagatorDenominatorExplicit"],

Cell[BoxData[
    FormBox[
      FractionBox["1", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox["q", "2"], "-", 
              SuperscriptBox["m", "2"]}], ")"}], ".", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"q", "-", "p"}], ")"}], "2"]}]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1219]=  (21:56:08 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"PropagatorDenominatorExplicit", "[", "%", "]"}], "//", 
      "FCE"}]], "Input",
  CellLabel->"In[1220]:=  (21:56:08 on 5/16/01)",
  CellTags->"PropagatorDenominatorExplicit"],

Cell[BoxData[
    FormBox[
      FractionBox["1", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              FormBox[
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"],
                "TraditionalForm"], "-", 
              SuperscriptBox["m", "2"]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              FormBox[
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"],
                "TraditionalForm"], "-", 
              RowBox[{"2", " ", 
                FormBox[
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}],
                  "TraditionalForm"]}], "+", 
              FormBox[
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"],
                "TraditionalForm"]}], ")"}]}]], TraditionalForm]], "Output",
  CellLabel->"Out[1220]=  (21:56:08 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "StandardForm"}]], "Input",
  CellLabel->"In[1221]:=  (21:56:08 on 5/16/01)",
  CellTags->"PropagatorDenominatorExplicit"],

Cell[BoxData[
    FractionBox["1", 
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{"-", 
              SuperscriptBox["m", "2"]}], "+", 
            RowBox[{"SPD", "[", 
              RowBox[{"q", ",", "q"}], "]"}]}], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"SPD", "[", 
              RowBox[{"p", ",", "p"}], "]"}], "-", 
            RowBox[{"2", " ", 
              RowBox[{"SPD", "[", 
                RowBox[{"p", ",", "q"}], "]"}]}], "+", 
            RowBox[{"SPD", "[", 
              RowBox[{"q", ",", "q"}], "]"}]}], ")"}]}]]], "Output",
  CellLabel->"Out[1221]//StandardForm=  (21:56:08 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["PropagatorDenominator", "ObjectName",
  CellTags->"PropagatorDenominator"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"PropagatorDenominator"],

Cell[TextData[{
  "PropagatorDenominator[q, m] is a factor of the denominator of a \
propagator. If p is supposed to be D-dimensional enter: \
PropagatorDenominator[Momentum[q, D], m]. What is meant is ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", "1", "/", 
          RowBox[{"(", 
            RowBox[{"q", "^", "2"}]}]}], TraditionalForm]]],
  " - ",
  Cell[BoxData[
      FormBox[
        RowBox[{"m", "^", "2"}], TraditionalForm]]],
  "). PropagatorDenominator[p] evaluates to PropagatorDenominator[p, 0]. "
}], "Text",
  CellTags->"PropagatorDenominator"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["FeynAmpDenominator",
    ButtonData:>"FeynAmpDenominator",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FeynAmpDenominator"],
  ", ",
  ButtonBox["PropagatorDenominatorExplicit",
    ButtonData:>"PropagatorDenominatorExplicit",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"PropagatorDenominatorExplicit"],
  "."
}], "Text",
  CellTags->"PropagatorDenominator"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"PropagatorDenominator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{" ", 
      RowBox[{"PropagatorDenominator", "[", 
        RowBox[{"p", ",", "m"}], "]"}]}]], "Input",
  CellLabel->"In[1222]:=  (21:56:08 on 5/16/01)",
  CellTags->"PropagatorDenominator"],

Cell[BoxData[
    FormBox[
      FractionBox["1", 
        RowBox[{
          SuperscriptBox["p", "2"], "-", 
          SuperscriptBox["m", "2"]}]], TraditionalForm]], "Output",
  CellLabel->"Out[1222]=  (21:56:08 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"PropagatorDenominator", "[", "p", "]"}]], "Input",
  CellLabel->"In[1223]:=  (21:56:08 on 5/16/01)",
  CellTags->"PropagatorDenominator"],

Cell[BoxData[
    FormBox[
      FractionBox["1", 
        SuperscriptBox["p", "2"]], TraditionalForm]], "Output",
  CellLabel->"Out[1223]=  (21:56:08 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"t1", "=", 
        RowBox[{"PropagatorDenominator", "[", 
          RowBox[{"q", ",", "m"}], "]"}]}], " "}]], "Input",
  CellLabel->"In[1224]:=  (21:56:08 on 5/16/01)",
  CellTags->"PropagatorDenominator"],

Cell[BoxData[
    FormBox[
      FractionBox["1", 
        RowBox[{
          SuperscriptBox["q", "2"], "-", 
          SuperscriptBox["m", "2"]}]], TraditionalForm]], "Output",
  CellLabel->"Out[1224]=  (21:56:08 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StandardForm", "[", 
      RowBox[{"FCI", "[", "t1", "]"}], "]"}]], "Input",
  CellLabel->"In[1225]:=  (21:56:08 on 5/16/01)",
  CellTags->"PropagatorDenominator"],

Cell[BoxData[
    RowBox[{"PropagatorDenominator", "[", 
      RowBox[{
        RowBox[{"Momentum", "[", 
          RowBox[{"q", ",", "D"}], "]"}], ",", "m"}], "]"}]], "Output",
  CellLabel->"Out[1225]//StandardForm=  (21:56:08 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StandardForm", "[", 
      RowBox[{"ChangeDimension", "[", 
        RowBox[{"t1", ",", "D"}], "]"}], "]"}]], "Input",
  CellLabel->"In[1226]:=  (21:56:08 on 5/16/01)",
  CellTags->"PropagatorDenominator"],

Cell[BoxData[
    RowBox[{"PropagatorDenominator", "[", 
      RowBox[{
        RowBox[{"Momentum", "[", 
          RowBox[{"q", ",", "D"}], "]"}], ",", "m"}], "]"}]], "Output",
  CellLabel->"Out[1226]//StandardForm=  (21:56:08 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"PropagatorDenominatorExplicit", "[", "t1", "]"}]], "Input",
  CellLabel->"In[1227]:=  (21:56:08 on 5/16/01)",
  CellTags->"PropagatorDenominator"],

Cell[BoxData[
    FormBox[
      FractionBox["1", 
        RowBox[{
          SuperscriptBox[
            FormBox["q",
              "TraditionalForm"], "2"], "-", 
          SuperscriptBox["m", "2"]}]], TraditionalForm]], "Output",
  CellLabel->"Out[1227]=  (21:56:08 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StandardForm", "[", "%", "]"}]], "Input",
  CellLabel->"In[1228]:=  (21:56:08 on 5/16/01)",
  CellTags->"PropagatorDenominator"],

Cell[BoxData[
    FractionBox["1", 
      RowBox[{
        RowBox[{"-", 
          SuperscriptBox["m", "2"]}], "+", 
        RowBox[{"Pair", "[", 
          RowBox[{
            RowBox[{"Momentum", "[", "q", "]"}], ",", 
            RowBox[{"Momentum", "[", "q", "]"}]}], "]"}]}]]], "Output",
  CellLabel->"Out[1228]//StandardForm=  (21:56:08 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{"Clear", "[", "t1", "]"}]], "Input",
  CellLabel->"In[1229]:=  (21:56:08 on 5/16/01)",
  CellTags->"PropagatorDenominator"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["QuantumField", "ObjectName",
  CellTags->"QuantumField"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"QuantumField"],

Cell["\<\
QuantumField is the head of quantized fields and their derivatives. \
QuantumField[par, ftype, {lorind}, {sunind}] denotes a quantum field of type \
ftype with (possible) Lorentz-indices lorind and SU(N)-indices sunind. The \
optional first argument par denotes a partial derivative acting on the field.\
\
\>", "Text",
  CellTags->"QuantumField"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["FeynRule",
    ButtonData:>"FeynRule",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FeynRule"],
  ", ",
  ButtonBox["PartialD",
    ButtonData:>"PartialD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"PartialD"],
  ", ",
  ButtonBox["ExpandPartialD",
    ButtonData:>"ExpandPartialD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"ExpandPartialD"],
  "."
}], "Text",
  CellTags->"QuantumField"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"QuantumField"],

Cell["This denotes a scalar field.", "Text",
  CellTags->"QuantumField"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"QuantumField", "[", "S", "]"}]], "Input",
  CellLabel->"In[1230]:=  (21:56:08 on 5/16/01)",
  CellTags->"QuantumField"],

Cell[BoxData[
    FormBox["S", TraditionalForm]], "Output",
  CellLabel->"Out[1230]=  (21:56:08 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"QuantumField", "[", "AntiQuarkField", "]"}]], "Input",
  CellLabel->"In[1231]:=  (21:56:08 on 5/16/01)",
  CellTags->"QuantumField"],

Cell[BoxData[
    FormBox[
      OverscriptBox["\[Psi]", "_"], TraditionalForm]], "Output",
  CellLabel->"Out[1231]=  (21:56:08 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"QuantumField", "[", "QuarkField", "]"}]], "Input",
  CellLabel->"In[1232]:=  (21:56:08 on 5/16/01)",
  CellTags->"QuantumField"],

Cell[BoxData[
    FormBox["\[Psi]", TraditionalForm]], "Output",
  CellLabel->"Out[1232]=  (21:56:08 on 5/16/01)"]
}, Closed]],

Cell["This is a field with a Lorentz index.", "Text",
  CellTags->"QuantumField"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"QuantumField", "[", 
      RowBox[{"B", ",", 
        RowBox[{"{", "\[Mu]", "}"}]}], "]"}]], "Input",
  CellLabel->"In[1233]:=  (21:56:08 on 5/16/01)",
  CellTags->"QuantumField"],

Cell[BoxData[
    FormBox[
      SubscriptBox["B", "\[Mu]"], TraditionalForm]], "Output",
  CellLabel->"Out[1233]=  (21:56:08 on 5/16/01)"]
}, Closed]],

Cell["Color indices should be put after the Lorentz ones.", "Text",
  CellTags->"QuantumField"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"QuantumField", "[", 
      RowBox[{"GaugeField", ",", 
        RowBox[{"{", "\[Mu]", "}"}], ",", 
        RowBox[{"{", "a", "}"}]}], "]"}]], "Input",
  CellLabel->"In[1234]:=  (21:56:09 on 5/16/01)",
  CellTags->"QuantumField"],

Cell[BoxData[
    FormBox[
      SubsuperscriptBox[
        FormBox["A",
          "TraditionalForm"], 
        FormBox[
          FormBox["\[Mu]",
            "TraditionalForm"],
          "TraditionalForm"], 
        FormBox[
          FormBox["a",
            "TraditionalForm"],
          "TraditionalForm"]], TraditionalForm]], "Output",
  CellLabel->"Out[1234]=  (21:56:09 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "StandardForm"}]], "Input",
  CellLabel->"In[1235]:=  (21:56:09 on 5/16/01)",
  CellTags->"QuantumField"],

Cell[BoxData[
    RowBox[{"QuantumField", "[", 
      RowBox[{"GaugeField", ",", 
        RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
        RowBox[{"SUNIndex", "[", "a", "]"}]}], "]"}]], "Output",
  CellLabel->"Out[1235]//StandardForm=  (21:56:09 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["A", "\[CapitalDelta]", "a"], TraditionalForm]]],
  " is a short form for ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[CapitalDelta]", "^", "\[Mu]"}], " ", 
          RowBox[{
            SubsuperscriptBox["A", "\[Mu]", "a"], "."}]}], 
        TraditionalForm]]],
  " "
}], "Text",
  CellTags->"QuantumField"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"QuantumField", "[", 
      RowBox[{"A", ",", 
        RowBox[{"{", "OPEDelta", "}"}], ",", 
        RowBox[{"{", "a", "}"}]}], "]"}]], "Input",
  CellLabel->"In[1236]:=  (21:56:09 on 5/16/01)",
  CellTags->"QuantumField"],

Cell[BoxData[
    FormBox[
      SubsuperscriptBox["A", 
        FormBox["\[CapitalDelta]",
          "TraditionalForm"], 
        FormBox[
          FormBox["a",
            "TraditionalForm"],
          "TraditionalForm"]], TraditionalForm]], "Output",
  CellLabel->"Out[1236]=  (21:56:09 on 5/16/01)"]
}, Closed]],

Cell["\<\
 The first list of indices is usually interpreted as type LorentzIndex, \
except for OPEDelta, which gets converted to type Momentum. \
\>", "Text",
  CellTags->"QuantumField"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"QuantumField", "[", 
        RowBox[{"A", ",", 
          RowBox[{"{", "OPEDelta", "}"}], ",", 
          RowBox[{"{", "a", "}"}]}], "]"}], "//", "StandardForm"}]], "Input",
  CellLabel->"In[1237]:=  (21:56:09 on 5/16/01)",
  CellTags->"QuantumField"],

Cell[BoxData[
    RowBox[{"QuantumField", "[", 
      RowBox[{"A", ",", 
        RowBox[{"Momentum", "[", "OPEDelta", "]"}], ",", 
        RowBox[{"SUNIndex", "[", "a", "]"}]}], "]"}]], "Output",
  CellLabel->"Out[1237]//StandardForm=  (21:56:09 on 5/16/01)"]
}, Closed]],

Cell["Derivatives of fields are denoted as follows.", "Text",
  CellTags->"QuantumField"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"QuantumField", "[", 
      RowBox[{
        RowBox[{"PartialD", "[", "\[Mu]", "]"}], ",", "A", ",", 
        RowBox[{"{", "\[Mu]", "}"}]}], "]"}]], "Input",
  CellLabel->"In[1238]:=  (21:56:09 on 5/16/01)",
  CellTags->"QuantumField"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["\[PartialD]", 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]], 
        SubsuperscriptBox["A", 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"], "\[Null]"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1238]=  (21:56:09 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"QuantumField", "[", 
      RowBox[{
        RowBox[{"PartialD", "[", "OPEDelta", "]"}], ",", "S"}], 
      "]"}]], "Input",
  CellLabel->"In[1239]:=  (21:56:09 on 5/16/01)",
  CellTags->"QuantumField"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["\[PartialD]", 
          FormBox["\[CapitalDelta]",
            "TraditionalForm"]], 
        SubsuperscriptBox["S", "\[Null]", "\[Null]"]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1239]=  (21:56:09 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"QuantumField", "[", 
      RowBox[{
        RowBox[{"PartialD", "[", "OPEDelta", "]"}], ",", "A", ",", 
        RowBox[{"{", "OPEDelta", "}"}], ",", 
        RowBox[{"{", "a", "}"}]}], "]"}]], "Input",
  CellLabel->"In[1240]:=  (21:56:09 on 5/16/01)",
  CellTags->"QuantumField"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          SubscriptBox["\[PartialD]", 
            FormBox["\[CapitalDelta]",
              "TraditionalForm"]],
          "TraditionalForm"], 
        SubsuperscriptBox["A", 
          FormBox["\[CapitalDelta]",
            "TraditionalForm"], 
          FormBox[
            FormBox["a",
              "TraditionalForm"],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1240]=  (21:56:09 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"QuantumField", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"PartialD", "[", "OPEDelta", "]"}], "^", "OPEm"}], ",", "A",
         ",", 
        RowBox[{"{", "OPEDelta", "}"}], ",", 
        RowBox[{"{", "a", "}"}]}], "]"}]], "Input",
  CellLabel->"In[1241]:=  (21:56:09 on 5/16/01)",
  CellTags->"QuantumField"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubsuperscriptBox["\[PartialD]", 
          FormBox["\[CapitalDelta]",
            "TraditionalForm"], 
          FormBox["m",
            "TraditionalForm"]], 
        SubsuperscriptBox["A", 
          FormBox["\[CapitalDelta]",
            "TraditionalForm"], 
          FormBox[
            FormBox["a",
              "TraditionalForm"],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1241]=  (21:56:09 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"QuantumField", "[", 
        RowBox[{"QuantumField", "[", "A", "]"}], "]"}], " ", "===", " ", 
      RowBox[{"QuantumField", "[", "A", "]"}]}]], "Input",
  CellLabel->"In[1242]:=  (21:56:09 on 5/16/01)",
  CellTags->"QuantumField"],

Cell[BoxData[
    FormBox["True", TraditionalForm]], "Output",
  CellLabel->"Out[1242]=  (21:56:09 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["QuarkField", "ObjectName",
  CellTags->"QuarkField"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"QuarkField"],

Cell["\<\
QuarkField is the name of a fermionic field. QuarkField is just a name with \
no functional properties. Only typesetting rules are attached.\
\>", "Text",
  CellTags->"QuarkField"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["AntiQuarkField",
    ButtonData:>"AntiQuarkField",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"AntiQuarkField"],
  ", ",
  ButtonBox["QuantumField",
    ButtonData:>"QuantumField",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"QuantumField"],
  "."
}], "Text",
  CellTags->"QuarkField"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"QuarkField"],

Cell[CellGroupData[{

Cell[BoxData["QuarkField"], "Input",
  CellLabel->"In[1243]:=  (21:56:09 on 5/16/01)",
  CellTags->"QuarkField"],

Cell[BoxData[
    FormBox["\[Psi]", TraditionalForm]], "Output",
  CellLabel->"Out[1243]=  (21:56:09 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["QuarkGluonVertex", "ObjectName",
  CellTags->"QuarkGluonVertex"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"QuarkGluonVertex"],

Cell[TextData[{
  "QuarkGluonVertex[",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Mu]", ",", " ", "a"}], TraditionalForm]]],
  "] gives the Feynman rule for the quark-gluon vertex. "
}], "Text",
  CellTags->"QuarkGluonVertex"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "QuarkGluonVertex", "]"}]], "Input",
  CellLabel->"In[1244]:=  (21:56:09 on 5/16/01)",
  CellTags->"QuarkGluonVertex"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"CounterTerm", "\[Rule]", "False"}], ",", 
          RowBox[{"CouplingConstant", "\[Rule]", 
            SubscriptBox["g", "s"]}], ",", 
          RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
          RowBox[{"\[CapitalKoppa]", "\[Rule]", "False"}], ",", 
          RowBox[{"Polarization", "\[Rule]", "0"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1244]=  (21:56:09 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["GluonVertex",
    ButtonData:>"GluonVertex",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"GluonVertex"],
  "."
}], "Text",
  CellTags->"QuarkGluonVertex"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"QuarkGluonVertex"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"QuarkGluonVertex", "[", 
      RowBox[{"\[Mu]", ",", "a"}], "]"}]], "Input",
  CellLabel->"In[1245]:=  (21:56:09 on 5/16/01)",
  CellTags->"QuarkGluonVertex"],

Cell[BoxData[
    FormBox[
      RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["g", "s"], " ", 
        RowBox[{
          SubscriptBox["T", 
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"]], ".", 
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1245]=  (21:56:09 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"QuarkGluonVertex", "[", 
      RowBox[{"\[Mu]", ",", "a", ",", 
        RowBox[{"CounterTerm", " ", "\[Rule]", "1"}]}], "]"}]], "Input",
  CellLabel->"In[1246]:=  (21:56:09 on 5/16/01)",
  CellTags->"QuarkGluonVertex"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", 
          RowBox[{"(", 
            RowBox[{
              SubscriptBox["C", "F"], "-", 
              FractionBox[
                SubscriptBox["C", "A"], "2"]}], ")"}], " ", 
          SubsuperscriptBox["g", "s", "3"], " ", 
          SubscriptBox["S", "n"], " ", 
          RowBox[{
            SubscriptBox["T", 
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"]]}]}], 
        TagBox["\[CurlyEpsilon]",
          TraditionalForm]], TraditionalForm]], "Output",
  CellLabel->"Out[1246]=  (21:56:09 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"QuarkGluonVertex", "[", 
      RowBox[{"\[Mu]", ",", "a", ",", 
        RowBox[{"CounterTerm", " ", "\[Rule]", "2"}]}], "]"}]], "Input",
  CellLabel->"In[1247]:=  (21:56:09 on 5/16/01)",
  CellTags->"QuarkGluonVertex"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{"3", " ", "\[ImaginaryI]", " ", 
          SubscriptBox["C", "A"], " ", 
          SubsuperscriptBox["g", "s", "3"], " ", 
          SubscriptBox["S", "n"], " ", 
          RowBox[{
            SubscriptBox["T", 
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"]]}]}], 
        TagBox["\[CurlyEpsilon]",
          TraditionalForm]], TraditionalForm]], "Output",
  CellLabel->"Out[1247]=  (21:56:09 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"QuarkGluonVertex", "[", 
      RowBox[{"\[Mu]", ",", "a", ",", 
        RowBox[{"CounterTerm", " ", "\[Rule]", "3"}]}], "]"}]], "Input",
  CellLabel->"In[1248]:=  (21:56:09 on 5/16/01)",
  CellTags->"QuarkGluonVertex"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", 
          RowBox[{"(", 
            RowBox[{
              SubscriptBox["C", "A"], "+", 
              SubscriptBox["C", "F"]}], ")"}], " ", 
          SubsuperscriptBox["g", "s", "3"], " ", 
          SubscriptBox["S", "n"], " ", 
          RowBox[{
            SubscriptBox["T", 
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"]]}]}], 
        TagBox["\[CurlyEpsilon]",
          TraditionalForm]], TraditionalForm]], "Output",
  CellLabel->"Out[1248]=  (21:56:09 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"QuarkGluonVertex", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
        RowBox[{"{", "q", "}"}], ",", 
        RowBox[{"{", "k", "}"}], ",", 
        RowBox[{"OPE", "\[Rule]", "True"}]}], "]"}]], "Input",
  CellLabel->"In[1249]:=  (21:56:10 on 5/16/01)",
  CellTags->"QuarkGluonVertex"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["g", "s"], " ", 
          RowBox[{
            SubscriptBox["T", 
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SuperscriptBox["\[Gamma]", 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"]]}]}], "+", 
        RowBox[{
          SubscriptBox["g", "s"], " ", "\[CapitalKoppa]", " ", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                FormBox["\<\"\[Gamma]\"\>",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"]}], ")"}], ".", 
            SubscriptBox["T", 
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"]]}], " ", 
          RowBox[{"(", 
            FormBox[
              TagBox[
                RowBox[{
                  UnderoverscriptBox["\[Sum]", 
                    RowBox[{"i", "=", "0"}], 
                    RowBox[{"m", "-", "2"}]], 
                  RowBox[{
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{"-", "1"}], ")"}], "i"], " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{
                          FormBox[
                            FormBox[
                              TagBox[
                                StyleBox["\<\"k\"\>",
                                  FontSlant->"Italic"],
                                (StyleForm[ #, FontSlant -> "Italic"]&)],
                              "TraditionalForm"],
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"]}], ")"}], "i"], " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["q",
                            "TraditionalForm"]}], ")"}], 
                      RowBox[{
                        RowBox[{"-", "i"}], "+", "m", "-", "2"}]]}]}],
                HoldForm],
              "TraditionalForm"], ")"}], " ", 
          SuperscriptBox[
            FormBox["\[CapitalDelta]",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1249]=  (21:56:10 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"QuarkGluonVertex", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
        RowBox[{"{", "q", "}"}], ",", 
        RowBox[{"{", "k", "}"}], ",", 
        RowBox[{"OPE", "\[Rule]", "False"}]}], "]"}]], "Input",
  CellLabel->"In[1250]:=  (21:56:10 on 5/16/01)",
  CellTags->"QuarkGluonVertex"],

Cell[BoxData[
    FormBox[
      RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["g", "s"], " ", 
        RowBox[{
          SubscriptBox["T", 
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"]], ".", 
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1250]=  (21:56:10 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["QuarkPropagator", "ObjectName",
  CellTags->"QuarkPropagator"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"QuarkPropagator"],

Cell["\<\
QuarkPropagator[p] is the massless quark propagator. QuarkPropagator[{p,m}] \
or gives the quark propagator with mass m.\
\>", "Text",
  CellTags->"QuarkPropagator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "QuarkPropagator", "]"}]], "Input",
  CellLabel->"In[1251]:=  (21:56:10 on 5/16/01)",
  CellTags->"QuarkPropagator"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"CounterTerm", "\[Rule]", "False"}], ",", 
          RowBox[{"CouplingConstant", "\[Rule]", 
            SubscriptBox["g", "s"]}], ",", 
          RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
          RowBox[{"Loop", "\[Rule]", "0"}], ",", 
          RowBox[{"\[CapitalKoppa]", "\[Rule]", "False"}], ",", 
          RowBox[{"Polarization", "\[Rule]", "0"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1251]=  (21:56:10 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["GluonPropagator",
    ButtonData:>"GluonPropagator",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"GluonPropagator"],
  ", ",
  ButtonBox["QuarkGluonVertex",
    ButtonData:>"QuarkGluonVertex",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"QuarkGluonVertex"],
  "."
}], "Text",
  CellTags->"QuarkPropagator"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"QuarkPropagator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"QuarkPropagator", "[", "p", "]"}]], "Input",
  CellLabel->"In[1252]:=  (21:56:10 on 5/16/01)",
  CellTags->"QuarkPropagator"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{
            FormBox["\<\"\[Gamma]\"\>",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["p",
              "TraditionalForm"]}]}], 
        SuperscriptBox["p", "2"]], TraditionalForm]], "Output",
  CellLabel->"Out[1252]=  (21:56:10 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"QuarkPropagator", "[", 
      RowBox[{"{", 
        RowBox[{"p", ",", "m"}], "}"}], "]"}]], "Input",
  CellLabel->"In[1253]:=  (21:56:10 on 5/16/01)",
  CellTags->"QuarkPropagator"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
            RowBox[{"m", "+", 
              RowBox[{
                FormBox["\<\"\[Gamma]\"\>",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["p",
                  "TraditionalForm"]}]}], ")"}]}], 
        RowBox[{
          SuperscriptBox["p", "2"], "-", 
          SuperscriptBox["m", "2"]}]], TraditionalForm]], "Output",
  CellLabel->"Out[1253]=  (21:56:10 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"QuarkPropagator", "[", 
      RowBox[{"p", ",", "1", ",", "2"}], "]"}]], "Input",
  CellLabel->"In[1254]:=  (21:56:10 on 5/16/01)",
  CellTags->"QuarkPropagator"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{
            FormBox["\<\"\[Gamma]\"\>",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["p",
              "TraditionalForm"]}]}], 
        SuperscriptBox["p", "2"]], TraditionalForm]], "Output",
  CellLabel->"Out[1254]=  (21:56:10 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["RightPartialD", "ObjectName",
  CellTags->"RightPartialD"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"RightPartialD"],

Cell[TextData[{
  "RightPartialD[",
  Cell[BoxData[
      FormBox["\[Mu]", TraditionalForm]]],
  "] denotes ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["\[PartialD]", "\[Mu]"], TraditionalForm]]],
  ", acting to the right."
}], "Text",
  CellTags->"RightPartialD"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["ExpandPartialD",
    ButtonData:>"ExpandPartialD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"ExpandPartialD"],
  ", ",
  ButtonBox["PartialD",
    ButtonData:>"PartialD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"PartialD"],
  ", ",
  ButtonBox["LeftPartialD",
    ButtonData:>"LeftPartialD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"LeftPartialD"],
  "."
}], "Text",
  CellTags->"RightPartialD"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"RightPartialD"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"RightPartialD", "[", "\[Mu]", "]"}]], "Input",
  CellLabel->"In[1255]:=  (21:56:10 on 5/16/01)",
  CellTags->"RightPartialD"],

Cell[BoxData[
    FormBox[
      SubscriptBox[
        OverscriptBox["\[PartialD]", "\[RightArrow]"], 
        FormBox[
          FormBox["\[Mu]",
            "TraditionalForm"],
          "TraditionalForm"]], TraditionalForm]], "Output",
  CellLabel->"Out[1255]=  (21:56:10 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"RightPartialD", "[", "\[Mu]", "]"}], ".", 
      RowBox[{"QuantumField", "[", 
        RowBox[{"A", ",", 
          RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}]}], "]"}]}]], "Input",
  CellLabel->"In[1256]:=  (21:56:10 on 5/16/01)",
  CellTags->"RightPartialD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox[
          OverscriptBox["\[PartialD]", "\[RightArrow]"], 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        SubscriptBox["A", "\[Mu]"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1256]=  (21:56:10 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ExpandPartialD", "[", "%", "]"}]], "Input",
  CellLabel->"In[1257]:=  (21:56:10 on 5/16/01)",
  CellTags->"RightPartialD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["\[PartialD]", 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]], 
        SubsuperscriptBox["A", 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"], "\[Null]"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1257]=  (21:56:10 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "StandardForm"}]], "Input",
  CellLabel->"In[1258]:=  (21:56:10 on 5/16/01)",
  CellTags->"RightPartialD"],

Cell[BoxData[
    RowBox[{"QuantumField", "[", 
      RowBox[{
        RowBox[{"PartialD", "[", 
          RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], "]"}], ",", "A", ",", 
        RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}]}], "]"}]], "Output",
  CellLabel->"Out[1258]//StandardForm=  (21:56:10 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"RightPartialD", "[", "\[Mu]", "]"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[1259]:=  (21:56:10 on 5/16/01)",
  CellTags->"RightPartialD"],

Cell[BoxData[
    RowBox[{"RightPartialD", "[", 
      RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], "]"}]], "Output",
  CellLabel->"Out[1259]//StandardForm=  (21:56:10 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["RussianTrick", "ObjectName",
  CellTags->"RussianTrick"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"RussianTrick"],

Cell["\<\
RussianTrick[exp, k, {q1,q2,p}] (=RussianTrick[exp,p,p,{q1,q2,p}]) does the \
integration by parts where p is the external momentum. RussianTrick[exp, k,l, \
{q1,q2,p}] (=RussianTrick[exp,k,l]) does integration by parts where l is the \
momentum to be differentiated.\
\>", "Text",
  CellTags->"RussianTrick"],

Cell["The result is an expression which is vanishing.", "Text",
  CellTags->"RussianTrick"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["FourDivergence",
    ButtonData:>"FourDivergence",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FourDivergence"],
  ", ",
  ButtonBox["FourLaplacian",
    ButtonData:>"FourLaplacian",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FourLaplacian"],
  "."
}], "Text",
  CellTags->"RussianTrick"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"RussianTrick"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t", "=", 
      RowBox[{"RHI", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{
            "OPEm", ",", "0", ",", " ", "0", ",", "0", ",", " ", "0"}], "}"}],
           ",", " ", 
          RowBox[{"{", 
            RowBox[{
            "1", ",", " ", "1", ",", " ", "1", ",", " ", "1", ",", " ", "1"}],
             "}"}]}], "]"}]}]], "Input",
  CellLabel->"In[1260]:=  (21:56:10 on 5/16/01)",
  CellTags->"RussianTrick"],

Cell[BoxData[
    FormBox[
      SubsuperscriptBox[
        StyleBox["T",
          FontFamily->"Times",
          FontWeight->"Bold"], 
        StyleBox[
          RowBox[{"1", "1", "1", "1", "1"}],
          FontColor->RGBColor[0, 0, 1]], 
        RowBox[{
          FormBox["m",
            "TraditionalForm"], 
          FormBox["0",
            "TraditionalForm"], 
          FormBox["0",
            "TraditionalForm"], 
          FormBox["0",
            "TraditionalForm"], 
          FormBox["0",
            "TraditionalForm"]}]], TraditionalForm]], "Output",
  CellLabel->"Out[1260]=  (21:56:10 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t", "//", "RHI2FC"}]], "Input",
  CellLabel->"In[1261]:=  (21:56:10 on 5/16/01)",
  CellTags->"RussianTrick"],

Cell[BoxData[
    FormBox[
      FractionBox[
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              FormBox["\[CapitalDelta]",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox[
                SubscriptBox[
                  StyleBox["\<\"q\"\>",
                    FontSlant->"Italic"], "1"],
                "TraditionalForm"]}], ")"}], "m"], 
        RowBox[{
          SubsuperscriptBox[
            StyleBox["\<\"q\"\>",
              FontSlant->"Italic"], "1", "2"], ".", 
          SubsuperscriptBox[
            StyleBox["\<\"q\"\>",
              FontSlant->"Italic"], "2", "2"], ".", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                SubscriptBox[
                  StyleBox["\<\"q\"\>",
                    FontSlant->"Italic"], "1"], "-", "p"}], ")"}], "2"], ".", 
          
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                SubscriptBox[
                  StyleBox["\<\"q\"\>",
                    FontSlant->"Italic"], "2"], "-", "p"}], ")"}], "2"], ".", 
          
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                SubscriptBox[
                  StyleBox["\<\"q\"\>",
                    FontSlant->"Italic"], "1"], "-", 
                SubscriptBox[
                  StyleBox["\<\"q\"\>",
                    FontSlant->"Italic"], "2"]}], ")"}], "2"]}]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1261]=  (21:56:10 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"RussianTrick", "[", 
      RowBox[{
        RowBox[{"%", "//", "RHI2FC"}], ",", "q2"}], "]"}]], "Input",
  CellLabel->"In[1262]:=  (21:56:10 on 5/16/01)",
  CellTags->"RussianTrick"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          FractionBox[
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox[
                    SubscriptBox[
                      StyleBox["\<\"q\"\>",
                        FontSlant->"Italic"], "1"],
                    "TraditionalForm"]}], ")"}], "m"], 
            RowBox[{
              SubsuperscriptBox[
                StyleBox["\<\"q\"\>",
                  FontSlant->"Italic"], "1", "2"], ".", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["\<\"q\"\>",
                        FontSlant->"Italic"], "1"], "-", "p"}], ")"}], "2"], 
              ".", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["\<\"q\"\>",
                        FontSlant->"Italic"], "2"], "-", "p"}], ")"}], "2"], 
              ".", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["\<\"q\"\>",
                        FontSlant->"Italic"], "2"], "-", 
                    SubscriptBox[
                      StyleBox["\<\"q\"\>",
                        FontSlant->"Italic"], "1"]}], ")"}], "2"], ".", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["\<\"q\"\>",
                        FontSlant->"Italic"], "2"], "-", 
                    SubscriptBox[
                      StyleBox["\<\"q\"\>",
                        FontSlant->"Italic"], "1"]}], ")"}], "2"]}]]}], "-", 
        FractionBox[
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox[
                  SubscriptBox[
                    StyleBox["\<\"q\"\>",
                      FontSlant->"Italic"], "1"],
                  "TraditionalForm"]}], ")"}], "m"], 
          RowBox[{
            SubsuperscriptBox[
              StyleBox["\<\"q\"\>",
                FontSlant->"Italic"], "1", "2"], ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  SubscriptBox[
                    StyleBox["\<\"q\"\>",
                      FontSlant->"Italic"], "1"], "-", "p"}], ")"}], "2"], 
            ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  SubscriptBox[
                    StyleBox["\<\"q\"\>",
                      FontSlant->"Italic"], "2"], "-", 
                  SubscriptBox[
                    StyleBox["\<\"q\"\>",
                      FontSlant->"Italic"], "1"]}], ")"}], "2"], ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  SubscriptBox[
                    StyleBox["\<\"q\"\>",
                      FontSlant->"Italic"], "2"], "-", "p"}], ")"}], "2"], 
            ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  SubscriptBox[
                    StyleBox["\<\"q\"\>",
                      FontSlant->"Italic"], "2"], "-", "p"}], ")"}], "2"]}]], 
        "-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"4", "-", "D"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox[
                    SubscriptBox[
                      StyleBox["\<\"q\"\>",
                        FontSlant->"Italic"], "1"],
                    "TraditionalForm"]}], ")"}], "m"]}], 
          RowBox[{
            SubsuperscriptBox[
              StyleBox["\<\"q\"\>",
                FontSlant->"Italic"], "1", "2"], ".", 
            SubsuperscriptBox[
              StyleBox["\<\"q\"\>",
                FontSlant->"Italic"], "2", "2"], ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  SubscriptBox[
                    StyleBox["\<\"q\"\>",
                      FontSlant->"Italic"], "1"], "-", "p"}], ")"}], "2"], 
            ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  SubscriptBox[
                    StyleBox["\<\"q\"\>",
                      FontSlant->"Italic"], "2"], "-", 
                  SubscriptBox[
                    StyleBox["\<\"q\"\>",
                      FontSlant->"Italic"], "1"]}], ")"}], "2"], ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  SubscriptBox[
                    StyleBox["\<\"q\"\>",
                      FontSlant->"Italic"], "2"], "-", "p"}], ")"}], "2"]}]], 
        "+", 
        FractionBox[
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox[
                  SubscriptBox[
                    StyleBox["\<\"q\"\>",
                      FontSlant->"Italic"], "1"],
                  "TraditionalForm"]}], ")"}], "m"], 
          RowBox[{
            SubsuperscriptBox[
              StyleBox["\<\"q\"\>",
                FontSlant->"Italic"], "2", "2"], ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  SubscriptBox[
                    StyleBox["\<\"q\"\>",
                      FontSlant->"Italic"], "1"], "-", "p"}], ")"}], "2"], 
            ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  SubscriptBox[
                    StyleBox["\<\"q\"\>",
                      FontSlant->"Italic"], "2"], "-", "p"}], ")"}], "2"], 
            ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  SubscriptBox[
                    StyleBox["\<\"q\"\>",
                      FontSlant->"Italic"], "2"], "-", 
                  SubscriptBox[
                    StyleBox["\<\"q\"\>",
                      FontSlant->"Italic"], "1"]}], ")"}], "2"], ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  SubscriptBox[
                    StyleBox["\<\"q\"\>",
                      FontSlant->"Italic"], "2"], "-", 
                  SubscriptBox[
                    StyleBox["\<\"q\"\>",
                      FontSlant->"Italic"], "1"]}], ")"}], "2"]}]], "+", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox[
                    SubscriptBox[
                      StyleBox["\<\"q\"\>",
                        FontSlant->"Italic"], "1"],
                    "TraditionalForm"]}], ")"}], "m"], " ", 
            SuperscriptBox[
              FormBox["p",
                "TraditionalForm"], "2"]}], 
          RowBox[{
            SubsuperscriptBox[
              StyleBox["\<\"q\"\>",
                FontSlant->"Italic"], "2", "2"], ".", 
            SubsuperscriptBox[
              StyleBox["\<\"q\"\>",
                FontSlant->"Italic"], "1", "2"], ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  SubscriptBox[
                    StyleBox["\<\"q\"\>",
                      FontSlant->"Italic"], "2"], "-", 
                  SubscriptBox[
                    StyleBox["\<\"q\"\>",
                      FontSlant->"Italic"], "1"]}], ")"}], "2"], ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  SubscriptBox[
                    StyleBox["\<\"q\"\>",
                      FontSlant->"Italic"], "1"], "-", "p"}], ")"}], "2"], 
            ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  SubscriptBox[
                    StyleBox["\<\"q\"\>",
                      FontSlant->"Italic"], "2"], "-", "p"}], ")"}], "2"], 
            ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  SubscriptBox[
                    StyleBox["\<\"q\"\>",
                      FontSlant->"Italic"], "2"], "-", "p"}], ")"}], 
              "2"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1262]=  (21:56:12 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FC2RHI", "[", "%", "]"}]], "Input",
  CellLabel->"In[1263]:=  (21:56:12 on 5/16/01)",
  CellTags->"RussianTrick"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          SubsuperscriptBox[
            StyleBox["T",
              FontFamily->"Times",
              FontWeight->"Bold"], 
            StyleBox[
              RowBox[{"0", "1", "1", "1", "2"}],
              FontColor->RGBColor[0, 0, 1]], 
            RowBox[{
              FormBox["m",
                "TraditionalForm"], 
              FormBox["0",
                "TraditionalForm"], 
              FormBox["0",
                "TraditionalForm"], 
              FormBox["0",
                "TraditionalForm"], 
              FormBox["0",
                "TraditionalForm"]}]],
          "TraditionalForm"], "-", 
        FormBox[
          SubsuperscriptBox[
            StyleBox["T",
              FontFamily->"Times",
              FontWeight->"Bold"], 
            StyleBox[
              RowBox[{"1", "0", "1", "1", "2"}],
              FontColor->RGBColor[0, 0, 1]], 
            RowBox[{
              FormBox["m",
                "TraditionalForm"], 
              FormBox["0",
                "TraditionalForm"], 
              FormBox["0",
                "TraditionalForm"], 
              FormBox["0",
                "TraditionalForm"], 
              FormBox["0",
                "TraditionalForm"]}]],
          "TraditionalForm"], "-", 
        FormBox[
          SubsuperscriptBox[
            StyleBox["T",
              FontFamily->"Times",
              FontWeight->"Bold"], 
            StyleBox[
              RowBox[{"1", "0", "1", "2", "1"}],
              FontColor->RGBColor[0, 0, 1]], 
            RowBox[{
              FormBox["m",
                "TraditionalForm"], 
              FormBox["0",
                "TraditionalForm"], 
              FormBox["0",
                "TraditionalForm"], 
              FormBox["0",
                "TraditionalForm"], 
              FormBox["0",
                "TraditionalForm"]}]],
          "TraditionalForm"], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"D", "-", "4"}], ")"}], " ", 
          FormBox[
            SubsuperscriptBox[
              StyleBox["T",
                FontFamily->"Times",
                FontWeight->"Bold"], 
              StyleBox[
                RowBox[{"1", "1", "1", "1", "1"}],
                FontColor->RGBColor[0, 0, 1]], 
              RowBox[{
                FormBox["m",
                  "TraditionalForm"], 
                FormBox["0",
                  "TraditionalForm"], 
                FormBox["0",
                  "TraditionalForm"], 
                FormBox["0",
                  "TraditionalForm"], 
                FormBox["0",
                  "TraditionalForm"]}]],
            "TraditionalForm"]}], "+", 
        RowBox[{
          SuperscriptBox[
            FormBox["p",
              "TraditionalForm"], "2"], " ", 
          FormBox[
            SubsuperscriptBox[
              StyleBox["T",
                FontFamily->"Times",
                FontWeight->"Bold"], 
              StyleBox[
                RowBox[{"1", "1", "1", "2", "1"}],
                FontColor->RGBColor[0, 0, 1]], 
              RowBox[{
                FormBox["m",
                  "TraditionalForm"], 
                FormBox["0",
                  "TraditionalForm"], 
                FormBox["0",
                  "TraditionalForm"], 
                FormBox["0",
                  "TraditionalForm"], 
                FormBox["0",
                  "TraditionalForm"]}]],
            "TraditionalForm"]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1263]=  (21:56:13 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Solve2", "[", 
      RowBox[{"%", ",", "t"}], "]"}]], "Input",
  CellLabel->"In[1264]:=  (21:56:13 on 5/16/01)",
  CellTags->"RussianTrick"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          FormBox[
            SubsuperscriptBox[
              StyleBox["T",
                FontFamily->"Times",
                FontWeight->"Bold"], 
              StyleBox[
                RowBox[{"1", "1", "1", "1", "1"}],
                FontColor->RGBColor[0, 0, 1]], 
              RowBox[{
                FormBox["m",
                  "TraditionalForm"], 
                FormBox["0",
                  "TraditionalForm"], 
                FormBox["0",
                  "TraditionalForm"], 
                FormBox["0",
                  "TraditionalForm"], 
                FormBox["0",
                  "TraditionalForm"]}]],
            "TraditionalForm"], "\[Rule]", 
          FractionBox[
            RowBox[{
              FormBox[
                SubsuperscriptBox[
                  StyleBox["T",
                    FontFamily->"Times",
                    FontWeight->"Bold"], 
                  StyleBox[
                    RowBox[{"0", "1", "1", "1", "2"}],
                    FontColor->RGBColor[0, 0, 1]], 
                  RowBox[{
                    FormBox["m",
                      "TraditionalForm"], 
                    FormBox["0",
                      "TraditionalForm"], 
                    FormBox["0",
                      "TraditionalForm"], 
                    FormBox["0",
                      "TraditionalForm"], 
                    FormBox["0",
                      "TraditionalForm"]}]],
                "TraditionalForm"], "-", 
              FormBox[
                SubsuperscriptBox[
                  StyleBox["T",
                    FontFamily->"Times",
                    FontWeight->"Bold"], 
                  StyleBox[
                    RowBox[{"1", "0", "1", "1", "2"}],
                    FontColor->RGBColor[0, 0, 1]], 
                  RowBox[{
                    FormBox["m",
                      "TraditionalForm"], 
                    FormBox["0",
                      "TraditionalForm"], 
                    FormBox["0",
                      "TraditionalForm"], 
                    FormBox["0",
                      "TraditionalForm"], 
                    FormBox["0",
                      "TraditionalForm"]}]],
                "TraditionalForm"], "-", 
              FormBox[
                SubsuperscriptBox[
                  StyleBox["T",
                    FontFamily->"Times",
                    FontWeight->"Bold"], 
                  StyleBox[
                    RowBox[{"1", "0", "1", "2", "1"}],
                    FontColor->RGBColor[0, 0, 1]], 
                  RowBox[{
                    FormBox["m",
                      "TraditionalForm"], 
                    FormBox["0",
                      "TraditionalForm"], 
                    FormBox["0",
                      "TraditionalForm"], 
                    FormBox["0",
                      "TraditionalForm"], 
                    FormBox["0",
                      "TraditionalForm"]}]],
                "TraditionalForm"], "+", 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], " ", 
                FormBox[
                  SubsuperscriptBox[
                    StyleBox["T",
                      FontFamily->"Times",
                      FontWeight->"Bold"], 
                    StyleBox[
                      RowBox[{"1", "1", "1", "2", "1"}],
                      FontColor->RGBColor[0, 0, 1]], 
                    RowBox[{
                      FormBox["m",
                        "TraditionalForm"], 
                      FormBox["0",
                        "TraditionalForm"], 
                      FormBox["0",
                        "TraditionalForm"], 
                      FormBox["0",
                        "TraditionalForm"], 
                      FormBox["0",
                        "TraditionalForm"]}]],
                  "TraditionalForm"]}]}], 
            RowBox[{"4", "-", "D"}]]}], "}"}], TraditionalForm]], "Output",
  CellLabel->"Out[1264]=  (21:56:13 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{"Clear", "[", "t", "]"}]], "Input",
  CellLabel->"In[1265]:=  (21:56:13 on 5/16/01)",
  CellTags->"RussianTrick"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["ScalarProduct", "ObjectName",
  CellTags->"ScalarProduct"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"ScalarProduct"],

Cell[TextData[{
  "ScalarProduct[p, q] is the input for scalar product. ScalarProduct[p] is \
equivalent to ScalarProduct[p, p]. Expansion of sums of momenta in \
ScalarProduct is done with ExpandScalarProduct. Scalar product may be set, \
e.g., ScalarProduct[a, b] = ",
  Cell[BoxData[
      FormBox[
        RowBox[{"m", "^", "2"}], TraditionalForm]]],
  "; but a and b must not contain sums. Note that ScalarProduct[a, b] = ",
  Cell[BoxData[
      FormBox[
        RowBox[{"m", "^", "2"}], TraditionalForm]]],
  " actually sets also: Pair[Momentum[a, ___], Momentum[b, ___]] = ",
  Cell[BoxData[
      FormBox[
        RowBox[{"m", "^", "2"}], TraditionalForm]]],
  ". It is encouraged to always set ScalarProduct's ",
  StyleBox["before",
    FontWeight->"Bold"],
  " any calculation. This improves the performance of FeynCalc ."
}], "Text",
  CellTags->"ScalarProduct"],

Cell[TextData[{
  "See also: ",
  ButtonBox["Calc",
    ButtonData:>"Calc",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Calc"],
  ", ",
  ButtonBox["ClearScalarProducts",
    ButtonData:>"ClearScalarProducts",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"ClearScalarProducts"],
  ", ",
  ButtonBox["ExpandScalarProduct",
    ButtonData:>"ExpandScalarProduct",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"ExpandScalarProduct"],
  ", ",
  ButtonBox["Pair",
    ButtonData:>"Pair",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Pair"],
  ", ",
  ButtonBox["SP",
    ButtonData:>"SP",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SP"],
  ", ",
  ButtonBox["SPD",
    ButtonData:>"SPD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SPD"],
  "."
}], "Text",
  CellTags->"ScalarProduct"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"ScalarProduct"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ScalarProduct", "[", 
      RowBox[{"p", ",", "q"}], "]"}]], "Input",
  CellLabel->"In[1266]:=  (21:56:13 on 5/16/01)",
  CellTags->"ScalarProduct"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox["p",
          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
        FormBox["q",
          "TraditionalForm"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1266]=  (21:56:13 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ScalarProduct", "[", 
      RowBox[{
        RowBox[{"p", "+", "q"}], ",", 
        RowBox[{"-", "q"}]}], "]"}]], "Input",
  CellLabel->"In[1267]:=  (21:56:13 on 5/16/01)",
  CellTags->"ScalarProduct"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        RowBox[{"(", 
          RowBox[{
            FormBox["q",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            "(", "\[NoBreak]", 
            FormBox[
              RowBox[{"p", "+", "q"}],
              "TraditionalForm"], "\[NoBreak]", ")"}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1267]=  (21:56:13 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ScalarProduct", "[", 
      RowBox[{"p", ",", "p"}], "]"}]], "Input",
  CellLabel->"In[1268]:=  (21:56:13 on 5/16/01)",
  CellTags->"ScalarProduct"],

Cell[BoxData[
    FormBox[
      SuperscriptBox[
        FormBox["p",
          "TraditionalForm"], "2"], TraditionalForm]], "Output",
  CellLabel->"Out[1268]=  (21:56:13 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ScalarProduct", "[", "q", "]"}]], "Input",
  CellLabel->"In[1269]:=  (21:56:13 on 5/16/01)",
  CellTags->"ScalarProduct"],

Cell[BoxData[
    FormBox[
      SuperscriptBox[
        FormBox["q",
          "TraditionalForm"], "2"], TraditionalForm]], "Output",
  CellLabel->"Out[1269]=  (21:56:13 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"ScalarProduct", "[", 
        RowBox[{"p", ",", "q"}], "]"}], "//", "StandardForm"}]], "Input",
  CellLabel->"In[1270]:=  (21:56:13 on 5/16/01)",
  CellTags->"ScalarProduct"],

Cell[BoxData[
    RowBox[{"Pair", "[", 
      RowBox[{
        RowBox[{"Momentum", "[", "p", "]"}], ",", 
        RowBox[{"Momentum", "[", "q", "]"}]}], "]"}]], "Output",
  CellLabel->"Out[1270]//StandardForm=  (21:56:13 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"ScalarProduct", "[", 
        RowBox[{"p", ",", "q", ",", 
          RowBox[{"Dimension", "\[Rule]", "D"}]}], "]"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[1271]:=  (21:56:13 on 5/16/01)",
  CellTags->"ScalarProduct"],

Cell[BoxData[
    RowBox[{"Pair", "[", 
      RowBox[{
        RowBox[{"Momentum", "[", 
          RowBox[{"p", ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
          RowBox[{"q", ",", "D"}], "]"}]}], "]"}]], "Output",
  CellLabel->"Out[1271]//StandardForm=  (21:56:13 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"ScalarProduct", "[", 
        RowBox[{
          SubscriptBox["p", "1"], ",", 
          SubscriptBox["p", "2"]}], "]"}], " ", "=", " ", 
      RowBox[{"s", "/", "2"}]}]], "Input",
  CellLabel->"In[1272]:=  (21:56:13 on 5/16/01)",
  CellTags->"ScalarProduct"],

Cell[BoxData[
    FormBox[
      FractionBox["s", "2"], TraditionalForm]], "Output",
  CellLabel->"Out[1272]=  (21:56:13 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ExpandScalarProduct", "[", " ", 
      RowBox[{"ScalarProduct", "[", 
        RowBox[{
          RowBox[{
            SubscriptBox["p", "1"], "-", "q"}], ",", 
          RowBox[{
            SubscriptBox["p", "2"], "-", "k"}]}], "]"}], "]"}]], "Input",
  CellLabel->"In[1273]:=  (21:56:13 on 5/16/01)",
  CellTags->"ScalarProduct"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox["s", "2"], "+", 
        RowBox[{
          FormBox[
            FormBox[
              TagBox[
                StyleBox["\<\"k\"\>",
                  FontSlant->"Italic"],
                (StyleForm[ #, FontSlant -> "Italic"]&)],
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
          FormBox["q",
            "TraditionalForm"]}], "-", 
        RowBox[{
          FormBox[
            FormBox[
              TagBox[
                StyleBox["\<\"k\"\>",
                  FontSlant->"Italic"],
                (StyleForm[ #, FontSlant -> "Italic"]&)],
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
          FormBox[
            SubscriptBox["p", "1"],
            "TraditionalForm"]}], "-", 
        RowBox[{
          FormBox["q",
            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
          FormBox[
            SubscriptBox["p", "2"],
            "TraditionalForm"]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1273]=  (21:56:13 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Calc", "[", " ", 
      RowBox[{"ScalarProduct", "[", 
        RowBox[{
          RowBox[{
            SubscriptBox["p", "1"], "-", "q"}], ",", 
          RowBox[{
            SubscriptBox["p", "2"], "-", "k"}]}], "]"}], "]"}]], "Input",
  CellLabel->"In[1274]:=  (21:56:13 on 5/16/01)",
  CellTags->"ScalarProduct"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox["s", "2"], "+", 
        RowBox[{
          FormBox[
            FormBox[
              TagBox[
                StyleBox["\<\"k\"\>",
                  FontSlant->"Italic"],
                (StyleForm[ #, FontSlant -> "Italic"]&)],
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
          FormBox["q",
            "TraditionalForm"]}], "-", 
        RowBox[{
          FormBox[
            FormBox[
              TagBox[
                StyleBox["\<\"k\"\>",
                  FontSlant->"Italic"],
                (StyleForm[ #, FontSlant -> "Italic"]&)],
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
          FormBox[
            SubscriptBox["p", "1"],
            "TraditionalForm"]}], "-", 
        RowBox[{
          FormBox["q",
            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
          FormBox[
            SubscriptBox["p", "2"],
            "TraditionalForm"]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1274]=  (21:56:13 on 5/16/01)"]
}, Closed]],

Cell[BoxData["ClearScalarProducts"], "Input",
  CellLabel->"In[1275]:=  (21:56:13 on 5/16/01)",
  CellTags->"ScalarProduct"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["ScalarProductCancel", "ObjectName",
  CellTags->"ScalarProductCancel"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"ScalarProductCancel"],

Cell["\<\
ScalarProductCancel[exp, q1, q2, ...] cancels scalar products with \
propagators. ScalarProductCancel[exp] cancels simple cases.\
\>", "Text",
  CellTags->"ScalarProductCancel"],

Cell[CellGroupData[{

Cell[BoxData["SPC"], "Input",
  CellLabel->"In[1276]:=  (21:56:13 on 5/16/01)",
  CellTags->"ScalarProductCancel"],

Cell[BoxData[
    FormBox["ScalarProductCancel", TraditionalForm]], "Output",
  CellLabel->"Out[1276]=  (21:56:13 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ScalarProductCancel", "//", "Options"}]], "Input",
  CellLabel->"In[1277]:=  (21:56:14 on 5/16/01)",
  CellTags->"ScalarProductCancel"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"ChangeDimension", "\[Rule]", "D"}], ",", 
          RowBox[{"Collecting", "\[Rule]", "True"}], ",", 
          RowBox[{"FeynAmpDenominatorSimplify", "\[Rule]", "False"}], ",", 
          RowBox[{"FeynAmpDenominatorCombine", "\[Rule]", "True"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1277]=  (21:56:14 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"?", "SPC"}]], "Input",
  CellLabel->"In[1278]:=  (21:56:14 on 5/16/01)",
  CellTags->"ScalarProductCancel"],

Cell[BoxData[
    FormBox["\<\"SPC is an abbreviation for ScalarProductCancel.\"\>", 
      TraditionalForm]], "Print"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"ScalarProductCancel"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["FeynAmpDenominatorSimplify",
    ButtonData:>"FeynAmpDenominatorSimplify",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FeynAmpDenominatorSimplify"],
  "."
}], "Text",
  CellTags->"ScalarProductCancel"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t1", " ", "=", " ", 
      RowBox[{
        RowBox[{
          RowBox[{"SPD", "[", 
            RowBox[{"q", ",", "p"}], "]"}], " ", 
          RowBox[{"FAD", "[", 
            RowBox[{
              RowBox[{"{", 
                RowBox[{"q", ",", "m"}], "}"}], ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"q", "-", "p"}], ",", "0"}], "}"}]}], "]"}]}], "//",
         "FCI"}]}]], "Input",
  CellLabel->"In[1279]:=  (21:56:14 on 5/16/01)",
  CellTags->"ScalarProductCancel"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{
          FormBox["p",
            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
          FormBox["q",
            "TraditionalForm"]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox["q", "2"], "-", 
              SuperscriptBox["m", "2"]}], ")"}], ".", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"q", "-", "p"}], ")"}], "2"]}]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1279]=  (21:56:14 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ScalarProductCancel", "[", 
      RowBox[{"t1", ",", "q"}], "]"}]], "Input",
  CellLabel->"In[1280]:=  (21:56:14 on 5/16/01)",
  CellTags->"ScalarProductCancel"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          FractionBox["1", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox["q", "2"], "-", 
                  SuperscriptBox["m", "2"]}], ")"}]}]]}], "+", 
        FractionBox["1", 
          RowBox[{"2", " ", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"q", "-", "p"}], ")"}], "2"]}]], "+", 
        FractionBox[
          RowBox[{
            FractionBox[
              SuperscriptBox["m", "2"], "2"], "+", 
            FractionBox[
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"], "2"]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox["q", "2"], "-", 
                SuperscriptBox["m", "2"]}], ")"}], ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"q", "-", "p"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1280]=  (21:56:14 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FeynAmpDenominatorSimplify", "[", 
      RowBox[{"%", ",", "q"}], "]"}]], "Input",
  CellLabel->"In[1281]:=  (21:56:14 on 5/16/01)",
  CellTags->"ScalarProductCancel"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{
            FractionBox[
              SuperscriptBox["m", "2"], "2"], "+", 
            FractionBox[
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"], "2"]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox["q", "2"], "-", 
                SuperscriptBox["m", "2"]}], ")"}], ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"q", "-", "p"}], ")"}], "2"]}]], "-", 
        FractionBox["1", 
          RowBox[{"2", " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox["q", "2"], "-", 
                SuperscriptBox["m", "2"]}], ")"}]}]]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1281]=  (21:56:14 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SPC", "[", 
      RowBox[{"t1", ",", "q", ",", 
        RowBox[{"FDS", "->", "True"}]}], "]"}]], "Input",
  CellLabel->"In[1282]:=  (21:56:14 on 5/16/01)",
  CellTags->"ScalarProductCancel"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{
            FractionBox[
              SuperscriptBox["m", "2"], "2"], "+", 
            FractionBox[
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"], "2"]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox["q", "2"], "-", 
                SuperscriptBox["m", "2"]}], ")"}], ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"q", "-", "p"}], ")"}], "2"]}]], "-", 
        FractionBox["1", 
          RowBox[{"2", " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox["q", "2"], "-", 
                SuperscriptBox["m", "2"]}], ")"}]}]]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1282]=  (21:56:14 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t2", " ", "=", " ", 
      RowBox[{
        RowBox[{
          RowBox[{"SPD", "[", 
            RowBox[{"q2", ",", "p"}], "]"}], 
          RowBox[{"SPD", "[", 
            RowBox[{"q1", ",", "p"}], "]"}], " ", 
          RowBox[{"FAD", "[", 
            RowBox[{
              RowBox[{"{", 
                RowBox[{"q1", ",", "m"}], "}"}], ",", 
              RowBox[{"{", 
                RowBox[{"q2", ",", "m"}], "}"}], ",", 
              RowBox[{"q1", "-", "p"}], ",", 
              RowBox[{"q2", "-", "p"}], ",", 
              RowBox[{"q2", "-", "q1"}]}], "]"}]}], "//", "FCI"}]}]], "Input",\

  CellLabel->"In[1283]:=  (21:56:14 on 5/16/01)",
  CellTags->"ScalarProductCancel"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{
          RowBox[{
            FormBox["p",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox[
              SubscriptBox[
                StyleBox["\<\"q\"\>",
                  FontSlant->"Italic"], "1"],
              "TraditionalForm"]}], " ", 
          RowBox[{
            FormBox["p",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox[
              SubscriptBox[
                StyleBox["\<\"q\"\>",
                  FontSlant->"Italic"], "2"],
              "TraditionalForm"]}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              SubsuperscriptBox[
                StyleBox["\<\"q\"\>",
                  FontSlant->"Italic"], "1", "2"], "-", 
              SuperscriptBox["m", "2"]}], ")"}], ".", 
          RowBox[{"(", 
            RowBox[{
              SubsuperscriptBox[
                StyleBox["\<\"q\"\>",
                  FontSlant->"Italic"], "2", "2"], "-", 
              SuperscriptBox["m", "2"]}], ")"}], ".", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                SubscriptBox[
                  StyleBox["\<\"q\"\>",
                    FontSlant->"Italic"], "1"], "-", "p"}], ")"}], "2"], ".", 
          
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                SubscriptBox[
                  StyleBox["\<\"q\"\>",
                    FontSlant->"Italic"], "2"], "-", "p"}], ")"}], "2"], ".", 
          
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                SubscriptBox[
                  StyleBox["\<\"q\"\>",
                    FontSlant->"Italic"], "2"], "-", 
                SubscriptBox[
                  StyleBox["\<\"q\"\>",
                    FontSlant->"Italic"], "1"]}], ")"}], "2"]}]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1283]=  (21:56:14 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SPC", "[", 
      RowBox[{"t2", ",", "q1", ",", "q2", ",", 
        RowBox[{"FDS", "\[Rule]", "True"}]}], "]"}]], "Input",
  CellLabel->"In[1284]:=  (21:56:14 on 5/16/01)",
  CellTags->"ScalarProductCancel"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox["1", 
          RowBox[{"4", " ", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SubsuperscriptBox[
                    StyleBox["\<\"q\"\>",
                      FontSlant->"Italic"], "1", "2"], "-", 
                  SuperscriptBox["m", "2"]}], ")"}], ".", 
              RowBox[{"(", 
                RowBox[{
                  SubsuperscriptBox[
                    StyleBox["\<\"q\"\>",
                      FontSlant->"Italic"], "2", "2"], "-", 
                  SuperscriptBox["m", "2"]}], ")"}], ".", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["\<\"q\"\>",
                        FontSlant->"Italic"], "2"], "-", 
                    SubscriptBox[
                      StyleBox["\<\"q\"\>",
                        FontSlant->"Italic"], "1"]}], ")"}], "2"]}]}]], "-", 
        FractionBox["1", 
          RowBox[{"2", " ", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SubsuperscriptBox[
                    StyleBox["\<\"q\"\>",
                      FontSlant->"Italic"], "1", "2"], "-", 
                  SuperscriptBox["m", "2"]}], ")"}], ".", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["\<\"q\"\>",
                        FontSlant->"Italic"], "2"], "-", "p"}], ")"}], "2"], 
              ".", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["\<\"q\"\>",
                        FontSlant->"Italic"], "2"], "-", 
                    SubscriptBox[
                      StyleBox["\<\"q\"\>",
                        FontSlant->"Italic"], "1"]}], ")"}], "2"]}]}]], "+", 
        FractionBox[
          RowBox[{
            RowBox[{"-", 
              FractionBox[
                SuperscriptBox["m", "2"], "2"]}], "-", 
            FractionBox[
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"], "2"]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SubsuperscriptBox[
                  StyleBox["\<\"q\"\>",
                    FontSlant->"Italic"], "1", "2"], "-", 
                SuperscriptBox["m", "2"]}], ")"}], ".", 
            RowBox[{"(", 
              RowBox[{
                SubsuperscriptBox[
                  StyleBox["\<\"q\"\>",
                    FontSlant->"Italic"], "2", "2"], "-", 
                SuperscriptBox["m", "2"]}], ")"}], ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  SubscriptBox[
                    StyleBox["\<\"q\"\>",
                      FontSlant->"Italic"], "1"], "-", "p"}], ")"}], "2"], 
            ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  SubscriptBox[
                    StyleBox["\<\"q\"\>",
                      FontSlant->"Italic"], "2"], "-", 
                  SubscriptBox[
                    StyleBox["\<\"q\"\>",
                      FontSlant->"Italic"], "1"]}], ")"}], "2"]}]], "+", 
        FractionBox[
          RowBox[{
            FractionBox[
              SuperscriptBox["m", "2"], "2"], "+", 
            FractionBox[
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"], "2"]}], 
          RowBox[{
            SubsuperscriptBox[
              StyleBox["\<\"q\"\>",
                FontSlant->"Italic"], "1", "2"], ".", 
            SubsuperscriptBox[
              StyleBox["\<\"q\"\>",
                FontSlant->"Italic"], "2", "2"], ".", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{
                      SubscriptBox[
                        StyleBox["\<\"q\"\>",
                          FontSlant->"Italic"], "1"], "-", "p"}], ")"}], "2"],
                 "-", 
                SuperscriptBox["m", "2"]}], ")"}], ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  SubscriptBox[
                    StyleBox["\<\"q\"\>",
                      FontSlant->"Italic"], "2"], "-", 
                  SubscriptBox[
                    StyleBox["\<\"q\"\>",
                      FontSlant->"Italic"], "1"]}], ")"}], "2"]}]], "+", 
        FractionBox[
          RowBox[{
            FractionBox[
              SuperscriptBox["m", "4"], "4"], "+", 
            FractionBox[
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], " ", 
                SuperscriptBox["m", "2"]}], "2"], "+", 
            FractionBox[
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "4"], "4"]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SubsuperscriptBox[
                  StyleBox["\<\"q\"\>",
                    FontSlant->"Italic"], "1", "2"], "-", 
                SuperscriptBox["m", "2"]}], ")"}], ".", 
            RowBox[{"(", 
              RowBox[{
                SubsuperscriptBox[
                  StyleBox["\<\"q\"\>",
                    FontSlant->"Italic"], "2", "2"], "-", 
                SuperscriptBox["m", "2"]}], ")"}], ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  SubscriptBox[
                    StyleBox["\<\"q\"\>",
                      FontSlant->"Italic"], "1"], "-", "p"}], ")"}], "2"], 
            ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  SubscriptBox[
                    StyleBox["\<\"q\"\>",
                      FontSlant->"Italic"], "2"], "-", "p"}], ")"}], "2"], 
            ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  SubscriptBox[
                    StyleBox["\<\"q\"\>",
                      FontSlant->"Italic"], "2"], "-", 
                  SubscriptBox[
                    StyleBox["\<\"q\"\>",
                      FontSlant->"Italic"], "1"]}], ")"}], "2"]}]]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1284]=  (21:56:17 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      RowBox[{"Clear", "[", 
        RowBox[{"t1", ",", "t2"}], "]"}], ";"}]], "Input",
  CellLabel->"In[1285]:=  (21:56:17 on 5/16/01)",
  CellTags->"ScalarProductCancel"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["SD", "ObjectName",
  CellTags->"SD"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"SD"],

Cell["\<\
SD[i, j] is the (FeynCalc-external) Kronecker-delta for SU(N) with color \
indices i and j. SD[i,j] is transformed into \
SUNDelta[SUNIndex[i],SUNIndex[j]] by FeynCalcInternal.\
\>", "Text",
  CellTags->"SD"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["SUNDelta",
    ButtonData:>"SUNDelta",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SUNDelta"],
  "."
}], "Text",
  CellTags->"SD"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"SD"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SD", "[", 
      RowBox[{"a", ",", "b"}], "]"}]], "Input",
  CellLabel->"In[1286]:=  (21:56:17 on 5/16/01)",
  CellTags->"SD"],

Cell[BoxData[
    FormBox[
      SubscriptBox["\[Delta]", 
        RowBox[{"a", "\[NoBreak]", "b"}]], TraditionalForm]], "Output",
  CellLabel->"Out[1286]=  (21:56:17 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"%", "//", "FCI"}], "//", "StandardForm"}]], "Input",
  CellLabel->"In[1287]:=  (21:56:17 on 5/16/01)",
  CellTags->"SD"],

Cell[BoxData[
    RowBox[{"SUNDelta", "[", 
      RowBox[{
        RowBox[{"SUNIndex", "[", "a", "]"}], ",", 
        RowBox[{"SUNIndex", "[", "b", "]"}]}], "]"}]], "Output",
  CellLabel->"Out[1287]//StandardForm=  (21:56:17 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"%", "//", "FCE"}], "//", "StandardForm"}]], "Input",
  CellLabel->"In[1288]:=  (21:56:17 on 5/16/01)",
  CellTags->"SD"],

Cell[BoxData[
    RowBox[{"SD", "[", 
      RowBox[{"a", ",", "b"}], "]"}]], "Output",
  CellLabel->"Out[1288]//StandardForm=  (21:56:17 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["SelectFree", "ObjectName",
  CellTags->"SelectFree"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"SelectFree"],

Cell["\<\
SelectFree[expr, a, b, ...] is equivalent to Select[expr, FreeQ2[#, {a,b, \
...}]&], except the special cases: SelectFree[a, b] returns a and \
SelectFree[a,a] returns 1 (where a is not a product or a sum).\
\>", "Text",
  CellTags->"SelectFree"],

Cell["SelectFree is equivalent to Select1.", "Text",
  CellTags->"SelectFree"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["FreeQ2",
    ButtonData:>"FreeQ2",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FreeQ2"],
  ", ",
  ButtonBox["SelectNotFree",
    ButtonData:>"SelectNotFree",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SelectNotFree"],
  "."
}], "Text",
  CellTags->"SelectFree"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"SelectFree"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SelectFree", "[", 
      RowBox[{
        RowBox[{"a", "+", "b", "+", 
          RowBox[{"f", "[", "a", "]"}], "+", "d"}], ",", "a"}], 
      "]"}]], "Input",
  CellLabel->"In[1289]:=  (21:56:17 on 5/16/01)",
  CellTags->"SelectFree"],

Cell[BoxData[
    FormBox[
      RowBox[{"b", "+", "d"}], TraditionalForm]], "Output",
  CellLabel->"Out[1289]=  (21:56:17 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SelectFree", "[", 
      RowBox[{
        RowBox[{"x", " ", "y"}], ",", " ", "x"}], "]"}]], "Input",
  CellLabel->"In[1290]:=  (21:56:17 on 5/16/01)",
  CellTags->"SelectFree"],

Cell[BoxData[
    FormBox["y", TraditionalForm]], "Output",
  CellLabel->"Out[1290]=  (21:56:17 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SelectFree", "[", 
      RowBox[{
        RowBox[{"2", " ", "x", " ", "y", " ", "z", " ", 
          RowBox[{"f", "[", "x", "]"}]}], ",", " ", 
        RowBox[{"{", 
          RowBox[{"x", ",", "y"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[1291]:=  (21:56:17 on 5/16/01)",
  CellTags->"SelectFree"],

Cell[BoxData[
    FormBox[
      RowBox[{"2", " ", "z"}], TraditionalForm]], "Output",
  CellLabel->"Out[1291]=  (21:56:17 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SelectFree", "[", 
      RowBox[{"a", ",", "b"}], "]"}]], "Input",
  CellLabel->"In[1292]:=  (21:56:17 on 5/16/01)",
  CellTags->"SelectFree"],

Cell[BoxData[
    FormBox["a", TraditionalForm]], "Output",
  CellLabel->"Out[1292]=  (21:56:17 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SelectFree", "[", 
      RowBox[{"a", ",", "a"}], "]"}]], "Input",
  CellLabel->"In[1293]:=  (21:56:17 on 5/16/01)",
  CellTags->"SelectFree"],

Cell[BoxData[
    FormBox["1", TraditionalForm]], "Output",
  CellLabel->"Out[1293]=  (21:56:17 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SelectFree", "[", 
      RowBox[{"1", ",", "c"}], "]"}]], "Input",
  CellLabel->"In[1294]:=  (21:56:17 on 5/16/01)",
  CellTags->"SelectFree"],

Cell[BoxData[
    FormBox["1", TraditionalForm]], "Output",
  CellLabel->"Out[1294]=  (21:56:17 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SelectFree", "[", 
      RowBox[{
        RowBox[{"f", "[", "x", "]"}], ",", "x"}], "]"}]], "Input",
  CellLabel->"In[1295]:=  (21:56:17 on 5/16/01)",
  CellTags->"SelectFree"],

Cell[BoxData[
    FormBox["1", TraditionalForm]], "Output",
  CellLabel->"Out[1295]=  (21:56:17 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["SelectNotFree", "ObjectName",
  CellTags->"SelectNotFree"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"SelectNotFree"],

Cell["\<\
SelectNotFree[expr, x] returns that part of expr which is not free of any \
occurance of x.\
\>", "Text",
  CellTags->"SelectNotFree"],

Cell["\<\
SelectNotFree[expr, a, b, ...] is equivalent to Select[expr, !FreeQ2[#, {a, \
b, ...}]&], except the special cases: SelectNotFree[a, b] returns 1 and \
SelectNotFree[a, a] returns a (where a is not a product or a sum).\
\>", "Text",
  CellTags->"SelectNotFree"],

Cell["SelectNotFree is equivalent to Select2.", "Text",
  CellTags->"SelectNotFree"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["FreeQ2",
    ButtonData:>"FreeQ2",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FreeQ2"],
  ", ",
  ButtonBox["SelectFree",
    ButtonData:>"SelectFree",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SelectFree"],
  "."
}], "Text",
  CellTags->"SelectNotFree"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"SelectNotFree"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SelectNotFree", "[", 
      RowBox[{
        RowBox[{"a", "+", "b", "+", 
          RowBox[{"f", "[", "a", "]"}]}], ",", "a"}], "]"}]], "Input",
  CellLabel->"In[1296]:=  (21:56:17 on 5/16/01)",
  CellTags->"SelectNotFree"],

Cell[BoxData[
    FormBox[
      RowBox[{"a", "+", 
        RowBox[{"f", "(", "a", ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1296]=  (21:56:17 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SelectNotFree", "[", 
      RowBox[{
        RowBox[{"2", " ", "x", " ", "y", " ", 
          RowBox[{"f", "[", "x", "]"}], " ", "z"}], ",", 
        RowBox[{"{", 
          RowBox[{"x", ",", "y"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[1297]:=  (21:56:17 on 5/16/01)",
  CellTags->"SelectNotFree"],

Cell[BoxData[
    FormBox[
      RowBox[{"x", " ", "y", " ", 
        RowBox[{"f", "(", "x", ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1297]=  (21:56:17 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SelectNotFree", "[", 
      RowBox[{"a", ",", "b"}], "]"}]], "Input",
  CellLabel->"In[1298]:=  (21:56:17 on 5/16/01)",
  CellTags->"SelectNotFree"],

Cell[BoxData[
    FormBox["1", TraditionalForm]], "Output",
  CellLabel->"Out[1298]=  (21:56:17 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SelectNotFree", "[", 
      RowBox[{
        RowBox[{"a", "+", "x"}], ",", "b"}], "]"}]], "Input",
  CellLabel->"In[1299]:=  (21:56:18 on 5/16/01)",
  CellTags->"SelectNotFree"],

Cell[BoxData[
    FormBox["0", TraditionalForm]], "Output",
  CellLabel->"Out[1299]=  (21:56:18 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SelectNotFree", "[", 
      RowBox[{"a", ",", "a"}], "]"}]], "Input",
  CellLabel->"In[1300]:=  (21:56:18 on 5/16/01)",
  CellTags->"SelectNotFree"],

Cell[BoxData[
    FormBox["a", TraditionalForm]], "Output",
  CellLabel->"Out[1300]=  (21:56:18 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SelectNotFree", "[", 
      RowBox[{"1", ",", "c"}], "]"}]], "Input",
  CellLabel->"In[1301]:=  (21:56:18 on 5/16/01)",
  CellTags->"SelectNotFree"],

Cell[BoxData[
    FormBox["1", TraditionalForm]], "Output",
  CellLabel->"Out[1301]=  (21:56:18 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SelectNotFree", "[", 
      RowBox[{
        RowBox[{"f", "[", "x", "]"}], ",", "x"}], "]"}]], "Input",
  CellLabel->"In[1302]:=  (21:56:18 on 5/16/01)",
  CellTags->"SelectNotFree"],

Cell[BoxData[
    FormBox[
      RowBox[{"f", "(", "x", ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[1302]=  (21:56:18 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Series2", "ObjectName",
  CellTags->"Series2"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"Series2"],

Cell["\<\
 Series2 performs a series expansion around 0. Series2 is (up to the Gamma - \
bug) equivalent to Series, except that it applies Normal on the result and \
has an option FinalSubstitutions. Series2[f, e, n] is equivalent to \
Series2[f, {e, 0, n}].\
\>", "Text",
  CellTags->"Series2"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "Series2", "]"}]], "Input",
  CellLabel->"In[1303]:=  (21:56:18 on 5/16/01)",
  CellTags->"Series2"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"Collecting", "\[Rule]", "False"}], ",", 
          RowBox[{"Factoring", "\[Rule]", "True"}], ",", 
          RowBox[{"FinalSubstitutions", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{
                TagBox["\[DoubledGamma]",
                  (EulerGamma&)], "\[Rule]", "0"}], "}"}]}], ",", 
          RowBox[{"Print", "\[Rule]", "False"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1303]=  (21:56:18 on 5/16/01)"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"Series2"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Series2", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{"x", " ", 
              RowBox[{"(", 
                RowBox[{"1", "-", "x"}], ")"}]}], ")"}], "^", 
          RowBox[{"(", 
            RowBox[{"\[Delta]", "/", "2"}], ")"}]}], ",", "\[Delta]", ",", 
        "1"}], "]"}]], "Input",
  CellLabel->"In[1304]:=  (21:56:18 on 5/16/01)",
  CellTags->"Series2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox["1", "2"], " ", "\[Delta]", " ", 
          RowBox[{"log", "(", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"1", "-", "x"}], ")"}], " ", "x"}], ")"}]}], "+", 
        "1"}], TraditionalForm]], "Output",
  CellLabel->"Out[1304]=  (21:56:18 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Series2", "[", 
      RowBox[{
        RowBox[{"Gamma", "[", "x", "]"}], ",", "x", ",", "1"}], 
      "]"}]], "Input",
  CellLabel->"In[1305]:=  (21:56:18 on 5/16/01)",
  CellTags->"Series2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{
            SuperscriptBox["\[Pi]", "2"], " ", "x"}], "12"], "+", 
        FractionBox["1", "x"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1305]=  (21:56:18 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Series", "[", 
      RowBox[{
        RowBox[{"Gamma", "[", "x", "]"}], ",", 
        RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[1306]:=  (21:56:18 on 5/16/01)",
  CellTags->"Series2"],

Cell[BoxData[
    FormBox[
      InterpretationBox[
        RowBox[{
          FractionBox["1", "x"], "+", 
          InterpretationBox[
            RowBox[{"O", "(", 
              SuperscriptBox["x", "0"], ")"}],
            SeriesData[ x, 0, {}, -1, 0, 1]]}],
        SeriesData[ x, 0, {1}, -1, 0, 1]], TraditionalForm]], "Output",
  CellLabel->"Out[1306]=  (21:56:18 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Series2", "[", 
      RowBox[{
        RowBox[{"Gamma", "[", "x", "]"}], ",", "x", ",", "2"}], 
      "]"}]], "Input",
  CellLabel->"In[1307]:=  (21:56:18 on 5/16/01)",
  CellTags->"Series2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"-", 
            FractionBox["1", "3"]}], " ", 
          TagBox[
            RowBox[{"\[Zeta]", "(", 
              TagBox["3",
                (Editable -> True)], ")"}],
            InterpretTemplate[ Zeta[ #]&]], " ", 
          SuperscriptBox["x", "2"]}], "+", 
        FractionBox[
          RowBox[{
            SuperscriptBox["\[Pi]", "2"], " ", "x"}], "12"], "+", 
        FractionBox["1", "x"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1307]=  (21:56:18 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Series2", "[", 
        RowBox[{
          RowBox[{"Gamma", "[", "x", "]"}], ",", "x", ",", "2", ",", 
          RowBox[{"FinalSubstitutions", "\[Rule]", 
            RowBox[{"{", "}"}]}]}], "]"}], "//", "FullSimplify"}]], "Input",
  CellLabel->"In[1308]:=  (21:56:18 on 5/16/01)",
  CellTags->"Series2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox["1", "12"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"-", "2"}], " ", 
              SuperscriptBox[
                TagBox["\[DoubledGamma]",
                  (EulerGamma&)], "3"], " ", 
              SuperscriptBox["x", "2"]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox["\[Pi]", "2"], "-", 
                  RowBox[{"4", " ", "x", " ", 
                    TagBox[
                      RowBox[{"\[Zeta]", "(", 
                        TagBox["3",
                          (Editable -> True)], ")"}],
                      InterpretTemplate[ Zeta[ #]&]]}]}], ")"}], " ", "x"}], 
            "+", 
            RowBox[{"6", " ", 
              SuperscriptBox[
                TagBox["\[DoubledGamma]",
                  (EulerGamma&)], "2"], " ", "x"}], "-", 
            RowBox[{
              TagBox["\[DoubledGamma]",
                (EulerGamma&)], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox["\[Pi]", "2"], " ", 
                    SuperscriptBox["x", "2"]}], "+", "12"}], ")"}]}], "+", 
            FractionBox["12", "x"]}], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1308]=  (21:56:20 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"Series", "[", 
          RowBox[{
            RowBox[{"Gamma", "[", "x", "]"}], ",", 
            RowBox[{"{", 
              RowBox[{"x", ",", "0", ",", "4"}], "}"}]}], "]"}], "//", 
        "Normal"}], "//", "FullSimplify"}]], "Input",
  CellLabel->"In[1309]:=  (21:56:20 on 5/16/01)",
  CellTags->"Series2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"-", 
            FractionBox["1", "12"]}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"2", " ", 
                SuperscriptBox[
                  TagBox["\[DoubledGamma]",
                    (EulerGamma&)], "3"]}], "+", 
              RowBox[{
                TagBox["\[DoubledGamma]",
                  (EulerGamma&)], " ", 
                SuperscriptBox["\[Pi]", "2"]}], "+", 
              RowBox[{"4", " ", 
                TagBox[
                  RowBox[{"\[Zeta]", "(", 
                    TagBox["3",
                      (Editable -> True)], ")"}],
                  InterpretTemplate[ Zeta[ #]&]]}]}], ")"}], " ", 
          SuperscriptBox["x", "2"]}], "+", 
        RowBox[{
          FractionBox["1", "12"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"6", " ", 
                SuperscriptBox[
                  TagBox["\[DoubledGamma]",
                    (EulerGamma&)], "2"]}], "+", 
              SuperscriptBox["\[Pi]", "2"]}], ")"}], " ", "x"}], "-", 
        TagBox["\[DoubledGamma]",
          (EulerGamma&)], "+", 
        FractionBox["1", "x"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1309]=  (21:56:21 on 5/16/01)"]
}, Closed]],

Cell["\<\
There is a table of expansions of special hypergeometric functions.\
\>", "Text",
  CellTags->"Series2"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Series2", "[", 
      RowBox[{
        RowBox[{"HypergeometricPFQ", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"1", ",", 
                RowBox[{"OPEm", "-", "1"}], ",", 
                RowBox[{
                  RowBox[{"Epsilon", "/", "2"}], "+", "OPEm"}]}], "}"}], ",", 
            
            RowBox[{"{", 
              RowBox[{"OPEm", ",", 
                RowBox[{"OPEm", "+", "Epsilon"}]}], "}"}], ",", "1"}], "]"}], 
        ",", 
        RowBox[{"{", 
          RowBox[{"Epsilon", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[1310]:=  (21:56:22 on 5/16/01)",
  CellTags->"Series2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox["1", "2"], " ", 
          TagBox["\[CurlyEpsilon]",
            TraditionalForm], " ", 
          RowBox[{
            SuperscriptBox[
              TagBox["\[Psi]",
                PolyGamma], 
              RowBox[{"(", "1", ")"}]], "(", "m", ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"m", "-", "1"}], ")"}]}], "+", 
        FractionBox[
          RowBox[{"2", " ", 
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}]}], 
          TagBox["\[CurlyEpsilon]",
            TraditionalForm]], "+", "1"}], TraditionalForm]], "Output",
  CellLabel->"Out[1310]=  (21:56:22 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{" ", 
      RowBox[{"Series2", "[", 
        RowBox[{
          RowBox[{"HypergeometricPFQ", "[", 
            RowBox[{
              RowBox[{"{", 
                RowBox[{"1", ",", " ", "OPEm", ",", " ", 
                  RowBox[{
                    RowBox[{"Epsilon", "/", "2"}], " ", "+", " ", "OPEm"}]}], 
                "}"}], ",", " ", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"1", " ", "+", " ", "OPEm"}], ",", " ", 
                  RowBox[{"Epsilon", " ", "+", " ", "OPEm"}]}], "}"}], ",", 
              " ", " ", "1"}], "]"}], ",", 
          RowBox[{"{", 
            RowBox[{"Epsilon", ",", "0", ",", "1"}], "}"}]}], 
        "]"}]}]], "Input",
  CellLabel->"In[1311]:=  (21:56:22 on 5/16/01)",
  CellTags->"Series2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox["1", "4"], " ", 
          TagBox["\[CurlyEpsilon]",
            TraditionalForm], " ", "m", " ", 
          SuperscriptBox[
            RowBox[{
              SuperscriptBox[
                TagBox["\[Psi]",
                  PolyGamma], 
                RowBox[{"(", "0", ")"}]], "(", "m", ")"}], "2"]}], "+", 
        FractionBox[
          RowBox[{"2", " ", "m"}], 
          TagBox["\[CurlyEpsilon]",
            TraditionalForm]], "+", 
        RowBox[{
          FractionBox["3", "4"], " ", 
          TagBox["\[CurlyEpsilon]",
            TraditionalForm], " ", "m", " ", 
          RowBox[{
            SuperscriptBox[
              TagBox["\[Psi]",
                PolyGamma], 
              RowBox[{"(", "1", ")"}]], "(", "m", ")"}]}], "-", 
        RowBox[{
          FractionBox["1", "2"], " ", 
          TagBox["\[CurlyEpsilon]",
            TraditionalForm], " ", "m", " ", 
          RowBox[{
            SubscriptBox["S", "11"], "(", 
            FormBox[
              RowBox[{"m", "-", "1"}],
              "TraditionalForm"], ")"}]}], "+", 
        RowBox[{
          FractionBox["1", "24"], " ", 
          TagBox["\[CurlyEpsilon]",
            TraditionalForm], " ", "m", " ", 
          SuperscriptBox["\[Pi]", "2"]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1311]=  (21:56:22 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Hypergeometric2F1", "[", 
      RowBox[{"1", ",", " ", "Epsilon", ",", " ", 
        RowBox[{"1", " ", "+", " ", 
          RowBox[{"2", " ", "Epsilon"}]}], ",", "x"}], "]"}]], "Input",
  CellLabel->"In[1312]:=  (21:56:22 on 5/16/01)",
  CellTags->"Series2"],

Cell[BoxData[
    FormBox[
      TagBox[
        TagBox[
          RowBox[{
            RowBox[{
              SubscriptBox["\[InvisiblePrefixScriptBase]", 
                FormBox["2",
                  "TraditionalForm"]], 
              SubscriptBox["F", 
                FormBox["1",
                  "TraditionalForm"]]}], "\[InvisibleApplication]", 
            RowBox[{"(", 
              RowBox[{
                TagBox[
                  TagBox[
                    RowBox[{
                      TagBox["1",
                        Hypergeometric2F1,
                        Editable->True], ",", 
                      TagBox[
                        TagBox["\[CurlyEpsilon]",
                          TraditionalForm],
                        Hypergeometric2F1,
                        Editable->True]}],
                    InterpretTemplate[ {
                      SlotSequence[ 1]}&]],
                  Hypergeometric2F1,
                  Editable->False], ";", 
                TagBox[
                  TagBox[
                    TagBox[
                      RowBox[{
                        RowBox[{"2", " ", 
                          TagBox["\[CurlyEpsilon]",
                            TraditionalForm]}], "+", "1"}],
                      Hypergeometric2F1,
                      Editable->True],
                    InterpretTemplate[ {
                      SlotSequence[ 1]}&]],
                  Hypergeometric2F1,
                  Editable->False], ";", 
                TagBox["x",
                  Hypergeometric2F1,
                  Editable->True]}], ")"}]}],
          InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
          Editable->False],
        Hypergeometric2F1], TraditionalForm]], "Output",
  CellLabel->"Out[1312]=  (21:56:22 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Series2", "[", 
      RowBox[{"%", ",", 
        RowBox[{"{", 
          RowBox[{"Epsilon", ",", "0", ",", "3"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[1313]:=  (21:56:22 on 5/16/01)",
  CellTags->"Series2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  FractionBox["1", "6"]}], " ", 
                RowBox[{
                  SuperscriptBox["log", "3"], "(", 
                  RowBox[{"1", "-", "x"}], ")"}]}], "+", 
              RowBox[{
                RowBox[{"log", "(", "x", ")"}], " ", 
                RowBox[{
                  SuperscriptBox["log", "2"], "(", 
                  RowBox[{"1", "-", "x"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
                RowBox[{"log", "(", 
                  RowBox[{"1", "-", "x"}], ")"}]}], "-", 
              RowBox[{
                FractionBox["1", "6"], " ", 
                SuperscriptBox["\[Pi]", "2"], " ", 
                RowBox[{"log", "(", 
                  RowBox[{"1", "-", "x"}], ")"}]}], "+", 
              RowBox[{"2", " ", 
                RowBox[{
                  SubscriptBox["Li", "3"], "(", 
                  RowBox[{"1", "-", "x"}], ")"}]}], "+", 
              RowBox[{"4", " ", 
                RowBox[{
                  SubscriptBox["Li", "3"], "(", "x", ")"}]}], "-", 
              RowBox[{"2", " ", 
                TagBox[
                  RowBox[{"\[Zeta]", "(", 
                    TagBox["3",
                      (Editable -> True)], ")"}],
                  InterpretTemplate[ Zeta[ #]&]]}]}], ")"}], " ", 
          SuperscriptBox[
            TagBox["\[CurlyEpsilon]",
              TraditionalForm], "3"]}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  FractionBox["1", "2"]}], " ", 
                RowBox[{
                  SuperscriptBox["log", "2"], "(", 
                  RowBox[{"1", "-", "x"}], ")"}]}], "+", 
              RowBox[{"2", " ", 
                RowBox[{"log", "(", "x", ")"}], " ", 
                RowBox[{"log", "(", 
                  RowBox[{"1", "-", "x"}], ")"}]}], "-", 
              RowBox[{"3", " ", 
                RowBox[{"\[Zeta]", "(", "2", ")"}]}], "+", 
              RowBox[{"2", " ", 
                RowBox[{
                  SubscriptBox["Li", "2"], "(", 
                  RowBox[{"1", "-", "x"}], ")"}]}], "+", 
              FractionBox[
                SuperscriptBox["\[Pi]", "2"], "6"]}], ")"}], " ", 
          SuperscriptBox[
            TagBox["\[CurlyEpsilon]",
              TraditionalForm], "2"]}], "-", 
        RowBox[{
          RowBox[{"log", "(", 
            RowBox[{"1", "-", "x"}], ")"}], " ", 
          TagBox["\[CurlyEpsilon]",
            TraditionalForm]}], "+", "1"}], TraditionalForm]], "Output",
  CellLabel->"Out[1313]=  (21:56:22 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "There are over 100 more special expansions of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox["\[ThinSpace]", "2"], 
          SubscriptBox["F", "1"]}], TraditionalForm]]],
  " tabulated in Series2.m. The interested user can consult the source code \
(search for HYPERLIST)."
}], "Text",
  CellTags->"Series2"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["SimplifyDeltaFunction", "ObjectName",
  CellTags->"SimplifyDeltaFunction"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"SimplifyDeltaFunction"],

Cell["\<\
SimplifyDeltaFunction[exp, x] simplifies f[x]*DeltaFunction[1-x] \
toLimit[f[x],x->1] DeltaFunction[1-x] and applies a list of transformation \
rules for DeltaFunctionPrime[1-x]*x^(OPEm-1)*f[x] where x^(OPEm-1) is \
suppressed in exp.\
\>", "Text",
  CellTags->"SimplifyDeltaFunction"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["DeltaFunction",
    ButtonData:>"DeltaFunction",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DeltaFunction"],
  ", ",
  ButtonBox["DeltaFunctionPrime",
    ButtonData:>"DeltaFunctionPrime",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DeltaFunctionPrime"],
  "."
}], "Text",
  CellTags->"SimplifyDeltaFunction"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"SimplifyDeltaFunction"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"g", "[", "x", "]"}], " ", 
      RowBox[{"DeltaFunction", "[", 
        RowBox[{"1", "-", "x"}], "]"}]}]], "Input",
  CellLabel->"In[1314]:=  (21:56:22 on 5/16/01)",
  CellTags->"SimplifyDeltaFunction"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[Delta]", "(", 
          FormBox[
            RowBox[{"1", "-", "x"}],
            "TraditionalForm"], ")"}], " ", 
        RowBox[{"g", "(", "x", ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1314]=  (21:56:22 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SimplifyDeltaFunction", "[", " ", 
      RowBox[{"%", ",", "x"}], "]"}]], "Input",
  CellLabel->"In[1315]:=  (21:56:23 on 5/16/01)",
  CellTags->"SimplifyDeltaFunction"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[Delta]", "(", 
          FormBox[
            RowBox[{"1", "-", "x"}],
            "TraditionalForm"], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{
            UnderscriptBox["lim", 
              RowBox[{"x", "\[Rule]", "1"}]], "\[ThinSpace]", 
            RowBox[{"g", "(", "x", ")"}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1315]=  (21:56:23 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"g", "[", "x", "]"}], 
      RowBox[{"DeltaFunctionPrime", "[", 
        RowBox[{"1", "-", "x"}], "]"}]}]], "Input",
  CellLabel->"In[1316]:=  (21:56:23 on 5/16/01)",
  CellTags->"SimplifyDeltaFunction"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SuperscriptBox["\[Delta]", "\[Prime]"], "(", 
          FormBox[
            RowBox[{"1", "-", "x"}],
            "TraditionalForm"], ")"}], " ", 
        RowBox[{"g", "(", "x", ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1316]=  (21:56:23 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SimplifyDeltaFunction", "[", " ", 
      RowBox[{"%", ",", "x"}], "]"}]], "Input",
  CellLabel->"In[1317]:=  (21:56:23 on 5/16/01)",
  CellTags->"SimplifyDeltaFunction"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Delta]", "\[Prime]"], "(", 
            FormBox[
              RowBox[{"1", "-", "x"}],
              "TraditionalForm"], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              UnderscriptBox["lim", 
                RowBox[{"x", "\[Rule]", "1"}]], "\[ThinSpace]", 
              RowBox[{"g", "(", "x", ")"}]}], ")"}]}], "+", 
        RowBox[{
          RowBox[{"\[Delta]", "(", 
            FormBox[
              RowBox[{"1", "-", "x"}],
              "TraditionalForm"], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              UnderscriptBox["lim", 
                RowBox[{"x", "\[Rule]", "1"}]], "\[ThinSpace]", 
              RowBox[{
                SuperscriptBox["g", "\[Prime]",
                  MultilineFunction->None], "(", "x", ")"}]}], ")"}]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1317]=  (21:56:23 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"x", " ", 
      RowBox[{"Log", "[", "x", "]"}], " ", 
      RowBox[{"DeltaFunctionPrime", "[", 
        RowBox[{"1", "-", "x"}], "]"}]}]], "Input",
  CellLabel->"In[1318]:=  (21:56:23 on 5/16/01)",
  CellTags->"SimplifyDeltaFunction"],

Cell[BoxData[
    FormBox[
      RowBox[{"x", " ", 
        RowBox[{
          SuperscriptBox["\[Delta]", "\[Prime]"], "(", 
          FormBox[
            RowBox[{"1", "-", "x"}],
            "TraditionalForm"], ")"}], " ", 
        RowBox[{"log", "(", "x", ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1318]=  (21:56:23 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SimplifyDeltaFunction", "[", " ", 
      RowBox[{"%", ",", "x"}], "]"}]], "Input",
  CellLabel->"In[1319]:=  (21:56:23 on 5/16/01)",
  CellTags->"SimplifyDeltaFunction"],

Cell[BoxData[
    FormBox[
      RowBox[{"\[Delta]", "(", 
        FormBox[
          RowBox[{"1", "-", "x"}],
          "TraditionalForm"], ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[1319]=  (21:56:23 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"PolyLog", "[", 
        RowBox[{"2", ",", 
          RowBox[{"1", "-", "x"}]}], "]"}], " ", 
      RowBox[{"DeltaFunctionPrime", "[", 
        RowBox[{"1", "-", "x"}], "]"}]}]], "Input",
  CellLabel->"In[1320]:=  (21:56:23 on 5/16/01)",
  CellTags->"SimplifyDeltaFunction"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SuperscriptBox["\[Delta]", "\[Prime]"], "(", 
          FormBox[
            RowBox[{"1", "-", "x"}],
            "TraditionalForm"], ")"}], " ", 
        RowBox[{
          SubscriptBox["Li", "2"], "(", 
          RowBox[{"1", "-", "x"}], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1320]=  (21:56:23 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SimplifyDeltaFunction", "[", " ", 
      RowBox[{"%", ",", "x"}], "]"}]], "Input",
  CellLabel->"In[1321]:=  (21:56:23 on 5/16/01)",
  CellTags->"SimplifyDeltaFunction"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        RowBox[{"\[Delta]", "(", 
          FormBox[
            RowBox[{"1", "-", "x"}],
            "TraditionalForm"], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1321]=  (21:56:23 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Log", "[", "x", "]"}], 
      RowBox[{"PolyLog", "[", 
        RowBox[{"2", ",", 
          RowBox[{"1", "-", "x"}]}], "]"}], " ", 
      RowBox[{"DeltaFunctionPrime", "[", 
        RowBox[{"1", "-", "x"}], "]"}]}]], "Input",
  CellLabel->"In[1322]:=  (21:56:23 on 5/16/01)",
  CellTags->"SimplifyDeltaFunction"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SuperscriptBox["\[Delta]", "\[Prime]"], "(", 
          FormBox[
            RowBox[{"1", "-", "x"}],
            "TraditionalForm"], ")"}], " ", 
        RowBox[{"log", "(", "x", ")"}], " ", 
        RowBox[{
          SubscriptBox["Li", "2"], "(", 
          RowBox[{"1", "-", "x"}], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1322]=  (21:56:23 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SimplifyDeltaFunction", "[", " ", 
      RowBox[{"%", ",", "x"}], "]"}]], "Input",
  CellLabel->"In[1323]:=  (21:56:23 on 5/16/01)",
  CellTags->"SimplifyDeltaFunction"],

Cell[BoxData[
    FormBox["0", TraditionalForm]], "Output",
  CellLabel->"Out[1323]=  (21:56:23 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"PolyLog", "[", 
        RowBox[{"3", ",", 
          RowBox[{"1", "-", "x"}]}], "]"}], " ", 
      RowBox[{"DeltaFunctionPrime", "[", 
        RowBox[{"1", "-", "x"}], "]"}]}]], "Input",
  CellLabel->"In[1324]:=  (21:56:23 on 5/16/01)",
  CellTags->"SimplifyDeltaFunction"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SuperscriptBox["\[Delta]", "\[Prime]"], "(", 
          FormBox[
            RowBox[{"1", "-", "x"}],
            "TraditionalForm"], ")"}], " ", 
        RowBox[{
          SubscriptBox["Li", "3"], "(", 
          RowBox[{"1", "-", "x"}], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1324]=  (21:56:23 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SimplifyDeltaFunction", "[", " ", 
      RowBox[{"%", ",", "x"}], "]"}]], "Input",
  CellLabel->"In[1325]:=  (21:56:23 on 5/16/01)",
  CellTags->"SimplifyDeltaFunction"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        RowBox[{"\[Delta]", "(", 
          FormBox[
            RowBox[{"1", "-", "x"}],
            "TraditionalForm"], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1325]=  (21:56:23 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["SimplifyPolyLog", "ObjectName",
  CellTags->"SimplifyPolyLog"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"SimplifyPolyLog"],

Cell["\<\
SimplifyPolyLog[y] performs several simplifications assuming that the \
variables occuring in the Log and PolyLog functions are between 0 and 1. \
\>", "Text",
  CellTags->"SimplifyPolyLog"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["Nielsen",
    ButtonData:>"Nielsen",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Nielsen"],
  "."
}], "Text",
  CellTags->"SimplifyPolyLog"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"SimplifyPolyLog"],

Cell[BoxData[
    RowBox[{
      RowBox[{"sip", "[", "y_", "]"}], " ", ":=", " ", 
      RowBox[{"y", " ", "==", " ", 
        RowBox[{"SimplifyPolyLog", "[", "y", "]"}]}]}]], "Input",
  CellLabel->"In[1326]:=  (21:56:23 on 5/16/01)",
  CellTags->"SimplifyPolyLog"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"sip", "[", 
      RowBox[{"PolyLog", "[", 
        RowBox[{"2", ",", 
          RowBox[{"1", "/", "x"}]}], "]"}], "]"}]], "Input",
  CellLabel->"In[1327]:=  (21:56:23 on 5/16/01)",
  CellTags->"SimplifyPolyLog"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["Li", "2"], "(", 
          FractionBox["1", "x"], ")"}], "==", 
        RowBox[{
          RowBox[{
            RowBox[{"-", 
              FractionBox["1", "2"]}], " ", 
            RowBox[{
              SuperscriptBox["log", "2"], "(", "x", ")"}]}], "+", 
          RowBox[{
            RowBox[{"log", "(", 
              RowBox[{"1", "-", "x"}], ")"}], " ", 
            RowBox[{"log", "(", "x", ")"}]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "\[Pi]", " ", 
            RowBox[{"log", "(", "x", ")"}]}], "+", 
          RowBox[{"\[Zeta]", "(", "2", ")"}], "+", 
          RowBox[{
            SubscriptBox["Li", "2"], "(", 
            RowBox[{"1", "-", "x"}], ")"}]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1327]=  (21:56:23 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"sip", "[", 
      RowBox[{"PolyLog", "[", 
        RowBox[{"2", ",", "x"}], "]"}], "]"}]], "Input",
  CellLabel->"In[1328]:=  (21:56:23 on 5/16/01)",
  CellTags->"SimplifyPolyLog"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["Li", "2"], "(", "x", ")"}], "==", 
        RowBox[{
          RowBox[{"\[Zeta]", "(", "2", ")"}], "-", 
          RowBox[{
            RowBox[{"log", "(", 
              RowBox[{"1", "-", "x"}], ")"}], " ", 
            RowBox[{"log", "(", "x", ")"}]}], "-", 
          RowBox[{
            SubscriptBox["Li", "2"], "(", 
            RowBox[{"1", "-", "x"}], ")"}]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1328]=  (21:56:23 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"sip", "[", 
      RowBox[{"PolyLog", "[", 
        RowBox[{"2", ",", 
          RowBox[{"1", "-", 
            RowBox[{"x", "^", "2"}]}]}], "]"}], "]"}]], "Input",
  CellLabel->"In[1329]:=  (21:56:23 on 5/16/01)",
  CellTags->"SimplifyPolyLog"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["Li", "2"], "(", 
          RowBox[{"1", "-", 
            SuperscriptBox["x", "2"]}], ")"}], "==", 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"\[Zeta]", "(", "2", ")"}]}], "-", 
          RowBox[{"2", " ", 
            RowBox[{"log", "(", "x", ")"}], " ", 
            RowBox[{"log", "(", 
              RowBox[{"x", "+", "1"}], ")"}]}], "+", 
          RowBox[{"2", " ", 
            RowBox[{
              SubscriptBox["Li", "2"], "(", 
              RowBox[{"1", "-", "x"}], ")"}]}], "-", 
          RowBox[{"2", " ", 
            RowBox[{
              SubscriptBox["Li", "2"], "(", 
              RowBox[{"-", "x"}], ")"}]}]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1329]=  (21:56:23 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"sip", "[", 
      RowBox[{"PolyLog", "[", 
        RowBox[{"2", ",", 
          RowBox[{"x", "^", "2"}]}], "]"}], "]"}]], "Input",
  CellLabel->"In[1330]:=  (21:56:23 on 5/16/01)",
  CellTags->"SimplifyPolyLog"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["Li", "2"], "(", 
          SuperscriptBox["x", "2"], ")"}], "==", 
        RowBox[{
          RowBox[{"2", " ", 
            RowBox[{"\[Zeta]", "(", "2", ")"}]}], "-", 
          RowBox[{"2", " ", 
            RowBox[{"log", "(", 
              RowBox[{"1", "-", "x"}], ")"}], " ", 
            RowBox[{"log", "(", "x", ")"}]}], "-", 
          RowBox[{"2", " ", 
            RowBox[{
              SubscriptBox["Li", "2"], "(", 
              RowBox[{"1", "-", "x"}], ")"}]}], "+", 
          RowBox[{"2", " ", 
            RowBox[{
              SubscriptBox["Li", "2"], "(", 
              RowBox[{"-", "x"}], ")"}]}]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1330]=  (21:56:23 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"sip", "[", 
      RowBox[{"PolyLog", "[", 
        RowBox[{"2", ",", 
          RowBox[{"-", 
            RowBox[{"x", "/", 
              RowBox[{"(", 
                RowBox[{"1", "-", "x"}], ")"}]}]}]}], "]"}], "]"}]], "Input",
  CellLabel->"In[1331]:=  (21:56:23 on 5/16/01)",
  CellTags->"SimplifyPolyLog"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["Li", "2"], "(", 
          RowBox[{"-", 
            FractionBox["x", 
              RowBox[{"1", "-", "x"}]]}], ")"}], "==", 
        RowBox[{
          RowBox[{
            RowBox[{"-", 
              FractionBox["1", "2"]}], " ", 
            RowBox[{
              SuperscriptBox["log", "2"], "(", 
              RowBox[{"1", "-", "x"}], ")"}]}], "+", 
          RowBox[{
            RowBox[{"log", "(", "x", ")"}], " ", 
            RowBox[{"log", "(", 
              RowBox[{"1", "-", "x"}], ")"}]}], "-", 
          RowBox[{"\[Zeta]", "(", "2", ")"}], "+", 
          RowBox[{
            SubscriptBox["Li", "2"], "(", 
            RowBox[{"1", "-", "x"}], ")"}]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1331]=  (21:56:24 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"sip", "[", 
      RowBox[{"PolyLog", "[", 
        RowBox[{"2", ",", 
          RowBox[{"x", "/", 
            RowBox[{"(", 
              RowBox[{"x", "-", "1"}], ")"}]}]}], "]"}], "]"}]], "Input",
  CellLabel->"In[1332]:=  (21:56:24 on 5/16/01)",
  CellTags->"SimplifyPolyLog"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["Li", "2"], "(", 
          FractionBox["x", 
            RowBox[{"x", "-", "1"}]], ")"}], "==", 
        RowBox[{
          RowBox[{
            RowBox[{"-", 
              FractionBox["1", "2"]}], " ", 
            RowBox[{
              SuperscriptBox["log", "2"], "(", 
              RowBox[{"1", "-", "x"}], ")"}]}], "+", 
          RowBox[{
            RowBox[{"log", "(", "x", ")"}], " ", 
            RowBox[{"log", "(", 
              RowBox[{"1", "-", "x"}], ")"}]}], "-", 
          RowBox[{"\[Zeta]", "(", "2", ")"}], "+", 
          RowBox[{
            SubscriptBox["Li", "2"], "(", 
            RowBox[{"1", "-", "x"}], ")"}]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1332]=  (21:56:24 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"sip", "[", 
      RowBox[{"Nielsen", "[", 
        RowBox[{"1", ",", "2", ",", 
          RowBox[{"-", 
            RowBox[{"x", "/", 
              RowBox[{"(", 
                RowBox[{"1", "-", "x"}], ")"}]}]}]}], "]"}], "]"}]], "Input",
  CellLabel->"In[1333]:=  (21:56:24 on 5/16/01)",
  CellTags->"SimplifyPolyLog"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["S", 
            RowBox[{
              FormBox["1",
                "TraditionalForm"], "\[NoBreak]", 
              FormBox["2",
                "TraditionalForm"]}]], "(", 
          FormBox[
            RowBox[{"-", 
              FractionBox["x", 
                RowBox[{"1", "-", "x"}]]}],
            "TraditionalForm"], ")"}], "==", 
        RowBox[{
          RowBox[{
            SubscriptBox["S", 
              RowBox[{
                FormBox["1",
                  "TraditionalForm"], "\[NoBreak]", 
                FormBox["2",
                  "TraditionalForm"]}]], "(", "x", ")"}], "-", 
          RowBox[{
            FractionBox["1", "6"], " ", 
            RowBox[{
              SuperscriptBox["log", "3"], "(", 
              RowBox[{"1", "-", "x"}], ")"}]}]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1333]=  (21:56:24 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"sip", "[", 
      RowBox[{"PolyLog", "[", 
        RowBox[{"3", ",", 
          RowBox[{"-", 
            RowBox[{"1", "/", "x"}]}]}], "]"}], "]"}]], "Input",
  CellLabel->"In[1334]:=  (21:56:24 on 5/16/01)",
  CellTags->"SimplifyPolyLog"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["Li", "3"], "(", 
          RowBox[{"-", 
            FractionBox["1", "x"]}], ")"}], "==", 
        RowBox[{
          FractionBox[
            RowBox[{
              SuperscriptBox["log", "3"], "(", "x", ")"}], "6"], "+", 
          RowBox[{
            RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
            RowBox[{"log", "(", "x", ")"}]}], "+", 
          RowBox[{
            SubscriptBox["Li", "3"], "(", 
            RowBox[{"-", "x"}], ")"}]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1334]=  (21:56:24 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"sip", "[", 
      RowBox[{"PolyLog", "[", 
        RowBox[{"3", ",", 
          RowBox[{"1", "-", "x"}]}], "]"}], "]"}]], "Input",
  CellLabel->"In[1335]:=  (21:56:24 on 5/16/01)",
  CellTags->"SimplifyPolyLog"],

Cell[BoxData[
    FormBox["True", TraditionalForm]], "Output",
  CellLabel->"Out[1335]=  (21:56:24 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"sip", "[", 
      RowBox[{"PolyLog", "[", 
        RowBox[{"3", ",", 
          RowBox[{"x", "^", "2"}]}], "]"}], "]"}]], "Input",
  CellLabel->"In[1336]:=  (21:56:24 on 5/16/01)",
  CellTags->"SimplifyPolyLog"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["Li", "3"], "(", 
          SuperscriptBox["x", "2"], ")"}], "==", 
        RowBox[{
          RowBox[{
            RowBox[{"-", "2"}], " ", 
            RowBox[{"log", "(", 
              RowBox[{"1", "-", "x"}], ")"}], " ", 
            RowBox[{
              SuperscriptBox["log", "2"], "(", "x", ")"}]}], "+", 
          RowBox[{"4", " ", 
            RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
            RowBox[{"log", "(", "x", ")"}]}], "-", 
          RowBox[{"4", " ", 
            RowBox[{
              SubscriptBox["Li", "2"], "(", 
              RowBox[{"1", "-", "x"}], ")"}], " ", 
            RowBox[{"log", "(", "x", ")"}]}], "-", 
          RowBox[{"4", " ", 
            RowBox[{
              SubscriptBox["S", 
                RowBox[{
                  FormBox["1",
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox["2",
                    "TraditionalForm"]}]], "(", 
              FormBox[
                RowBox[{"1", "-", "x"}],
                "TraditionalForm"], ")"}]}], "+", 
          RowBox[{"4", " ", 
            RowBox[{
              SubscriptBox["Li", "3"], "(", 
              RowBox[{"-", "x"}], ")"}]}], "+", 
          RowBox[{"4", " ", 
            TagBox[
              RowBox[{"\[Zeta]", "(", 
                TagBox["3",
                  (Editable -> True)], ")"}],
              InterpretTemplate[ Zeta[ #]&]]}]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1336]=  (21:56:24 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"sip", "[", 
      RowBox[{"PolyLog", "[", 
        RowBox[{"3", ",", 
          RowBox[{"-", 
            RowBox[{"x", "/", 
              RowBox[{"(", 
                RowBox[{"1", "-", "x"}], ")"}]}]}]}], "]"}], "]"}]], "Input",
  CellLabel->"In[1337]:=  (21:56:24 on 5/16/01)",
  CellTags->"SimplifyPolyLog"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["Li", "3"], "(", 
          RowBox[{"-", 
            FractionBox["x", 
              RowBox[{"1", "-", "x"}]]}], ")"}], "==", 
        RowBox[{
          RowBox[{
            FractionBox["1", "6"], " ", 
            RowBox[{
              SuperscriptBox["log", "3"], "(", 
              RowBox[{"1", "-", "x"}], ")"}]}], "-", 
          RowBox[{
            FractionBox["1", "2"], " ", 
            RowBox[{"log", "(", "x", ")"}], " ", 
            RowBox[{
              SuperscriptBox["log", "2"], "(", 
              RowBox[{"1", "-", "x"}], ")"}]}], "+", 
          RowBox[{
            FractionBox["1", "2"], " ", 
            RowBox[{
              SuperscriptBox["log", "2"], "(", "x", ")"}], " ", 
            RowBox[{"log", "(", 
              RowBox[{"1", "-", "x"}], ")"}]}], "+", 
          RowBox[{
            RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
            RowBox[{"log", "(", 
              RowBox[{"1", "-", "x"}], ")"}]}], "-", 
          RowBox[{
            RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
            RowBox[{"log", "(", "x", ")"}]}], "+", 
          RowBox[{
            SubscriptBox["S", 
              RowBox[{
                FormBox["1",
                  "TraditionalForm"], "\[NoBreak]", 
                FormBox["2",
                  "TraditionalForm"]}]], "(", 
            FormBox[
              RowBox[{"1", "-", "x"}],
              "TraditionalForm"], ")"}], "+", 
          RowBox[{
            RowBox[{"log", "(", "x", ")"}], " ", 
            RowBox[{
              SubscriptBox["Li", "2"], "(", 
              RowBox[{"1", "-", "x"}], ")"}]}], "-", 
          RowBox[{
            SubscriptBox["Li", "3"], "(", 
            RowBox[{"1", "-", "x"}], ")"}]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1337]=  (21:56:24 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"sip", "[", 
      RowBox[{"PolyLog", "[", 
        RowBox[{"3", ",", 
          RowBox[{"1", "-", 
            RowBox[{"1", "/", "x"}]}]}], "]"}], "]"}]], "Input",
  CellLabel->"In[1338]:=  (21:56:24 on 5/16/01)",
  CellTags->"SimplifyPolyLog"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["Li", "3"], "(", 
          RowBox[{"1", "-", 
            FractionBox["1", "x"]}], ")"}], "==", 
        RowBox[{
          FractionBox[
            RowBox[{
              SuperscriptBox["log", "3"], "(", "x", ")"}], "6"], "-", 
          RowBox[{
            FractionBox["1", "2"], " ", 
            RowBox[{
              SuperscriptBox["log", "2"], "(", 
              RowBox[{"1", "-", "x"}], ")"}], " ", 
            RowBox[{"log", "(", "x", ")"}]}], "+", 
          RowBox[{
            RowBox[{
              SubscriptBox["Li", "2"], "(", 
              RowBox[{"1", "-", "x"}], ")"}], " ", 
            RowBox[{"log", "(", "x", ")"}]}], "+", 
          RowBox[{
            SubscriptBox["S", 
              RowBox[{
                FormBox["1",
                  "TraditionalForm"], "\[NoBreak]", 
                FormBox["2",
                  "TraditionalForm"]}]], "(", 
            FormBox[
              RowBox[{"1", "-", "x"}],
              "TraditionalForm"], ")"}], "+", 
          RowBox[{
            SubscriptBox["S", 
              RowBox[{
                FormBox["1",
                  "TraditionalForm"], "\[NoBreak]", 
                FormBox["2",
                  "TraditionalForm"]}]], "(", "x", ")"}], "-", 
          RowBox[{
            RowBox[{"log", "(", 
              RowBox[{"1", "-", "x"}], ")"}], " ", 
            RowBox[{
              SubscriptBox["Li", "2"], "(", 
              RowBox[{"1", "-", "x"}], ")"}]}], "-", 
          TagBox[
            RowBox[{"\[Zeta]", "(", 
              TagBox["3",
                (Editable -> True)], ")"}],
            InterpretTemplate[ Zeta[ #]&]]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1338]=  (21:56:24 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"sip", "[", 
      RowBox[{"PolyLog", "[", 
        RowBox[{"4", ",", 
          RowBox[{"-", 
            RowBox[{"x", "/", 
              RowBox[{"(", 
                RowBox[{"1", "-", "x"}], ")"}]}]}]}], "]"}], "]"}]], "Input",
  CellLabel->"In[1339]:=  (21:56:24 on 5/16/01)",
  CellTags->"SimplifyPolyLog"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["Li", "4"], "(", 
          RowBox[{"-", 
            FractionBox["x", 
              RowBox[{"1", "-", "x"}]]}], ")"}], "==", 
        RowBox[{
          RowBox[{
            RowBox[{"-", 
              FractionBox["1", "24"]}], " ", 
            RowBox[{
              SuperscriptBox["log", "4"], "(", 
              RowBox[{"1", "-", "x"}], ")"}]}], "+", 
          RowBox[{
            FractionBox["1", "2"], " ", 
            RowBox[{"log", "(", "x", ")"}], " ", 
            RowBox[{
              SuperscriptBox["log", "3"], "(", 
              RowBox[{"1", "-", "x"}], ")"}]}], "-", 
          RowBox[{
            FractionBox["1", "2"], " ", 
            RowBox[{
              SuperscriptBox["log", "2"], "(", "x", ")"}], " ", 
            RowBox[{
              SuperscriptBox["log", "2"], "(", 
              RowBox[{"1", "-", "x"}], ")"}]}], "-", 
          RowBox[{
            FractionBox["1", "2"], " ", 
            RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
            RowBox[{
              SuperscriptBox["log", "2"], "(", 
              RowBox[{"1", "-", "x"}], ")"}]}], "+", 
          RowBox[{
            FractionBox["1", "2"], " ", 
            RowBox[{
              SubscriptBox["Li", "2"], "(", 
              RowBox[{"1", "-", "x"}], ")"}], " ", 
            RowBox[{
              SuperscriptBox["log", "2"], "(", 
              RowBox[{"1", "-", "x"}], ")"}]}], "+", 
          RowBox[{
            RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
            RowBox[{"log", "(", "x", ")"}], " ", 
            RowBox[{"log", "(", 
              RowBox[{"1", "-", "x"}], ")"}]}], "-", 
          RowBox[{
            RowBox[{
              SubscriptBox["S", 
                RowBox[{
                  FormBox["1",
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox["2",
                    "TraditionalForm"]}]], "(", 
              FormBox[
                RowBox[{"1", "-", "x"}],
                "TraditionalForm"], ")"}], " ", 
            RowBox[{"log", "(", 
              RowBox[{"1", "-", "x"}], ")"}]}], "-", 
          RowBox[{
            RowBox[{
              SubscriptBox["S", 
                RowBox[{
                  FormBox["1",
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox["2",
                    "TraditionalForm"]}]], "(", "x", ")"}], " ", 
            RowBox[{"log", "(", 
              RowBox[{"1", "-", "x"}], ")"}]}], "-", 
          RowBox[{
            RowBox[{"log", "(", "x", ")"}], " ", 
            RowBox[{
              SubscriptBox["Li", "2"], "(", 
              RowBox[{"1", "-", "x"}], ")"}], " ", 
            RowBox[{"log", "(", 
              RowBox[{"1", "-", "x"}], ")"}]}], "+", 
          RowBox[{
            TagBox[
              RowBox[{"\[Zeta]", "(", 
                TagBox["3",
                  (Editable -> True)], ")"}],
              InterpretTemplate[ Zeta[ #]&]], " ", 
            RowBox[{"log", "(", 
              RowBox[{"1", "-", "x"}], ")"}]}], "-", 
          RowBox[{
            SubscriptBox["S", 
              RowBox[{
                FormBox["1",
                  "TraditionalForm"], "\[NoBreak]", 
                FormBox["3",
                  "TraditionalForm"]}]], "(", "x", ")"}], "+", 
          RowBox[{
            SubscriptBox["S", 
              RowBox[{
                FormBox["2",
                  "TraditionalForm"], "\[NoBreak]", 
                FormBox["2",
                  "TraditionalForm"]}]], "(", "x", ")"}], "-", 
          RowBox[{
            SubscriptBox["Li", "4"], "(", "x", ")"}]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1339]=  (21:56:24 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"sip", "[", 
      RowBox[{"Log", "[", 
        RowBox[{"a", "+", 
          RowBox[{"b", "/", "c"}]}], "]"}], "]"}]], "Input",
  CellLabel->"In[1340]:=  (21:56:24 on 5/16/01)",
  CellTags->"SimplifyPolyLog"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"log", "(", 
          RowBox[{"a", "+", 
            FractionBox["b", "c"]}], ")"}], "==", 
        RowBox[{"log", "(", 
          FractionBox[
            RowBox[{"b", "+", 
              RowBox[{"a", " ", "c"}]}], "c"], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1340]=  (21:56:24 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"sip", "[", 
      RowBox[{"Log", "[", 
        RowBox[{"1", "/", "x"}], "]"}], "]"}]], "Input",
  CellLabel->"In[1341]:=  (21:56:24 on 5/16/01)",
  CellTags->"SimplifyPolyLog"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"log", "(", 
          FractionBox["1", "x"], ")"}], "==", 
        RowBox[{"-", 
          RowBox[{"log", "(", "x", ")"}]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1341]=  (21:56:24 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"sip", "[", 
      RowBox[{"ArcTanh", "[", "x", "]"}], "]"}]], "Input",
  CellLabel->"In[1342]:=  (21:56:24 on 5/16/01)",
  CellTags->"SimplifyPolyLog"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SuperscriptBox["tanh", 
            RowBox[{"-", "1"}]], "(", "x", ")"}], "==", 
        RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"log", "(", 
            RowBox[{"-", 
              FractionBox[
                RowBox[{"x", "+", "1"}], 
                RowBox[{"1", "-", "x"}]]}], ")"}]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1342]=  (21:56:24 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"sip", "[", 
      RowBox[{"ArcSinh", "[", "x", "]"}], "]"}]], "Input",
  CellLabel->"In[1343]:=  (21:56:24 on 5/16/01)",
  CellTags->"SimplifyPolyLog"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SuperscriptBox["sinh", 
            RowBox[{"-", "1"}]], "(", "x", ")"}], "==", 
        RowBox[{"log", "(", 
          RowBox[{"x", "+", 
            SqrtBox[
              RowBox[{
                SuperscriptBox["x", "2"], "+", "1"}]]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1343]=  (21:56:24 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"sip", "[", 
      RowBox[{"ArcCosh", "[", "x", "]"}], "]"}]], "Input",
  CellLabel->"In[1344]:=  (21:56:24 on 5/16/01)",
  CellTags->"SimplifyPolyLog"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SuperscriptBox["cosh", 
            RowBox[{"-", "1"}]], "(", "x", ")"}], "==", 
        RowBox[{"log", "(", 
          RowBox[{"x", "+", 
            SqrtBox[
              RowBox[{
                SuperscriptBox["x", "2"], "-", "1"}]]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1344]=  (21:56:24 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{"Clear", "[", "sip", "]"}]], "Input",
  CellLabel->"In[1345]:=  (21:56:24 on 5/16/01)",
  CellTags->"SimplifyPolyLog"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["SOD", "ObjectName",
  CellTags->"SOD"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"SOD"],

Cell["\<\
SOD[q] is a D-dimensional scalar product of OPEDelta with q. It is \
transformed into Pair[Momentum[q,D], Momentum[OPEDelta,D] by \
FeynCalcInternal.\
\>", "Text",
  CellTags->"SOD"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["OPEDelta",
    ButtonData:>"OPEDelta",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"OPEDelta"],
  ", ",
  ButtonBox["Pair",
    ButtonData:>"Pair",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Pair"],
  ", ",
  ButtonBox["ScalarProduct",
    ButtonData:>"ScalarProduct",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"ScalarProduct"],
  ", ",
  ButtonBox["SOD",
    ButtonData:>"SOD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SOD"],
  "."
}], "Text",
  CellTags->"SOD"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"SOD"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SOD", "[", "p", "]"}]], "Input",
  CellLabel->"In[1346]:=  (21:56:24 on 5/16/01)",
  CellTags->"SOD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox["\<\"\[CapitalDelta]\"\>",
          "TraditionalForm"], 
        FormBox["\<\"\[CenterDot]\"\>",
          "TraditionalForm"], 
        FormBox["p",
          "TraditionalForm"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1346]=  (21:56:24 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SOD", "[", 
      RowBox[{"p", "-", "q"}], "]"}]], "Input",
  CellLabel->"In[1347]:=  (21:56:25 on 5/16/01)",
  CellTags->"SOD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox["\<\"\[CapitalDelta]\"\>",
          "TraditionalForm"], 
        FormBox["\<\"\[CenterDot]\"\>",
          "TraditionalForm"], 
        FormBox["\<\"(\"\>",
          "TraditionalForm"], 
        FormBox[
          RowBox[{"p", "-", "q"}],
          "TraditionalForm"], 
        FormBox["\<\")\"\>",
          "TraditionalForm"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1347]=  (21:56:25 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"SOD", "[", "p", "]"}], "//", "FCI"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[1348]:=  (21:56:25 on 5/16/01)",
  CellTags->"SOD"],

Cell[BoxData[
    RowBox[{"Pair", "[", 
      RowBox[{
        RowBox[{"Momentum", "[", 
          RowBox[{"OPEDelta", ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
          RowBox[{"p", ",", "D"}], "]"}]}], "]"}]], "Output",
  CellLabel->"Out[1348]//StandardForm=  (21:56:25 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Solve2", "ObjectName",
  CellTags->"Solve2"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"Solve2"],

Cell["\<\
Solve2 is equivalent to Solve, except that it works only for linear equations \
(and returns just a list) and accepts the options Factoring and \
FinalSubstitutions. Solve2 uses the \"high school algorithm\" and factors \
intermediate results.Therefore it can be drastically more useful than \
Solve.\
\>", "Text",
  CellTags->"Solve2"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "Solve2", "]"}]], "Input",
  CellLabel->"In[1349]:=  (21:56:25 on 5/16/01)",
  CellTags->"Solve2"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"Factoring", "\[Rule]", "Factor2"}], ",", 
          RowBox[{"FinalSubstitutions", "\[Rule]", 
            RowBox[{"{", "}"}]}]}], "}"}], TraditionalForm]], "Output",
  CellLabel->"Out[1349]=  (21:56:25 on 5/16/01)"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"Solve2"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Solve2", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{"2", " ", "x"}], "==", 
              RowBox[{"b", "-", 
                RowBox[{"w", "/", "2"}]}]}], ",", 
            RowBox[{
              RowBox[{"y", "-", "d"}], "==", "p"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"x", ",", "y"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[1350]:=  (21:56:25 on 5/16/01)",
  CellTags->"Solve2"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"x", "\[Rule]", 
            RowBox[{
              FractionBox["1", "4"], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"2", " ", "b"}], "-", "w"}], ")"}]}]}], ",", 
          RowBox[{"y", "\[Rule]", 
            RowBox[{"d", "+", "p"}]}]}], "}"}], TraditionalForm]], "Output",
  CellLabel->"Out[1350]=  (21:56:25 on 5/16/01)"]
}, Closed]],

Cell["\<\
If no equation sign is given the polynomials are supposed to be 0.\
\>", "Text",
  CellTags->"Solve2"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Solve2", "[", 
      RowBox[{
        RowBox[{"x", "+", "y"}], ",", "x"}], "]"}]], "Input",
  CellLabel->"In[1351]:=  (21:56:25 on 5/16/01)",
  CellTags->"Solve2"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"x", "\[Rule]", 
          RowBox[{"-", "y"}]}], "}"}], TraditionalForm]], "Output",
  CellLabel->"Out[1351]=  (21:56:25 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Solve2", "[", 
      RowBox[{
        RowBox[{"x", "+", "y"}], ",", "x", ",", 
        RowBox[{"FinalSubstitutions", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{"y", "\[Rule]", "h"}], "}"}]}]}], "]"}]], "Input",
  CellLabel->"In[1352]:=  (21:56:25 on 5/16/01)",
  CellTags->"Solve2"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"x", "\[Rule]", 
          RowBox[{"-", "h"}]}], "}"}], TraditionalForm]], "Output",
  CellLabel->"Out[1352]=  (21:56:25 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Solve2", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{"2", " ", "x"}], "==", 
              RowBox[{"b", "-", 
                RowBox[{"w", "/", "2"}]}]}], ",", 
            RowBox[{
              RowBox[{"y", "-", "d"}], "==", "p"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"x", ",", "y"}], "}"}], ",", 
        RowBox[{"Factoring", "\[Rule]", "Expand"}]}], "]"}]], "Input",
  CellLabel->"In[1353]:=  (21:56:25 on 5/16/01)",
  CellTags->"Solve2"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"x", "\[Rule]", 
            RowBox[{
              FractionBox["b", "2"], "-", 
              FractionBox["w", "4"]}]}], ",", 
          RowBox[{"y", "\[Rule]", 
            RowBox[{"d", "+", "p"}]}]}], "}"}], TraditionalForm]], "Output",
  CellLabel->"Out[1353]=  (21:56:25 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Solve", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{"2", " ", "x"}], "==", 
              RowBox[{"b", "-", 
                RowBox[{"w", "/", "2"}]}]}], ",", 
            RowBox[{
              RowBox[{"y", "-", "d"}], "==", "p"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"x", ",", "y"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[1354]:=  (21:56:25 on 5/16/01)",
  CellTags->"Solve2"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"x", "\[Rule]", 
              RowBox[{
                FractionBox["1", "4"], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"2", " ", "b"}], "-", "w"}], ")"}]}]}], ",", 
            RowBox[{"y", "\[Rule]", 
              RowBox[{"d", "+", "p"}]}]}], "}"}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1354]=  (21:56:25 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["SO", "ObjectName",
  CellTags->"SO"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"SO"],

Cell["\<\
SO[q] is a four-dimensional scalar product of OPEDelta with q. It is \
transformed into Pair[Momentum[q], Momentum[OPEDelta] by FCI.\
\>", "Text",
  CellTags->"SO"],

Cell[TextData[{
  "See also: ",
  ButtonBox["FCI",
    ButtonData:>"FCI",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FCI"],
  ", ",
  ButtonBox["OPEDelta",
    ButtonData:>"OPEDelta",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"OPEDelta"],
  ", ",
  ButtonBox["Pair",
    ButtonData:>"Pair",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Pair"],
  ", ",
  ButtonBox["ScalarProduct",
    ButtonData:>"ScalarProduct",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"ScalarProduct"],
  ", ",
  ButtonBox["SOD",
    ButtonData:>"SOD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SOD"],
  "."
}], "Text",
  CellTags->"SO"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"SO"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SO", "[", "p", "]"}]], "Input",
  CellLabel->"In[1355]:=  (21:56:25 on 5/16/01)",
  CellTags->"SO"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox["\<\"\[CapitalDelta]\"\>",
          "TraditionalForm"], 
        FormBox["\<\"\[CenterDot]\"\>",
          "TraditionalForm"], 
        FormBox["p",
          "TraditionalForm"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1355]=  (21:56:25 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SO", "[", 
      RowBox[{"p", "-", "q"}], "]"}]], "Input",
  CellLabel->"In[1356]:=  (21:56:25 on 5/16/01)",
  CellTags->"SO"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox["\<\"\[CapitalDelta]\"\>",
          "TraditionalForm"], 
        FormBox["\<\"\[CenterDot]\"\>",
          "TraditionalForm"], 
        FormBox["\<\"(\"\>",
          "TraditionalForm"], 
        FormBox[
          RowBox[{"p", "-", "q"}],
          "TraditionalForm"], 
        FormBox["\<\")\"\>",
          "TraditionalForm"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1356]=  (21:56:25 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"SO", "[", "p", "]"}], "//", "FCI"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[1357]:=  (21:56:25 on 5/16/01)",
  CellTags->"SO"],

Cell[BoxData[
    RowBox[{"Pair", "[", 
      RowBox[{
        RowBox[{"Momentum", "[", "OPEDelta", "]"}], ",", 
        RowBox[{"Momentum", "[", "p", "]"}]}], "]"}]], "Output",
  CellLabel->"Out[1357]//StandardForm=  (21:56:25 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["SP", "ObjectName",
  CellTags->"SP"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"SP"],

Cell[TextData[{
  "SP[a, b] denotes a four-dimensional scalar product. SP[a, b] is \
transformed into ScalarProduct[a, b] by FeynCalcInternal. SP[p] is the same \
as SP[p, p] ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", 
          RowBox[{"=", 
            SuperscriptBox["p", "2"]}]}], TraditionalForm]]],
  ")."
}], "Text",
  CellTags->"SP"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["Calc",
    ButtonData:>"Calc",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Calc"],
  ", ",
  ButtonBox["ExpandScalarProduct",
    ButtonData:>"ExpandScalarProduct",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"ExpandScalarProduct"],
  ", ",
  ButtonBox["ScalarProduct",
    ButtonData:>"ScalarProduct",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"ScalarProduct"],
  "."
}], "Text",
  CellTags->"SP"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"SP"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"SP", "[", 
        RowBox[{"p", ",", "q"}], "]"}], " ", "+", " ", 
      RowBox[{"SP", "[", "q", "]"}]}]], "Input",
  CellLabel->"In[1358]:=  (21:56:25 on 5/16/01)",
  CellTags->"SP"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          RowBox[{
            FormBox["p",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["q",
              "TraditionalForm"]}],
          "TraditionalForm"], "+", 
        FormBox[
          SuperscriptBox[
            FormBox["q",
              "TraditionalForm"], "2"],
          "TraditionalForm"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1358]=  (21:56:25 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SP", "[", 
      RowBox[{
        RowBox[{"p", "-", "q"}], ",", 
        RowBox[{"q", "+", 
          RowBox[{"2", "p"}]}]}], "]"}]], "Input",
  CellLabel->"In[1359]:=  (21:56:25 on 5/16/01)",
  CellTags->"SP"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", 
        FormBox[
          RowBox[{"p", "-", "q"}],
          "TraditionalForm"], "\[NoBreak]", ")", "\[NoBreak]", "\[CenterDot]",
         "\[NoBreak]", "(", "\[NoBreak]", 
        FormBox[
          RowBox[{
            RowBox[{"2", " ", "p"}], "+", "q"}],
          "TraditionalForm"], "\[NoBreak]", ")"}], TraditionalForm]], "Output",\

  CellLabel->"Out[1359]=  (21:56:25 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Calc", "[", " ", 
      RowBox[{"SP", "[", 
        RowBox[{
          RowBox[{"p", "-", "q"}], ",", 
          RowBox[{"q", "+", 
            RowBox[{"2", "p"}]}]}], "]"}], " ", "]"}]], "Input",
  CellLabel->"In[1360]:=  (21:56:25 on 5/16/01)",
  CellTags->"SP"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"2", " ", 
          SuperscriptBox[
            FormBox["p",
              "TraditionalForm"], "2"]}], "-", 
        RowBox[{
          FormBox["p",
            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
          FormBox["q",
            "TraditionalForm"]}], "-", 
        SuperscriptBox[
          FormBox["q",
            "TraditionalForm"], "2"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1360]=  (21:56:25 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ExpandScalarProduct", "[", 
      RowBox[{"SP", "[", 
        RowBox[{"p", "-", "q"}], "]"}], "]"}]], "Input",
  CellLabel->"In[1361]:=  (21:56:25 on 5/16/01)",
  CellTags->"SP"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox[
          FormBox["p",
            "TraditionalForm"], "2"], "-", 
        RowBox[{"2", " ", 
          RowBox[{
            FormBox["p",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["q",
              "TraditionalForm"]}]}], "+", 
        SuperscriptBox[
          FormBox["q",
            "TraditionalForm"], "2"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1361]=  (21:56:25 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"SP", "[", 
        RowBox[{"a", ",", "b"}], "]"}], "//", "StandardForm"}]], "Input",
  CellLabel->"In[1362]:=  (21:56:25 on 5/16/01)",
  CellTags->"SP"],

Cell[BoxData[
    RowBox[{"SP", "[", 
      RowBox[{"a", ",", "b"}], "]"}]], "Output",
  CellLabel->"Out[1362]//StandardForm=  (21:56:25 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"SP", "[", 
          RowBox[{"a", ",", "b"}], "]"}], "//", "FCI"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[1363]:=  (21:56:25 on 5/16/01)",
  CellTags->"SP"],

Cell[BoxData[
    RowBox[{"Pair", "[", 
      RowBox[{
        RowBox[{"Momentum", "[", "a", "]"}], ",", 
        RowBox[{"Momentum", "[", "b", "]"}]}], "]"}]], "Output",
  CellLabel->"Out[1363]//StandardForm=  (21:56:25 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          RowBox[{"SP", "[", 
            RowBox[{"a", ",", "b"}], "]"}], "//", "FCI"}], "//", "FCE"}], "//",
       "StandardForm"}]], "Input",
  CellLabel->"In[1364]:=  (21:56:25 on 5/16/01)",
  CellTags->"SP"],

Cell[BoxData[
    RowBox[{"SP", "[", 
      RowBox[{"a", ",", "b"}], "]"}]], "Output",
  CellLabel->"Out[1364]//StandardForm=  (21:56:26 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["SPD", "ObjectName",
  CellTags->"SPD"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"SPD"],

Cell[TextData[{
  "SPD[a, b] denotes a D-dimensional scalar product. SPD[a, b] is transformed \
into ScalarProduct[a, b,Dimension\[Rule]D] by FeynCalcInternal. SPD[p] is the \
same as SPD[p,p] ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", 
          RowBox[{"=", 
            SuperscriptBox["p", "2"]}]}], TraditionalForm]]],
  ")."
}], "Text",
  CellTags->"SPD"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["Calc",
    ButtonData:>"Calc",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Calc"],
  ", ",
  ButtonBox["ExpandScalarProduct",
    ButtonData:>"ExpandScalarProduct",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"ExpandScalarProduct"],
  ", ",
  ButtonBox["ScalarProduct",
    ButtonData:>"ScalarProduct",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"ScalarProduct"],
  "."
}], "Text",
  CellTags->"SPD"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"SPD"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"SPD", "[", 
        RowBox[{"p", ",", "q"}], "]"}], " ", "+", " ", 
      RowBox[{"SPD", "[", "q", "]"}]}]], "Input",
  CellLabel->"In[1365]:=  (21:56:26 on 5/16/01)",
  CellTags->"SPD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          RowBox[{
            FormBox["p",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["q",
              "TraditionalForm"]}],
          "TraditionalForm"], "+", 
        FormBox[
          SuperscriptBox[
            FormBox["q",
              "TraditionalForm"], "2"],
          "TraditionalForm"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1365]=  (21:56:26 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SPD", "[", 
      RowBox[{
        RowBox[{"p", "-", "q"}], ",", 
        RowBox[{"q", "+", 
          RowBox[{"2", "p"}]}]}], "]"}]], "Input",
  CellLabel->"In[1366]:=  (21:56:26 on 5/16/01)",
  CellTags->"SPD"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", 
        FormBox[
          RowBox[{"p", "-", "q"}],
          "TraditionalForm"], "\[NoBreak]", ")", "\[NoBreak]", "\[CenterDot]",
         "\[NoBreak]", "(", "\[NoBreak]", 
        FormBox[
          RowBox[{
            RowBox[{"2", " ", "p"}], "+", "q"}],
          "TraditionalForm"], "\[NoBreak]", ")"}], TraditionalForm]], "Output",\

  CellLabel->"Out[1366]=  (21:56:26 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Calc", "[", " ", 
      RowBox[{"SPD", "[", 
        RowBox[{
          RowBox[{"p", "-", "q"}], ",", 
          RowBox[{"q", "+", 
            RowBox[{"2", "p"}]}]}], "]"}], " ", "]"}]], "Input",
  CellLabel->"In[1367]:=  (21:56:26 on 5/16/01)",
  CellTags->"SPD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"2", " ", 
          SuperscriptBox[
            FormBox["p",
              "TraditionalForm"], "2"]}], "-", 
        RowBox[{
          FormBox["p",
            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
          FormBox["q",
            "TraditionalForm"]}], "-", 
        SuperscriptBox[
          FormBox["q",
            "TraditionalForm"], "2"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1367]=  (21:56:26 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ExpandScalarProduct", "[", 
      RowBox[{"SPD", "[", 
        RowBox[{"p", "-", "q"}], "]"}], "]"}]], "Input",
  CellLabel->"In[1368]:=  (21:56:26 on 5/16/01)",
  CellTags->"SPD"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox[
          FormBox["p",
            "TraditionalForm"], "2"], "-", 
        RowBox[{"2", " ", 
          RowBox[{
            FormBox["p",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["q",
              "TraditionalForm"]}]}], "+", 
        SuperscriptBox[
          FormBox["q",
            "TraditionalForm"], "2"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1368]=  (21:56:26 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"SPD", "[", 
        RowBox[{"a", ",", "b"}], "]"}], "//", "StandardForm"}]], "Input",
  CellLabel->"In[1369]:=  (21:56:26 on 5/16/01)",
  CellTags->"SPD"],

Cell[BoxData[
    RowBox[{"SPD", "[", 
      RowBox[{"a", ",", "b"}], "]"}]], "Output",
  CellLabel->"Out[1369]//StandardForm=  (21:56:26 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"SPD", "[", 
          RowBox[{"a", ",", "b"}], "]"}], "//", "FCI"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[1370]:=  (21:56:26 on 5/16/01)",
  CellTags->"SPD"],

Cell[BoxData[
    RowBox[{"Pair", "[", 
      RowBox[{
        RowBox[{"Momentum", "[", 
          RowBox[{"a", ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
          RowBox[{"b", ",", "D"}], "]"}]}], "]"}]], "Output",
  CellLabel->"Out[1370]//StandardForm=  (21:56:26 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          RowBox[{"SPD", "[", 
            RowBox[{"a", ",", "b"}], "]"}], "//", "FCI"}], "//", "FCE"}], "//",
       "StandardForm"}]], "Input",
  CellLabel->"In[1371]:=  (21:56:26 on 5/16/01)",
  CellTags->"SPD"],

Cell[BoxData[
    RowBox[{"SPD", "[", 
      RowBox[{"a", ",", "b"}], "]"}]], "Output",
  CellLabel->"Out[1371]//StandardForm=  (21:56:26 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"FCE", "[", 
        RowBox[{"ChangeDimension", "[", 
          RowBox[{
            RowBox[{"SP", "[", 
              RowBox[{"p", ",", "q"}], "]"}], ",", " ", "D"}], "]"}], "]"}], "//",
       "StandardForm"}]], "Input",
  CellLabel->"In[1372]:=  (21:56:26 on 5/16/01)",
  CellTags->"SPD"],

Cell[BoxData[
    RowBox[{"SPD", "[", 
      RowBox[{"p", ",", "q"}], "]"}]], "Output",
  CellLabel->"Out[1372]//StandardForm=  (21:56:26 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Spinor", "ObjectName",
  CellTags->"Spinor"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"Spinor"],

Cell[TextData[{
  "Spinor[p, m, optarg] is the head of Dirac spinors. Which of the spinors u, \
v, ",
  Cell[BoxData[
      FormBox[
        OverscriptBox["u", "_"], TraditionalForm]]],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{",", " "}], TraditionalForm]]],
  "or ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          OverscriptBox["v", "_"], " "}], TraditionalForm]]],
  "is understood, depends on the sign of the momentum (p) argument and the \
relative position of DiracSlash[p]: Spinor[sign p, mass] is that spinor which \
yields: sign*mass*Spinor[p, mass] if the Dirac equation is applied (by \
DiracEquation or DiracSimplify)."
}], "Text",
  CellTags->"Spinor"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["DiracSimplify",
    ButtonData:>"DiracSimplify",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracSimplify"],
  ", ",
  ButtonBox["SpinorU",
    ButtonData:>"SpinorU",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SpinorU"],
  ", ",
  ButtonBox["SpinorV",
    ButtonData:>"SpinorV",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SpinorV"],
  ", ",
  ButtonBox["SpinorUBar",
    ButtonData:>"SpinorUBar",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SpinorUBar"],
  ", ",
  ButtonBox["SpinorVBar",
    ButtonData:>"SpinorVBar",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SpinorVBar"],
  "."
}], "Text",
  CellTags->"Spinor"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"Spinor"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Spinor", "[", "p", "]"}]], "Input",
  CellLabel->"In[1373]:=  (21:56:26 on 5/16/01)",
  CellTags->"Spinor"],

Cell[BoxData[
    FormBox[
      RowBox[{"\[CurlyPhi]", "\[NoBreak]", "(", "\[NoBreak]", 
        FormBox["p",
          "TraditionalForm"], "\[NoBreak]", ")"}], TraditionalForm]], "Output",\

  CellLabel->"Out[1373]=  (21:56:26 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Spinor", "[", 
      RowBox[{"p", ",", "m"}], "]"}]], "Input",
  CellLabel->"In[1374]:=  (21:56:26 on 5/16/01)",
  CellTags->"Spinor"],

Cell[BoxData[
    FormBox[
      RowBox[{"\[CurlyPhi]", "\[NoBreak]", "(", "\[NoBreak]", 
        FormBox["p",
          "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", "m", 
        "\[NoBreak]", ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[1374]=  (21:56:26 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DiracSimplify", "[", 
      RowBox[{
        RowBox[{"Spinor", "[", 
          RowBox[{
            RowBox[{"-", "p"}], ",", "m"}], "]"}], ".", 
        RowBox[{"DiracSlash", "[", "p", "]"}]}], "]"}]], "Input",
  CellLabel->"In[1375]:=  (21:56:26 on 5/16/01)",
  CellTags->"Spinor"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", "m"}], " ", 
        RowBox[{"\[CurlyPhi]", "\[NoBreak]", "(", "\[NoBreak]", 
          FormBox[
            RowBox[{"-", "p"}],
            "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", "m", 
          "\[NoBreak]", ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1375]=  (21:56:26 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Spinor", "[", "p", "]"}], "//", "StandardForm"}]], "Input",
  CellLabel->"In[1376]:=  (21:56:26 on 5/16/01)",
  CellTags->"Spinor"],

Cell[BoxData[
    RowBox[{"Spinor", "[", 
      RowBox[{
        RowBox[{"Momentum", "[", "p", "]"}], ",", "0", ",", "1"}], 
      "]"}]], "Output",
  CellLabel->"Out[1376]//StandardForm=  (21:56:26 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"ChangeDimension", "[", 
        RowBox[{
          RowBox[{"Spinor", "[", "p", "]"}], ",", "D"}], "]"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[1377]:=  (21:56:26 on 5/16/01)",
  CellTags->"Spinor"],

Cell[BoxData[
    RowBox[{"Spinor", "[", 
      RowBox[{
        RowBox[{"Momentum", "[", "p", "]"}], ",", "0", ",", "1"}], 
      "]"}]], "Output",
  CellLabel->"Out[1377]//StandardForm=  (21:56:26 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Spinor", "[", 
        RowBox[{"p", ",", "m"}], "]"}], "//", "StandardForm"}]], "Input",
  CellLabel->"In[1378]:=  (21:56:26 on 5/16/01)",
  CellTags->"Spinor"],

Cell[BoxData[
    RowBox[{"Spinor", "[", 
      RowBox[{
        RowBox[{"Momentum", "[", "p", "]"}], ",", "m", ",", "1"}], 
      "]"}]], "Output",
  CellLabel->"Out[1378]//StandardForm=  (21:56:27 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Spinor", "[", 
        RowBox[{"p", ",", 
          RowBox[{"SmallVariable", "[", "m", "]"}]}], "]"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[1379]:=  (21:56:27 on 5/16/01)",
  CellTags->"Spinor"],

Cell[BoxData[
    RowBox[{"Spinor", "[", 
      RowBox[{
        RowBox[{"Momentum", "[", "p", "]"}], ",", "0", ",", "1"}], 
      "]"}]], "Output",
  CellLabel->"Out[1379]//StandardForm=  (21:56:27 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["SpinorUBar", "ObjectName",
  CellTags->"SpinorUBar"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"SpinorUBar"],

Cell[TextData[{
  "SpinorUBar[p, m] denotes a ",
  Cell[BoxData[
      FormBox[
        OverscriptBox["u", "_"], TraditionalForm]]],
  " - spinor."
}], "Text",
  CellTags->"SpinorUBar"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["Spinor",
    ButtonData:>"Spinor",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Spinor"],
  ", ",
  ButtonBox["SpinorU",
    ButtonData:>"SpinorU",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SpinorU"],
  ", ",
  ButtonBox["SpinorV",
    ButtonData:>"SpinorV",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SpinorV"],
  ", ",
  ButtonBox["SpinorVBar",
    ButtonData:>"SpinorVBar",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SpinorVBar"],
  "."
}], "Text",
  CellTags->"SpinorUBar"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"SpinorUBar"],

Cell["One argument only assumes a massless spinor.", "Text",
  CellTags->"SpinorUBar"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SpinorUBar", "[", "p", "]"}]], "Input",
  CellLabel->"In[1380]:=  (21:56:27 on 5/16/01)",
  CellTags->"SpinorUBar"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          OverscriptBox["\<\"u\"\>", "_"],
          "TraditionalForm"], "\[NoBreak]", "(", "\[NoBreak]", "p", 
        "\[NoBreak]", ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[1380]=  (21:56:27 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SpinorUBar", "[", 
      RowBox[{"p", ",", "m"}], "]"}]], "Input",
  CellLabel->"In[1381]:=  (21:56:27 on 5/16/01)",
  CellTags->"SpinorUBar"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          OverscriptBox["\<\"u\"\>", "_"],
          "TraditionalForm"], "\[NoBreak]", "(", "\[NoBreak]", "p", 
        "\[NoBreak]", ",", "\[NoBreak]", "m", "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1381]=  (21:56:27 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"SpinorUBar", "[", 
        RowBox[{"p", ",", "m"}], "]"}], "//", "StandardForm"}]], "Input",
  CellLabel->"In[1382]:=  (21:56:27 on 5/16/01)",
  CellTags->"SpinorUBar"],

Cell[BoxData[
    RowBox[{"SpinorUBar", "[", 
      RowBox[{"p", ",", "m"}], "]"}]], "Output",
  CellLabel->"Out[1382]//StandardForm=  (21:56:27 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"SpinorUBar", "[", 
          RowBox[{"p", ",", "m"}], "]"}], "//", "FCI"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[1383]:=  (21:56:27 on 5/16/01)",
  CellTags->"SpinorUBar"],

Cell[BoxData[
    RowBox[{"Spinor", "[", 
      RowBox[{
        RowBox[{"Momentum", "[", "p", "]"}], ",", "m", ",", "1"}], 
      "]"}]], "Output",
  CellLabel->"Out[1383]//StandardForm=  (21:56:27 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          RowBox[{"SpinorUBar", "[", 
            RowBox[{"p", ",", "m"}], "]"}], "//", "FCI"}], "//", "FCE"}], "//",
       "StandardForm"}]], "Input",
  CellLabel->"In[1384]:=  (21:56:27 on 5/16/01)",
  CellTags->"SpinorUBar"],

Cell[BoxData[
    RowBox[{"Spinor", "[", 
      RowBox[{
        RowBox[{"Momentum", "[", "p", "]"}], ",", "m", ",", "1"}], 
      "]"}]], "Output",
  CellLabel->"Out[1384]//StandardForm=  (21:56:27 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["SpinorU", "ObjectName",
  CellTags->"SpinorU"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"SpinorU"],

Cell["SpinorU[p, m, optarg] denotes a u-spinor.", "Text",
  CellTags->"SpinorU"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["Spinor",
    ButtonData:>"Spinor",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Spinor"],
  ", ",
  ButtonBox["SpinorUBar",
    ButtonData:>"SpinorUBar",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SpinorUBar"],
  ", ",
  ButtonBox["SpinorV",
    ButtonData:>"SpinorV",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SpinorV"],
  ", ",
  ButtonBox["SpinorVBar",
    ButtonData:>"SpinorVBar",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SpinorVBar"],
  "."
}], "Text",
  CellTags->"SpinorU"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"SpinorU"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SpinorU", "[", "p", "]"}]], "Input",
  CellLabel->"In[1385]:=  (21:56:27 on 5/16/01)",
  CellTags->"SpinorU"],

Cell[BoxData[
    FormBox[
      RowBox[{"u", "\[NoBreak]", "(", "\[NoBreak]", "p", "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1385]=  (21:56:27 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SpinorU", "[", 
      RowBox[{"p", ",", "m"}], "]"}]], "Input",
  CellLabel->"In[1386]:=  (21:56:27 on 5/16/01)",
  CellTags->"SpinorU"],

Cell[BoxData[
    FormBox[
      RowBox[{
      "u", "\[NoBreak]", "(", "\[NoBreak]", "p", "\[NoBreak]", ",", 
        "\[NoBreak]", "m", "\[NoBreak]", ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[1386]=  (21:56:27 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"SpinorU", "[", 
        RowBox[{"p", ",", "m"}], "]"}], "//", "StandardForm"}]], "Input",
  CellLabel->"In[1387]:=  (21:56:27 on 5/16/01)",
  CellTags->"SpinorU"],

Cell[BoxData[
    RowBox[{"SpinorU", "[", 
      RowBox[{"p", ",", "m"}], "]"}]], "Output",
  CellLabel->"Out[1387]//StandardForm=  (21:56:27 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"SpinorU", "[", 
          RowBox[{"p", ",", "m"}], "]"}], "//", "FCI"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[1388]:=  (21:56:27 on 5/16/01)",
  CellTags->"SpinorU"],

Cell[BoxData[
    RowBox[{"Spinor", "[", 
      RowBox[{
        RowBox[{"Momentum", "[", "p", "]"}], ",", "m", ",", "1"}], 
      "]"}]], "Output",
  CellLabel->"Out[1388]//StandardForm=  (21:56:27 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          RowBox[{"SpinorU", "[", 
            RowBox[{"p", ",", "m"}], "]"}], "//", "FCI"}], "//", "FCE"}], "//",
       "StandardForm"}]], "Input",
  CellLabel->"In[1389]:=  (21:56:27 on 5/16/01)",
  CellTags->"SpinorU"],

Cell[BoxData[
    RowBox[{"Spinor", "[", 
      RowBox[{
        RowBox[{"Momentum", "[", "p", "]"}], ",", "m", ",", "1"}], 
      "]"}]], "Output",
  CellLabel->"Out[1389]//StandardForm=  (21:56:27 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["SpinorVBar", "ObjectName",
  CellTags->"SpinorVBar"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"SpinorVBar"],

Cell[TextData[{
  "SpinorVBar[p, m] denotes a ",
  Cell[BoxData[
      FormBox[
        OverscriptBox["v", "_"], TraditionalForm]]],
  "(p,m) - spinor."
}], "Text",
  CellTags->"SpinorVBar"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["Spinor",
    ButtonData:>"Spinor",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Spinor"],
  ", ",
  ButtonBox["SpinorU",
    ButtonData:>"SpinorU",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SpinorU"],
  ", ",
  ButtonBox["SpinorV",
    ButtonData:>"SpinorV",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SpinorV"],
  ", ",
  ButtonBox["SpinorUBar",
    ButtonData:>"SpinorUBar",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SpinorUBar"],
  "."
}], "Text",
  CellTags->"SpinorVBar"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"SpinorVBar"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SpinorVBar", "[", "p", "]"}]], "Input",
  CellLabel->"In[1390]:=  (21:56:27 on 5/16/01)",
  CellTags->"SpinorVBar"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          OverscriptBox["\<\"v\"\>", "_"],
          "TraditionalForm"], "\[NoBreak]", "(", "\[NoBreak]", "p", 
        "\[NoBreak]", ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[1390]=  (21:56:27 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SpinorVBar", "[", 
      RowBox[{"p", ",", "m"}], "]"}]], "Input",
  CellLabel->"In[1391]:=  (21:56:27 on 5/16/01)",
  CellTags->"SpinorVBar"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          OverscriptBox["\<\"v\"\>", "_"],
          "TraditionalForm"], "\[NoBreak]", "(", "\[NoBreak]", "p", 
        "\[NoBreak]", ",", "\[NoBreak]", "m", "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1391]=  (21:56:27 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"SpinorVBar", "[", 
        RowBox[{"p", ",", "m"}], "]"}], "//", "StandardForm"}]], "Input",
  CellLabel->"In[1392]:=  (21:56:27 on 5/16/01)",
  CellTags->"SpinorVBar"],

Cell[BoxData[
    RowBox[{"SpinorVBar", "[", 
      RowBox[{"p", ",", "m"}], "]"}]], "Output",
  CellLabel->"Out[1392]//StandardForm=  (21:56:27 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"SpinorVBar", "[", 
          RowBox[{"p", ",", "m"}], "]"}], "//", "FCI"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[1393]:=  (21:56:27 on 5/16/01)",
  CellTags->"SpinorVBar"],

Cell[BoxData[
    RowBox[{"Spinor", "[", 
      RowBox[{
        RowBox[{"-", 
          RowBox[{"Momentum", "[", "p", "]"}]}], ",", "m", ",", "1"}], 
      "]"}]], "Output",
  CellLabel->"Out[1393]//StandardForm=  (21:56:27 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          RowBox[{"SpinorVBar", "[", 
            RowBox[{"p", ",", "m"}], "]"}], "//", "FCI"}], "//", "FCE"}], "//",
       "StandardForm"}]], "Input",
  CellLabel->"In[1394]:=  (21:56:27 on 5/16/01)",
  CellTags->"SpinorVBar"],

Cell[BoxData[
    RowBox[{"Spinor", "[", 
      RowBox[{
        RowBox[{"-", 
          RowBox[{"Momentum", "[", "p", "]"}]}], ",", "m", ",", "1"}], 
      "]"}]], "Output",
  CellLabel->"Out[1394]//StandardForm=  (21:56:27 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["SpinorV", "ObjectName",
  CellTags->"SpinorV"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"SpinorV"],

Cell["SpinorV[p, m, optarg] denotes a v-spinor.", "Text",
  CellTags->"SpinorV"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["Spinor",
    ButtonData:>"Spinor",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Spinor"],
  ", ",
  ButtonBox["SpinorUBar",
    ButtonData:>"SpinorUBar",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SpinorUBar"],
  ", ",
  ButtonBox["SpinorU",
    ButtonData:>"SpinorU",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SpinorU"],
  ", ",
  ButtonBox["SpinorVBar",
    ButtonData:>"SpinorVBar",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SpinorVBar"],
  "."
}], "Text",
  CellTags->"SpinorV"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"SpinorV"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SpinorV", "[", "p", "]"}]], "Input",
  CellLabel->"In[1395]:=  (21:56:27 on 5/16/01)",
  CellTags->"SpinorV"],

Cell[BoxData[
    FormBox[
      RowBox[{"v", "\[NoBreak]", "(", "\[NoBreak]", "p", "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1395]=  (21:56:27 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SpinorV", "[", 
      RowBox[{"p", ",", "m"}], "]"}]], "Input",
  CellLabel->"In[1396]:=  (21:56:27 on 5/16/01)",
  CellTags->"SpinorV"],

Cell[BoxData[
    FormBox[
      RowBox[{
      "v", "\[NoBreak]", "(", "\[NoBreak]", "p", "\[NoBreak]", ",", 
        "\[NoBreak]", "m", "\[NoBreak]", ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[1396]=  (21:56:27 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"SpinorV", "[", 
        RowBox[{"p", ",", "m"}], "]"}], "//", "StandardForm"}]], "Input",
  CellLabel->"In[1397]:=  (21:56:27 on 5/16/01)",
  CellTags->"SpinorV"],

Cell[BoxData[
    RowBox[{"SpinorV", "[", 
      RowBox[{"p", ",", "m"}], "]"}]], "Output",
  CellLabel->"Out[1397]//StandardForm=  (21:56:27 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"SpinorV", "[", 
          RowBox[{"p", ",", "m"}], "]"}], "//", "FCI"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[1398]:=  (21:56:28 on 5/16/01)",
  CellTags->"SpinorV"],

Cell[BoxData[
    RowBox[{"Spinor", "[", 
      RowBox[{
        RowBox[{"-", 
          RowBox[{"Momentum", "[", "p", "]"}]}], ",", "m", ",", "1"}], 
      "]"}]], "Output",
  CellLabel->"Out[1398]//StandardForm=  (21:56:28 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          RowBox[{"SpinorV", "[", 
            RowBox[{"p", ",", "m"}], "]"}], "//", "FCI"}], "//", "FCE"}], "//",
       "StandardForm"}]], "Input",
  CellLabel->"In[1399]:=  (21:56:28 on 5/16/01)",
  CellTags->"SpinorV"],

Cell[BoxData[
    RowBox[{"Spinor", "[", 
      RowBox[{
        RowBox[{"-", 
          RowBox[{"Momentum", "[", "p", "]"}]}], ",", "m", ",", "1"}], 
      "]"}]], "Output",
  CellLabel->"Out[1399]//StandardForm=  (21:56:28 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["SplittingFunction", "ObjectName",
  CellTags->"SplittingFunction"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"SplittingFunction"],

Cell[TextData[{
  "SplittingFunction[pxy] is a database of splitting functions in the ",
  Cell[BoxData[
      FormBox[
        OverscriptBox["MS", "_"], TraditionalForm]]],
  " scheme."
}], "Text",
  CellTags->"SplittingFunction"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "SplittingFunction", "]"}]], "Input",
  CellLabel->"In[1400]:=  (21:56:28 on 5/16/01)",
  CellTags->"SplittingFunction"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"Polarization", "\[Rule]", "1"}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1400]=  (21:56:28 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["AnomalousDimension",
    ButtonData:>"AnomalousDimension",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"AnomalousDimension"],
  "."
}], "Text",
  CellTags->"SplittingFunction"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"SplittingFunction"],

Cell["Unpolarized case:", "Text",
  CellTags->"SplittingFunction"],

Cell[BoxData[
    RowBox[{
      RowBox[{"SetOptions", "[", 
        RowBox[{"SplittingFunction", ",", 
          RowBox[{"Polarization", "\[Rule]", "0"}]}], "]"}], ";"}]], "Input",
  CellLabel->"In[1401]:=  (21:56:29 on 5/16/01)",
  CellTags->"SplittingFunction"],

Cell["\<\
In general the argument should be a string, but if the variables Pqq, etc. \
have no value, you can omit the \"\".\
\>", "Text",
  CellTags->"SplittingFunction"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SplittingFunction", "[", "Pqq", "]"}]], "Input",
  CellLabel->"In[1402]:=  (21:56:29 on 5/16/01)",
  CellTags->"SplittingFunction"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["C", "F"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"-", "4"}], " ", "x"}], "+", 
            RowBox[{"6", " ", 
              RowBox[{"\[Delta]", "(", 
                FormBox[
                  RowBox[{"1", "-", "x"}],
                  "TraditionalForm"], ")"}]}], "+", 
            RowBox[{"8", " ", 
              SubscriptBox[
                RowBox[{"(", 
                  FractionBox["1", 
                    RowBox[{"1", "-", "x"}]], ")"}], "+"]}], "-", "4"}], 
          ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1402]=  (21:56:29 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SplittingFunction", "[", "Pqg", "]"}]], "Input",
  CellLabel->"In[1403]:=  (21:56:29 on 5/16/01)",
  CellTags->"SplittingFunction"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["T", "f"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"16", " ", 
              SuperscriptBox["x", "2"]}], "-", 
            RowBox[{"16", " ", "x"}], "+", "8"}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1403]=  (21:56:29 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SplittingFunction", "[", "Pgq", "]"}]], "Input",
  CellLabel->"In[1404]:=  (21:56:29 on 5/16/01)",
  CellTags->"SplittingFunction"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["C", "F"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"4", " ", "x"}], "-", "8", "+", 
            FractionBox["8", "x"]}], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1404]=  (21:56:29 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SplittingFunction", "[", "Pgg", "]"}]], "Input",
  CellLabel->"In[1405]:=  (21:56:29 on 5/16/01)",
  CellTags->"SplittingFunction"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"8", " ", 
          SubscriptBox["C", "A"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                SuperscriptBox["x", "2"]}], "+", "x", "+", 
              RowBox[{
                FractionBox["11", "12"], " ", 
                RowBox[{"\[Delta]", "(", 
                  FormBox[
                    RowBox[{"1", "-", "x"}],
                    "TraditionalForm"], ")"}]}], "+", 
              SubscriptBox[
                RowBox[{"(", 
                  FractionBox["1", 
                    RowBox[{"1", "-", "x"}]], ")"}], "+"], "-", "2", "+", 
              FractionBox["1", "x"]}], ")"}]}], "-", 
        RowBox[{
          FractionBox["8", "3"], " ", 
          SubscriptBox["N", "f"], " ", 
          SubscriptBox["T", "f"], " ", 
          RowBox[{"\[Delta]", "(", 
            FormBox[
              RowBox[{"1", "-", "x"}],
              "TraditionalForm"], ")"}]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1405]=  (21:56:29 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SplittingFunction", "[", "aqq", "]"}]], "Input",
  CellLabel->"In[1406]:=  (21:56:29 on 5/16/01)",
  CellTags->"SplittingFunction"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["C", "F"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"2", " ", "x"}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"7", "-", 
                  RowBox[{"4", " ", 
                    RowBox[{"\[Zeta]", "(", "2", ")"}]}]}], ")"}], " ", 
              RowBox[{"\[Delta]", "(", 
                FormBox[
                  RowBox[{"1", "-", "x"}],
                  "TraditionalForm"], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"2", " ", "x"}], "+", "2"}], ")"}], " ", 
              RowBox[{"log", "(", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"1", "-", "x"}], ")"}], " ", "x"}], ")"}]}], "-", 
            
            RowBox[{"4", " ", 
              RowBox[{"(", 
                RowBox[{
                  FractionBox[
                    RowBox[{"log", "(", "x", ")"}], 
                    RowBox[{"1", "-", "x"}]], "+", 
                  SubscriptBox[
                    RowBox[{"(", 
                      FractionBox[
                        RowBox[{"log", "(", 
                          RowBox[{"1", "-", "x"}], ")"}], 
                        RowBox[{"1", "-", "x"}]], ")"}], "+"]}], ")"}]}], "-",
             "4"}], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1406]=  (21:56:29 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SplittingFunction", "[", "agq", "]"}]], "Input",
  CellLabel->"In[1407]:=  (21:56:29 on 5/16/01)",
  CellTags->"SplittingFunction"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["C", "F"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"-", "2"}], " ", "x"}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"-", "2"}], " ", "x"}], "+", "4", "-", 
                  FractionBox["4", "x"]}], ")"}], " ", 
              RowBox[{"log", "(", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"1", "-", "x"}], ")"}], " ", "x"}], ")"}]}], "+", 
            "2", "-", 
            FractionBox["4", "x"]}], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1407]=  (21:56:29 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SplittingFunction", "[", "aqg", "]"}]], "Input",
  CellLabel->"In[1408]:=  (21:56:29 on 5/16/01)",
  CellTags->"SplittingFunction"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["T", "f"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"-", "8"}], " ", 
                    SuperscriptBox["x", "2"]}], "+", 
                  RowBox[{"8", " ", "x"}], "-", "4"}], ")"}], " ", 
              RowBox[{"log", "(", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"1", "-", "x"}], ")"}], " ", "x"}], ")"}]}], "-", 
            "4"}], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1408]=  (21:56:29 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{"SplittingFunction", "[", "agg", "]"}]], "Input",
  CellLabel->"In[1409]:=  (21:56:29 on 5/16/01)",
  CellTags->"SplittingFunction"],

Cell["Polarized case:", "Text",
  CellTags->"SplittingFunction"],

Cell[BoxData[
    RowBox[{
      RowBox[{"SetOptions", "[", 
        RowBox[{"SplittingFunction", ",", 
          RowBox[{"Polarization", "\[Rule]", "1"}]}], "]"}], ";"}]], "Input",
  CellLabel->"In[1410]:=  (21:56:29 on 5/16/01)",
  CellTags->"SplittingFunction"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SplittingFunction", "[", "Pqq", "]"}]], "Input",
  CellLabel->"In[1411]:=  (21:56:29 on 5/16/01)",
  CellTags->"SplittingFunction"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["C", "F"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"-", "4"}], " ", "x"}], "+", 
            RowBox[{"6", " ", 
              RowBox[{"\[Delta]", "(", 
                FormBox[
                  RowBox[{"1", "-", "x"}],
                  "TraditionalForm"], ")"}]}], "+", 
            RowBox[{"8", " ", 
              SubscriptBox[
                RowBox[{"(", 
                  FractionBox["1", 
                    RowBox[{"1", "-", "x"}]], ")"}], "+"]}], "-", "4"}], 
          ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1411]=  (21:56:29 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SplittingFunction", "[", "Pqg", "]"}]], "Input",
  CellLabel->"In[1412]:=  (21:56:29 on 5/16/01)",
  CellTags->"SplittingFunction"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["T", "f"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"16", " ", "x"}], "-", "8"}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1412]=  (21:56:29 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SplittingFunction", "[", "Pgq", "]"}]], "Input",
  CellLabel->"In[1413]:=  (21:56:29 on 5/16/01)",
  CellTags->"SplittingFunction"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["C", "F"], " ", 
        RowBox[{"(", 
          RowBox[{"8", "-", 
            RowBox[{"4", " ", "x"}]}], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1413]=  (21:56:29 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SplittingFunction", "[", "Pgg", "]"}]], "Input",
  CellLabel->"In[1414]:=  (21:56:29 on 5/16/01)",
  CellTags->"SplittingFunction"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["C", "A"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"-", "16"}], " ", "x"}], "+", 
              RowBox[{
                FractionBox["22", "3"], " ", 
                RowBox[{"\[Delta]", "(", 
                  FormBox[
                    RowBox[{"1", "-", "x"}],
                    "TraditionalForm"], ")"}]}], "+", 
              RowBox[{"8", " ", 
                SubscriptBox[
                  RowBox[{"(", 
                    FractionBox["1", 
                      RowBox[{"1", "-", "x"}]], ")"}], "+"]}], "+", "8"}], 
            ")"}]}], "-", 
        RowBox[{
          FractionBox["8", "3"], " ", 
          SubscriptBox["N", "f"], " ", 
          SubscriptBox["T", "f"], " ", 
          RowBox[{"\[Delta]", "(", 
            FormBox[
              RowBox[{"1", "-", "x"}],
              "TraditionalForm"], ")"}]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1414]=  (21:56:29 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SplittingFunction", "[", "aqq", "]"}]], "Input",
  CellLabel->"In[1415]:=  (21:56:29 on 5/16/01)",
  CellTags->"SplittingFunction"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["C", "F"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"8", " ", 
              RowBox[{"(", 
                RowBox[{"1", "-", "x"}], ")"}]}], "+", 
            RowBox[{"2", " ", "x"}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"7", "-", 
                  RowBox[{"4", " ", 
                    RowBox[{"\[Zeta]", "(", "2", ")"}]}]}], ")"}], " ", 
              RowBox[{"\[Delta]", "(", 
                FormBox[
                  RowBox[{"1", "-", "x"}],
                  "TraditionalForm"], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"2", " ", "x"}], "+", "2"}], ")"}], " ", 
              RowBox[{"log", "(", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"1", "-", "x"}], ")"}], " ", "x"}], ")"}]}], "-", 
            
            RowBox[{"4", " ", 
              RowBox[{"log", "(", "x", ")"}], " ", 
              SubscriptBox[
                RowBox[{"(", 
                  FractionBox["1", 
                    RowBox[{"1", "-", "x"}]], ")"}], "+"]}], "-", 
            RowBox[{"4", " ", 
              SubscriptBox[
                RowBox[{"(", 
                  FractionBox[
                    RowBox[{"log", "(", 
                      RowBox[{"1", "-", "x"}], ")"}], 
                    RowBox[{"1", "-", "x"}]], ")"}], "+"]}], "-", "4"}], 
          ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1415]=  (21:56:29 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SplittingFunction", "[", "agq", "]"}]], "Input",
  CellLabel->"In[1416]:=  (21:56:29 on 5/16/01)",
  CellTags->"SplittingFunction"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["C", "F"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"-", "4"}], " ", "x"}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"2", " ", "x"}], "-", "4"}], ")"}], " ", 
              RowBox[{"log", "(", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"1", "-", "x"}], ")"}], " ", "x"}], ")"}]}], "+", 
            "2"}], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1416]=  (21:56:29 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SplittingFunction", "[", "agqd", "]"}]], "Input",
  CellLabel->"In[1417]:=  (21:56:29 on 5/16/01)",
  CellTags->"SplittingFunction"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["C", "F"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"2", " ", "x"}], "-", "4"}], ")"}], " ", 
              RowBox[{"log", "(", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"1", "-", "x"}], ")"}], " ", "x"}], ")"}]}], "-", 
            "2"}], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1417]=  (21:56:29 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SplittingFunction", "[", "aqg", "]"}]], "Input",
  CellLabel->"In[1418]:=  (21:56:29 on 5/16/01)",
  CellTags->"SplittingFunction"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["T", "f"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{"4", "-", 
                  RowBox[{"8", " ", "x"}]}], ")"}], " ", 
              RowBox[{"log", "(", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"1", "-", "x"}], ")"}], " ", "x"}], ")"}]}], "-", 
            "4"}], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1418]=  (21:56:30 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SplittingFunction", "[", "aqgd", "]"}]], "Input",
  CellLabel->"In[1419]:=  (21:56:30 on 5/16/01)",
  CellTags->"SplittingFunction"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["T", "f"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{"4", "-", 
                  RowBox[{"8", " ", "x"}]}], ")"}], " ", 
              RowBox[{"log", "(", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"1", "-", "x"}], ")"}], " ", "x"}], ")"}]}], "-", 
            "4"}], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1419]=  (21:56:30 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SplittingFunction", "[", "agg", "]"}]], "Input",
  CellLabel->"In[1420]:=  (21:56:30 on 5/16/01)",
  CellTags->"SplittingFunction"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["C", "A"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    FractionBox["67", "9"], "-", 
                    RowBox[{"4", " ", 
                      RowBox[{"\[Zeta]", "(", "2", ")"}]}]}], ")"}], " ", 
                RowBox[{"\[Delta]", "(", 
                  FormBox[
                    RowBox[{"1", "-", "x"}],
                    "TraditionalForm"], ")"}]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"8", " ", "x"}], "-", "4"}], ")"}], " ", 
                RowBox[{"log", "(", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{"1", "-", "x"}], ")"}], " ", "x"}], ")"}]}], 
              "-", 
              RowBox[{"4", " ", 
                RowBox[{"(", 
                  RowBox[{
                    FractionBox[
                      RowBox[{"log", "(", "x", ")"}], 
                      RowBox[{"1", "-", "x"}]], "+", 
                    SubscriptBox[
                      RowBox[{"(", 
                        FractionBox[
                          RowBox[{"log", "(", 
                            RowBox[{"1", "-", "x"}], ")"}], 
                          RowBox[{"1", "-", "x"}]], ")"}], "+"]}], ")"}]}], 
              "+", "2"}], ")"}]}], "-", 
        RowBox[{
          FractionBox["20", "9"], " ", 
          SubscriptBox["T", "f"], " ", 
          RowBox[{"\[Delta]", "(", 
            FormBox[
              RowBox[{"1", "-", "x"}],
              "TraditionalForm"], ")"}]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1420]=  (21:56:30 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SplittingFunction", "[", "aggd", "]"}]], "Input",
  CellLabel->"In[1421]:=  (21:56:30 on 5/16/01)",
  CellTags->"SplittingFunction"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["C", "A"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    FractionBox["67", "9"], "-", 
                    RowBox[{"4", " ", 
                      RowBox[{"\[Zeta]", "(", "2", ")"}]}]}], ")"}], " ", 
                RowBox[{"\[Delta]", "(", 
                  FormBox[
                    RowBox[{"1", "-", "x"}],
                    "TraditionalForm"], ")"}]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"8", " ", "x"}], "-", "4"}], ")"}], " ", 
                RowBox[{"log", "(", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{"1", "-", "x"}], ")"}], " ", "x"}], ")"}]}], 
              "-", 
              RowBox[{"4", " ", 
                RowBox[{"(", 
                  RowBox[{
                    FractionBox[
                      RowBox[{"log", "(", "x", ")"}], 
                      RowBox[{"1", "-", "x"}]], "+", 
                    SubscriptBox[
                      RowBox[{"(", 
                        FractionBox[
                          RowBox[{"log", "(", 
                            RowBox[{"1", "-", "x"}], ")"}], 
                          RowBox[{"1", "-", "x"}]], ")"}], "+"]}], ")"}]}], 
              "+", "2"}], ")"}]}], "-", 
        RowBox[{
          FractionBox["20", "9"], " ", 
          SubscriptBox["T", "f"], " ", 
          RowBox[{"\[Delta]", "(", 
            FormBox[
              RowBox[{"1", "-", "x"}],
              "TraditionalForm"], ")"}]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1421]=  (21:56:30 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SplittingFunction", "[", "PQQS", "]"}]], "Input",
  CellLabel->"In[1422]:=  (21:56:30 on 5/16/01)",
  CellTags->"SplittingFunction"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["C", "F"], " ", 
        SubscriptBox["T", "f"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"-", "16"}], " ", 
              RowBox[{"(", 
                RowBox[{"x", "+", "1"}], ")"}], " ", 
              RowBox[{
                SuperscriptBox["log", "2"], "(", "x", ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"48", " ", "x"}], "-", "16"}], ")"}], " ", 
              RowBox[{"log", "(", "x", ")"}]}], "+", 
            RowBox[{"16", " ", 
              RowBox[{"(", 
                RowBox[{"1", "-", "x"}], ")"}]}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1422]=  (21:56:30 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SplittingFunction", "[", "PQQNS", "]"}]], "Input",
  CellLabel->"In[1423]:=  (21:56:30 on 5/16/01)",
  CellTags->"SplittingFunction"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"-", "4"}], " ", 
                RowBox[{"(", 
                  RowBox[{"x", "+", "1"}], ")"}], " ", 
                RowBox[{
                  SuperscriptBox["log", "2"], "(", "x", ")"}]}], "-", 
              RowBox[{"8", " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"2", " ", "x"}], "+", 
                    FractionBox["3", 
                      RowBox[{"1", "-", "x"}]]}], ")"}], " ", 
                RowBox[{"log", "(", "x", ")"}]}], "-", 
              FractionBox[
                RowBox[{"16", " ", 
                  RowBox[{"(", 
                    RowBox[{
                      SuperscriptBox["x", "2"], "+", "1"}], ")"}], " ", 
                  RowBox[{"log", "(", 
                    RowBox[{"1", "-", "x"}], ")"}], " ", 
                  RowBox[{"log", "(", "x", ")"}]}], 
                RowBox[{"1", "-", "x"}]], "-", 
              RowBox[{"40", " ", 
                RowBox[{"(", 
                  RowBox[{"1", "-", "x"}], ")"}]}], "+", 
              RowBox[{
                RowBox[{"\[Delta]", "(", 
                  FormBox[
                    RowBox[{"1", "-", "x"}],
                    "TraditionalForm"], ")"}], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      RowBox[{"-", "24"}], " ", 
                      RowBox[{"\[Zeta]", "(", "2", ")"}]}], "+", 
                    RowBox[{"48", " ", 
                      TagBox[
                        RowBox[{"\[Zeta]", "(", 
                          TagBox["3",
                            (Editable -> True)], ")"}],
                        InterpretTemplate[ Zeta[ #]&]]}], "+", "3"}], 
                  ")"}]}]}], ")"}], " ", 
          SubsuperscriptBox["C", "F", "2"]}], "+", 
        RowBox[{
          SubscriptBox["N", "f"], " ", 
          RowBox[{"(", 
            RowBox[{
              FractionBox[
                RowBox[{"88", " ", "x"}], "9"], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"-", 
                      FractionBox[
                        RowBox[{"16", " ", 
                          RowBox[{"\[Zeta]", "(", "2", ")"}]}], "3"]}], "-", 
                    FractionBox["2", "3"]}], ")"}], " ", 
                RowBox[{"\[Delta]", "(", 
                  FormBox[
                    RowBox[{"1", "-", "x"}],
                    "TraditionalForm"], ")"}]}], "-", 
              FractionBox[
                RowBox[{"8", " ", 
                  RowBox[{"(", 
                    RowBox[{
                      SuperscriptBox["x", "2"], "+", "1"}], ")"}], " ", 
                  RowBox[{"log", "(", "x", ")"}]}], 
                RowBox[{"3", " ", 
                  RowBox[{"(", 
                    RowBox[{"1", "-", "x"}], ")"}]}]], "-", 
              RowBox[{
                FractionBox["80", "9"], " ", 
                SubscriptBox[
                  RowBox[{"(", 
                    FractionBox["1", 
                      RowBox[{"1", "-", "x"}]], ")"}], "+"]}], "-", 
              FractionBox["8", "9"]}], ")"}], " ", 
          SubscriptBox["C", "F"]}], "-", 
        RowBox[{"8", " ", 
          RowBox[{"(", 
            RowBox[{
              SubscriptBox["C", "F"], "-", 
              FractionBox[
                SubscriptBox["C", "A"], "2"]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"4", " ", 
                RowBox[{"(", 
                  RowBox[{"1", "-", "x"}], ")"}]}], "+", 
              RowBox[{"2", " ", 
                RowBox[{"(", 
                  RowBox[{"x", "+", "1"}], ")"}], " ", 
                RowBox[{"log", "(", "x", ")"}]}], "+", 
              FractionBox[
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      SuperscriptBox["x", "2"], "+", "1"}], ")"}], " ", 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox["log", "2"], "(", "x", ")"}], "-", 
                      RowBox[{"4", " ", 
                        RowBox[{"log", "(", 
                          RowBox[{"x", "+", "1"}], ")"}], " ", 
                        RowBox[{"log", "(", "x", ")"}]}], "-", 
                      RowBox[{"2", " ", 
                        RowBox[{"\[Zeta]", "(", "2", ")"}]}], "-", 
                      RowBox[{"4", " ", 
                        RowBox[{
                          SubscriptBox["Li", "2"], "(", 
                          RowBox[{"-", "x"}], ")"}]}]}], ")"}]}], 
                RowBox[{"x", "+", "1"}]]}], ")"}], " ", 
          SubscriptBox["C", "F"]}], "+", 
        RowBox[{
          SubscriptBox["C", "A"], " ", 
          RowBox[{"(", 
            RowBox[{
              FractionBox[
                RowBox[{"4", " ", 
                  RowBox[{"(", 
                    RowBox[{
                      SuperscriptBox["x", "2"], "+", "1"}], ")"}], " ", 
                  RowBox[{
                    SuperscriptBox["log", "2"], "(", "x", ")"}]}], 
                RowBox[{"1", "-", "x"}]], "-", 
              RowBox[{
                FractionBox["4", "3"], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"5", " ", "x"}], "-", 
                    FractionBox["22", 
                      RowBox[{"1", "-", "x"}]], "+", "5"}], ")"}], " ", 
                RowBox[{"log", "(", "x", ")"}]}], "+", 
              RowBox[{
                FractionBox["4", "9"], " ", 
                RowBox[{"(", 
                  RowBox[{"53", "-", 
                    RowBox[{"187", " ", "x"}]}], ")"}]}], "+", 
              RowBox[{"8", " ", 
                RowBox[{"(", 
                  RowBox[{"x", "+", "1"}], ")"}], " ", 
                RowBox[{"\[Zeta]", "(", "2", ")"}]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    FractionBox["536", "9"], "-", 
                    RowBox[{"16", " ", 
                      RowBox[{"\[Zeta]", "(", "2", ")"}]}]}], ")"}], " ", 
                SubscriptBox[
                  RowBox[{"(", 
                    FractionBox["1", 
                      RowBox[{"1", "-", "x"}]], ")"}], "+"]}], "+", 
              RowBox[{
                RowBox[{"\[Delta]", "(", 
                  FormBox[
                    RowBox[{"1", "-", "x"}],
                    "TraditionalForm"], ")"}], " ", 
                RowBox[{"(", 
                  RowBox[{
                    FractionBox[
                      RowBox[{"88", " ", 
                        RowBox[{"\[Zeta]", "(", "2", ")"}]}], "3"], "-", 
                    RowBox[{"24", " ", 
                      TagBox[
                        RowBox[{"\[Zeta]", "(", 
                          TagBox["3",
                            (Editable -> True)], ")"}],
                        InterpretTemplate[ Zeta[ #]&]]}], "+", 
                    FractionBox["17", "3"]}], ")"}]}]}], ")"}], " ", 
          SubscriptBox["C", "F"]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1423]=  (21:56:30 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SplittingFunction", "[", "PQG", "]"}]], "Input",
  CellLabel->"In[1424]:=  (21:56:30 on 5/16/01)",
  CellTags->"SplittingFunction"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"4", " ", 
          SubscriptBox["C", "F"], " ", 
          SubscriptBox["T", "f"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"8", " ", "x"}], "-", "4"}], ")"}], " ", 
                RowBox[{
                  SuperscriptBox["log", "2"], "(", 
                  RowBox[{"1", "-", "x"}], ")"}]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{"16", "-", 
                    RowBox[{"16", " ", "x"}]}], ")"}], " ", 
                RowBox[{"log", "(", 
                  RowBox[{"1", "-", "x"}], ")"}]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{"8", "-", 
                    RowBox[{"16", " ", "x"}]}], ")"}], " ", 
                RowBox[{"log", "(", "x", ")"}], " ", 
                RowBox[{"log", "(", 
                  RowBox[{"1", "-", "x"}], ")"}]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"4", " ", "x"}], "-", "2"}], ")"}], " ", 
                RowBox[{
                  SuperscriptBox["log", "2"], "(", "x", ")"}]}], "+", 
              RowBox[{"54", " ", "x"}], "-", 
              RowBox[{"16", " ", "x", " ", 
                RowBox[{"\[Zeta]", "(", "2", ")"}]}], "+", 
              RowBox[{"8", " ", 
                RowBox[{"\[Zeta]", "(", "2", ")"}]}], "-", 
              RowBox[{"18", " ", 
                RowBox[{"log", "(", "x", ")"}]}], "-", "44"}], ")"}]}], "+", 
        RowBox[{"4", " ", 
          SubscriptBox["C", "A"], " ", 
          SubscriptBox["T", "f"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"(", 
                  RowBox[{"4", "-", 
                    RowBox[{"8", " ", "x"}]}], ")"}], " ", 
                RowBox[{
                  SuperscriptBox["log", "2"], "(", 
                  RowBox[{"1", "-", "x"}], ")"}]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"16", " ", "x"}], "-", "16"}], ")"}], " ", 
                RowBox[{"log", "(", 
                  RowBox[{"1", "-", "x"}], ")"}]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      RowBox[{"-", "8"}], " ", "x"}], "-", "4"}], ")"}], " ", 
                
                RowBox[{
                  SuperscriptBox["log", "2"], "(", "x", ")"}]}], "-", 
              RowBox[{"44", " ", "x"}], "-", 
              RowBox[{"8", " ", 
                RowBox[{"\[Zeta]", "(", "2", ")"}]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"32", " ", "x"}], "+", "4"}], ")"}], " ", 
                RowBox[{"log", "(", "x", ")"}]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      RowBox[{"-", "16"}], " ", "x"}], "-", "8"}], ")"}], " ",
                 
                RowBox[{"log", "(", "x", ")"}], " ", 
                RowBox[{"log", "(", 
                  RowBox[{"x", "+", "1"}], ")"}]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      RowBox[{"-", "16"}], " ", "x"}], "-", "8"}], ")"}], " ",
                 
                RowBox[{
                  SubscriptBox["Li", "2"], "(", 
                  RowBox[{"-", "x"}], ")"}]}], "+", "48"}], ")"}]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1424]=  (21:56:30 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SplittingFunction", "[", "PGQ", "]"}]], "Input",
  CellLabel->"In[1425]:=  (21:56:30 on 5/16/01)",
  CellTags->"SplittingFunction"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              SubscriptBox["C", "A"], " ", 
              SubscriptBox["C", "F"]}], ")"}], ".", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"(", 
                  RowBox[{"16", "-", 
                    RowBox[{"8", " ", "x"}]}], ")"}], " ", 
                RowBox[{
                  SuperscriptBox["log", "2"], "(", 
                  RowBox[{"1", "-", "x"}], ")"}]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    FractionBox[
                      RowBox[{"8", " ", "x"}], "3"], "+", 
                    FractionBox["80", "3"]}], ")"}], " ", 
                RowBox[{"log", "(", 
                  RowBox[{"1", "-", "x"}], ")"}]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"16", " ", "x"}], "-", "32"}], ")"}], " ", 
                RowBox[{"log", "(", "x", ")"}], " ", 
                RowBox[{"log", "(", 
                  RowBox[{"1", "-", "x"}], ")"}]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"8", " ", "x"}], "+", "16"}], ")"}], " ", 
                RowBox[{
                  SuperscriptBox["log", "2"], "(", "x", ")"}]}], "+", 
              FractionBox[
                RowBox[{"280", " ", "x"}], "9"], "+", 
              RowBox[{"16", " ", "x", " ", 
                RowBox[{"\[Zeta]", "(", "2", ")"}]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{"32", "-", 
                    RowBox[{"104", " ", "x"}]}], ")"}], " ", 
                RowBox[{"log", "(", "x", ")"}]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"16", " ", "x"}], "+", "32"}], ")"}], " ", 
                RowBox[{"log", "(", "x", ")"}], " ", 
                RowBox[{"log", "(", 
                  RowBox[{"x", "+", "1"}], ")"}]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"16", " ", "x"}], "+", "32"}], ")"}], " ", 
                RowBox[{
                  SubscriptBox["Li", "2"], "(", 
                  RowBox[{"-", "x"}], ")"}]}], "+", 
              FractionBox["328", "9"]}], ")"}]}], "+", 
        RowBox[{
          SubsuperscriptBox["C", "F", "2"], ".", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"8", " ", "x"}], "-", "16"}], ")"}], " ", 
                RowBox[{
                  SuperscriptBox["log", "2"], "(", 
                  RowBox[{"1", "-", "x"}], ")"}]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      RowBox[{"-", "8"}], " ", "x"}], "-", "16"}], ")"}], " ",
                 
                RowBox[{"log", "(", 
                  RowBox[{"1", "-", "x"}], ")"}]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{"8", "-", 
                    RowBox[{"4", " ", "x"}]}], ")"}], " ", 
                RowBox[{
                  SuperscriptBox["log", "2"], "(", "x", ")"}]}], "+", 
              RowBox[{"32", " ", "x"}], "-", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"32", " ", "x"}], "+", "64"}], ")"}], " ", 
                RowBox[{"log", "(", "x", ")"}]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"36", " ", "x"}], "+", "48"}], ")"}], " ", 
                RowBox[{"log", "(", "x", ")"}]}], "-", "68"}], ")"}]}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              SubscriptBox["C", "F"], " ", 
              SubscriptBox["T", "f"]}], ")"}], ".", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                FractionBox[
                  RowBox[{"32", " ", "x"}], "9"]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    FractionBox[
                      RowBox[{"32", " ", "x"}], "3"], "-", 
                    FractionBox["64", "3"]}], ")"}], " ", 
                RowBox[{"log", "(", 
                  RowBox[{"1", "-", "x"}], ")"}]}], "-", 
              FractionBox["128", "9"]}], ")"}]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1425]=  (21:56:30 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SplittingFunction", "[", "PGG", "]"}]], "Input",
  CellLabel->"In[1426]:=  (21:56:30 on 5/16/01)",
  CellTags->"SplittingFunction"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"-", 
                      FractionBox["8", 
                        RowBox[{"x", "+", "1"}]]}], "+", "32", "+", 
                    FractionBox["8", 
                      RowBox[{"1", "-", "x"}]]}], ")"}], " ", 
                RowBox[{
                  SuperscriptBox["log", "2"], "(", "x", ")"}]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    FractionBox["232", "3"], "-", 
                    FractionBox[
                      RowBox[{"536", " ", "x"}], "3"]}], ")"}], " ", 
                RowBox[{"log", "(", "x", ")"}]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"64", " ", "x"}], "-", 
                    FractionBox["32", 
                      RowBox[{"1", "-", "x"}]], "-", "32"}], ")"}], " ", 
                RowBox[{"log", "(", 
                  RowBox[{"1", "-", "x"}], ")"}], " ", 
                RowBox[{"log", "(", "x", ")"}]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"64", " ", "x"}], "+", 
                    FractionBox["32", 
                      RowBox[{"x", "+", "1"}]], "+", "32"}], ")"}], " ", 
                RowBox[{"log", "(", 
                  RowBox[{"x", "+", "1"}], ")"}], " ", 
                RowBox[{"log", "(", "x", ")"}]}], "-", 
              FractionBox[
                RowBox[{"388", " ", "x"}], "9"], "+", 
              RowBox[{
                FractionBox["64", "3"], " ", 
                RowBox[{"\[Delta]", "(", 
                  FormBox[
                    RowBox[{"1", "-", "x"}],
                    "TraditionalForm"], ")"}]}], "+", 
              RowBox[{
                RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"64", " ", "x"}], "-", 
                    RowBox[{"16", " ", 
                      SubscriptBox[
                        RowBox[{"(", 
                          FractionBox["1", 
                            RowBox[{"1", "-", "x"}]], ")"}], "+"]}], "+", 
                    FractionBox["16", 
                      RowBox[{"x", "+", "1"}]]}], ")"}]}], "+", 
              RowBox[{
                FractionBox["536", "9"], " ", 
                SubscriptBox[
                  RowBox[{"(", 
                    FractionBox["1", 
                      RowBox[{"1", "-", "x"}]], ")"}], "+"]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"64", " ", "x"}], "+", 
                    FractionBox["32", 
                      RowBox[{"x", "+", "1"}]], "+", "32"}], ")"}], " ", 
                RowBox[{
                  SubscriptBox["Li", "2"], "(", 
                  RowBox[{"-", "x"}], ")"}]}], "+", 
              RowBox[{"24", " ", 
                RowBox[{"\[Delta]", "(", 
                  FormBox[
                    RowBox[{"1", "-", "x"}],
                    "TraditionalForm"], ")"}], " ", 
                TagBox[
                  RowBox[{"\[Zeta]", "(", 
                    TagBox["3",
                      (Editable -> True)], ")"}],
                  InterpretTemplate[ Zeta[ #]&]]}], "-", 
              FractionBox["148", "9"]}], ")"}], " ", 
          SubsuperscriptBox["C", "A", "2"]}], "+", 
        RowBox[{
          SubscriptBox["T", "f"], " ", 
          RowBox[{"(", 
            RowBox[{
              FractionBox[
                RowBox[{"608", " ", "x"}], "9"], "-", 
              RowBox[{
                FractionBox["32", "3"], " ", 
                RowBox[{"\[Delta]", "(", 
                  FormBox[
                    RowBox[{"1", "-", "x"}],
                    "TraditionalForm"], ")"}]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"-", 
                      FractionBox[
                        RowBox[{"32", " ", "x"}], "3"]}], "-", 
                    FractionBox["32", "3"]}], ")"}], " ", 
                RowBox[{"log", "(", "x", ")"}]}], "-", 
              RowBox[{
                FractionBox["160", "9"], " ", 
                SubscriptBox[
                  RowBox[{"(", 
                    FractionBox["1", 
                      RowBox[{"1", "-", "x"}]], ")"}], "+"]}], "-", 
              FractionBox["448", "9"]}], ")"}], " ", 
          SubscriptBox["C", "A"]}], "+", 
        RowBox[{
          SubscriptBox["C", "F"], " ", 
          SubscriptBox["T", "f"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      RowBox[{"-", "16"}], " ", "x"}], "-", "16"}], ")"}], 
                " ", 
                RowBox[{
                  SuperscriptBox["log", "2"], "(", "x", ")"}]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"16", " ", "x"}], "-", "80"}], ")"}], " ", 
                RowBox[{"log", "(", "x", ")"}]}], "+", 
              RowBox[{"80", " ", "x"}], "-", 
              RowBox[{"8", " ", 
                RowBox[{"\[Delta]", "(", 
                  FormBox[
                    RowBox[{"1", "-", "x"}],
                    "TraditionalForm"], ")"}]}], "-", "80"}], ")"}]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1426]=  (21:56:30 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["SumP", "ObjectName",
  CellTags->"SumP"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"SumP"],

Cell[TextData[{
  "SumP[k, m] is ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"2", "^", 
            RowBox[{"(", 
              RowBox[{"k", "-", "1"}], ")"}]}], 
          RowBox[{
            SubsuperscriptBox["\[Sum]", 
              RowBox[{"i", "=", "1"}], 
              RowBox[{"2", "m"}]], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"1", "+", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{"-", "1"}], ")"}], "^", "i"}]}], ")"}], "/", 
              SuperscriptBox["i", "k"]}]}]}], TraditionalForm]]]
}], "Text",
  CellTags->"SumP"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["SumS",
    ButtonData:>"SumS",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SumS"],
  ", ",
  ButtonBox["SumT",
    ButtonData:>"SumT",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SumT"],
  "."
}], "Text",
  CellTags->"SumP"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"SumP"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SumP", "[", 
      RowBox[{"1", ",", 
        RowBox[{"m", "-", "1"}]}], "]"}]], "Input",
  CellLabel->"In[1427]:=  (21:56:30 on 5/16/01)",
  CellTags->"SumP"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubsuperscriptBox["S", "1", "'"], "\[NoBreak]", "(", "\[NoBreak]", 
        FormBox[
          RowBox[{"m", "-", "1"}],
          "TraditionalForm"], "\[NoBreak]", ")"}], TraditionalForm]], "Output",\

  CellLabel->"Out[1427]=  (21:56:30 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SumP", "[", 
      RowBox[{"2", ",", 
        RowBox[{"m", "-", "1"}]}], "]"}]], "Input",
  CellLabel->"In[1428]:=  (21:56:30 on 5/16/01)",
  CellTags->"SumP"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubsuperscriptBox["S", "2", "'"], "\[NoBreak]", "(", "\[NoBreak]", 
        FormBox[
          RowBox[{"m", "-", "1"}],
          "TraditionalForm"], "\[NoBreak]", ")"}], TraditionalForm]], "Output",\

  CellLabel->"Out[1428]=  (21:56:30 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SumP", "[", 
      RowBox[{"1", ",", "m"}], "]"}]], "Input",
  CellLabel->"In[1429]:=  (21:56:31 on 5/16/01)",
  CellTags->"SumP"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubsuperscriptBox["S", "1", "'"], "\[NoBreak]", "(", "\[NoBreak]", 
        FormBox["m",
          "TraditionalForm"], "\[NoBreak]", ")"}], TraditionalForm]], "Output",\

  CellLabel->"Out[1429]=  (21:56:31 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SumP", "[", 
      RowBox[{"1", ",", "4"}], "]"}]], "Input",
  CellLabel->"In[1430]:=  (21:56:31 on 5/16/01)",
  CellTags->"SumP"],

Cell[BoxData[
    FormBox[
      FractionBox["25", "12"], TraditionalForm]], "Output",
  CellLabel->"Out[1430]=  (21:56:31 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      UnderoverscriptBox["\[Sum]", 
        RowBox[{"i", "=", "1"}], "8"], 
      RowBox[{
        RowBox[{"(", 
          RowBox[{"1", "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "^", "i"}]}], ")"}], "/", 
        "i"}]}]], "Input",
  CellLabel->"In[1431]:=  (21:56:31 on 5/16/01)",
  CellTags->"SumP"],

Cell[BoxData[
    FormBox[
      FractionBox["25", "12"], TraditionalForm]], "Output",
  CellLabel->"Out[1431]=  (21:56:31 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Explicit", "[", 
      RowBox[{"SumP", "[", 
        RowBox[{"1", ",", 
          RowBox[{"n", "/", "2"}]}], "]"}], "]"}]], "Input",
  CellLabel->"In[1432]:=  (21:56:31 on 5/16/01)",
  CellTags->"SumP"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"(", 
            RowBox[{"1", "-", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"-", "1"}], ")"}], "n"]}], ")"}], " ", 
          RowBox[{
            SubscriptBox["S", "1"], "(", 
            FormBox[
              FractionBox[
                RowBox[{"n", "-", "1"}], "2"],
              "TraditionalForm"], ")"}]}], "+", 
        RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"-", "1"}], ")"}], "n"]}], ")"}], " ", 
          RowBox[{
            SubscriptBox["S", "1"], "(", 
            FormBox[
              FractionBox["n", "2"],
              "TraditionalForm"], ")"}]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1432]=  (21:56:31 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "/.", 
      RowBox[{"n", "\[Rule]", "8"}]}]], "Input",
  CellLabel->"In[1433]:=  (21:56:31 on 5/16/01)",
  CellTags->"SumP"],

Cell[BoxData[
    FormBox[
      FractionBox["25", "12"], TraditionalForm]], "Output",
  CellLabel->"Out[1433]=  (21:56:31 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["SumS", "ObjectName",
  CellTags->"SumS"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"SumS"],

Cell[TextData[{
  "SumS[1, m] is the harmonic number ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubsuperscriptBox["\[Sum]", 
            RowBox[{"i", "=", "1"}], "m"], " ", 
          RowBox[{"i", "^", 
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}]}]}], TraditionalForm]]],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"=", 
              RowBox[{
                SubscriptBox["S", "1"], "(", "m", ")"}]}], " ", ")"}], "."}], 
        TraditionalForm]]],
  " SumS[1,1,m] is ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubsuperscriptBox["\[Sum]", 
            RowBox[{"i", "=", "1"}], "m"], 
          SubscriptBox["S", "1"]}], TraditionalForm]]],
  "(i)/i. SumS[k,l,m] is ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubsuperscriptBox["\[Sum]", 
            RowBox[{"i", "=", "1"}], "m"], " ", 
          RowBox[{
            RowBox[{
              SubscriptBox["S", "l"], "(", "i", ")"}], "/", 
            SuperscriptBox["i", "k"]}]}], TraditionalForm]]],
  ". SumS[r, n] represents Sum[Sign[r]^i/i^Abs[r], {i, 1, n}]. SumS[r,s, n] \
is Sum[Sign[r]^k/k^Abs[r] Sign[s]^j/j^Abs[s], {k, 1, n}, {j, 1, k}], etc."
}], "Text",
  CellTags->"SumS"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "SumS", "]"}]], "Input",
  CellLabel->"In[1434]:=  (21:56:31 on 5/16/01)",
  CellTags->"SumS"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"Reduce", "\[Rule]", "False"}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1434]=  (21:56:31 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["SumP",
    ButtonData:>"SumP",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SumP"],
  ", ",
  ButtonBox["SumT",
    ButtonData:>"SumT",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SumT"],
  "."
}], "Text",
  CellTags->"SumS"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"SumS"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SumS", "[", 
      RowBox[{"1", ",", 
        RowBox[{"m", "-", "1"}]}], "]"}]], "Input",
  CellLabel->"In[1435]:=  (21:56:31 on 5/16/01)",
  CellTags->"SumS"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["S", "1"], "(", 
        FormBox[
          RowBox[{"m", "-", "1"}],
          "TraditionalForm"], ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[1435]=  (21:56:31 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SumS", "[", 
      RowBox[{"2", ",", 
        RowBox[{"m", "-", "1"}]}], "]"}]], "Input",
  CellLabel->"In[1436]:=  (21:56:31 on 5/16/01)",
  CellTags->"SumS"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["S", "2"], "(", 
        FormBox[
          RowBox[{"m", "-", "1"}],
          "TraditionalForm"], ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[1436]=  (21:56:31 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SumS", "[", 
      RowBox[{
        RowBox[{"-", "1"}], ",", "m"}], "]"}]], "Input",
  CellLabel->"In[1437]:=  (21:56:31 on 5/16/01)",
  CellTags->"SumS"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["S", 
          RowBox[{"-", "1"}]], "(", "m", ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[1437]=  (21:56:31 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SumS", "[", 
      RowBox[{"1", ",", "m", ",", 
        RowBox[{"Reduce", "\[Rule]", "True"}]}], "]"}]], "Input",
  CellLabel->"In[1438]:=  (21:56:31 on 5/16/01)",
  CellTags->"SumS"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["S", "1"], "(", 
          FormBox[
            RowBox[{"m", "-", "1"}],
            "TraditionalForm"], ")"}], "+", 
        FractionBox["1", "m"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1438]=  (21:56:31 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SumS", "[", 
      RowBox[{"3", ",", 
        RowBox[{"m", "+", "2"}], ",", 
        RowBox[{"Reduce", "\[Rule]", "True"}]}], "]"}]], "Input",
  CellLabel->"In[1439]:=  (21:56:31 on 5/16/01)",
  CellTags->"SumS"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["S", "3"], "(", 
          FormBox[
            RowBox[{"m", "+", "1"}],
            "TraditionalForm"], ")"}], "+", 
        FractionBox["1", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"m", "+", "2"}], ")"}], "3"]]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1439]=  (21:56:31 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      RowBox[{"SetOptions", "[", 
        RowBox[{"SumS", ",", 
          RowBox[{"Reduce", "\[Rule]", "True"}]}], "]"}], ";"}]], "Input",
  CellLabel->"In[1440]:=  (21:56:31 on 5/16/01)",
  CellTags->"SumS"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SumS", "[", 
      RowBox[{"3", ",", 
        RowBox[{"m", "+", "2"}]}], "]"}]], "Input",
  CellLabel->"In[1441]:=  (21:56:31 on 5/16/01)",
  CellTags->"SumS"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["S", "3"], "(", 
          FormBox[
            RowBox[{"m", "-", "1"}],
            "TraditionalForm"], ")"}], "+", 
        FractionBox["1", 
          SuperscriptBox["m", "3"]], "+", 
        FractionBox["1", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"m", "+", "1"}], ")"}], "3"]], "+", 
        FractionBox["1", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"m", "+", "2"}], ")"}], "3"]]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1441]=  (21:56:31 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      RowBox[{"SetOptions", "[", 
        RowBox[{"SumS", ",", 
          RowBox[{"Reduce", "\[Rule]", "False"}]}], "]"}], ";"}]], "Input",
  CellLabel->"In[1442]:=  (21:56:31 on 5/16/01)",
  CellTags->"SumS"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SumS", "[", 
      RowBox[{"1", ",", "4"}], "]"}]], "Input",
  CellLabel->"In[1443]:=  (21:56:31 on 5/16/01)",
  CellTags->"SumS"],

Cell[BoxData[
    FormBox[
      FractionBox["25", "12"], TraditionalForm]], "Output",
  CellLabel->"Out[1443]=  (21:56:31 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      UnderoverscriptBox["\[Sum]", 
        RowBox[{"i", "=", "1"}], "4"], 
      RowBox[{"1", "/", "i"}]}]], "Input",
  CellLabel->"In[1444]:=  (21:56:31 on 5/16/01)",
  CellTags->"SumS"],

Cell[BoxData[
    FormBox[
      FractionBox["25", "12"], TraditionalForm]], "Output",
  CellLabel->"Out[1444]=  (21:56:31 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SumS", "[", 
      RowBox[{"1", ",", "2", ",", 
        RowBox[{"m", "-", "1"}]}], "]"}]], "Input",
  CellLabel->"In[1445]:=  (21:56:31 on 5/16/01)",
  CellTags->"SumS"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["S", "12"], "(", 
        FormBox[
          RowBox[{"m", "-", "1"}],
          "TraditionalForm"], ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[1445]=  (21:56:31 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SumS", "[", 
      RowBox[{"1", ",", "1", ",", "1", ",", "11"}], "]"}]], "Input",
  CellLabel->"In[1446]:=  (21:56:31 on 5/16/01)",
  CellTags->"SumS"],

Cell[BoxData[
    FormBox[
      FractionBox["31276937512951", "4260000729600"], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1446]=  (21:56:31 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SumS", "[", 
      RowBox[{
        RowBox[{"-", "1"}], ",", "4"}], "]"}]], "Input",
  CellLabel->"In[1447]:=  (21:56:32 on 5/16/01)",
  CellTags->"SumS"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        FractionBox["7", "12"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1447]=  (21:56:32 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SumT", "[", 
      RowBox[{"1", ",", "4"}], "]"}]], "Input",
  CellLabel->"In[1448]:=  (21:56:32 on 5/16/01)",
  CellTags->"SumS"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        FractionBox["7", "12"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1448]=  (21:56:32 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["SumT", "ObjectName",
  CellTags->"SumT"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"SumT"],

Cell[TextData[{
  "SumT[1, m] is the alternative harmonic number ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubsuperscriptBox["\[Sum]", 
            RowBox[{"i", "=", "1"}], "m"], " ", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "^", "i"}], "/", 
            RowBox[{"i", " "}]}]}], TraditionalForm]]],
  " SumT[r, n] represents Sum[(-1)^i/i^r, {i,1,n}], SumT[r,s, n] is Sum[1/k^r \
(-1)^j/j^s, {k, 1, n}, {j, 1, k}]."
}], "Text",
  CellTags->"SumT"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["SumP",
    ButtonData:>"SumP",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SumP"],
  ", ",
  ButtonBox["SumS",
    ButtonData:>"SumS",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SumS"],
  "."
}], "Text",
  CellTags->"SumT"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"SumT"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SumT", "[", 
      RowBox[{"1", ",", 
        RowBox[{"m", "-", "1"}]}], "]"}]], "Input",
  CellLabel->"In[1449]:=  (21:56:32 on 5/16/01)",
  CellTags->"SumT"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox[
          OverscriptBox["S", "~"], "1"], "(", 
        FormBox[
          RowBox[{"m", "-", "1"}],
          "TraditionalForm"], ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[1449]=  (21:56:32 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SumT", "[", 
      RowBox[{"2", ",", 
        RowBox[{"m", "-", "1"}]}], "]"}]], "Input",
  CellLabel->"In[1450]:=  (21:56:32 on 5/16/01)",
  CellTags->"SumT"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox[
          OverscriptBox["S", "~"], "2"], "(", 
        FormBox[
          RowBox[{"m", "-", "1"}],
          "TraditionalForm"], ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[1450]=  (21:56:32 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SumT", "[", 
      RowBox[{"1", ",", "m"}], "]"}]], "Input",
  CellLabel->"In[1451]:=  (21:56:32 on 5/16/01)",
  CellTags->"SumT"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox[
          OverscriptBox["S", "~"], "1"], "(", "m", ")"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1451]=  (21:56:32 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SumT", "[", 
      RowBox[{"1", ",", "m", ",", 
        RowBox[{"Reduce", "\[Rule]", "True"}]}], "]"}]], "Input",
  CellLabel->"In[1452]:=  (21:56:32 on 5/16/01)",
  CellTags->"SumT"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox[
            OverscriptBox["S", "~"], "1"], "(", 
          FormBox[
            RowBox[{"m", "-", "1"}],
            "TraditionalForm"], ")"}], "+", 
        FractionBox[
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "m"], "m"]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1452]=  (21:56:32 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SumT", "[", 
      RowBox[{"1", ",", "4"}], "]"}]], "Input",
  CellLabel->"In[1453]:=  (21:56:32 on 5/16/01)",
  CellTags->"SumT"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        FractionBox["7", "12"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1453]=  (21:56:32 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      UnderoverscriptBox["\[Sum]", 
        RowBox[{"i", "=", "1"}], "4"], 
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "^", "i"}], "/", "i"}]}]], "Input",
  CellLabel->"In[1454]:=  (21:56:32 on 5/16/01)",
  CellTags->"SumT"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        FractionBox["7", "12"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1454]=  (21:56:32 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SumT", "[", 
      RowBox[{"1", ",", "2", ",", 
        RowBox[{"m", "-", "1"}]}], "]"}]], "Input",
  CellLabel->"In[1455]:=  (21:56:32 on 5/16/01)",
  CellTags->"SumT"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox[
          OverscriptBox["S", "~"], "12"], "(", 
        FormBox[
          RowBox[{"m", "-", "1"}],
          "TraditionalForm"], ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[1455]=  (21:56:32 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SumT", "[", 
      RowBox[{"1", ",", "2", ",", "42"}], "]"}]], "Input",
  CellLabel->"In[1456]:=  (21:56:32 on 5/16/01)",
  CellTags->"SumT"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        FractionBox["38987958697055013360489864298703621429610152138683927", 
          "10512121660702378405316004964483761080879190528000000"]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1456]=  (21:56:32 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SumT", "[", 
      RowBox[{"1", ",", "4"}], "]"}]], "Input",
  CellLabel->"In[1457]:=  (21:56:32 on 5/16/01)",
  CellTags->"SumT"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        FractionBox["7", "12"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1457]=  (21:56:32 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SumS", "[", 
      RowBox[{
        RowBox[{"-", "1"}], ",", "4"}], "]"}]], "Input",
  CellLabel->"In[1458]:=  (21:56:32 on 5/16/01)",
  CellTags->"SumT"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        FractionBox["7", "12"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1458]=  (21:56:32 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      UnderoverscriptBox["\[Sum]", 
        RowBox[{"i", "=", "1"}], 
        RowBox[{"m", "-", "1"}]], 
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "^", "i"}], "/", "i"}]}]], "Input",
  CellLabel->"In[1459]:=  (21:56:32 on 5/16/01)",
  CellTags->"SumT"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "m"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SuperscriptBox[
                  TagBox["\[Psi]",
                    PolyGamma], 
                  RowBox[{"(", "0", ")"}]], "(", 
                FractionBox["m", "2"], ")"}], "-", 
              RowBox[{
                SuperscriptBox[
                  TagBox["\[Psi]",
                    PolyGamma], 
                  RowBox[{"(", "0", ")"}]], "(", 
                FractionBox[
                  RowBox[{"m", "+", "1"}], "2"], ")"}]}], ")"}]}], "-", 
        FractionBox[
          RowBox[{"log", "(", "4", ")"}], "2"]}], TraditionalForm]], "Output",\

  CellLabel->"Out[1459]=  (21:56:32 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SumT", "[", 
      RowBox[{"1", ",", "2", ",", "12"}], "]"}]], "Input",
  CellLabel->"In[1460]:=  (21:56:32 on 5/16/01)",
  CellTags->"SumT"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        FractionBox["57561743656913", "21300003648000"]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1460]=  (21:56:32 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SumS", "[", 
      RowBox[{"1", ",", 
        RowBox[{"-", "2"}], ",", "42"}], "]"}]], "Input",
  CellLabel->"In[1461]:=  (21:56:32 on 5/16/01)",
  CellTags->"SumT"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        FractionBox["38987958697055013360489864298703621429610152138683927", 
          "10512121660702378405316004964483761080879190528000000"]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1461]=  (21:56:32 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Array", "[", 
      RowBox[{"SumT", ",", "6"}], "]"}]], "Input",
  CellLabel->"In[1462]:=  (21:56:32 on 5/16/01)",
  CellTags->"SumT"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"-", "1"}], ",", 
          RowBox[{"-", 
            FractionBox["5", "8"]}], ",", 
          RowBox[{"-", 
            FractionBox["179", "216"]}], ",", 
          RowBox[{"-", 
            FractionBox["1207", "1728"]}], ",", 
          RowBox[{"-", 
            FractionBox["170603", "216000"]}], ",", 
          RowBox[{"-", 
            FractionBox["155903", "216000"]}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1462]=  (21:56:32 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Array", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"SumS", "[", 
            RowBox[{
              RowBox[{"-", "2"}], ",", "1", ",", "#1"}], "]"}], "&"}], ",", 
        "6"}], "]"}]], "Input",
  CellLabel->"In[1463]:=  (21:56:32 on 5/16/01)",
  CellTags->"SumT"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"-", "1"}], ",", 
          RowBox[{"-", 
            FractionBox["5", "8"]}], ",", 
          RowBox[{"-", 
            FractionBox["179", "216"]}], ",", 
          RowBox[{"-", 
            FractionBox["1207", "1728"]}], ",", 
          RowBox[{"-", 
            FractionBox["170603", "216000"]}], ",", 
          RowBox[{"-", 
            FractionBox["155903", "216000"]}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1463]=  (21:56:32 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["SUNDelta", "ObjectName",
  CellTags->"SUNDelta"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"SUNDelta"],

Cell["\<\
SUNDelta[a, b] is the Kronecker-delta for SU(N) with color indices a and b.\
\>", "Text",
  CellTags->"SUNDelta"],

Cell[TextData[{
  "See also: ",
  ButtonBox["ExplicitSUNIndex",
    ButtonData:>"ExplicitSUNIndex",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"ExplicitSUNIndex"],
  ", ",
  ButtonBox["SD",
    ButtonData:>"SD",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SD"],
  ", ",
  ButtonBox["SUNF",
    ButtonData:>"SUNF",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SUNF"],
  ", ",
  ButtonBox["SUNIndex",
    ButtonData:>"SUNIndex",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SUNIndex"],
  ", ",
  ButtonBox["SUNSimplify",
    ButtonData:>"SUNSimplify",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SUNSimplify"],
  ", ",
  ButtonBox["Trick",
    ButtonData:>"Trick",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Trick"],
  "."
}], "Text",
  CellTags->"SUNDelta"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"SUNDelta"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNDelta", "[", 
      RowBox[{"a", ",", "b"}], "]"}]], "Input",
  CellLabel->"In[1464]:=  (21:56:32 on 5/16/01)",
  CellTags->"SUNDelta"],

Cell[BoxData[
    FormBox[
      SubscriptBox["\[Delta]", 
        RowBox[{"a", "\[NoBreak]", "b"}]], TraditionalForm]], "Output",
  CellLabel->"Out[1464]=  (21:56:32 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Trick", "[", " ", 
      RowBox[{
        RowBox[{"SUNDelta", "[", 
          RowBox[{"a", ",", "b"}], "]"}], " ", 
        RowBox[{"SUNDelta", "[", 
          RowBox[{"b", ",", "c"}], "]"}]}], " ", "]"}]], "Input",
  CellLabel->"In[1465]:=  (21:56:32 on 5/16/01)",
  CellTags->"SUNDelta"],

Cell[BoxData[
    FormBox[
      SubscriptBox["\[Delta]", 
        RowBox[{
          FormBox[
            FormBox["a",
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", 
          FormBox[
            FormBox["c",
              "TraditionalForm"],
            "TraditionalForm"]}]], TraditionalForm]], "Output",
  CellLabel->"Out[1465]=  (21:56:33 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNDelta", "[", 
      RowBox[{
        RowBox[{"SUNIndex", "[", "a", "]"}], ",", 
        RowBox[{"SUNIndex", "[", "b", "]"}]}], "]"}]], "Input",
  CellLabel->"In[1466]:=  (21:56:33 on 5/16/01)",
  CellTags->"SUNDelta"],

Cell[BoxData[
    FormBox[
      SubscriptBox["\[Delta]", 
        RowBox[{
          FormBox[
            FormBox["a",
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", 
          FormBox[
            FormBox["b",
              "TraditionalForm"],
            "TraditionalForm"]}]], TraditionalForm]], "Output",
  CellLabel->"Out[1466]=  (21:56:33 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"SUNDelta", "[", 
        RowBox[{"a", ",", "b"}], "]"}], "//", "StandardForm"}]], "Input",
  CellLabel->"In[1467]:=  (21:56:33 on 5/16/01)",
  CellTags->"SUNDelta"],

Cell[BoxData[
    RowBox[{"SUNDelta", "[", 
      RowBox[{"a", ",", "b"}], "]"}]], "Output",
  CellLabel->"Out[1467]//StandardForm=  (21:56:33 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"SUNDelta", "[", 
          RowBox[{"a", ",", "b"}], "]"}], "//", "FCI"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[1468]:=  (21:56:33 on 5/16/01)",
  CellTags->"SUNDelta"],

Cell[BoxData[
    RowBox[{"SUNDelta", "[", 
      RowBox[{
        RowBox[{"SUNIndex", "[", "a", "]"}], ",", 
        RowBox[{"SUNIndex", "[", "b", "]"}]}], "]"}]], "Output",
  CellLabel->"Out[1468]//StandardForm=  (21:56:33 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          RowBox[{"SUNDelta", "[", 
            RowBox[{"a", ",", "b"}], "]"}], "//", "FCI"}], "//", "FCE"}], "//",
       "StandardForm"}]], "Input",
  CellLabel->"In[1469]:=  (21:56:33 on 5/16/01)",
  CellTags->"SUNDelta"],

Cell[BoxData[
    RowBox[{"SD", "[", 
      RowBox[{"a", ",", "b"}], "]"}]], "Output",
  CellLabel->"Out[1469]//StandardForm=  (21:56:33 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"SD", "[", 
          RowBox[{"a", ",", "b"}], "]"}], "//", "FCI"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[1470]:=  (21:56:33 on 5/16/01)",
  CellTags->"SUNDelta"],

Cell[BoxData[
    RowBox[{"SUNDelta", "[", 
      RowBox[{
        RowBox[{"SUNIndex", "[", "a", "]"}], ",", 
        RowBox[{"SUNIndex", "[", "b", "]"}]}], "]"}]], "Output",
  CellLabel->"Out[1470]//StandardForm=  (21:56:33 on 5/16/01)"]
}, Closed]],

Cell["\<\
Symbolic arguments to SUNDelta are transformed into the data type SUNIndex \
and integer arguments are transformed to ExplicitSUNIndex. The difference is \
that SUNSimplify will only sum over symbolic indices.\
\>", "Text",
  CellTags->"SUNDelta"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"SUNDelta", "[", 
          RowBox[{"a", ",", "2"}], "]"}], 
        RowBox[{"SUNDelta", "[", 
          RowBox[{"a", ",", "b"}], "]"}], 
        RowBox[{"SUNDelta", "[", 
          RowBox[{"c", ",", "2"}], "]"}]}], "//", "SUNSimplify"}]], "Input",
  CellLabel->"In[1471]:=  (21:56:33 on 5/16/01)",
  CellTags->"SUNDelta"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["\[Delta]", 
          RowBox[{
            FormBox["2",
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"]}]], " ", 
        SubscriptBox["\[Delta]", 
          RowBox[{
            FormBox["2",
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["c",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1471]=  (21:56:33 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "StandardForm"}]], "Input",
  CellLabel->"In[1472]:=  (21:56:33 on 5/16/01)",
  CellTags->"SUNDelta"],

Cell[BoxData[
    RowBox[{
      RowBox[{"SUNDelta", "[", 
        RowBox[{
          RowBox[{"ExplicitSUNIndex", "[", "2", "]"}], ",", 
          RowBox[{"SUNIndex", "[", "b", "]"}]}], "]"}], " ", 
      RowBox[{"SUNDelta", "[", 
        RowBox[{
          RowBox[{"ExplicitSUNIndex", "[", "2", "]"}], ",", 
          RowBox[{"SUNIndex", "[", "c", "]"}]}], "]"}]}]], "Output",
  CellLabel->"Out[1472]//StandardForm=  (21:56:33 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"SUNDelta", "[", 
          RowBox[{"1", ",", "2"}], "]"}], "//", "FCI"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[1473]:=  (21:56:33 on 5/16/01)",
  CellTags->"SUNDelta"],

Cell[BoxData[
    RowBox[{"SUNDelta", "[", 
      RowBox[{
        RowBox[{"ExplicitSUNIndex", "[", "1", "]"}], ",", 
        RowBox[{"ExplicitSUNIndex", "[", "2", "]"}]}], "]"}]], "Output",
  CellLabel->"Out[1473]//StandardForm=  (21:56:33 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["SUND", "ObjectName",
  CellTags->"SUND"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"SUND"],

Cell[TextData[{
  "SUND[a,b,c] are the symmetric SU(N) ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox["d", "abc"], "."}], TraditionalForm]]]
}], "Text",
  CellTags->"SUND"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["SUNDelta",
    ButtonData:>"SUNDelta",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SUNDelta"],
  ", ",
  ButtonBox["SUNF",
    ButtonData:>"SUNF",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SUNF"],
  ", ",
  ButtonBox["SUNSimplify",
    ButtonData:>"SUNSimplify",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SUNSimplify"],
  "."
}], "Text",
  CellTags->"SUND"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"SUND"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUND", "[", 
      RowBox[{"a", ",", "b", ",", "c"}], "]"}]], "Input",
  CellLabel->"In[1474]:=  (21:56:33 on 5/16/01)",
  CellTags->"SUND"],

Cell[BoxData[
    FormBox[
      SubscriptBox["d", 
        RowBox[{"a", "\[NoBreak]", "b", "\[NoBreak]", "c"}]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1474]=  (21:56:33 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"tt", "=", 
      RowBox[{"SUND", "[", 
        RowBox[{"a", ",", "b", ",", "c", ",", 
          RowBox[{"Explicit", "->", "True"}]}], "]"}]}]], "Input",
  CellLabel->"In[1475]:=  (21:56:33 on 5/16/01)",
  CellTags->"SUND"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"2", " ", 
          RowBox[{"tr", "\[NoBreak]", "(", "\[NoBreak]", 
            FormBox[
              RowBox[{
                SubscriptBox["T", 
                  FormBox[
                    FormBox["a",
                      "TraditionalForm"],
                    "TraditionalForm"]], ".", 
                SubscriptBox["T", 
                  FormBox[
                    FormBox["b",
                      "TraditionalForm"],
                    "TraditionalForm"]], ".", 
                SubscriptBox["T", 
                  FormBox[
                    FormBox["c",
                      "TraditionalForm"],
                    "TraditionalForm"]]}],
              "TraditionalForm"], "\[NoBreak]", ")"}]}], "+", 
        RowBox[{"2", " ", 
          RowBox[{"tr", "\[NoBreak]", "(", "\[NoBreak]", 
            FormBox[
              RowBox[{
                SubscriptBox["T", 
                  FormBox[
                    FormBox["b",
                      "TraditionalForm"],
                    "TraditionalForm"]], ".", 
                SubscriptBox["T", 
                  FormBox[
                    FormBox["a",
                      "TraditionalForm"],
                    "TraditionalForm"]], ".", 
                SubscriptBox["T", 
                  FormBox[
                    FormBox["c",
                      "TraditionalForm"],
                    "TraditionalForm"]]}],
              "TraditionalForm"], "\[NoBreak]", ")"}]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1475]=  (21:56:33 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUND", "[", 
      RowBox[{"c", ",", "a", ",", "b"}], "]"}]], "Input",
  CellLabel->"In[1476]:=  (21:56:34 on 5/16/01)",
  CellTags->"SUND"],

Cell[BoxData[
    FormBox[
      SubscriptBox["d", 
        RowBox[{"a", "\[NoBreak]", "b", "\[NoBreak]", "c"}]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1476]=  (21:56:34 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUND", "[", 
      RowBox[{"a", ",", "b", ",", "b"}], "]"}]], "Input",
  CellLabel->"In[1477]:=  (21:56:34 on 5/16/01)",
  CellTags->"SUND"],

Cell[BoxData[
    FormBox["0", TraditionalForm]], "Output",
  CellLabel->"Out[1477]=  (21:56:34 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNSimplify", "[", 
      RowBox[{
        RowBox[{"SUND", "[", 
          RowBox[{"a", ",", "b", ",", "c"}], "]"}], " ", 
        RowBox[{"SUND", "[", 
          RowBox[{"a", ",", "b", ",", "c"}], "]"}]}], "]"}]], "Input",
  CellLabel->"In[1478]:=  (21:56:34 on 5/16/01)",
  CellTags->"SUND"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"(", 
          RowBox[{"4", "-", 
            SubsuperscriptBox["C", "A", "2"]}], ")"}], " ", 
        SubscriptBox["C", "F"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1478]=  (21:56:34 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"SUNSimplify", "[", 
        RowBox[{
          RowBox[{
            RowBox[{"SUND", "[", 
              RowBox[{"a", ",", "b", ",", "c"}], "]"}], " ", 
            RowBox[{"SUND", "[", 
              RowBox[{"a", ",", "b", ",", "c"}], "]"}]}], ",", 
          RowBox[{"SUNNToCACF", "->", "False"}]}], "]"}], "//", 
      "Factor2"}]], "Input",
  CellLabel->"In[1479]:=  (21:56:34 on 5/16/01)",
  CellTags->"SUND"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "-", 
              SuperscriptBox["N", "2"]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"4", "-", 
              SuperscriptBox["N", "2"]}], ")"}]}], "N"], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1479]=  (21:56:34 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"SUNSimplify", "[", 
        RowBox[{
          RowBox[{
            RowBox[{"SUND", "[", 
              RowBox[{"a", ",", "b", ",", "c"}], "]"}], " ", 
            RowBox[{"SUND", "[", 
              RowBox[{"e", ",", "b", ",", "c"}], "]"}]}], ",", 
          RowBox[{"SUNNToCACF", "->", "False"}]}], "]"}], "//", 
      "Factor2"}]], "Input",
  CellLabel->"In[1480]:=  (21:56:34 on 5/16/01)",
  CellTags->"SUND"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"4", "-", 
                SuperscriptBox["N", "2"]}], ")"}], " ", 
            SubscriptBox["\[Delta]", 
              RowBox[{
                FormBox[
                  FormBox["a",
                    "TraditionalForm"],
                  "TraditionalForm"], "\[NoBreak]", 
                FormBox[
                  FormBox["e",
                    "TraditionalForm"],
                  "TraditionalForm"]}]]}], "N"]}], TraditionalForm]], "Output",\

  CellLabel->"Out[1480]=  (21:56:34 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"SUND", "[", 
        RowBox[{"a", ",", "b", ",", "c"}], "]"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[1481]:=  (21:56:34 on 5/16/01)",
  CellTags->"SUND"],

Cell[BoxData[
    RowBox[{"SUND", "[", 
      RowBox[{"a", ",", "b", ",", "c"}], "]"}]], "Output",
  CellLabel->"Out[1481]//StandardForm=  (21:56:34 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"SUND", "[", 
          RowBox[{"a", ",", "b", ",", "c"}], "]"}], "//", "FCI"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[1482]:=  (21:56:34 on 5/16/01)",
  CellTags->"SUND"],

Cell[BoxData[
    RowBox[{"SUND", "[", 
      RowBox[{
        RowBox[{"SUNIndex", "[", "a", "]"}], ",", 
        RowBox[{"SUNIndex", "[", "b", "]"}], ",", 
        RowBox[{"SUNIndex", "[", "c", "]"}]}], "]"}]], "Output",
  CellLabel->"Out[1482]//StandardForm=  (21:56:34 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          RowBox[{"SUND", "[", 
            RowBox[{"a", ",", "b", ",", "c"}], "]"}], "//", "FCI"}], "//", 
        "FCE"}], "//", "StandardForm"}]], "Input",
  CellLabel->"In[1483]:=  (21:56:34 on 5/16/01)",
  CellTags->"SUND"],

Cell[BoxData[
    RowBox[{"SUND", "[", 
      RowBox[{"a", ",", "b", ",", "c"}], "]"}]], "Output",
  CellLabel->"Out[1483]//StandardForm=  (21:56:34 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{"Clear", "[", "tt", "]"}]], "Input",
  CellLabel->"In[1484]:=  (21:56:34 on 5/16/01)",
  CellTags->"SUND"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["SUNF", "ObjectName",
  CellTags->"SUNF"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"SUNF"],

Cell["\<\
SUNF[a,b,c] are the structure constants of SU(N). The arguments a,b,c should \
be of symbolic type.\
\>", "Text",
  CellTags->"SUNF"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "SUNF", "]"}]], "Input",
  CellLabel->"In[1485]:=  (21:56:34 on 5/16/01)",
  CellTags->"SUNF"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"Explicit", "\[Rule]", "False"}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1485]=  (21:56:34 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["SUND",
    ButtonData:>"SUND",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SUND"],
  ", ",
  ButtonBox["SUNDelta",
    ButtonData:>"SUNDelta",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SUNDelta"],
  ", ",
  ButtonBox["SUNIndex",
    ButtonData:>"SUNIndex",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SUNIndex"],
  ", ",
  ButtonBox["SUNSimplify",
    ButtonData:>"SUNSimplify",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SUNSimplify"],
  ", ",
  ButtonBox["SUNT",
    ButtonData:>"SUNT",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SUNT"],
  ", ",
  ButtonBox["Trick",
    ButtonData:>"Trick",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Trick"],
  "."
}], "Text",
  CellTags->"SUNF"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"SUNF"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t1", "=", 
      RowBox[{
        RowBox[{
          RowBox[{"SUNF", "[", 
            RowBox[{"a", ",", "b", ",", "c"}], "]"}], "x"}], "+", 
        RowBox[{
          RowBox[{"SUNF", "[", 
            RowBox[{"b", ",", "a", ",", "c"}], "]"}], "y"}]}]}]], "Input",
  CellLabel->"In[1486]:=  (21:56:34 on 5/16/01)",
  CellTags->"SUNF"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"x", " ", 
          SubscriptBox["f", 
            RowBox[{"a", "\[NoBreak]", "b", "\[NoBreak]", "c"}]]}], "+", 
        RowBox[{"y", " ", 
          SubscriptBox["f", 
            RowBox[{"b", "\[NoBreak]", "a", "\[NoBreak]", "c"}]]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1486]=  (21:56:34 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Calc", "[", "t1", "]"}]], "Input",
  CellLabel->"In[1487]:=  (21:56:34 on 5/16/01)",
  CellTags->"SUNF"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"x", " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "-", 
        RowBox[{"y", " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1487]=  (21:56:34 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNSimplify", "[", "t1", "]"}]], "Input",
  CellLabel->"In[1488]:=  (21:56:35 on 5/16/01)",
  CellTags->"SUNF"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"(", 
          RowBox[{"x", "-", "y"}], ")"}], " ", 
        SubscriptBox["f", 
          RowBox[{
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["c",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1488]=  (21:56:35 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNF", "[", 
      RowBox[{"a", ",", "a", ",", "b"}], "]"}]], "Input",
  CellLabel->"In[1489]:=  (21:56:35 on 5/16/01)",
  CellTags->"SUNF"],

Cell[BoxData[
    FormBox[
      SubscriptBox["f", 
        RowBox[{"a", "\[NoBreak]", "a", "\[NoBreak]", "b"}]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1489]=  (21:56:35 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"SUNF", "[", 
        RowBox[{"a", ",", "a", ",", "b"}], "]"}], "//", "Calc"}]], "Input",
  CellLabel->"In[1490]:=  (21:56:35 on 5/16/01)",
  CellTags->"SUNF"],

Cell[BoxData[
    FormBox["0", TraditionalForm]], "Output",
  CellLabel->"Out[1490]=  (21:56:35 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "This is a consequence of the usual choice for the normalization of the ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox["T", "a"], " ", "generators", "in", " ", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"see", " ", " ", "SUNT"}], ")"}], "."}]}], 
        TraditionalForm]]]
}], "Text",
  CellTags->"SUNF"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNF", "[", 
      RowBox[{"a", ",", "b", ",", "c", ",", 
        RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]], "Input",
  CellLabel->"In[1491]:=  (21:56:35 on 5/16/01)",
  CellTags->"SUNF"],

Cell[BoxData[
    FormBox[
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"tr", "\[NoBreak]", "(", "\[NoBreak]", 
              FormBox[
                RowBox[{
                  SubscriptBox["T", 
                    FormBox[
                      FormBox["a",
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SubscriptBox["T", 
                    FormBox[
                      FormBox["c",
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SubscriptBox["T", 
                    FormBox[
                      FormBox["b",
                        "TraditionalForm"],
                      "TraditionalForm"]]}],
                "TraditionalForm"], "\[NoBreak]", ")"}], "-", 
            RowBox[{"tr", "\[NoBreak]", "(", "\[NoBreak]", 
              FormBox[
                RowBox[{
                  SubscriptBox["T", 
                    FormBox[
                      FormBox["a",
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SubscriptBox["T", 
                    FormBox[
                      FormBox["b",
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SubscriptBox["T", 
                    FormBox[
                      FormBox["c",
                        "TraditionalForm"],
                      "TraditionalForm"]]}],
                "TraditionalForm"], "\[NoBreak]", ")"}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1491]=  (21:56:35 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNSimplify", "[", 
      RowBox[{
        RowBox[{"SUNF", "[", 
          RowBox[{"a", ",", "b", ",", "c"}], "]"}], " ", 
        RowBox[{"SUNF", "[", 
          RowBox[{"a", ",", "b", ",", "d"}], "]"}]}], "]"}]], "Input",
  CellLabel->"In[1492]:=  (21:56:35 on 5/16/01)",
  CellTags->"SUNF"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["C", "A"], " ", 
        SubscriptBox["\[Delta]", 
          RowBox[{
            FormBox[
              FormBox["c",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["d",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1492]=  (21:56:35 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNSimplify", "[", 
      RowBox[{
        RowBox[{"SUNF", "[", 
          RowBox[{"a", ",", "b", ",", "c"}], "]"}], ",", 
        RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]], "Input",
  CellLabel->"In[1493]:=  (21:56:35 on 5/16/01)",
  CellTags->"SUNF"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"tr", "\[NoBreak]", "(", "\[NoBreak]", 
              FormBox[
                RowBox[{
                  SubscriptBox["T", 
                    FormBox[
                      FormBox["a",
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SubscriptBox["T", 
                    FormBox[
                      FormBox["b",
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SubscriptBox["T", 
                    FormBox[
                      FormBox["c",
                        "TraditionalForm"],
                      "TraditionalForm"]]}],
                "TraditionalForm"], "\[NoBreak]", ")"}], "-", 
            RowBox[{"tr", "\[NoBreak]", "(", "\[NoBreak]", 
              FormBox[
                RowBox[{
                  SubscriptBox["T", 
                    FormBox[
                      FormBox["b",
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SubscriptBox["T", 
                    FormBox[
                      FormBox["a",
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SubscriptBox["T", 
                    FormBox[
                      FormBox["c",
                        "TraditionalForm"],
                      "TraditionalForm"]]}],
                "TraditionalForm"], "\[NoBreak]", ")"}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1493]=  (21:56:35 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"SUNF", "[", 
        RowBox[{"a", ",", "b", ",", "c"}], "]"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[1494]:=  (21:56:36 on 5/16/01)",
  CellTags->"SUNF"],

Cell[BoxData[
    RowBox[{"SUNF", "[", 
      RowBox[{"a", ",", "b", ",", "c"}], "]"}]], "Output",
  CellLabel->"Out[1494]//StandardForm=  (21:56:36 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"SUNF", "[", 
          RowBox[{"a", ",", "b", ",", "c"}], "]"}], "//", "FCI"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[1495]:=  (21:56:36 on 5/16/01)",
  CellTags->"SUNF"],

Cell[BoxData[
    RowBox[{"SUNF", "[", 
      RowBox[{
        RowBox[{"SUNIndex", "[", "a", "]"}], ",", 
        RowBox[{"SUNIndex", "[", "b", "]"}], ",", 
        RowBox[{"SUNIndex", "[", "c", "]"}]}], "]"}]], "Output",
  CellLabel->"Out[1495]//StandardForm=  (21:56:36 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          RowBox[{"SUNF", "[", 
            RowBox[{"a", ",", "b", ",", "c"}], "]"}], "//", "FCI"}], "//", 
        "FCE"}], "//", "StandardForm"}]], "Input",
  CellLabel->"In[1496]:=  (21:56:36 on 5/16/01)",
  CellTags->"SUNF"],

Cell[BoxData[
    RowBox[{"SUNF", "[", 
      RowBox[{"a", ",", "b", ",", "c"}], "]"}]], "Output",
  CellLabel->"Out[1496]//StandardForm=  (21:56:36 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNF", "[", 
      RowBox[{"b", ",", "a", ",", "c"}], "]"}]], "Input",
  CellLabel->"In[1497]:=  (21:56:36 on 5/16/01)",
  CellTags->"SUNF"],

Cell[BoxData[
    FormBox[
      SubscriptBox["f", 
        RowBox[{"b", "\[NoBreak]", "a", "\[NoBreak]", "c"}]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1497]=  (21:56:36 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"SUNF", "[", 
        RowBox[{"b", ",", "a", ",", "c"}], "]"}], "//", "FCI"}]], "Input",
  CellLabel->"In[1498]:=  (21:56:36 on 5/16/01)",
  CellTags->"SUNF"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        SubscriptBox["f", 
          RowBox[{
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["c",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1498]=  (21:56:36 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["SUNIndex", "ObjectName",
  CellTags->"SUNIndex"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"SUNIndex"],

Cell["SUNIndex is the head of SU(N)indices.", "Text",
  CellTags->"SUNIndex"],

Cell[TextData[{
  "See also: ",
  ButtonBox["ExplicitSUNIndex",
    ButtonData:>"ExplicitSUNIndex",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"ExplicitSUNIndex"],
  ", ",
  ButtonBox["SUNDelta",
    ButtonData:>"SUNDelta",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SUNDelta"],
  ", ",
  ButtonBox["SUNF",
    ButtonData:>"SUNF",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SUNF"],
  "."
}], "Text",
  CellTags->"SUNIndex"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"SUNIndex"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNIndex", "[", "i", "]"}]], "Input",
  CellLabel->"In[1499]:=  (21:56:36 on 5/16/01)",
  CellTags->"SUNIndex"],

Cell[BoxData[
    FormBox["i", TraditionalForm]], "Output",
  CellLabel->"Out[1499]=  (21:56:36 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "StandardForm"}]], "Input",
  CellLabel->"In[1500]:=  (21:56:36 on 5/16/01)",
  CellTags->"SUNIndex"],

Cell[BoxData[
    RowBox[{"SUNIndex", "[", "i", "]"}]], "Output",
  CellLabel->"Out[1500]//StandardForm=  (21:56:36 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"SUNDelta", "[", 
          RowBox[{"i", ",", "j"}], "]"}], "//", "FCI"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[1501]:=  (21:56:36 on 5/16/01)",
  CellTags->"SUNIndex"],

Cell[BoxData[
    RowBox[{"SUNDelta", "[", 
      RowBox[{
        RowBox[{"SUNIndex", "[", "i", "]"}], ",", 
        RowBox[{"SUNIndex", "[", "j", "]"}]}], "]"}]], "Output",
  CellLabel->"Out[1501]//StandardForm=  (21:56:36 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["SUNSimplify", "ObjectName",
  CellTags->"SUNSimplify"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"SUNSimplify"],

Cell["\<\
SUNSimplify simplifies products of SUNT (and complex conjugated) matrices. \
Basic renaming of dummy indices is done. If the option SUNTrace is set to \
False, then any SUNT-matrices are taken out of DiracTrace[...]; otherwise a \
color-trace is taken (by SUNTrace) before taking the SUN-objects in front of \
DiracTrace[...].\
\>", "Text",
  CellTags->"SUNSimplify"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "SUNSimplify", "]"}]], "Input",
  CellLabel->"In[1502]:=  (21:56:36 on 5/16/01)",
  CellTags->"SUNSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"Expanding", "\[Rule]", "False"}], ",", 
          RowBox[{"Explicit", "\[Rule]", "False"}], ",", 
          RowBox[{"Factoring", "\[Rule]", "False"}], ",", 
          RowBox[{"SUNIndexRename", "\[Rule]", "True"}], ",", 
          RowBox[{"SUNFJacobi", "\[Rule]", "False"}], ",", 
          RowBox[{"SUNNToCACF", "\[Rule]", "True"}], ",", 
          RowBox[{"SUNTrace", "\[Rule]", "True"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1502]=  (21:56:36 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["Trick",
    ButtonData:>"Trick",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Trick"],
  "."
}], "Text",
  CellTags->"SUNSimplify"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"SUNSimplify"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t1", "=", 
      RowBox[{
        RowBox[{"SUNDelta", "[", 
          RowBox[{"a", ",", "b"}], "]"}], " ", 
        RowBox[{"SUNDelta", "[", 
          RowBox[{"b", ",", "c"}], "]"}]}]}]], "Input",
  CellLabel->"In[1503]:=  (21:56:36 on 5/16/01)",
  CellTags->"SUNSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["\[Delta]", 
          RowBox[{"a", "\[NoBreak]", "b"}]], " ", 
        SubscriptBox["\[Delta]", 
          RowBox[{"b", "\[NoBreak]", "c"}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1503]=  (21:56:36 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNSimplify", "[", "t1", "]"}]], "Input",
  CellLabel->"In[1504]:=  (21:56:36 on 5/16/01)",
  CellTags->"SUNSimplify"],

Cell[BoxData[
    FormBox[
      SubscriptBox["\[Delta]", 
        RowBox[{
          FormBox[
            FormBox["a",
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", 
          FormBox[
            FormBox["c",
              "TraditionalForm"],
            "TraditionalForm"]}]], TraditionalForm]], "Output",
  CellLabel->"Out[1504]=  (21:56:37 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t2", "=", 
      RowBox[{
        RowBox[{"SUNT", "[", "a", "]"}], ".", 
        RowBox[{"SUNT", "[", "a", "]"}]}]}]], "Input",
  CellLabel->"In[1505]:=  (21:56:37 on 5/16/01)",
  CellTags->"SUNSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["T", 
          FormBox["a",
            "TraditionalForm"]], ".", 
        SubscriptBox["T", 
          FormBox["a",
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1505]=  (21:56:37 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNSimplify", "[", "t2", "]"}]], "Input",
  CellLabel->"In[1506]:=  (21:56:37 on 5/16/01)",
  CellTags->"SUNSimplify"],

Cell[BoxData[
    FormBox[
      SubscriptBox["C", "F"], TraditionalForm]], "Output",
  CellLabel->"Out[1506]=  (21:56:37 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNSimplify", "[", 
      RowBox[{"t2", ",", 
        RowBox[{"SUNNToCACF", "->", "False"}]}], "]"}]], "Input",
  CellLabel->"In[1507]:=  (21:56:37 on 5/16/01)",
  CellTags->"SUNSimplify"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{
          SuperscriptBox["N", "2"], "-", "1"}], 
        RowBox[{"2", " ", "N"}]], TraditionalForm]], "Output",
  CellLabel->"Out[1507]=  (21:56:37 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t3", "=", 
      RowBox[{
        RowBox[{"SUNF", "[", 
          RowBox[{"a", ",", "r", ",", "s"}], "]"}], 
        RowBox[{"SUNF", "[", 
          RowBox[{"b", ",", "r", ",", "s"}], "]"}]}]}]], "Input",
  CellLabel->"In[1508]:=  (21:56:37 on 5/16/01)",
  CellTags->"SUNSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["f", 
          RowBox[{"a", "\[NoBreak]", "r", "\[NoBreak]", "s"}]], " ", 
        SubscriptBox["f", 
          RowBox[{"b", "\[NoBreak]", "r", "\[NoBreak]", "s"}]]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1508]=  (21:56:37 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNSimplify", "[", "t3", "]"}]], "Input",
  CellLabel->"In[1509]:=  (21:56:37 on 5/16/01)",
  CellTags->"SUNSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["C", "A"], " ", 
        SubscriptBox["\[Delta]", 
          RowBox[{
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1509]=  (21:56:37 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t4", "=", 
      RowBox[{
        RowBox[{"SUNF", "[", 
          RowBox[{"a", ",", "b", ",", "c"}], "]"}], " ", ".", " ", 
        RowBox[{"SUNF", "[", 
          RowBox[{"a", ",", "b", ",", "c"}], "]"}]}]}]], "Input",
  CellLabel->"In[1510]:=  (21:56:37 on 5/16/01)",
  CellTags->"SUNSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["f", 
          RowBox[{"a", "\[NoBreak]", "b", "\[NoBreak]", "c"}]], ".", 
        SubscriptBox["f", 
          RowBox[{"a", "\[NoBreak]", "b", "\[NoBreak]", "c"}]]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1510]=  (21:56:37 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNSimplify", "[", "t4", "]"}]], "Input",
  CellLabel->"In[1511]:=  (21:56:37 on 5/16/01)",
  CellTags->"SUNSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{"2", " ", 
        SubsuperscriptBox["C", "A", "2"], " ", 
        SubscriptBox["C", "F"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1511]=  (21:56:37 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t5", "=", 
      RowBox[{
        RowBox[{"SUNF", "[", 
          RowBox[{"a", ",", "b", ",", "c"}], "]"}], " ", 
        RowBox[{"SUNF", "[", 
          RowBox[{"d", ",", "b", ",", "c"}], "]"}]}]}]], "Input",
  CellLabel->"In[1512]:=  (21:56:38 on 5/16/01)",
  CellTags->"SUNSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["f", 
          RowBox[{"a", "\[NoBreak]", "b", "\[NoBreak]", "c"}]], " ", 
        SubscriptBox["f", 
          RowBox[{"d", "\[NoBreak]", "b", "\[NoBreak]", "c"}]]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1512]=  (21:56:38 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNSimplify", "[", "t5", "]"}]], "Input",
  CellLabel->"In[1513]:=  (21:56:38 on 5/16/01)",
  CellTags->"SUNSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["C", "A"], " ", 
        SubscriptBox["\[Delta]", 
          RowBox[{
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["d",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1513]=  (21:56:38 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t6", "=", 
      RowBox[{
        RowBox[{"SUNF", "[", 
          RowBox[{"a", ",", "b", ",", "c"}], "]"}], " ", 
        RowBox[{"SUND", "[", 
          RowBox[{"d", ",", "b", ",", "c"}], "]"}]}]}]], "Input",
  CellLabel->"In[1514]:=  (21:56:38 on 5/16/01)",
  CellTags->"SUNSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["d", 
          RowBox[{"b", "\[NoBreak]", "c", "\[NoBreak]", "d"}]], " ", 
        SubscriptBox["f", 
          RowBox[{"a", "\[NoBreak]", "b", "\[NoBreak]", "c"}]]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1514]=  (21:56:38 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNSimplify", "[", 
      RowBox[{"t6", ",", 
        RowBox[{"Explicit", "->", "True"}]}], "]"}]], "Input",
  CellLabel->"In[1515]:=  (21:56:38 on 5/16/01)",
  CellTags->"SUNSimplify"],

Cell[BoxData[
    FormBox["0", TraditionalForm]], "Output",
  CellLabel->"Out[1515]=  (21:56:38 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"SUNSimplify", "[", 
        RowBox[{
          RowBox[{
            RowBox[{"SUND", "[", 
              RowBox[{"a", ",", "b", ",", "c"}], "]"}], " ", 
            RowBox[{"SUND", "[", 
              RowBox[{"a", ",", "b", ",", "c"}], "]"}]}], ",", 
          RowBox[{"SUNNToCACF", "\[Rule]", "False"}]}], "]"}], "//", 
      "Factor2"}]], "Input",
  CellLabel->"In[1516]:=  (21:56:38 on 5/16/01)",
  CellTags->"SUNSimplify"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "-", 
              SuperscriptBox["N", "2"]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"4", "-", 
              SuperscriptBox["N", "2"]}], ")"}]}], "N"], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1516]=  (21:56:38 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"SUNSimplify", "[", 
        RowBox[{
          RowBox[{
            RowBox[{"SUND", "[", 
              RowBox[{"a", ",", "b", ",", "c"}], "]"}], " ", 
            RowBox[{"SUND", "[", 
              RowBox[{"e", ",", "b", ",", "c"}], "]"}]}], ",", 
          RowBox[{"SUNNToCACF", "\[Rule]", "False"}]}], "]"}], "//", 
      "FullSimplify"}]], "Input",
  CellLabel->"In[1517]:=  (21:56:38 on 5/16/01)",
  CellTags->"SUNSimplify"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox["N", "2"], "-", "4"}], ")"}], " ", 
          SubscriptBox["\[Delta]", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["e",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "N"], TraditionalForm]], "Output",
  CellLabel->"Out[1517]=  (21:56:38 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNSimplify", "[", 
      RowBox[{
        RowBox[{"SUNF", "[", 
          RowBox[{"a", ",", "b", ",", "c"}], "]"}], ",", 
        RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]], "Input",
  CellLabel->"In[1518]:=  (21:56:38 on 5/16/01)",
  CellTags->"SUNSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"tr", "\[NoBreak]", "(", "\[NoBreak]", 
              FormBox[
                RowBox[{
                  SubscriptBox["T", 
                    FormBox[
                      FormBox["a",
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SubscriptBox["T", 
                    FormBox[
                      FormBox["b",
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SubscriptBox["T", 
                    FormBox[
                      FormBox["c",
                        "TraditionalForm"],
                      "TraditionalForm"]]}],
                "TraditionalForm"], "\[NoBreak]", ")"}], "-", 
            RowBox[{"tr", "\[NoBreak]", "(", "\[NoBreak]", 
              FormBox[
                RowBox[{
                  SubscriptBox["T", 
                    FormBox[
                      FormBox["b",
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SubscriptBox["T", 
                    FormBox[
                      FormBox["a",
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SubscriptBox["T", 
                    FormBox[
                      FormBox["c",
                        "TraditionalForm"],
                      "TraditionalForm"]]}],
                "TraditionalForm"], "\[NoBreak]", ")"}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1518]=  (21:56:38 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNSimplify", "[", 
      RowBox[{
        RowBox[{"SUND", "[", 
          RowBox[{"a", ",", "b", ",", "c"}], "]"}], ",", 
        RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]], "Input",
  CellLabel->"In[1519]:=  (21:56:38 on 5/16/01)",
  CellTags->"SUNSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{"2", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"tr", "\[NoBreak]", "(", "\[NoBreak]", 
              FormBox[
                RowBox[{
                  SubscriptBox["T", 
                    FormBox[
                      FormBox["a",
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SubscriptBox["T", 
                    FormBox[
                      FormBox["b",
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SubscriptBox["T", 
                    FormBox[
                      FormBox["c",
                        "TraditionalForm"],
                      "TraditionalForm"]]}],
                "TraditionalForm"], "\[NoBreak]", ")"}], "+", 
            RowBox[{"tr", "\[NoBreak]", "(", "\[NoBreak]", 
              FormBox[
                RowBox[{
                  SubscriptBox["T", 
                    FormBox[
                      FormBox["b",
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SubscriptBox["T", 
                    FormBox[
                      FormBox["a",
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SubscriptBox["T", 
                    FormBox[
                      FormBox["c",
                        "TraditionalForm"],
                      "TraditionalForm"]]}],
                "TraditionalForm"], "\[NoBreak]", ")"}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1519]=  (21:56:39 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNSimplify", "[", 
      RowBox[{
        RowBox[{"SUNF", "[", 
          RowBox[{"a", ",", "b", ",", "c"}], "]"}], " ", 
        RowBox[{"SUNT", "[", 
          RowBox[{"c", ",", "b", ",", "a"}], "]"}]}], "]"}]], "Input",
  CellLabel->"In[1520]:=  (21:56:39 on 5/16/01)",
  CellTags->"SUNSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
        SubscriptBox["C", "A"], " ", 
        SubscriptBox["C", "F"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1520]=  (21:56:39 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"a1", "=", 
      RowBox[{
        RowBox[{
          RowBox[{"SUNF", "[", 
            RowBox[{"a", ",", "b", ",", "e"}], "]"}], 
          RowBox[{"SUNF", "[", 
            RowBox[{"c", ",", "d", ",", "e"}], "]"}]}], "+", 
        RowBox[{
          RowBox[{"SUNF", "[", 
            RowBox[{"a", ",", "b", ",", "z"}], "]"}], 
          RowBox[{"SUNF", "[", 
            RowBox[{"c", ",", "d", ",", "z"}], "]"}]}]}]}]], "Input",
  CellLabel->"In[1521]:=  (21:56:39 on 5/16/01)",
  CellTags->"SUNSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["f", 
            RowBox[{"a", "\[NoBreak]", "b", "\[NoBreak]", "e"}]], " ", 
          SubscriptBox["f", 
            RowBox[{"c", "\[NoBreak]", "d", "\[NoBreak]", "e"}]]}], "+", 
        RowBox[{
          SubscriptBox["f", 
            RowBox[{"a", "\[NoBreak]", "b", "\[NoBreak]", "z"}]], " ", 
          SubscriptBox["f", 
            RowBox[{"c", "\[NoBreak]", "d", "\[NoBreak]", "z"}]]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1521]=  (21:56:39 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNSimplify", "[", 
      RowBox[{"a1", ",", 
        RowBox[{"Explicit", "\[Rule]", "False"}]}], "]"}]], "Input",
  CellLabel->"In[1522]:=  (21:56:39 on 5/16/01)",
  CellTags->"SUNSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{"2", " ", 
        SubscriptBox["f", 
          RowBox[{
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["e",
                "TraditionalForm"],
              "TraditionalForm"]}]], " ", 
        SubscriptBox["f", 
          RowBox[{
            FormBox[
              FormBox["c",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["d",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["e",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1522]=  (21:56:39 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNSimplify", "[", 
      RowBox[{"a1", ",", 
        RowBox[{"Explicit", "\[Rule]", "False"}], ",", 
        RowBox[{"SUNIndexRename", "\[Rule]", "False"}]}], "]"}]], "Input",
  CellLabel->"In[1523]:=  (21:56:39 on 5/16/01)",
  CellTags->"SUNSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["e",
                  "TraditionalForm"],
                "TraditionalForm"]}]], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["d",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["e",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "+", 
        RowBox[{
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["z",
                  "TraditionalForm"],
                "TraditionalForm"]}]], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["d",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["z",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1523]=  (21:56:39 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"a2", "=", 
      RowBox[{"DiracTrace", "[", 
        RowBox[{
          RowBox[{"SUNT", "[", 
            RowBox[{"a", ",", "b"}], "]"}], ".", 
          RowBox[{"DiracMatrix", "[", 
            RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}]}], "]"}]}]], "Input",
  CellLabel->"In[1524]:=  (21:56:39 on 5/16/01)",
  CellTags->"SUNSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{"tr", "(", 
        FormBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SubscriptBox["T", 
                  FormBox["a",
                    "TraditionalForm"]], 
                SubscriptBox["T", 
                  FormBox["b",
                    "TraditionalForm"]]}], ")"}], ".", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox["\[Gamma]", "\[Mu]"], 
                SuperscriptBox["\[Gamma]", "\[Nu]"]}], ")"}]}],
          "TraditionalForm"], ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[1524]=  (21:56:39 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNSimplify", "[", "a2", "]"}]], "Input",
  CellLabel->"In[1525]:=  (21:56:39 on 5/16/01)",
  CellTags->"SUNSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"tr", "(", 
          FormBox[
            RowBox[{
              SuperscriptBox["\[Gamma]", 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], ".", 
              SuperscriptBox["\[Gamma]", 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}],
            "TraditionalForm"], ")"}], " ", 
        SubscriptBox["\[Delta]", 
          RowBox[{
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1525]=  (21:56:40 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNSimplify", "[", 
      RowBox[{"a2", ",", 
        RowBox[{"SUNTrace", "\[Rule]", "False"}]}], "]"}]], "Input",
  CellLabel->"In[1526]:=  (21:56:40 on 5/16/01)",
  CellTags->"SUNSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"tr", "(", 
          FormBox[
            RowBox[{
              SuperscriptBox["\[Gamma]", 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], ".", 
              SuperscriptBox["\[Gamma]", 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}],
            "TraditionalForm"], ")"}], ".", 
        SubscriptBox["T", 
          FormBox[
            FormBox["a",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        SubscriptBox["T", 
          FormBox[
            FormBox["b",
              "TraditionalForm"],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1526]=  (21:56:40 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"SUNSimplify", "[", 
        RowBox[{"a2", ",", 
          RowBox[{"SUNTrace", "\[Rule]", "False"}]}], "]"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[1527]:=  (21:56:40 on 5/16/01)",
  CellTags->"SUNSimplify"],

Cell[BoxData[
    RowBox[{
      RowBox[{"DiracTrace", "[", 
        RowBox[{
          RowBox[{"DiracGamma", "[", 
            RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], "]"}], ".", 
          RowBox[{"DiracGamma", "[", 
            RowBox[{"LorentzIndex", "[", "\[Nu]", "]"}], "]"}]}], "]"}], ".", 
      
      RowBox[{"SUNT", "[", 
        RowBox[{"SUNIndex", "[", "a", "]"}], "]"}], ".", 
      RowBox[{"SUNT", "[", 
        RowBox[{"SUNIndex", "[", "b", "]"}], "]"}]}]], "Output",
  CellLabel->"Out[1527]//StandardForm=  (21:56:40 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNSimplify", "[", 
      RowBox[{"1", "-", 
        RowBox[{"SUNDelta", "[", 
          RowBox[{"i1", ",", "i2"}], "]"}]}], "]"}]], "Input",
  CellLabel->"In[1528]:=  (21:56:40 on 5/16/01)",
  CellTags->"SUNSimplify"],

Cell[BoxData[
    FormBox[
      RowBox[{"1", "-", 
        SubscriptBox["\[Delta]", 
          RowBox[{
            FormBox[
              FormBox[
                SubscriptBox[
                  StyleBox["\<\"i\"\>",
                    FontSlant->"Italic"], "1"],
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox[
                SubscriptBox[
                  StyleBox["\<\"i\"\>",
                    FontSlant->"Italic"], "2"],
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1528]=  (21:56:40 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "StandardForm"}]], "Input",
  CellLabel->"In[1529]:=  (21:56:40 on 5/16/01)",
  CellTags->"SUNSimplify"],

Cell[BoxData[
    RowBox[{"1", "-", 
      RowBox[{"SUNDelta", "[", 
        RowBox[{
          RowBox[{"SUNIndex", "[", "i1", "]"}], ",", 
          RowBox[{"SUNIndex", "[", "i2", "]"}]}], "]"}]}]], "Output",
  CellLabel->"Out[1529]//StandardForm=  (21:56:40 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{"Clear", "[", 
      RowBox[{
      "t1", ",", "t2", ",", "t3", ",", "t4", ",", "t5", ",", "t6", ",", "a1", 
        ",", "a2"}], "]"}]], "Input",
  CellLabel->"In[1530]:=  (21:56:40 on 5/16/01)",
  CellTags->"SUNSimplify"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["SUNT", "ObjectName",
  CellTags->"SUNT"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"SUNT"],

Cell[TextData[{
  "SUNT[a] is the SU(N) ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["T", "a"], TraditionalForm]]],
  " generator in the fundamental representation."
}], "Text",
  CellTags->"SUNT"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["CA",
    ButtonData:>"CA",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"CA"],
  ", ",
  ButtonBox["CF",
    ButtonData:>"CF",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"CF"],
  ", ",
  ButtonBox["SUND",
    ButtonData:>"SUND",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SUND"],
  ", ",
  ButtonBox["SUNDelta",
    ButtonData:>"SUNDelta",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SUNDelta"],
  ", ",
  ButtonBox["SUNF",
    ButtonData:>"SUNF",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SUNF"],
  ", ",
  ButtonBox["SUNSimplify",
    ButtonData:>"SUNSimplify",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SUNSimplify"],
  "."
}], "Text",
  CellTags->"SUNT"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"SUNT"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNT", "[", "a", "]"}]], "Input",
  CellLabel->"In[1531]:=  (21:56:40 on 5/16/01)",
  CellTags->"SUNT"],

Cell[BoxData[
    FormBox[
      SubscriptBox["T", 
        FormBox["a",
          "TraditionalForm"]], TraditionalForm]], "Output",
  CellLabel->"Out[1531]=  (21:56:40 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "Since ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["T", "a"], TraditionalForm]]],
  " is a noncommutative object, products have to separated by a dot (.)."
}], "Text",
  CellTags->"SUNT"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"SUNT", "[", "a", "]"}], ".", " ", 
      RowBox[{"SUNT", "[", "b", "]"}], ".", " ", 
      RowBox[{"SUNT", "[", "c", "]"}]}]], "Input",
  CellLabel->"In[1532]:=  (21:56:40 on 5/16/01)",
  CellTags->"SUNT"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["T", 
          FormBox["a",
            "TraditionalForm"]], ".", 
        SubscriptBox["T", 
          FormBox["b",
            "TraditionalForm"]], ".", 
        SubscriptBox["T", 
          FormBox["c",
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1532]=  (21:56:40 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNT", "[", 
      RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}]], "Input",
  CellLabel->"In[1533]:=  (21:56:40 on 5/16/01)",
  CellTags->"SUNT"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["T", 
          FormBox["a",
            "TraditionalForm"]], 
        SubscriptBox["T", 
          FormBox["b",
            "TraditionalForm"]], 
        SubscriptBox["T", 
          FormBox["c",
            "TraditionalForm"]], 
        SubscriptBox["T", 
          FormBox["d",
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1533]=  (21:56:40 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNSimplify", "[", 
      RowBox[{
        RowBox[{"SUNT", "[", 
          RowBox[{"a", ",", "b", ",", "a"}], "]"}], ",", 
        RowBox[{"SUNNToCACF", "\[Rule]", "False"}]}], "]"}]], "Input",
  CellLabel->"In[1534]:=  (21:56:40 on 5/16/01)",
  CellTags->"SUNT"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        FractionBox[
          SubscriptBox["T", 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"]], 
          RowBox[{"2", " ", "N"}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1534]=  (21:56:40 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNSimplify", "[", 
      RowBox[{"SUNT", "[", 
        RowBox[{"a", ",", "b", ",", "b", ",", "a"}], "]"}], "]"}]], "Input",
  CellLabel->"In[1535]:=  (21:56:41 on 5/16/01)",
  CellTags->"SUNT"],

Cell[BoxData[
    FormBox[
      SubsuperscriptBox["C", "F", "2"], TraditionalForm]], "Output",
  CellLabel->"Out[1535]=  (21:56:41 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNSimplify", "[", 
      RowBox[{"SUNT", "[", 
        RowBox[{"a", ",", "b", ",", "a"}], "]"}], "]"}]], "Input",
  CellLabel->"In[1536]:=  (21:56:41 on 5/16/01)",
  CellTags->"SUNT"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          FractionBox["1", "2"]}], " ", 
        RowBox[{"(", 
          RowBox[{
            SubscriptBox["C", "A"], "-", 
            RowBox[{"2", " ", 
              SubscriptBox["C", "F"]}]}], ")"}], " ", 
        SubscriptBox["T", 
          FormBox[
            FormBox["b",
              "TraditionalForm"],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1536]=  (21:56:41 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNSimplify", "[", 
      RowBox[{
        RowBox[{"SUNT", "[", 
          RowBox[{"a", ",", "b", ",", "a"}], "]"}], ",", 
        RowBox[{"SUNNToCACF", "\[Rule]", "False"}]}], "]"}]], "Input",
  CellLabel->"In[1537]:=  (21:56:41 on 5/16/01)",
  CellTags->"SUNT"],

Cell[BoxData[
    FormBox[
      RowBox[{"-", 
        FractionBox[
          SubscriptBox["T", 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"]], 
          RowBox[{"2", " ", "N"}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1537]=  (21:56:41 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "The normalizaton of the generators is chosen in the standard way, \
therefore ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"tr", "(", 
            RowBox[{
              SubscriptBox["T", "a"], 
              SubscriptBox["T", "b"]}], ")"}], " ", "=", " ", 
          RowBox[{
            RowBox[{"1", "/", "2"}], " ", 
            RowBox[{
              SubscriptBox["\[Delta]", "ab"], "."}]}]}], TraditionalForm]]]
}], "Text",
  CellTags->"SUNT"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNTrace", "[", 
      RowBox[{"SUNT", "[", 
        RowBox[{"a", ",", "b"}], "]"}], "]"}]], "Input",
  CellLabel->"In[1538]:=  (21:56:41 on 5/16/01)",
  CellTags->"SUNT"],

Cell[BoxData[
    FormBox[
      FractionBox[
        SubscriptBox["\[Delta]", 
          RowBox[{
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"]}]], "2"], TraditionalForm]], "Output",
  CellLabel->"Out[1538]=  (21:56:41 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "In case you want ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["T", "f"], TraditionalForm]]],
  ", you need to include a factor 2Tf inside the trace."
}], "Text",
  CellTags->"SUNT"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNTrace", "[", 
      RowBox[{"2", " ", "Tf", " ", 
        RowBox[{"SUNT", "[", 
          RowBox[{"a", ",", "b"}], "]"}]}], "]"}]], "Input",
  CellLabel->"In[1539]:=  (21:56:41 on 5/16/01)",
  CellTags->"SUNT"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["T", "f"], " ", 
        SubscriptBox["\[Delta]", 
          RowBox[{
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1539]=  (21:56:41 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"SUNTrace", "[", 
        RowBox[{"SUNT", "[", 
          RowBox[{"a", ",", "b"}], "]"}], "]"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[1540]:=  (21:56:41 on 5/16/01)",
  CellTags->"SUNT"],

Cell[BoxData[
    RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"SUNDelta", "[", 
        RowBox[{
          RowBox[{"SUNIndex", "[", "a", "]"}], ",", 
          RowBox[{"SUNIndex", "[", "b", "]"}]}], "]"}]}]], "Output",
  CellLabel->"Out[1540]//StandardForm=  (21:56:41 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"SUNT", "[", "a", "]"}], "//", "FCI"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[1541]:=  (21:56:41 on 5/16/01)",
  CellTags->"SUNT"],

Cell[BoxData[
    RowBox[{"SUNT", "[", 
      RowBox[{"SUNIndex", "[", "a", "]"}], "]"}]], "Output",
  CellLabel->"Out[1541]//StandardForm=  (21:56:41 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          RowBox[{"SUNT", "[", "a", "]"}], "//", "FCI"}], "//", "FCE"}], "//",
       "StandardForm"}]], "Input",
  CellLabel->"In[1542]:=  (21:56:41 on 5/16/01)",
  CellTags->"SUNT"],

Cell[BoxData[
    RowBox[{"SUNT", "[", "a", "]"}]], "Output",
  CellLabel->"Out[1542]//StandardForm=  (21:56:41 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["SUNTrace", "ObjectName",
  CellTags->"SUNTrace"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"SUNTrace"],

Cell["SUNTrace[expr] calculates the color-trace.", "Text",
  CellTags->"SUNTrace"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "SUNTrace", "]"}]], "Input",
  CellLabel->"In[1543]:=  (21:56:41 on 5/16/01)",
  CellTags->"SUNTrace"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"Explicit", "\[Rule]", "False"}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1543]=  (21:56:41 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["SUNSimplify",
    ButtonData:>"SUNSimplify",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SUNSimplify"],
  ", ",
  ButtonBox["Tr",
    ButtonData:>"Tr",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Tr"],
  "."
}], "Text",
  CellTags->"SUNTrace"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"SUNTrace"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNTrace", "[", 
      RowBox[{"SUNT", "[", 
        RowBox[{"a", ",", "b"}], "]"}], "]"}]], "Input",
  CellLabel->"In[1544]:=  (21:56:41 on 5/16/01)",
  CellTags->"SUNTrace"],

Cell[BoxData[
    FormBox[
      FractionBox[
        SubscriptBox["\[Delta]", 
          RowBox[{
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"]}]], "2"], TraditionalForm]], "Output",
  CellLabel->"Out[1544]=  (21:56:41 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNTrace", "[", 
      RowBox[{"SUNT", "[", 
        RowBox[{"a", ",", "b", ",", "c"}], "]"}], "]"}]], "Input",
  CellLabel->"In[1545]:=  (21:56:41 on 5/16/01)",
  CellTags->"SUNTrace"],

Cell[BoxData[
    FormBox[
      RowBox[{"tr", "\[NoBreak]", "(", "\[NoBreak]", 
        FormBox[
          RowBox[{
            SubscriptBox["T", 
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SubscriptBox["T", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SubscriptBox["T", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"]]}],
          "TraditionalForm"], "\[NoBreak]", ")"}], TraditionalForm]], "Output",\

  CellLabel->"Out[1545]=  (21:56:41 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNTrace", "[", 
      RowBox[{
        RowBox[{"SUNT", "[", 
          RowBox[{"a", ",", "b", ",", "c"}], "]"}], ",", 
        RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]], "Input",
  CellLabel->"In[1546]:=  (21:56:41 on 5/16/01)",
  CellTags->"SUNTrace"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox["1", "4"], " ", 
          SubscriptBox["d", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "+", 
        RowBox[{
          FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1546]=  (21:56:41 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNTrace", "[", 
      RowBox[{"SUNT", "[", 
        RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}], "]"}]], "Input",
  CellLabel->"In[1547]:=  (21:56:42 on 5/16/01)",
  CellTags->"SUNTrace"],

Cell[BoxData[
    FormBox[
      RowBox[{"tr", "\[NoBreak]", "(", "\[NoBreak]", 
        FormBox[
          RowBox[{
            SubscriptBox["T", 
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SubscriptBox["T", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SubscriptBox["T", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SubscriptBox["T", 
              FormBox[
                FormBox["d",
                  "TraditionalForm"],
                "TraditionalForm"]]}],
          "TraditionalForm"], "\[NoBreak]", ")"}], TraditionalForm]], "Output",\

  CellLabel->"Out[1547]=  (21:56:42 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t1", "=", 
      RowBox[{"SUNTrace", "[", 
        RowBox[{
          RowBox[{"SUNT", "[", 
            RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}], ",", 
          RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]}]], "Input",
  CellLabel->"In[1548]:=  (21:56:42 on 5/16/01)",
  CellTags->"SUNTrace"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox["1", "8"], " ", 
          SubscriptBox["d", 
            RowBox[{"e", "\[NoBreak]", 
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["d",
                  "TraditionalForm"],
                "TraditionalForm"]}]], " ", 
          SubscriptBox["d", 
            RowBox[{"e", "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "-", 
        RowBox[{
          FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["d",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", "e"}]], " ", 
          SubscriptBox["d", 
            RowBox[{"e", "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "-", 
        RowBox[{
          FractionBox["1", "8"], " ", 
          SubscriptBox["d", 
            RowBox[{"e", "\[NoBreak]", 
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"]}]], " ", 
          SubscriptBox["d", 
            RowBox[{"e", "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["d",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "+", 
        RowBox[{
          FractionBox["1", "8"], " ", 
          SubscriptBox["d", 
            RowBox[{"e", "\[NoBreak]", 
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]}]], " ", 
          SubscriptBox["d", 
            RowBox[{"e", "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["d",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}], "+", 
        FractionBox[
          RowBox[{
            SubscriptBox["\[Delta]", 
              RowBox[{
                FormBox[
                  FormBox["a",
                    "TraditionalForm"],
                  "TraditionalForm"], "\[NoBreak]", 
                FormBox[
                  FormBox["d",
                    "TraditionalForm"],
                  "TraditionalForm"]}]], " ", 
            SubscriptBox["\[Delta]", 
              RowBox[{
                FormBox[
                  FormBox["b",
                    "TraditionalForm"],
                  "TraditionalForm"], "\[NoBreak]", 
                FormBox[
                  FormBox["c",
                    "TraditionalForm"],
                  "TraditionalForm"]}]]}], 
          RowBox[{"4", " ", "N"}]], "-", 
        FractionBox[
          RowBox[{
            SubscriptBox["\[Delta]", 
              RowBox[{
                FormBox[
                  FormBox["a",
                    "TraditionalForm"],
                  "TraditionalForm"], "\[NoBreak]", 
                FormBox[
                  FormBox["c",
                    "TraditionalForm"],
                  "TraditionalForm"]}]], " ", 
            SubscriptBox["\[Delta]", 
              RowBox[{
                FormBox[
                  FormBox["b",
                    "TraditionalForm"],
                  "TraditionalForm"], "\[NoBreak]", 
                FormBox[
                  FormBox["d",
                    "TraditionalForm"],
                  "TraditionalForm"]}]]}], 
          RowBox[{"4", " ", "N"}]], "+", 
        FractionBox[
          RowBox[{
            SubscriptBox["\[Delta]", 
              RowBox[{
                FormBox[
                  FormBox["a",
                    "TraditionalForm"],
                  "TraditionalForm"], "\[NoBreak]", 
                FormBox[
                  FormBox["b",
                    "TraditionalForm"],
                  "TraditionalForm"]}]], " ", 
            SubscriptBox["\[Delta]", 
              RowBox[{
                FormBox[
                  FormBox["c",
                    "TraditionalForm"],
                  "TraditionalForm"], "\[NoBreak]", 
                FormBox[
                  FormBox["d",
                    "TraditionalForm"],
                  "TraditionalForm"]}]]}], 
          RowBox[{"4", " ", "N"}]], "+", 
        RowBox[{
          FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
          SubscriptBox["d", 
            RowBox[{"e", "\[NoBreak]", 
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["d",
                  "TraditionalForm"],
                "TraditionalForm"]}]], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", "e"}]]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1548]=  (21:56:42 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNSimplify", "[", 
      RowBox[{"t1", ",", 
        RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]], "Input",
  CellLabel->"In[1549]:=  (21:56:42 on 5/16/01)",
  CellTags->"SUNTrace"],

Cell[BoxData[
    FormBox[
      RowBox[{"tr", "\[NoBreak]", "(", "\[NoBreak]", 
        FormBox[
          RowBox[{
            SubscriptBox["T", 
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SubscriptBox["T", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SubscriptBox["T", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SubscriptBox["T", 
              FormBox[
                FormBox["d",
                  "TraditionalForm"],
                "TraditionalForm"]]}],
          "TraditionalForm"], "\[NoBreak]", ")"}], TraditionalForm]], "Output",\

  CellLabel->"Out[1549]=  (21:56:43 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t2", "=", 
      RowBox[{"SUNTrace", "[", 
        RowBox[{
          RowBox[{"SUNT", "[", 
            RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "e"}], "]"}], ",",
           
          RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]}]], "Input",
  CellLabel->"In[1550]:=  (21:56:43 on 5/16/01)",
  CellTags->"SUNTrace"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{
            SubscriptBox["\[Delta]", 
              RowBox[{
                FormBox[
                  FormBox["a",
                    "TraditionalForm"],
                  "TraditionalForm"], "\[NoBreak]", 
                FormBox[
                  FormBox["b",
                    "TraditionalForm"],
                  "TraditionalForm"]}]], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  FractionBox["1", "4"], " ", 
                  SubscriptBox["d", 
                    RowBox[{
                      FormBox[
                        FormBox["c",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["d",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["e",
                          "TraditionalForm"],
                        "TraditionalForm"]}]]}], "+", 
                RowBox[{
                  FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
                  SubscriptBox["f", 
                    RowBox[{
                      FormBox[
                        FormBox["c",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["d",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["e",
                          "TraditionalForm"],
                        "TraditionalForm"]}]]}]}], ")"}]}], 
          RowBox[{"2", " ", "N"}]], "+", 
        RowBox[{
          FractionBox["1", "2"], " ", 
          SubscriptBox["d", 
            RowBox[{"c101", "\[NoBreak]", 
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]}]], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  FractionBox["1", "8"]}], " ", 
                SubscriptBox["d", 
                  RowBox[{"c102", "\[NoBreak]", 
                    FormBox[
                      FormBox["c",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["e",
                        "TraditionalForm"],
                      "TraditionalForm"]}]], " ", 
                SubscriptBox["d", 
                  RowBox[{"c102", "\[NoBreak]", 
                    FormBox[
                      FormBox["c101",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["d",
                        "TraditionalForm"],
                      "TraditionalForm"]}]]}], "+", 
              RowBox[{
                FractionBox["1", "8"], " ", 
                SubscriptBox["d", 
                  RowBox[{"c102", "\[NoBreak]", 
                    FormBox[
                      FormBox["c",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["d",
                        "TraditionalForm"],
                      "TraditionalForm"]}]], " ", 
                SubscriptBox["d", 
                  RowBox[{"c102", "\[NoBreak]", 
                    FormBox[
                      FormBox["c101",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["e",
                        "TraditionalForm"],
                      "TraditionalForm"]}]]}], "+", 
              RowBox[{
                FractionBox["1", "8"], " ", 
                SubscriptBox["d", 
                  RowBox[{"c102", "\[NoBreak]", 
                    FormBox[
                      FormBox["c",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["c101",
                        "TraditionalForm"],
                      "TraditionalForm"]}]], " ", 
                SubscriptBox["d", 
                  RowBox[{"c102", "\[NoBreak]", 
                    FormBox[
                      FormBox["d",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["e",
                        "TraditionalForm"],
                      "TraditionalForm"]}]]}], "-", 
              FractionBox[
                RowBox[{
                  SubscriptBox["\[Delta]", 
                    RowBox[{
                      FormBox[
                        FormBox["c",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["e",
                          "TraditionalForm"],
                        "TraditionalForm"]}]], " ", 
                  SubscriptBox["\[Delta]", 
                    RowBox[{
                      FormBox[
                        FormBox["c101",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["d",
                          "TraditionalForm"],
                        "TraditionalForm"]}]]}], 
                RowBox[{"4", " ", "N"}]], "+", 
              FractionBox[
                RowBox[{
                  SubscriptBox["\[Delta]", 
                    RowBox[{
                      FormBox[
                        FormBox["c",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["d",
                          "TraditionalForm"],
                        "TraditionalForm"]}]], " ", 
                  SubscriptBox["\[Delta]", 
                    RowBox[{
                      FormBox[
                        FormBox["c101",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["e",
                          "TraditionalForm"],
                        "TraditionalForm"]}]]}], 
                RowBox[{"4", " ", "N"}]], "+", 
              FractionBox[
                RowBox[{
                  SubscriptBox["\[Delta]", 
                    RowBox[{
                      FormBox[
                        FormBox["c",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["c101",
                          "TraditionalForm"],
                        "TraditionalForm"]}]], " ", 
                  SubscriptBox["\[Delta]", 
                    RowBox[{
                      FormBox[
                        FormBox["d",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["e",
                          "TraditionalForm"],
                        "TraditionalForm"]}]]}], 
                RowBox[{"4", " ", "N"}]], "+", 
              RowBox[{
                FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
                SubscriptBox["d", 
                  RowBox[{"c102", "\[NoBreak]", 
                    FormBox[
                      FormBox["c101",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["e",
                        "TraditionalForm"],
                      "TraditionalForm"]}]], " ", 
                SubscriptBox["f", 
                  RowBox[{
                    FormBox[
                      FormBox["c",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["d",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", "c102"}]]}], "-", 
              RowBox[{
                FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
                SubscriptBox["d", 
                  RowBox[{"c102", "\[NoBreak]", 
                    FormBox[
                      FormBox["c",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["d",
                        "TraditionalForm"],
                      "TraditionalForm"]}]], " ", 
                SubscriptBox["f", 
                  RowBox[{
                    FormBox[
                      FormBox["c101",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["e",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", "c102"}]]}]}], 
            ")"}]}], "+", 
        RowBox[{
          FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", "c101"}]], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  FractionBox["1", "8"]}], " ", 
                SubscriptBox["d", 
                  RowBox[{"c103", "\[NoBreak]", 
                    FormBox[
                      FormBox["c",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["e",
                        "TraditionalForm"],
                      "TraditionalForm"]}]], " ", 
                SubscriptBox["d", 
                  RowBox[{"c103", "\[NoBreak]", 
                    FormBox[
                      FormBox["c101",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["d",
                        "TraditionalForm"],
                      "TraditionalForm"]}]]}], "+", 
              RowBox[{
                FractionBox["1", "8"], " ", 
                SubscriptBox["d", 
                  RowBox[{"c103", "\[NoBreak]", 
                    FormBox[
                      FormBox["c",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["d",
                        "TraditionalForm"],
                      "TraditionalForm"]}]], " ", 
                SubscriptBox["d", 
                  RowBox[{"c103", "\[NoBreak]", 
                    FormBox[
                      FormBox["c101",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["e",
                        "TraditionalForm"],
                      "TraditionalForm"]}]]}], "+", 
              RowBox[{
                FractionBox["1", "8"], " ", 
                SubscriptBox["d", 
                  RowBox[{"c103", "\[NoBreak]", 
                    FormBox[
                      FormBox["c",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["c101",
                        "TraditionalForm"],
                      "TraditionalForm"]}]], " ", 
                SubscriptBox["d", 
                  RowBox[{"c103", "\[NoBreak]", 
                    FormBox[
                      FormBox["d",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["e",
                        "TraditionalForm"],
                      "TraditionalForm"]}]]}], "-", 
              FractionBox[
                RowBox[{
                  SubscriptBox["\[Delta]", 
                    RowBox[{
                      FormBox[
                        FormBox["c",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["e",
                          "TraditionalForm"],
                        "TraditionalForm"]}]], " ", 
                  SubscriptBox["\[Delta]", 
                    RowBox[{
                      FormBox[
                        FormBox["c101",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["d",
                          "TraditionalForm"],
                        "TraditionalForm"]}]]}], 
                RowBox[{"4", " ", "N"}]], "+", 
              FractionBox[
                RowBox[{
                  SubscriptBox["\[Delta]", 
                    RowBox[{
                      FormBox[
                        FormBox["c",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["d",
                          "TraditionalForm"],
                        "TraditionalForm"]}]], " ", 
                  SubscriptBox["\[Delta]", 
                    RowBox[{
                      FormBox[
                        FormBox["c101",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["e",
                          "TraditionalForm"],
                        "TraditionalForm"]}]]}], 
                RowBox[{"4", " ", "N"}]], "+", 
              FractionBox[
                RowBox[{
                  SubscriptBox["\[Delta]", 
                    RowBox[{
                      FormBox[
                        FormBox["c",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["c101",
                          "TraditionalForm"],
                        "TraditionalForm"]}]], " ", 
                  SubscriptBox["\[Delta]", 
                    RowBox[{
                      FormBox[
                        FormBox["d",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["e",
                          "TraditionalForm"],
                        "TraditionalForm"]}]]}], 
                RowBox[{"4", " ", "N"}]], "+", 
              RowBox[{
                FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
                SubscriptBox["d", 
                  RowBox[{"c103", "\[NoBreak]", 
                    FormBox[
                      FormBox["c101",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["e",
                        "TraditionalForm"],
                      "TraditionalForm"]}]], " ", 
                SubscriptBox["f", 
                  RowBox[{
                    FormBox[
                      FormBox["c",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["d",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", "c103"}]]}], "-", 
              RowBox[{
                FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
                SubscriptBox["d", 
                  RowBox[{"c103", "\[NoBreak]", 
                    FormBox[
                      FormBox["c",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["d",
                        "TraditionalForm"],
                      "TraditionalForm"]}]], " ", 
                SubscriptBox["f", 
                  RowBox[{
                    FormBox[
                      FormBox["c101",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["e",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", "c103"}]]}]}], 
            ")"}]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1550]=  (21:56:43 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNSimplify", "[", 
      RowBox[{"t2", ",", 
        RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]], "Input",
  CellLabel->"In[1551]:=  (21:56:43 on 5/16/01)",
  CellTags->"SUNTrace"],

Cell[BoxData[
    FormBox[
      RowBox[{"tr", "\[NoBreak]", "(", "\[NoBreak]", 
        FormBox[
          RowBox[{
            SubscriptBox["T", 
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SubscriptBox["T", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SubscriptBox["T", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SubscriptBox["T", 
              FormBox[
                FormBox["d",
                  "TraditionalForm"],
                "TraditionalForm"]], ".", 
            SubscriptBox["T", 
              FormBox[
                FormBox["e",
                  "TraditionalForm"],
                "TraditionalForm"]]}],
          "TraditionalForm"], "\[NoBreak]", ")"}], TraditionalForm]], "Output",\

  CellLabel->"Out[1551]=  (21:56:48 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNSimplify", "[", 
      RowBox[{
        RowBox[{"SUNF", "[", 
          RowBox[{"a", ",", "b", ",", "c"}], "]"}], " ", 
        RowBox[{"SUND", "[", 
          RowBox[{"d", ",", "b", ",", "c"}], "]"}]}], "]"}]], "Input",
  CellLabel->"In[1552]:=  (21:56:48 on 5/16/01)",
  CellTags->"SUNTrace"],

Cell[BoxData[
    FormBox["0", TraditionalForm]], "Output",
  CellLabel->"Out[1552]=  (21:56:48 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNSimplify", "[", 
      RowBox[{
        RowBox[{"SUNF", "[", 
          RowBox[{"a", ",", "b", ",", "c"}], "]"}], " ", 
        RowBox[{"SUND", "[", 
          RowBox[{"a", ",", "b", ",", "d"}], "]"}]}], "]"}]], "Input",
  CellLabel->"In[1553]:=  (21:56:48 on 5/16/01)",
  CellTags->"SUNTrace"],

Cell[BoxData[
    FormBox["0", TraditionalForm]], "Output",
  CellLabel->"Out[1553]=  (21:56:48 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNSimplify", "[", 
      RowBox[{
        RowBox[{"SUNF", "[", 
          RowBox[{"a", ",", "b", ",", "c"}], "]"}], " ", 
        RowBox[{"SUND", "[", 
          RowBox[{"a", ",", "d", ",", "c"}], "]"}]}], "]"}]], "Input",
  CellLabel->"In[1554]:=  (21:56:48 on 5/16/01)",
  CellTags->"SUNTrace"],

Cell[BoxData[
    FormBox["0", TraditionalForm]], "Output",
  CellLabel->"Out[1554]=  (21:56:49 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SUNSimplify", "[", 
      RowBox[{
        RowBox[{"SUND", "[", 
          RowBox[{"a", ",", "b", ",", "c"}], "]"}], " ", 
        RowBox[{"SUND", "[", 
          RowBox[{"d", ",", "b", ",", "c"}], "]"}]}], "]"}]], "Input",
  CellLabel->"In[1555]:=  (21:56:49 on 5/16/01)",
  CellTags->"SUNTrace"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          RowBox[{"(", 
            RowBox[{"4", "-", 
              SubsuperscriptBox["C", "A", "2"]}], ")"}]}], " ", 
        RowBox[{"(", 
          RowBox[{
            SubscriptBox["C", "A"], "-", 
            RowBox[{"2", " ", 
              SubscriptBox["C", "F"]}]}], ")"}], " ", 
        SubscriptBox["\[Delta]", 
          RowBox[{
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["d",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1555]=  (21:56:49 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Symmetrize", "ObjectName",
  CellTags->"Symmetrize"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"Symmetrize"],

Cell["\<\
Symmetrize[expr, {a1, a2, ...}] antisymmetrizes expr with respect to the \
variables a1,a2, ... \
\>", "Text",
  CellTags->"Symmetrize"],

Cell[TextData[{
  "See also: ",
  ButtonBox["AntiSymmetrize",
    ButtonData:>"AntiSymmetrize",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"AntiSymmetrize"],
  "."
}], "Text",
  CellTags->"Symmetrize"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"Symmetrize"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Symmetrize", "[", 
      RowBox[{
        RowBox[{"f", "[", 
          RowBox[{"a", ",", "b"}], "]"}], ",", 
        RowBox[{"{", 
          RowBox[{"a", ",", "b"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[1556]:=  (21:56:49 on 5/16/01)",
  CellTags->"Symmetrize"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"f", "(", 
              RowBox[{"a", ",", "b"}], ")"}], "+", 
            RowBox[{"f", "(", 
              RowBox[{"b", ",", "a"}], ")"}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1556]=  (21:56:49 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Symmetrize", "[", 
      RowBox[{
        RowBox[{"f", "[", 
          RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", 
        RowBox[{"{", 
          RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[1557]:=  (21:56:49 on 5/16/01)",
  CellTags->"Symmetrize"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox["1", "6"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"f", "(", 
              RowBox[{"x", ",", "y", ",", "z"}], ")"}], "+", 
            RowBox[{"f", "(", 
              RowBox[{"x", ",", "z", ",", "y"}], ")"}], "+", 
            RowBox[{"f", "(", 
              RowBox[{"y", ",", "x", ",", "z"}], ")"}], "+", 
            RowBox[{"f", "(", 
              RowBox[{"y", ",", "z", ",", "x"}], ")"}], "+", 
            RowBox[{"f", "(", 
              RowBox[{"z", ",", "x", ",", "y"}], ")"}], "+", 
            RowBox[{"f", "(", 
              RowBox[{"z", ",", "y", ",", "x"}], ")"}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1557]=  (21:56:49 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Tdec", "ObjectName",
  CellTags->"Tdec"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"Tdec"],

Cell["\<\
Tdec[{q,mu}, {p}]; Tdec[{{qi, mu}, {qj, nu}, ...}, {p1, p2, ...}] or \
Tdec[exp, {{qi, mu}, {qj, nu}, ...}, {p1, p2, ...}] calculates the tensorial \
decomposition formulas. The more common ones are saved in TIDL.\
\>", "Text",
  CellTags->"Tdec"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "Tdec", "]"}]], "Input",
  CellLabel->"In[1558]:=  (21:56:49 on 5/16/01)",
  CellTags->"Tdec"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
          RowBox[{"Factoring", "\[Rule]", "Factor2"}], ",", 
          RowBox[{"FeynCalcExternal", "\[Rule]", "True"}], ",", 
          RowBox[{"List", "\[Rule]", "True"}], ",", 
          RowBox[{"NumberOfMetricTensors", "\[Rule]", 
            InterpretationBox["\[Infinity]",
              DirectedInfinity[ 1]]}]}], "}"}], TraditionalForm]], "Output",
  CellLabel->"Out[1558]=  (21:56:50 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["TID",
    ButtonData:>"TID",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"TID"],
  ", ",
  ButtonBox["TIDL",
    ButtonData:>"TIDL",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"TIDL"],
  ", ",
  ButtonBox["OneLoopSimplify",
    ButtonData:>"OneLoopSimplify",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"OneLoopSimplify"],
  "."
}], "Text",
  CellTags->"Tdec"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"Tdec"],

Cell[TextData[{
  "Check that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[Integral]", 
            RowBox[{
              SuperscriptBox["d", "D"], 
              RowBox[{"f", "(", 
                RowBox[{"p", ",", "q"}], ")"}], 
              SuperscriptBox["q", "\[Mu]"]}]}], "=", " ", 
          RowBox[{
            FractionBox[
              SuperscriptBox["p", "\[Mu]"], 
              SuperscriptBox["p", "2"]], 
            RowBox[{"\[Integral]", 
              RowBox[{
                SuperscriptBox["d", "D"], 
                RowBox[{"f", "(", 
                  RowBox[{"p", ",", "q"}], ")"}], 
                RowBox[{"p", "\[CenterDot]", "q"}]}]}]}]}], 
        TraditionalForm]]]
}], "Text",
  CellTags->"Tdec"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Tdec", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"q", ",", "\[Mu]"}], "}"}], ",", 
        RowBox[{"{", "p", "}"}]}], "]"}]], "Input",
  CellLabel->"In[1559]:=  (21:56:51 on 5/16/01)",
  CellTags->"Tdec"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{
              RowBox[{"X1", "\[Rule]", 
                FormBox[
                  SuperscriptBox[
                    FormBox["p",
                      "TraditionalForm"], "2"],
                  "TraditionalForm"]}], ",", 
              RowBox[{"X2", "\[Rule]", 
                FormBox[
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}],
                  "TraditionalForm"]}]}], "}"}], ",", 
          FractionBox[
            RowBox[{"X2", " ", 
              SuperscriptBox["p", "\[Mu]"]}], "X1"]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1559]=  (21:56:51 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"%", "[", 
        RowBox[{"[", "2", "]"}], "]"}], "/.", 
      RowBox[{"%", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
  CellLabel->"In[1560]:=  (21:56:51 on 5/16/01)",
  CellTags->"Tdec"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{
          SuperscriptBox["p", "\[Mu]"], " ", 
          FormBox[
            RowBox[{
              FormBox["p",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox["q",
                "TraditionalForm"]}],
            "TraditionalForm"]}], 
        FormBox[
          SuperscriptBox[
            FormBox["p",
              "TraditionalForm"], "2"],
          "TraditionalForm"]], TraditionalForm]], "Output",
  CellLabel->"Out[1560]=  (21:56:51 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "This calculates integral transformation for any ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Integral]", 
          RowBox[{
            SuperscriptBox["d", "D"], 
            SubscriptBox["q", "1"], 
            SuperscriptBox["d", "D"], 
            SubscriptBox["q", "2"], 
            SuperscriptBox["d", "D"], 
            SubscriptBox["q", "3"]}]}], TraditionalForm]]],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"f", "(", 
            RowBox[{"p", ",", 
              RowBox[{
                SubscriptBox["q", 
                  RowBox[{"1", ","}]], 
                SubscriptBox["q", "2"]}], ",", 
              SubscriptBox["q", "3"]}], ")"}], " ", 
          SubsuperscriptBox["q", "1", "\[Mu]"], 
          SubsuperscriptBox["q", "2", "\[Nu]"], 
          SubsuperscriptBox["q", "3", "\[Rho]"]}], TraditionalForm]]],
  "."
}], "Text",
  CellTags->"Tdec"],

Cell[BoxData[
    RowBox[{
      RowBox[{"t", "=", 
        RowBox[{"Tdec", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"{", 
                  RowBox[{
                    SubscriptBox["q", "1"], ",", "\[Mu]"}], "}"}], ",", 
                RowBox[{"{", 
                  RowBox[{
                    SubscriptBox["q", "2"], ",", "\[Nu]"}], "}"}], ",", 
                RowBox[{"{", 
                  RowBox[{
                    SubscriptBox["q", "3"], ",", "\[Rho]"}], "}"}]}], "}"}], 
            ",", 
            RowBox[{"{", "p", "}"}]}], "]"}]}], ";"}]], "Input",
  CellLabel->"In[1561]:=  (21:56:51 on 5/16/01)",
  CellTags->"Tdec"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"t", "[", 
        RowBox[{"[", "2", "]"}], "]"}], "/.", 
      RowBox[{"t", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
  CellLabel->"In[1562]:=  (21:56:52 on 5/16/01)",
  CellTags->"Tdec"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"1", "-", 
                SuperscriptBox["D", "2"]}], ")"}], " ", 
            SuperscriptBox["p", "\[Rho]"], " ", 
            SuperscriptBox["g", 
              RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]], " ", 
            FormBox[
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox[
                  SubscriptBox["q", "3"],
                  "TraditionalForm"]}],
              "TraditionalForm"], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  FormBox[
                    RowBox[{
                      FormBox["p",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["q", "1"],
                        "TraditionalForm"]}],
                    "TraditionalForm"], " ", 
                  FormBox[
                    RowBox[{
                      FormBox["p",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["q", "2"],
                        "TraditionalForm"]}],
                    "TraditionalForm"]}], "-", 
                RowBox[{
                  FormBox[
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"],
                    "TraditionalForm"], " ", 
                  FormBox[
                    RowBox[{
                      FormBox[
                        SubscriptBox["q", "1"],
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["q", "2"],
                        "TraditionalForm"]}],
                    "TraditionalForm"]}]}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"1", "-", "D"}], ")"}], "2"], " ", 
            RowBox[{"(", 
              RowBox[{"D", "+", "1"}], ")"}], " ", 
            SuperscriptBox[
              FormBox[
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"],
                "TraditionalForm"], "2"]}]], "+", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"1", "-", 
                SuperscriptBox["D", "2"]}], ")"}], " ", 
            SuperscriptBox["p", "\[Nu]"], " ", 
            SuperscriptBox["g", 
              RowBox[{"\[Mu]", "\[NoBreak]", "\[Rho]"}]], " ", 
            FormBox[
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox[
                  SubscriptBox["q", "2"],
                  "TraditionalForm"]}],
              "TraditionalForm"], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  FormBox[
                    RowBox[{
                      FormBox["p",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["q", "1"],
                        "TraditionalForm"]}],
                    "TraditionalForm"], " ", 
                  FormBox[
                    RowBox[{
                      FormBox["p",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["q", "3"],
                        "TraditionalForm"]}],
                    "TraditionalForm"]}], "-", 
                RowBox[{
                  FormBox[
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"],
                    "TraditionalForm"], " ", 
                  FormBox[
                    RowBox[{
                      FormBox[
                        SubscriptBox["q", "1"],
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["q", "3"],
                        "TraditionalForm"]}],
                    "TraditionalForm"]}]}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"1", "-", "D"}], ")"}], "2"], " ", 
            RowBox[{"(", 
              RowBox[{"D", "+", "1"}], ")"}], " ", 
            SuperscriptBox[
              FormBox[
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"],
                "TraditionalForm"], "2"]}]], "+", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"1", "-", 
                SuperscriptBox["D", "2"]}], ")"}], " ", 
            SuperscriptBox["p", "\[Mu]"], " ", 
            SuperscriptBox["g", 
              RowBox[{"\[Nu]", "\[NoBreak]", "\[Rho]"}]], " ", 
            FormBox[
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox[
                  SubscriptBox["q", "1"],
                  "TraditionalForm"]}],
              "TraditionalForm"], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  FormBox[
                    RowBox[{
                      FormBox["p",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["q", "2"],
                        "TraditionalForm"]}],
                    "TraditionalForm"], " ", 
                  FormBox[
                    RowBox[{
                      FormBox["p",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["q", "3"],
                        "TraditionalForm"]}],
                    "TraditionalForm"]}], "-", 
                RowBox[{
                  FormBox[
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"],
                    "TraditionalForm"], " ", 
                  FormBox[
                    RowBox[{
                      FormBox[
                        SubscriptBox["q", "2"],
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["q", "3"],
                        "TraditionalForm"]}],
                    "TraditionalForm"]}]}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"1", "-", "D"}], ")"}], "2"], " ", 
            RowBox[{"(", 
              RowBox[{"D", "+", "1"}], ")"}], " ", 
            SuperscriptBox[
              FormBox[
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"],
                "TraditionalForm"], "2"]}]], "-", 
        RowBox[{
          FractionBox["1", 
            RowBox[{
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"1", "-", "D"}], ")"}], "2"], " ", 
              RowBox[{"(", 
                RowBox[{"D", "+", "1"}], ")"}], " ", 
              SuperscriptBox[
                FormBox[
                  SuperscriptBox[
                    FormBox["p",
                      "TraditionalForm"], "2"],
                  "TraditionalForm"], "3"]}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"1", "-", 
                  SuperscriptBox["D", "2"]}], ")"}], " ", 
              SuperscriptBox["p", "\[Mu]"], " ", 
              SuperscriptBox["p", "\[Nu]"], " ", 
              SuperscriptBox["p", "\[Rho]"], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"D", " ", 
                    FormBox[
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox[
                          SubscriptBox["q", "1"],
                          "TraditionalForm"]}],
                      "TraditionalForm"], " ", 
                    FormBox[
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox[
                          SubscriptBox["q", "2"],
                          "TraditionalForm"]}],
                      "TraditionalForm"], " ", 
                    FormBox[
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox[
                          SubscriptBox["q", "3"],
                          "TraditionalForm"]}],
                      "TraditionalForm"]}], "+", 
                  RowBox[{"2", " ", 
                    FormBox[
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox[
                          SubscriptBox["q", "1"],
                          "TraditionalForm"]}],
                      "TraditionalForm"], " ", 
                    FormBox[
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox[
                          SubscriptBox["q", "2"],
                          "TraditionalForm"]}],
                      "TraditionalForm"], " ", 
                    FormBox[
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox[
                          SubscriptBox["q", "3"],
                          "TraditionalForm"]}],
                      "TraditionalForm"]}], "-", 
                  RowBox[{
                    FormBox[
                      SuperscriptBox[
                        FormBox["p",
                          "TraditionalForm"], "2"],
                      "TraditionalForm"], " ", 
                    FormBox[
                      RowBox[{
                        FormBox[
                          SubscriptBox["q", "1"],
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox[
                          SubscriptBox["q", "2"],
                          "TraditionalForm"]}],
                      "TraditionalForm"], " ", 
                    FormBox[
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox[
                          SubscriptBox["q", "3"],
                          "TraditionalForm"]}],
                      "TraditionalForm"]}], "-", 
                  RowBox[{
                    FormBox[
                      SuperscriptBox[
                        FormBox["p",
                          "TraditionalForm"], "2"],
                      "TraditionalForm"], " ", 
                    FormBox[
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox[
                          SubscriptBox["q", "2"],
                          "TraditionalForm"]}],
                      "TraditionalForm"], " ", 
                    FormBox[
                      RowBox[{
                        FormBox[
                          SubscriptBox["q", "1"],
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox[
                          SubscriptBox["q", "3"],
                          "TraditionalForm"]}],
                      "TraditionalForm"]}], "-", 
                  RowBox[{
                    FormBox[
                      SuperscriptBox[
                        FormBox["p",
                          "TraditionalForm"], "2"],
                      "TraditionalForm"], " ", 
                    FormBox[
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox[
                          SubscriptBox["q", "1"],
                          "TraditionalForm"]}],
                      "TraditionalForm"], " ", 
                    FormBox[
                      RowBox[{
                        FormBox[
                          SubscriptBox["q", "2"],
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox[
                          SubscriptBox["q", "3"],
                          "TraditionalForm"]}],
                      "TraditionalForm"]}]}], ")"}]}], ")"}]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1562]=  (21:56:52 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Contract", "[", 
        RowBox[{
          RowBox[{"%", " ", 
            RowBox[{"FVD", "[", 
              RowBox[{"p", ",", "\[Mu]"}], "]"}]}], 
          RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "\[Nu]"}], "]"}], " ", 
          RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "\[Rho]"}], "]"}]}], "]"}], "//", 
      "Factor"}]], "Input",
  CellLabel->"In[1563]:=  (21:56:52 on 5/16/01)",
  CellTags->"Tdec"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FormBox["p",
            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
          FormBox[
            SubscriptBox["q", "1"],
            "TraditionalForm"]}], " ", 
        RowBox[{
          FormBox["p",
            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
          FormBox[
            SubscriptBox["q", "2"],
            "TraditionalForm"]}], " ", 
        RowBox[{
          FormBox["p",
            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
          FormBox[
            SubscriptBox["q", "3"],
            "TraditionalForm"]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1563]=  (21:56:53 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      RowBox[{"Clear", "[", "t", "]"}], ";"}]], "Input",
  CellLabel->"In[1564]:=  (21:56:53 on 5/16/01)",
  CellTags->"Tdec"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Tensorfunction", "ObjectName",
  CellTags->"Tensorfunction"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"Tensorfunction"],

Cell["\<\
Tensorfunction[t, mu, nu, ...] transform into t[LorentzIndex[mu], \
LorentzIndex[nu], ...], i.e., it can be used as an unspecified tensoriell \
function t. A symmetric tensor can be obtained by Tensorfunction[{t, \"S\"}, \
mu, nu, ...], and an antisymmteric one by Tensorfunction[{t, \"A\"}, mu, nu, \
...].\
\>", "Text",
  CellTags->"Tensorfunction"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["Symmetrize",
    ButtonData:>"Symmetrize",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Symmetrize"],
  "."
}], "Text",
  CellTags->"Tensorfunction"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"Tensorfunction"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Tensorfunction", "[", 
      RowBox[{"t", ",", "\[Mu]", ",", "\[Nu]", ",", "\[Tau]"}], 
      "]"}]], "Input",
  CellLabel->"In[1565]:=  (21:56:53 on 5/16/01)",
  CellTags->"Tensorfunction"],

Cell[BoxData[
    FormBox[
      RowBox[{"Tensorfunction", "(", 
        RowBox[{"t", ",", "\[Mu]", ",", "\[Nu]", ",", "\[Tau]"}], ")"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1565]=  (21:56:53 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "StandardForm"}]], "Input",
  CellLabel->"In[1566]:=  (21:56:53 on 5/16/01)",
  CellTags->"Tensorfunction"],

Cell[BoxData[
    RowBox[{"Tensorfunction", "[", 
      RowBox[{"t", ",", "\[Mu]", ",", "\[Nu]", ",", "\[Tau]"}], 
      "]"}]], "Output",
  CellLabel->"Out[1566]//StandardForm=  (21:56:53 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Contract", "[", 
      RowBox[{
        RowBox[{"FV", "[", 
          RowBox[{"p", ",", "\[Mu]"}], "]"}], " ", "%"}], "]"}]], "Input",
  CellLabel->"In[1567]:=  (21:56:53 on 5/16/01)",
  CellTags->"Tensorfunction"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox[
          FormBox["p",
            "TraditionalForm"], 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]], " ", 
        RowBox[{"Tensorfunction", "(", 
          RowBox[{"t", ",", "\[Mu]", ",", "\[Nu]", ",", "\[Tau]"}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1567]=  (21:56:53 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "StandardForm"}]], "Input",
  CellLabel->"In[1568]:=  (21:56:53 on 5/16/01)",
  CellTags->"Tensorfunction"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Pair", "[", 
        RowBox[{
          RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
          RowBox[{"Momentum", "[", "p", "]"}]}], "]"}], " ", 
      RowBox[{"Tensorfunction", "[", 
        RowBox[{"t", ",", "\[Mu]", ",", "\[Nu]", ",", "\[Tau]"}], 
        "]"}]}]], "Output",
  CellLabel->"Out[1568]//StandardForm=  (21:56:53 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Tensorfunction", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"f", ",", "\"\<S\>\""}], "}"}], ",", "\[Alpha]", ",", 
        "\[Beta]"}], "]"}]], "Input",
  CellLabel->"In[1569]:=  (21:56:54 on 5/16/01)",
  CellTags->"Tensorfunction"],

Cell[BoxData[
    FormBox[
      RowBox[{"Tensorfunction", "(", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{"f", ",", "\<\"S\"\>"}], "}"}], ",", "\[Alpha]", ",", 
          "\[Beta]"}], ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[1569]=  (21:56:54 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Tensorfunction", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"f", ",", "\"\<S\>\""}], "}"}], ",", "\[Beta]", ",", 
        "\[Alpha]"}], "]"}]], "Input",
  CellLabel->"In[1570]:=  (21:56:54 on 5/16/01)",
  CellTags->"Tensorfunction"],

Cell[BoxData[
    FormBox[
      RowBox[{"Tensorfunction", "(", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{"f", ",", "\<\"S\"\>"}], "}"}], ",", "\[Beta]", ",", 
          "\[Alpha]"}], ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[1570]=  (21:56:54 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "StandardForm"}]], "Input",
  CellLabel->"In[1571]:=  (21:56:54 on 5/16/01)",
  CellTags->"Tensorfunction"],

Cell[BoxData[
    RowBox[{"Tensorfunction", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"f", ",", "\<\"S\"\>"}], "}"}], ",", "\[Beta]", ",", 
        "\[Alpha]"}], "]"}]], "Output",
  CellLabel->"Out[1571]//StandardForm=  (21:56:54 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Attributes", "[", "f", "]"}]], "Input",
  CellLabel->"In[1572]:=  (21:56:54 on 5/16/01)",
  CellTags->"Tensorfunction"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", "}"}], TraditionalForm]], "Output",
  CellLabel->"Out[1572]=  (21:56:54 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{"ClearAttributes", "[", 
      RowBox[{"f", ",", "Orderless"}], "]"}]], "Input",
  CellLabel->"In[1573]:=  (21:56:54 on 5/16/01)",
  CellTags->"Tensorfunction"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["TFi", "ObjectName",
  CellTags->"TFi"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"TFi"],

Cell["\<\
TFi[d, pp, {{n1,m1},{n2,m2},{n3,m3},{n4,m4},{n5,m5}}] is the \.02loop \
d-dimensional integral 1/( (q1^2 - m1^2)^n1 (q2^2 - m2^2)^n2 ((q1-p)^2 - \
m3^2)^n3 *((q2-p)^2 - m4^2)^n4 * ((q1-q2)^2 - m5^2)^n5 ) . TFi[d, pp, \
{x,y,z,v,w}, {{n1,m1},{n2,m2},{n3,m3},{n4,m4},{n5,m5}}] has as additional \
factors in the numerator (q1^2)^x*(q2^2)^y*(q1.p)^z* (q2.p)^v*(q1.q2)^w. \
TFi[d, pp, dp, {a,b}, {{n1,m1},{n2,m2},{n3,m3},{n4,m4},{n5,m5}}] has as \
additional factors in the numerator (OPEDelta.q1)^a * (OPEDelta.q2)^b; dp is \
(OPEDelta.p).\
\>", "Text",
  CellTags->"TFi"],

Cell[TextData[{
  "TFi is similar to TFI from the TARCER package, see ",
  " ",
  ButtonBox["hep-ph/9801383.",
    ButtonData:>{
      URL[ "http://xxx.lanl.gov/abs/hep-ph/9801383"], None},
    ButtonStyle->"Hyperlink"]
}], "Text",
  CellTags->"TFi"],

Cell["\<\
The function TarcerRecurse from the TARCER package recognize TFi (as well as \
TFI, which is defined in the HighEnergyPhysics`Tarcer` context).\
\>", "Text",
  CellTags->"TFi"],

Cell[TextData[{
  "See also: ",
  ButtonBox["ToTFi",
    ButtonData:>"ToTFi",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"ToTFi"],
  ", ",
  ButtonBox["FromTFi",
    ButtonData:>"FromTFi",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FromTFi"],
  "."
}], "Text",
  CellTags->"TFi"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"TFi"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"TFi", "[", 
      RowBox[{"D", ",", 
        RowBox[{"M", "^", "2"}], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"2", ",", "m1"}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"1", ",", "m2"}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"3", ",", "m3"}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"1", ",", "m4"}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"1", ",", "m5"}], "}"}]}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[1574]:=  (21:56:54 on 5/16/01)",
  CellTags->"TFi"],

Cell[BoxData[
    FormBox[
      InterpretationBox[
        SubsuperscriptBox[
          StyleBox["F",
            SingleLetterItalics->False,
            FontWeight->"Bold"], 
          RowBox[{
            FormBox[
              RowBox[{"{", 
                RowBox[{"2", ",", "m1"}], "}"}],
              "TraditionalForm"], 
            FormBox[
              RowBox[{"{", 
                RowBox[{"1", ",", "m2"}], "}"}],
              "TraditionalForm"], 
            FormBox[
              RowBox[{"{", 
                RowBox[{"3", ",", "m3"}], "}"}],
              "TraditionalForm"], 
            FormBox[
              RowBox[{"{", 
                RowBox[{"1", ",", "m4"}], "}"}],
              "TraditionalForm"], 
            FormBox[
              RowBox[{"{", 
                RowBox[{"1", ",", "m5"}], "}"}],
              "TraditionalForm"]}], 
          RowBox[{"(", 
            FormBox["D",
              "TraditionalForm"], ")"}]],
        TFi[ D, 
          Power[ M, 2], {{2, m1}, {1, m2}, {3, m3}, {1, m4}, {1, m5}}],
        Editable->True], TraditionalForm]], "Output",
  CellLabel->"Out[1574]=  (21:56:55 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"TFi", "[", 
      RowBox[{"D", ",", 
        RowBox[{"M", "^", "2"}], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"2", ",", "M"}], "}"}], ",", "1", ",", "1", ",", "1", 
            ",", "1"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[1575]:=  (21:56:55 on 5/16/01)",
  CellTags->"TFi"],

Cell[BoxData[
    FormBox[
      InterpretationBox[
        SubsuperscriptBox[
          StyleBox["F",
            SingleLetterItalics->False,
            FontWeight->"Bold"], 
          RowBox[{
            FormBox[
              RowBox[{"{", 
                RowBox[{"2", ",", "M"}], "}"}],
              "TraditionalForm"], 
            FormBox[
              RowBox[{"{", 
                RowBox[{"1", ",", "0"}], "}"}],
              "TraditionalForm"], 
            FormBox[
              RowBox[{"{", 
                RowBox[{"1", ",", "0"}], "}"}],
              "TraditionalForm"], 
            FormBox[
              RowBox[{"{", 
                RowBox[{"1", ",", "0"}], "}"}],
              "TraditionalForm"], 
            FormBox[
              RowBox[{"{", 
                RowBox[{"1", ",", "0"}], "}"}],
              "TraditionalForm"]}], 
          RowBox[{"(", 
            FormBox["D",
              "TraditionalForm"], ")"}]],
        TFi[ D, 
          Power[ M, 2], {{2, M}, {1, 0}, {1, 0}, {1, 0}, {1, 0}}],
        Editable->True], TraditionalForm]], "Output",
  CellLabel->"Out[1575]=  (21:56:55 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["TIDL", "ObjectName",
  CellTags->"TIDL"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"TIDL"],

Cell[" TIDL is a database of tensorial reduction formalae.", "Text",
  CellTags->"TIDL"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["TID",
    ButtonData:>"TID",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"TID"]
}], "Text",
  CellTags->"TIDL"]
}, Closed]],

Cell["Examples", "Subsubsection",
  CellTags->"TIDL"],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["B", "\[Mu]"], "-", "type"}], 
      TraditionalForm]]]], "Subsubsection",
  CellTags->"TIDL"],

Cell[TextData[{
  "In any n-dimensional integral ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[Integral]", 
            RowBox[{
              SuperscriptBox["d", "n"], "\[NegativeVeryThinSpace]", " ", 
              SuperscriptBox["q", "\[Mu]"], " ", 
              RowBox[{"f", "(", 
                RowBox[{"q", ",", "p"}], ")"}], " ", "the", " ", 
              SuperscriptBox["q", "\[Mu]"]}]}], " "}], TraditionalForm]]],
  "can be replaced by"
}], "Text",
  CellTags->"TIDL"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"TIDL", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"q", ",", "\[Mu]"}], "}"}], ",", 
        RowBox[{"{", "p", "}"}]}], "]"}]], "Input",
  CellLabel->"In[1576]:=  (21:56:55 on 5/16/01)",
  CellTags->"TIDL"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{
          SuperscriptBox[
            FormBox["p",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          RowBox[{
            FormBox["p",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["q",
              "TraditionalForm"]}]}], 
        SuperscriptBox[
          FormBox["p",
            "TraditionalForm"], "2"]], TraditionalForm]], "Output",
  CellLabel->"Out[1576]=  (21:56:55 on 5/16/01)"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["B", "\[Mu]\[Nu]"], "-", "type"}], 
      TraditionalForm]]]], "Subsubsection",
  CellTags->"TIDL"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"TIDL", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"q", ",", "\[Mu]"}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"q", ",", "\[Nu]"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", "p", "}"}]}], "]"}]], "Input",
  CellLabel->"In[1577]:=  (21:56:55 on 5/16/01)",
  CellTags->"TIDL"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{
            SuperscriptBox["g", 
              RowBox[{
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"], "\[NoBreak]", 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]}]], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}],
                      "TraditionalForm"], ")"}], "2"], "-", 
                RowBox[{
                  SuperscriptBox[
                    FormBox["p",
                      "TraditionalForm"], "2"], " ", 
                  SuperscriptBox[
                    FormBox["q",
                      "TraditionalForm"], "2"]}]}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"1", "-", "D"}], ")"}], " ", 
            SuperscriptBox[
              FormBox["p",
                "TraditionalForm"], "2"]}]], "-", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              FormBox["p",
                "TraditionalForm"], 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"]], " ", 
            SuperscriptBox[
              FormBox["p",
                "TraditionalForm"], 
              FormBox[
                FormBox["\[Nu]",
                  "TraditionalForm"],
                "TraditionalForm"]], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"D", " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      FormBox[
                        RowBox[{
                          FormBox["p",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["q",
                            "TraditionalForm"]}],
                        "TraditionalForm"], ")"}], "2"]}], "-", 
                RowBox[{
                  SuperscriptBox[
                    FormBox["p",
                      "TraditionalForm"], "2"], " ", 
                  SuperscriptBox[
                    FormBox["q",
                      "TraditionalForm"], "2"]}]}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"1", "-", "D"}], ")"}], " ", 
            SuperscriptBox[
              FormBox["p",
                "TraditionalForm"], "4"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1577]=  (21:56:55 on 5/16/01)"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["C", "\[Mu]"], "-", "type"}], 
      TraditionalForm]]]], "Subsubsection",
  CellTags->"TIDL"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"TIDL", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"q", ",", "\[Mu]"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            SubscriptBox["p", "1"], ",", 
            SubscriptBox["p", "2"]}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[1578]:=  (21:56:55 on 5/16/01)",
  CellTags->"TIDL"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{
            RowBox[{
              SubsuperscriptBox["p", 
                FormBox["2",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["q",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox[
                  SubscriptBox["p", "1"],
                  "TraditionalForm"]}], " ", 
              RowBox[{
                FormBox[
                  SubscriptBox["p", "1"],
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox[
                  SubscriptBox["p", "2"],
                  "TraditionalForm"]}]}], "-", 
            RowBox[{
              SubsuperscriptBox["p", 
                FormBox["2",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["q",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox[
                  SubscriptBox["p", "2"],
                  "TraditionalForm"]}], " ", 
              SubsuperscriptBox["p", "1", "2"]}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                FormBox[
                  RowBox[{
                    FormBox[
                      SubscriptBox["p", "1"],
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox[
                      SubscriptBox["p", "2"],
                      "TraditionalForm"]}],
                  "TraditionalForm"], ")"}], "2"], "-", 
            RowBox[{
              SubsuperscriptBox["p", "1", "2"], " ", 
              SubsuperscriptBox["p", "2", "2"]}]}]], "+", 
        FractionBox[
          RowBox[{
            RowBox[{
              SubsuperscriptBox["p", 
                FormBox["1",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["q",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox[
                  SubscriptBox["p", "2"],
                  "TraditionalForm"]}], " ", 
              RowBox[{
                FormBox[
                  SubscriptBox["p", "1"],
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox[
                  SubscriptBox["p", "2"],
                  "TraditionalForm"]}]}], "-", 
            RowBox[{
              SubsuperscriptBox["p", 
                FormBox["1",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["q",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox[
                  SubscriptBox["p", "1"],
                  "TraditionalForm"]}], " ", 
              SubsuperscriptBox["p", "2", "2"]}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                FormBox[
                  RowBox[{
                    FormBox[
                      SubscriptBox["p", "1"],
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox[
                      SubscriptBox["p", "2"],
                      "TraditionalForm"]}],
                  "TraditionalForm"], ")"}], "2"], "-", 
            RowBox[{
              SubsuperscriptBox["p", "1", "2"], " ", 
              SubsuperscriptBox["p", "2", "2"]}]}]]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1578]=  (21:56:56 on 5/16/01)"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["C", "\[Mu]\[Nu]"], "-", "type"}], 
      TraditionalForm]]]], "Subsubsection",
  CellTags->"TIDL"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"TIDL", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"q", ",", "\[Mu]"}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"q", ",", "\[Nu]"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            SubscriptBox["p", "1"], ",", 
            SubscriptBox["p", "2"]}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[1579]:=  (21:56:56 on 5/16/01)",
  CellTags->"TIDL"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{
            SuperscriptBox["g", 
              RowBox[{
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"], "\[NoBreak]", 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]}]], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  SubsuperscriptBox["p", "2", "2"], " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      FormBox[
                        RowBox[{
                          FormBox["q",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox[
                            SubscriptBox["p", "1"],
                            "TraditionalForm"]}],
                        "TraditionalForm"], ")"}], "2"]}], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["q",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox[
                      SubscriptBox["p", "2"],
                      "TraditionalForm"]}], " ", 
                  RowBox[{
                    FormBox[
                      SubscriptBox["p", "1"],
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox[
                      SubscriptBox["p", "2"],
                      "TraditionalForm"]}], " ", 
                  RowBox[{
                    FormBox["q",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox[
                      SubscriptBox["p", "1"],
                      "TraditionalForm"]}]}], "+", 
                RowBox[{
                  SuperscriptBox[
                    FormBox["q",
                      "TraditionalForm"], "2"], " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      FormBox[
                        RowBox[{
                          FormBox[
                            SubscriptBox["p", "1"],
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox[
                            SubscriptBox["p", "2"],
                            "TraditionalForm"]}],
                        "TraditionalForm"], ")"}], "2"]}], "+", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"(", 
                      FormBox[
                        RowBox[{
                          FormBox["q",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox[
                            SubscriptBox["p", "2"],
                            "TraditionalForm"]}],
                        "TraditionalForm"], ")"}], "2"], " ", 
                  SubsuperscriptBox["p", "1", "2"]}], "-", 
                RowBox[{
                  SuperscriptBox[
                    FormBox["q",
                      "TraditionalForm"], "2"], " ", 
                  SubsuperscriptBox["p", "1", "2"], " ", 
                  SubsuperscriptBox["p", "2", "2"]}]}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"D", "-", "2"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{
                        FormBox[
                          SubscriptBox["p", "1"],
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox[
                          SubscriptBox["p", "2"],
                          "TraditionalForm"]}],
                      "TraditionalForm"], ")"}], "2"], "-", 
                RowBox[{
                  SubsuperscriptBox["p", "1", "2"], " ", 
                  SubsuperscriptBox["p", "2", "2"]}]}], ")"}]}]], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              SubsuperscriptBox["p", 
                FormBox["2",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SubsuperscriptBox["p", 
                FormBox["2",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"D", " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        FormBox[
                          RowBox[{
                            FormBox[
                              SubscriptBox["p", "1"],
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox[
                              SubscriptBox["p", "2"],
                              "TraditionalForm"]}],
                          "TraditionalForm"], ")"}], "2"], " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        FormBox[
                          RowBox[{
                            FormBox["q",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox[
                              SubscriptBox["p", "1"],
                              "TraditionalForm"]}],
                          "TraditionalForm"], ")"}], "2"]}], "-", 
                  RowBox[{"2", " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        FormBox[
                          RowBox[{
                            FormBox[
                              SubscriptBox["p", "1"],
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox[
                              SubscriptBox["p", "2"],
                              "TraditionalForm"]}],
                          "TraditionalForm"], ")"}], "2"], " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        FormBox[
                          RowBox[{
                            FormBox["q",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox[
                              SubscriptBox["p", "1"],
                              "TraditionalForm"]}],
                          "TraditionalForm"], ")"}], "2"]}], "+", 
                  RowBox[{
                    SubsuperscriptBox["p", "1", "2"], " ", 
                    SubsuperscriptBox["p", "2", "2"], " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        FormBox[
                          RowBox[{
                            FormBox["q",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox[
                              SubscriptBox["p", "1"],
                              "TraditionalForm"]}],
                          "TraditionalForm"], ")"}], "2"]}], "-", 
                  RowBox[{"2", " ", "D", " ", 
                    RowBox[{
                      FormBox["q",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"]}], " ", 
                    SubsuperscriptBox["p", "1", "2"], " ", 
                    RowBox[{
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"]}], " ", 
                    RowBox[{
                      FormBox["q",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"]}]}], "+", 
                  RowBox[{"2", " ", 
                    RowBox[{
                      FormBox["q",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"]}], " ", 
                    SubsuperscriptBox["p", "1", "2"], " ", 
                    RowBox[{
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"]}], " ", 
                    RowBox[{
                      FormBox["q",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"]}]}], "+", 
                  RowBox[{"D", " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        FormBox[
                          RowBox[{
                            FormBox["q",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox[
                              SubscriptBox["p", "2"],
                              "TraditionalForm"]}],
                          "TraditionalForm"], ")"}], "2"], " ", 
                    SubsuperscriptBox["p", "1", "4"]}], "-", 
                  RowBox[{
                    SuperscriptBox[
                      RowBox[{"(", 
                        FormBox[
                          RowBox[{
                            FormBox["q",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox[
                              SubscriptBox["p", "2"],
                              "TraditionalForm"]}],
                          "TraditionalForm"], ")"}], "2"], " ", 
                    SubsuperscriptBox["p", "1", "4"]}], "+", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"], " ", 
                    SubsuperscriptBox["p", "1", "2"], " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        FormBox[
                          RowBox[{
                            FormBox[
                              SubscriptBox["p", "1"],
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox[
                              SubscriptBox["p", "2"],
                              "TraditionalForm"]}],
                          "TraditionalForm"], ")"}], "2"]}], "-", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"], " ", 
                    SubsuperscriptBox["p", "1", "4"], " ", 
                    SubsuperscriptBox["p", "2", "2"]}]}], ")"}]}], ")"}], "/",
           
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"D", "-", "2"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      RowBox[{"(", 
                        FormBox[
                          RowBox[{
                            FormBox[
                              SubscriptBox["p", "1"],
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox[
                              SubscriptBox["p", "2"],
                              "TraditionalForm"]}],
                          "TraditionalForm"], ")"}], "2"], "-", 
                    RowBox[{
                      SubsuperscriptBox["p", "1", "2"], " ", 
                      SubsuperscriptBox["p", "2", "2"]}]}], ")"}], "2"]}], 
            ")"}]}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              SubsuperscriptBox["p", 
                FormBox["2",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SubsuperscriptBox["p", 
                FormBox["1",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"-", 
                      SuperscriptBox[
                        FormBox["q",
                          "TraditionalForm"], "2"]}], " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        FormBox[
                          RowBox[{
                            FormBox[
                              SubscriptBox["p", "1"],
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox[
                              SubscriptBox["p", "2"],
                              "TraditionalForm"]}],
                          "TraditionalForm"], ")"}], "3"]}], "+", 
                  RowBox[{"D", " ", 
                    RowBox[{
                      FormBox["q",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"]}], " ", 
                    RowBox[{
                      FormBox["q",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"]}], " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        FormBox[
                          RowBox[{
                            FormBox[
                              SubscriptBox["p", "1"],
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox[
                              SubscriptBox["p", "2"],
                              "TraditionalForm"]}],
                          "TraditionalForm"], ")"}], "2"]}], "-", 
                  RowBox[{"D", " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        FormBox[
                          RowBox[{
                            FormBox["q",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox[
                              SubscriptBox["p", "2"],
                              "TraditionalForm"]}],
                          "TraditionalForm"], ")"}], "2"], " ", 
                    SubsuperscriptBox["p", "1", "2"], " ", 
                    RowBox[{
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"]}]}], "+", 
                  RowBox[{
                    SuperscriptBox[
                      RowBox[{"(", 
                        FormBox[
                          RowBox[{
                            FormBox["q",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox[
                              SubscriptBox["p", "2"],
                              "TraditionalForm"]}],
                          "TraditionalForm"], ")"}], "2"], " ", 
                    SubsuperscriptBox["p", "1", "2"], " ", 
                    RowBox[{
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"]}]}], "-", 
                  RowBox[{"D", " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        FormBox[
                          RowBox[{
                            FormBox["q",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox[
                              SubscriptBox["p", "1"],
                              "TraditionalForm"]}],
                          "TraditionalForm"], ")"}], "2"], " ", 
                    SubsuperscriptBox["p", "2", "2"], " ", 
                    RowBox[{
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"]}]}], "+", 
                  RowBox[{
                    SuperscriptBox[
                      RowBox[{"(", 
                        FormBox[
                          RowBox[{
                            FormBox["q",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox[
                              SubscriptBox["p", "1"],
                              "TraditionalForm"]}],
                          "TraditionalForm"], ")"}], "2"], " ", 
                    SubsuperscriptBox["p", "2", "2"], " ", 
                    RowBox[{
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"]}]}], "+", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"], " ", 
                    SubsuperscriptBox["p", "1", "2"], " ", 
                    SubsuperscriptBox["p", "2", "2"], " ", 
                    RowBox[{
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"]}]}], "+", 
                  RowBox[{"D", " ", 
                    RowBox[{
                      FormBox["q",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"]}], " ", 
                    RowBox[{
                      FormBox["q",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"]}], " ", 
                    SubsuperscriptBox["p", "1", "2"], " ", 
                    SubsuperscriptBox["p", "2", "2"]}], "-", 
                  RowBox[{"2", " ", 
                    RowBox[{
                      FormBox["q",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"]}], " ", 
                    RowBox[{
                      FormBox["q",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"]}], " ", 
                    SubsuperscriptBox["p", "1", "2"], " ", 
                    SubsuperscriptBox["p", "2", "2"]}]}], ")"}]}], ")"}], "/",
           
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"D", "-", "2"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      RowBox[{"(", 
                        FormBox[
                          RowBox[{
                            FormBox[
                              SubscriptBox["p", "1"],
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox[
                              SubscriptBox["p", "2"],
                              "TraditionalForm"]}],
                          "TraditionalForm"], ")"}], "2"], "-", 
                    RowBox[{
                      SubsuperscriptBox["p", "1", "2"], " ", 
                      SubsuperscriptBox["p", "2", "2"]}]}], ")"}], "2"]}], 
            ")"}]}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              SubsuperscriptBox["p", 
                FormBox["1",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SubsuperscriptBox["p", 
                FormBox["2",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"-", 
                      SuperscriptBox[
                        FormBox["q",
                          "TraditionalForm"], "2"]}], " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        FormBox[
                          RowBox[{
                            FormBox[
                              SubscriptBox["p", "1"],
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox[
                              SubscriptBox["p", "2"],
                              "TraditionalForm"]}],
                          "TraditionalForm"], ")"}], "3"]}], "+", 
                  RowBox[{"D", " ", 
                    RowBox[{
                      FormBox["q",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"]}], " ", 
                    RowBox[{
                      FormBox["q",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"]}], " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        FormBox[
                          RowBox[{
                            FormBox[
                              SubscriptBox["p", "1"],
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox[
                              SubscriptBox["p", "2"],
                              "TraditionalForm"]}],
                          "TraditionalForm"], ")"}], "2"]}], "-", 
                  RowBox[{"D", " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        FormBox[
                          RowBox[{
                            FormBox["q",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox[
                              SubscriptBox["p", "2"],
                              "TraditionalForm"]}],
                          "TraditionalForm"], ")"}], "2"], " ", 
                    SubsuperscriptBox["p", "1", "2"], " ", 
                    RowBox[{
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"]}]}], "+", 
                  RowBox[{
                    SuperscriptBox[
                      RowBox[{"(", 
                        FormBox[
                          RowBox[{
                            FormBox["q",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox[
                              SubscriptBox["p", "2"],
                              "TraditionalForm"]}],
                          "TraditionalForm"], ")"}], "2"], " ", 
                    SubsuperscriptBox["p", "1", "2"], " ", 
                    RowBox[{
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"]}]}], "-", 
                  RowBox[{"D", " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        FormBox[
                          RowBox[{
                            FormBox["q",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox[
                              SubscriptBox["p", "1"],
                              "TraditionalForm"]}],
                          "TraditionalForm"], ")"}], "2"], " ", 
                    SubsuperscriptBox["p", "2", "2"], " ", 
                    RowBox[{
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"]}]}], "+", 
                  RowBox[{
                    SuperscriptBox[
                      RowBox[{"(", 
                        FormBox[
                          RowBox[{
                            FormBox["q",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox[
                              SubscriptBox["p", "1"],
                              "TraditionalForm"]}],
                          "TraditionalForm"], ")"}], "2"], " ", 
                    SubsuperscriptBox["p", "2", "2"], " ", 
                    RowBox[{
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"]}]}], "+", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"], " ", 
                    SubsuperscriptBox["p", "1", "2"], " ", 
                    SubsuperscriptBox["p", "2", "2"], " ", 
                    RowBox[{
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"]}]}], "+", 
                  RowBox[{"D", " ", 
                    RowBox[{
                      FormBox["q",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"]}], " ", 
                    RowBox[{
                      FormBox["q",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"]}], " ", 
                    SubsuperscriptBox["p", "1", "2"], " ", 
                    SubsuperscriptBox["p", "2", "2"]}], "-", 
                  RowBox[{"2", " ", 
                    RowBox[{
                      FormBox["q",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"]}], " ", 
                    RowBox[{
                      FormBox["q",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"]}], " ", 
                    SubsuperscriptBox["p", "1", "2"], " ", 
                    SubsuperscriptBox["p", "2", "2"]}]}], ")"}]}], ")"}], "/",
           
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"D", "-", "2"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      RowBox[{"(", 
                        FormBox[
                          RowBox[{
                            FormBox[
                              SubscriptBox["p", "1"],
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox[
                              SubscriptBox["p", "2"],
                              "TraditionalForm"]}],
                          "TraditionalForm"], ")"}], "2"], "-", 
                    RowBox[{
                      SubsuperscriptBox["p", "1", "2"], " ", 
                      SubsuperscriptBox["p", "2", "2"]}]}], ")"}], "2"]}], 
            ")"}]}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              SubsuperscriptBox["p", 
                FormBox["1",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SubsuperscriptBox["p", 
                FormBox["1",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"D", " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        FormBox[
                          RowBox[{
                            FormBox[
                              SubscriptBox["p", "1"],
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox[
                              SubscriptBox["p", "2"],
                              "TraditionalForm"]}],
                          "TraditionalForm"], ")"}], "2"], " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        FormBox[
                          RowBox[{
                            FormBox["q",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox[
                              SubscriptBox["p", "2"],
                              "TraditionalForm"]}],
                          "TraditionalForm"], ")"}], "2"]}], "-", 
                  RowBox[{"2", " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        FormBox[
                          RowBox[{
                            FormBox[
                              SubscriptBox["p", "1"],
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox[
                              SubscriptBox["p", "2"],
                              "TraditionalForm"]}],
                          "TraditionalForm"], ")"}], "2"], " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        FormBox[
                          RowBox[{
                            FormBox["q",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox[
                              SubscriptBox["p", "2"],
                              "TraditionalForm"]}],
                          "TraditionalForm"], ")"}], "2"]}], "+", 
                  RowBox[{
                    SubsuperscriptBox["p", "1", "2"], " ", 
                    SubsuperscriptBox["p", "2", "2"], " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        FormBox[
                          RowBox[{
                            FormBox["q",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox[
                              SubscriptBox["p", "2"],
                              "TraditionalForm"]}],
                          "TraditionalForm"], ")"}], "2"]}], "-", 
                  RowBox[{"2", " ", "D", " ", 
                    RowBox[{
                      FormBox["q",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"]}], " ", 
                    RowBox[{
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"]}], " ", 
                    SubsuperscriptBox["p", "2", "2"], " ", 
                    RowBox[{
                      FormBox["q",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"]}]}], "+", 
                  RowBox[{"2", " ", 
                    RowBox[{
                      FormBox["q",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"]}], " ", 
                    RowBox[{
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"]}], " ", 
                    SubsuperscriptBox["p", "2", "2"], " ", 
                    RowBox[{
                      FormBox["q",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"]}]}], "+", 
                  RowBox[{"D", " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        FormBox[
                          RowBox[{
                            FormBox["q",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox[
                              SubscriptBox["p", "1"],
                              "TraditionalForm"]}],
                          "TraditionalForm"], ")"}], "2"], " ", 
                    SubsuperscriptBox["p", "2", "4"]}], "-", 
                  RowBox[{
                    SuperscriptBox[
                      RowBox[{"(", 
                        FormBox[
                          RowBox[{
                            FormBox["q",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox[
                              SubscriptBox["p", "1"],
                              "TraditionalForm"]}],
                          "TraditionalForm"], ")"}], "2"], " ", 
                    SubsuperscriptBox["p", "2", "4"]}], "-", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"], " ", 
                    SubsuperscriptBox["p", "1", "2"], " ", 
                    SubsuperscriptBox["p", "2", "4"]}], "+", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"], " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        FormBox[
                          RowBox[{
                            FormBox[
                              SubscriptBox["p", "1"],
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox[
                              SubscriptBox["p", "2"],
                              "TraditionalForm"]}],
                          "TraditionalForm"], ")"}], "2"], " ", 
                    SubsuperscriptBox["p", "2", "2"]}]}], ")"}]}], ")"}], "/",
           
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"D", "-", "2"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      RowBox[{"(", 
                        FormBox[
                          RowBox[{
                            FormBox[
                              SubscriptBox["p", "1"],
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox[
                              SubscriptBox["p", "2"],
                              "TraditionalForm"]}],
                          "TraditionalForm"], ")"}], "2"], "-", 
                    RowBox[{
                      SubsuperscriptBox["p", "1", "2"], " ", 
                      SubsuperscriptBox["p", "2", "2"]}]}], ")"}], "2"]}], 
            ")"}]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1579]=  (21:56:56 on 5/16/01)"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["C", "\[Mu]\[Nu]\[Rho]"], "-", "type"}], 
      TraditionalForm]]]], "Subsubsection",
  CellTags->"TIDL"],

Cell[BoxData[
    RowBox[{
      RowBox[{"TIDL", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{
              RowBox[{"{", 
                RowBox[{"q", ",", "\[Mu]"}], "}"}], ",", 
              RowBox[{"{", 
                RowBox[{"q", ",", "\[Nu]"}], "}"}], ",", 
              RowBox[{"{", 
                RowBox[{"q", ",", "\[Rho]"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{"p", ",", "k"}], "}"}]}], "]"}], ";"}]], "Input",
  CellLabel->"In[1580]:=  (21:56:56 on 5/16/01)",
  CellTags->"TIDL"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["C", "\[Mu]\[Nu]\[Rho]\[Sigma]"], "-", "type"}], 
      TraditionalForm]]]], "Subsubsection",
  CellTags->"TIDL"],

Cell[BoxData[
    RowBox[{
      RowBox[{"TIDL", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{
              RowBox[{"{", 
                RowBox[{"q", ",", "\[Mu]"}], "}"}], ",", 
              RowBox[{"{", 
                RowBox[{"q", ",", "\[Nu]"}], "}"}], ",", 
              RowBox[{"{", 
                RowBox[{"q", ",", "\[Rho]"}], "}"}], ",", 
              RowBox[{"{", 
                RowBox[{"q", ",", "\[Sigma]"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{"p", ",", "k"}], "}"}]}], "]"}], ";"}]], "Input",
  CellLabel->"In[1581]:=  (21:56:56 on 5/16/01)",
  CellTags->"TIDL"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["D", "\[Mu]"], "-", "type"}], 
      TraditionalForm]]]], "Subsubsection",
  CellTags->"TIDL"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"TIDL", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"q", ",", "\[Mu]"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            SubscriptBox["p", "1"], ",", 
            SubscriptBox["p", "2"], ",", 
            SubscriptBox["p", "3"]}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[1582]:=  (21:56:56 on 5/16/01)",
  CellTags->"TIDL"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              SubsuperscriptBox["p", 
                FormBox["3",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{
                      FormBox["q",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "3"],
                        "TraditionalForm"]}], " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        FormBox[
                          RowBox[{
                            FormBox[
                              SubscriptBox["p", "1"],
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox[
                              SubscriptBox["p", "2"],
                              "TraditionalForm"]}],
                          "TraditionalForm"], ")"}], "2"]}], "-", 
                  RowBox[{
                    RowBox[{
                      FormBox["q",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"]}], " ", 
                    RowBox[{
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "3"],
                        "TraditionalForm"]}], " ", 
                    RowBox[{
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"]}]}], "-", 
                  RowBox[{
                    RowBox[{
                      FormBox["q",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"]}], " ", 
                    RowBox[{
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "3"],
                        "TraditionalForm"]}], " ", 
                    RowBox[{
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"]}]}], "-", 
                  RowBox[{
                    RowBox[{
                      FormBox["q",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "3"],
                        "TraditionalForm"]}], " ", 
                    SubsuperscriptBox["p", "1", "2"], " ", 
                    SubsuperscriptBox["p", "2", "2"]}], "+", 
                  RowBox[{
                    RowBox[{
                      FormBox["q",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"]}], " ", 
                    RowBox[{
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "3"],
                        "TraditionalForm"]}], " ", 
                    SubsuperscriptBox["p", "2", "2"]}], "+", 
                  RowBox[{
                    RowBox[{
                      FormBox["q",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"]}], " ", 
                    SubsuperscriptBox["p", "1", "2"], " ", 
                    RowBox[{
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "3"],
                        "TraditionalForm"]}]}]}], ")"}]}], ")"}], "/", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SubsuperscriptBox["p", "3", "2"], " ", 
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{
                        FormBox[
                          SubscriptBox["p", "1"],
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox[
                          SubscriptBox["p", "2"],
                          "TraditionalForm"]}],
                      "TraditionalForm"], ")"}], "2"]}], "-", 
              RowBox[{"2", " ", 
                RowBox[{
                  FormBox[
                    SubscriptBox["p", "1"],
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox[
                    SubscriptBox["p", "3"],
                    "TraditionalForm"]}], " ", 
                RowBox[{
                  FormBox[
                    SubscriptBox["p", "2"],
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox[
                    SubscriptBox["p", "3"],
                    "TraditionalForm"]}], " ", 
                RowBox[{
                  FormBox[
                    SubscriptBox["p", "1"],
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox[
                    SubscriptBox["p", "2"],
                    "TraditionalForm"]}]}], "+", 
              RowBox[{
                SubsuperscriptBox["p", "1", "2"], " ", 
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{
                        FormBox[
                          SubscriptBox["p", "2"],
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox[
                          SubscriptBox["p", "3"],
                          "TraditionalForm"]}],
                      "TraditionalForm"], ")"}], "2"]}], "+", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{
                        FormBox[
                          SubscriptBox["p", "1"],
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox[
                          SubscriptBox["p", "3"],
                          "TraditionalForm"]}],
                      "TraditionalForm"], ")"}], "2"], " ", 
                SubsuperscriptBox["p", "2", "2"]}], "-", 
              RowBox[{
                SubsuperscriptBox["p", "1", "2"], " ", 
                SubsuperscriptBox["p", "2", "2"], " ", 
                SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}], "-", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              SubsuperscriptBox["p", 
                FormBox["2",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"-", 
                      RowBox[{"(", 
                        RowBox[{
                          FormBox["q",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox[
                            SubscriptBox["p", "2"],
                            "TraditionalForm"]}], ")"}]}], " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        FormBox[
                          RowBox[{
                            FormBox[
                              SubscriptBox["p", "1"],
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox[
                              SubscriptBox["p", "3"],
                              "TraditionalForm"]}],
                          "TraditionalForm"], ")"}], "2"]}], "+", 
                  RowBox[{
                    RowBox[{
                      FormBox["q",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "3"],
                        "TraditionalForm"]}], " ", 
                    RowBox[{
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"]}], " ", 
                    RowBox[{
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "3"],
                        "TraditionalForm"]}]}], "+", 
                  RowBox[{
                    RowBox[{
                      FormBox["q",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"]}], " ", 
                    RowBox[{
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "3"],
                        "TraditionalForm"]}], " ", 
                    RowBox[{
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "3"],
                        "TraditionalForm"]}]}], "-", 
                  RowBox[{
                    RowBox[{
                      FormBox["q",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "3"],
                        "TraditionalForm"]}], " ", 
                    SubsuperscriptBox["p", "1", "2"], " ", 
                    RowBox[{
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "3"],
                        "TraditionalForm"]}]}], "+", 
                  RowBox[{
                    RowBox[{
                      FormBox["q",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"]}], " ", 
                    SubsuperscriptBox["p", "1", "2"], " ", 
                    SubsuperscriptBox["p", "3", "2"]}], "-", 
                  RowBox[{
                    RowBox[{
                      FormBox["q",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"]}], " ", 
                    RowBox[{
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"]}], " ", 
                    SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}], ")"}], "/",
           
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SubsuperscriptBox["p", "3", "2"], " ", 
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{
                        FormBox[
                          SubscriptBox["p", "1"],
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox[
                          SubscriptBox["p", "2"],
                          "TraditionalForm"]}],
                      "TraditionalForm"], ")"}], "2"]}], "-", 
              RowBox[{"2", " ", 
                RowBox[{
                  FormBox[
                    SubscriptBox["p", "1"],
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox[
                    SubscriptBox["p", "3"],
                    "TraditionalForm"]}], " ", 
                RowBox[{
                  FormBox[
                    SubscriptBox["p", "2"],
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox[
                    SubscriptBox["p", "3"],
                    "TraditionalForm"]}], " ", 
                RowBox[{
                  FormBox[
                    SubscriptBox["p", "1"],
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox[
                    SubscriptBox["p", "2"],
                    "TraditionalForm"]}]}], "+", 
              RowBox[{
                SubsuperscriptBox["p", "1", "2"], " ", 
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{
                        FormBox[
                          SubscriptBox["p", "2"],
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox[
                          SubscriptBox["p", "3"],
                          "TraditionalForm"]}],
                      "TraditionalForm"], ")"}], "2"]}], "+", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{
                        FormBox[
                          SubscriptBox["p", "1"],
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox[
                          SubscriptBox["p", "3"],
                          "TraditionalForm"]}],
                      "TraditionalForm"], ")"}], "2"], " ", 
                SubsuperscriptBox["p", "2", "2"]}], "-", 
              RowBox[{
                SubsuperscriptBox["p", "1", "2"], " ", 
                SubsuperscriptBox["p", "2", "2"], " ", 
                SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              SubsuperscriptBox["p", 
                FormBox["1",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{
                      FormBox["q",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"]}], " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        FormBox[
                          RowBox[{
                            FormBox[
                              SubscriptBox["p", "2"],
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox[
                              SubscriptBox["p", "3"],
                              "TraditionalForm"]}],
                          "TraditionalForm"], ")"}], "2"]}], "-", 
                  RowBox[{
                    RowBox[{
                      FormBox["q",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "3"],
                        "TraditionalForm"]}], " ", 
                    RowBox[{
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"]}], " ", 
                    RowBox[{
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "3"],
                        "TraditionalForm"]}]}], "-", 
                  RowBox[{
                    RowBox[{
                      FormBox["q",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"]}], " ", 
                    RowBox[{
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "3"],
                        "TraditionalForm"]}], " ", 
                    RowBox[{
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "3"],
                        "TraditionalForm"]}]}], "+", 
                  RowBox[{
                    RowBox[{
                      FormBox["q",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "3"],
                        "TraditionalForm"]}], " ", 
                    RowBox[{
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "3"],
                        "TraditionalForm"]}], " ", 
                    SubsuperscriptBox["p", "2", "2"]}], "+", 
                  RowBox[{
                    RowBox[{
                      FormBox["q",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"]}], " ", 
                    RowBox[{
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"]}], " ", 
                    SubsuperscriptBox["p", "3", "2"]}], "-", 
                  RowBox[{
                    RowBox[{
                      FormBox["q",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"]}], " ", 
                    SubsuperscriptBox["p", "2", "2"], " ", 
                    SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}], ")"}], "/",
           
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SubsuperscriptBox["p", "3", "2"], " ", 
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{
                        FormBox[
                          SubscriptBox["p", "1"],
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox[
                          SubscriptBox["p", "2"],
                          "TraditionalForm"]}],
                      "TraditionalForm"], ")"}], "2"]}], "-", 
              RowBox[{"2", " ", 
                RowBox[{
                  FormBox[
                    SubscriptBox["p", "1"],
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox[
                    SubscriptBox["p", "3"],
                    "TraditionalForm"]}], " ", 
                RowBox[{
                  FormBox[
                    SubscriptBox["p", "2"],
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox[
                    SubscriptBox["p", "3"],
                    "TraditionalForm"]}], " ", 
                RowBox[{
                  FormBox[
                    SubscriptBox["p", "1"],
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox[
                    SubscriptBox["p", "2"],
                    "TraditionalForm"]}]}], "+", 
              RowBox[{
                SubsuperscriptBox["p", "1", "2"], " ", 
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{
                        FormBox[
                          SubscriptBox["p", "2"],
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox[
                          SubscriptBox["p", "3"],
                          "TraditionalForm"]}],
                      "TraditionalForm"], ")"}], "2"]}], "+", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{
                        FormBox[
                          SubscriptBox["p", "1"],
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox[
                          SubscriptBox["p", "3"],
                          "TraditionalForm"]}],
                      "TraditionalForm"], ")"}], "2"], " ", 
                SubsuperscriptBox["p", "2", "2"]}], "-", 
              RowBox[{
                SubsuperscriptBox["p", "1", "2"], " ", 
                SubsuperscriptBox["p", "2", "2"], " ", 
                SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1582]=  (21:56:57 on 5/16/01)"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["D", "\[Mu]\[Nu]"], "-", "type"}], 
      TraditionalForm]]]], "Subsubsection",
  CellTags->"TIDL"],

Cell[BoxData[
    RowBox[{
      RowBox[{"TIDL", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{
              RowBox[{"{", 
                RowBox[{"q", ",", "\[Mu]"}], "}"}], ",", 
              RowBox[{"{", 
                RowBox[{"q", ",", "\[Nu]"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{"p", ",", "k", ",", "r"}], "}"}]}], "]"}], ";"}]], "Input",\

  CellLabel->"In[1583]:=  (21:56:57 on 5/16/01)",
  CellTags->"TIDL"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["D", "\[Mu]\[Nu]\[Rho]"], "-", "type"}], 
      TraditionalForm]]]], "Subsubsection",
  CellTags->"TIDL"],

Cell[BoxData[
    RowBox[{
      RowBox[{"TIDL", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{
              RowBox[{"{", 
                RowBox[{"q", ",", "\[Mu]"}], "}"}], ",", 
              RowBox[{"{", 
                RowBox[{"q", ",", "\[Nu]"}], "}"}], ",", 
              RowBox[{"{", 
                RowBox[{"q", ",", "\[Rho]"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{"p", ",", "k", ",", "r"}], "}"}]}], "]"}], ";"}]], "Input",\

  CellLabel->"In[1584]:=  (21:56:57 on 5/16/01)",
  CellTags->"TIDL"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["D", "\[Mu]\[Nu]\[Rho]\[Sigma]"], "-", "type"}], 
      TraditionalForm]]]], "Subsubsection",
  CellTags->"TIDL"],

Cell[BoxData[
    RowBox[{
      RowBox[{"TIDL", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{
              RowBox[{"{", 
                RowBox[{"q", ",", "\[Mu]"}], "}"}], ",", 
              RowBox[{"{", 
                RowBox[{"q", ",", "\[Nu]"}], "}"}], ",", 
              RowBox[{"{", 
                RowBox[{"q", ",", "\[Rho]"}], "}"}], ",", 
              RowBox[{"{", 
                RowBox[{"q", ",", "\[Sigma]"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{"p", ",", "k", ",", "r", ",", "s"}], "}"}]}], "]"}], 
      ";"}]], "Input",
  CellLabel->"In[1585]:=  (21:56:57 on 5/16/01)",
  CellTags->"TIDL"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"Length", "[", "%", "]"}], ",", " ", 
        RowBox[{"LeafCount", "[", "%", "]"}], ",", 
        RowBox[{"ByteCount", "[", "%", "]"}]}], "}"}]], "Input",
  CellLabel->"In[1586]:=  (21:56:57 on 5/16/01)",
  CellTags->"TIDL"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"4", ",", "29", ",", "320"}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1586]=  (21:56:57 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["TID", "ObjectName",
  CellTags->"TID"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"TID"],

Cell["TID[amp,q] performs a tensorial decomposition.", "Text",
  CellTags->"TID"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "TID", "]"}]], "Input",
  CellLabel->"In[1587]:=  (21:56:57 on 5/16/01)",
  CellTags->"TID"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"Collecting", "\[Rule]", "True"}], ",", 
          RowBox[{"Contract", "\[Rule]", "False"}], ",", 
          RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
          RowBox[{"ChangeDimension", "\[Rule]", "D"}], ",", 
          RowBox[{"DimensionalReduction", "\[Rule]", "False"}], ",", 
          RowBox[{"FeynAmpDenominatorCombine", "\[Rule]", "True"}], ",", 
          RowBox[{"FeynAmpDenominatorSimplify", "\[Rule]", "False"}], ",", 
          RowBox[{"Isolate", "\[Rule]", "False"}], ",", 
          RowBox[{"ScalarProductCancel", "\[Rule]", "True"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1587]=  (21:56:57 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["OneLoopSimplify",
    ButtonData:>"OneLoopSimplify",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"OneLoopSimplify"],
  ", ",
  ButtonBox["TIDL",
    ButtonData:>"TIDL",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"TIDL"],
  "."
}], "Text",
  CellTags->"TID"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"TID"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"FAD", "[", 
          RowBox[{"k", ",", " ", 
            RowBox[{"k", " ", "-", " ", 
              SubscriptBox["p", "1"]}], ",", " ", 
            RowBox[{"k", " ", "-", " ", 
              SubscriptBox["p", "2"]}]}], "]"}], 
        RowBox[{"FVD", "[", 
          RowBox[{"k", ",", "\[Mu]"}], "]"}]}], "//", "FCI"}]], "Input",
  CellLabel->"In[1588]:=  (21:56:57 on 5/16/01)",
  CellTags->"TID"],

Cell[BoxData[
    FormBox[
      FractionBox[
        SuperscriptBox[
          FormBox[
            FormBox[
              TagBox[
                StyleBox["\<\"k\"\>",
                  FontSlant->"Italic"],
                (StyleForm[ #, FontSlant -> "Italic"]&)],
              "TraditionalForm"],
            "TraditionalForm"], 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]], 
        RowBox[{
          SuperscriptBox[
            FormBox[
              TagBox[
                StyleBox["\<\"k\"\>",
                  FontSlant->"Italic"],
                (StyleForm[ #, FontSlant -> "Italic"]&)],
              "TraditionalForm"], "2"], ".", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"], "-", 
                SubscriptBox["p", "1"]}], ")"}], "2"], ".", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"], "-", 
                SubscriptBox["p", "2"]}], ")"}], "2"]}]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1588]=  (21:56:57 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Factor", "/@", 
        RowBox[{"TID", "[", 
          RowBox[{"%", ",", "k"}], "]"}]}], "//", "FCE"}]], "Input",
  CellLabel->"In[1589]:=  (21:56:57 on 5/16/01)",
  CellTags->"TID"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              FormBox[
                FractionBox["1", 
                  RowBox[{
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
                          SuperscriptBox[
                            FormBox[
                              TagBox[
                                StyleBox["\<\"k\"\>",
                                  FontSlant->"Italic"],
                                (StyleForm[ #, FontSlant -> "Italic"]&)],
                              "TraditionalForm"], "2"], 
                          "\[InvisibleSpace]", "\<\"]\"\>"}],
                        SequenceForm[ "[", 
                          Power[ k, 2], "]"],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
                          SuperscriptBox[
                            RowBox[{"(", 
                              RowBox[{
                                FormBox[
                                  TagBox[
                                    StyleBox["\<\"k\"\>",
                                      FontSlant->"Italic"],
                                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                                  "TraditionalForm"], "-", 
                                SubscriptBox["p", "1"]}], ")"}], "2"], 
                          "\[InvisibleSpace]", "\<\"]\"\>"}],
                        SequenceForm[ "[", 
                          Power[ 
                            Plus[ k, 
                              Times[ -1, 
                                Subscript[ p, 1]]], 2], "]"],
                        Editable->False], ")"}]}]],
                "TraditionalForm"], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    SubsuperscriptBox["p", 
                      FormBox["2",
                        "TraditionalForm"], "\[Mu]"], " ", 
                    FormBox[
                      SubsuperscriptBox["p", "1", "2"],
                      "TraditionalForm"]}], "-", 
                  RowBox[{
                    SubsuperscriptBox["p", 
                      FormBox["1",
                        "TraditionalForm"], "\[Mu]"], " ", 
                    FormBox[
                      RowBox[{
                        FormBox[
                          SubscriptBox["p", "1"],
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox[
                          SubscriptBox["p", "2"],
                          "TraditionalForm"]}],
                      "TraditionalForm"]}]}], ")"}]}], 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    FormBox[
                      SubsuperscriptBox["p", "1", "2"],
                      "TraditionalForm"], " ", 
                    FormBox[
                      SubsuperscriptBox["p", "2", "2"],
                      "TraditionalForm"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      FormBox[
                        RowBox[{
                          FormBox[
                            SubscriptBox["p", "1"],
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox[
                            SubscriptBox["p", "2"],
                            "TraditionalForm"]}],
                        "TraditionalForm"], ")"}], "2"]}], ")"}]}]]}], "-", 
        FractionBox[
          RowBox[{
            FormBox[
              FractionBox["1", 
                RowBox[{
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
                        SuperscriptBox[
                          FormBox[
                            TagBox[
                              StyleBox["\<\"k\"\>",
                                FontSlant->"Italic"],
                              (StyleForm[ #, FontSlant -> "Italic"]&)],
                            "TraditionalForm"], "2"], 
                        "\[InvisibleSpace]", "\<\"]\"\>"}],
                      SequenceForm[ "[", 
                        Power[ k, 2], "]"],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{
                              FormBox[
                                TagBox[
                                  StyleBox["\<\"k\"\>",
                                    FontSlant->"Italic"],
                                  (StyleForm[ #, FontSlant -> "Italic"]&)],
                                "TraditionalForm"], "-", 
                              SubscriptBox["p", "1"]}], ")"}], "2"], 
                        "\[InvisibleSpace]", "\<\"]\"\>"}],
                      SequenceForm[ "[", 
                        Power[ 
                          Plus[ k, 
                            Times[ -1, 
                              Subscript[ p, 1]]], 2], "]"],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{
                              FormBox[
                                TagBox[
                                  StyleBox["\<\"k\"\>",
                                    FontSlant->"Italic"],
                                  (StyleForm[ #, FontSlant -> "Italic"]&)],
                                "TraditionalForm"], "-", 
                              SubscriptBox["p", "2"]}], ")"}], "2"], 
                        "\[InvisibleSpace]", "\<\"]\"\>"}],
                      SequenceForm[ "[", 
                        Power[ 
                          Plus[ k, 
                            Times[ -1, 
                              Subscript[ p, 2]]], 2], "]"],
                      Editable->False], ")"}]}]],
              "TraditionalForm"], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  SubsuperscriptBox["p", 
                    FormBox["2",
                      "TraditionalForm"], "\[Mu]"], " ", 
                  FormBox[
                    SubsuperscriptBox["p", "1", "2"],
                    "TraditionalForm"], " ", 
                  FormBox[
                    RowBox[{
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"]}],
                    "TraditionalForm"]}], "+", 
                RowBox[{
                  SubsuperscriptBox["p", 
                    FormBox["1",
                      "TraditionalForm"], "\[Mu]"], " ", 
                  FormBox[
                    SubsuperscriptBox["p", "2", "2"],
                    "TraditionalForm"], " ", 
                  FormBox[
                    RowBox[{
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"]}],
                    "TraditionalForm"]}], "-", 
                RowBox[{
                  SubsuperscriptBox["p", 
                    FormBox["1",
                      "TraditionalForm"], "\[Mu]"], " ", 
                  FormBox[
                    SubsuperscriptBox["p", "1", "2"],
                    "TraditionalForm"], " ", 
                  FormBox[
                    SubsuperscriptBox["p", "2", "2"],
                    "TraditionalForm"]}], "-", 
                RowBox[{
                  SubsuperscriptBox["p", 
                    FormBox["2",
                      "TraditionalForm"], "\[Mu]"], " ", 
                  FormBox[
                    SubsuperscriptBox["p", "1", "2"],
                    "TraditionalForm"], " ", 
                  FormBox[
                    SubsuperscriptBox["p", "2", "2"],
                    "TraditionalForm"]}]}], ")"}]}], 
          RowBox[{"2", " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  FormBox[
                    SubsuperscriptBox["p", "1", "2"],
                    "TraditionalForm"], " ", 
                  FormBox[
                    SubsuperscriptBox["p", "2", "2"],
                    "TraditionalForm"]}], "-", 
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{
                        FormBox[
                          SubscriptBox["p", "1"],
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox[
                          SubscriptBox["p", "2"],
                          "TraditionalForm"]}],
                      "TraditionalForm"], ")"}], "2"]}], ")"}]}]], "-", 
        FractionBox[
          RowBox[{
            FormBox[
              FractionBox["1", 
                RowBox[{
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
                        SuperscriptBox[
                          FormBox[
                            TagBox[
                              StyleBox["\<\"k\"\>",
                                FontSlant->"Italic"],
                              (StyleForm[ #, FontSlant -> "Italic"]&)],
                            "TraditionalForm"], "2"], 
                        "\[InvisibleSpace]", "\<\"]\"\>"}],
                      SequenceForm[ "[", 
                        Power[ k, 2], "]"],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{
                              FormBox[
                                TagBox[
                                  StyleBox["\<\"k\"\>",
                                    FontSlant->"Italic"],
                                  (StyleForm[ #, FontSlant -> "Italic"]&)],
                                "TraditionalForm"], "-", 
                              SubscriptBox["p", "2"]}], ")"}], "2"], 
                        "\[InvisibleSpace]", "\<\"]\"\>"}],
                      SequenceForm[ "[", 
                        Power[ 
                          Plus[ k, 
                            Times[ -1, 
                              Subscript[ p, 2]]], 2], "]"],
                      Editable->False], ")"}]}]],
              "TraditionalForm"], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  SubsuperscriptBox["p", 
                    FormBox["2",
                      "TraditionalForm"], "\[Mu]"], " ", 
                  FormBox[
                    RowBox[{
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"]}],
                    "TraditionalForm"]}], "-", 
                RowBox[{
                  SubsuperscriptBox["p", 
                    FormBox["1",
                      "TraditionalForm"], "\[Mu]"], " ", 
                  FormBox[
                    SubsuperscriptBox["p", "2", "2"],
                    "TraditionalForm"]}]}], ")"}]}], 
          RowBox[{"2", " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{
                        FormBox[
                          SubscriptBox["p", "1"],
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox[
                          SubscriptBox["p", "2"],
                          "TraditionalForm"]}],
                      "TraditionalForm"], ")"}], "2"], "-", 
                RowBox[{
                  FormBox[
                    SubsuperscriptBox["p", "1", "2"],
                    "TraditionalForm"], " ", 
                  FormBox[
                    SubsuperscriptBox["p", "2", "2"],
                    "TraditionalForm"]}]}], ")"}]}]], "+", 
        FractionBox[
          RowBox[{
            FormBox[
              FractionBox["1", 
                RowBox[{
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{
                              FormBox[
                                TagBox[
                                  StyleBox["\<\"k\"\>",
                                    FontSlant->"Italic"],
                                  (StyleForm[ #, FontSlant -> "Italic"]&)],
                                "TraditionalForm"], "-", 
                              SubscriptBox["p", "1"]}], ")"}], "2"], 
                        "\[InvisibleSpace]", "\<\"]\"\>"}],
                      SequenceForm[ "[", 
                        Power[ 
                          Plus[ k, 
                            Times[ -1, 
                              Subscript[ p, 1]]], 2], "]"],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{
                              FormBox[
                                TagBox[
                                  StyleBox["\<\"k\"\>",
                                    FontSlant->"Italic"],
                                  (StyleForm[ #, FontSlant -> "Italic"]&)],
                                "TraditionalForm"], "-", 
                              SubscriptBox["p", "2"]}], ")"}], "2"], 
                        "\[InvisibleSpace]", "\<\"]\"\>"}],
                      SequenceForm[ "[", 
                        Power[ 
                          Plus[ k, 
                            Times[ -1, 
                              Subscript[ p, 2]]], 2], "]"],
                      Editable->False], ")"}]}]],
              "TraditionalForm"], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  SubsuperscriptBox["p", 
                    FormBox["2",
                      "TraditionalForm"], "\[Mu]"], " ", 
                  FormBox[
                    SubsuperscriptBox["p", "1", "2"],
                    "TraditionalForm"]}], "-", 
                RowBox[{
                  SubsuperscriptBox["p", 
                    FormBox["1",
                      "TraditionalForm"], "\[Mu]"], " ", 
                  FormBox[
                    RowBox[{
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"]}],
                    "TraditionalForm"]}], "-", 
                RowBox[{
                  SubsuperscriptBox["p", 
                    FormBox["2",
                      "TraditionalForm"], "\[Mu]"], " ", 
                  FormBox[
                    RowBox[{
                      FormBox[
                        SubscriptBox["p", "1"],
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox[
                        SubscriptBox["p", "2"],
                        "TraditionalForm"]}],
                    "TraditionalForm"]}], "+", 
                RowBox[{
                  SubsuperscriptBox["p", 
                    FormBox["1",
                      "TraditionalForm"], "\[Mu]"], " ", 
                  FormBox[
                    SubsuperscriptBox["p", "2", "2"],
                    "TraditionalForm"]}]}], ")"}]}], 
          RowBox[{"2", " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  FormBox[
                    SubsuperscriptBox["p", "1", "2"],
                    "TraditionalForm"], " ", 
                  FormBox[
                    SubsuperscriptBox["p", "2", "2"],
                    "TraditionalForm"]}], "-", 
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{
                        FormBox[
                          SubscriptBox["p", "1"],
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox[
                          SubscriptBox["p", "2"],
                          "TraditionalForm"]}],
                      "TraditionalForm"], ")"}], "2"]}], ")"}]}]]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1589]=  (21:56:58 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"FAD", "[", 
          RowBox[{"k", ",", " ", 
            RowBox[{"k", " ", "-", " ", "p"}]}], "]"}], 
        RowBox[{"FVD", "[", 
          RowBox[{"k", ",", "\[Mu]"}], "]"}]}], "//", "FCI"}]], "Input",
  CellLabel->"In[1590]:=  (21:56:58 on 5/16/01)",
  CellTags->"TID"],

Cell[BoxData[
    FormBox[
      FractionBox[
        SuperscriptBox[
          FormBox[
            FormBox[
              TagBox[
                StyleBox["\<\"k\"\>",
                  FontSlant->"Italic"],
                (StyleForm[ #, FontSlant -> "Italic"]&)],
              "TraditionalForm"],
            "TraditionalForm"], 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]], 
        RowBox[{
          SuperscriptBox[
            FormBox[
              TagBox[
                StyleBox["\<\"k\"\>",
                  FontSlant->"Italic"],
                (StyleForm[ #, FontSlant -> "Italic"]&)],
              "TraditionalForm"], "2"], ".", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"], "-", "p"}], ")"}], "2"]}]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1590]=  (21:56:58 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"TID", "[", 
      RowBox[{"%", ",", "k"}], "]"}]], "Input",
  CellLabel->"In[1591]:=  (21:56:58 on 5/16/01)",
  CellTags->"TID"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          SuperscriptBox[
            FormBox["p",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], 
          RowBox[{"2", " ", 
            RowBox[{
              SuperscriptBox[
                FormBox[
                  TagBox[
                    StyleBox["\<\"k\"\>",
                      FontSlant->"Italic"],
                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                  "TraditionalForm"], "2"], ".", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    FormBox[
                      TagBox[
                        StyleBox["\<\"k\"\>",
                          FontSlant->"Italic"],
                        (StyleForm[ #, FontSlant -> "Italic"]&)],
                      "TraditionalForm"], "-", "p"}], ")"}], "2"]}]}]], "-", 
        FractionBox[
          SuperscriptBox[
            FormBox["p",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], 
          RowBox[{"2", " ", 
            SuperscriptBox[
              FormBox[
                TagBox[
                  StyleBox["\<\"k\"\>",
                    FontSlant->"Italic"],
                  (StyleForm[ #, FontSlant -> "Italic"]&)],
                "TraditionalForm"], "2"], " ", 
            SuperscriptBox[
              FormBox["p",
                "TraditionalForm"], "2"]}]], "+", 
        FractionBox[
          SuperscriptBox[
            FormBox["p",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], 
          RowBox[{"2", " ", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  FormBox[
                    TagBox[
                      StyleBox["\<\"k\"\>",
                        FontSlant->"Italic"],
                      (StyleForm[ #, FontSlant -> "Italic"]&)],
                    "TraditionalForm"], "-", "p"}], ")"}], "2"], " ", 
            SuperscriptBox[
              FormBox["p",
                "TraditionalForm"], "2"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1591]=  (21:56:59 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"TID", "[", 
      RowBox[{"%%", ",", "k", ",", 
        RowBox[{"FeynAmpDenominatorSimplify", "\[Rule]", "True"}]}], 
      "]"}]], "Input",
  CellLabel->"In[1592]:=  (21:56:59 on 5/16/01)",
  CellTags->"TID"],

Cell[BoxData[
    FormBox[
      FractionBox[
        SuperscriptBox[
          FormBox["p",
            "TraditionalForm"], 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]], 
        RowBox[{"2", " ", 
          RowBox[{
            SuperscriptBox[
              FormBox[
                TagBox[
                  StyleBox["\<\"k\"\>",
                    FontSlant->"Italic"],
                  (StyleForm[ #, FontSlant -> "Italic"]&)],
                "TraditionalForm"], "2"], ".", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  FormBox[
                    TagBox[
                      StyleBox["\<\"k\"\>",
                        FontSlant->"Italic"],
                      (StyleForm[ #, FontSlant -> "Italic"]&)],
                    "TraditionalForm"], "-", "p"}], ")"}], "2"]}]}]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1592]=  (21:56:59 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["ToDistribution", "ObjectName",
  CellTags->"ToDistribution"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"ToDistribution"],

Cell["\<\
ToDistribution[exp,x] replaces (1-x)^(a Epsilon - 1) in exp by 1/(a Epsilon) \
DeltaFunction[1-x] + 1/(1-x) + a Epsilon Log[1-x]/(1-x) + 1/2 a^2 Epsilon^2 \
Log[1-x]^2/(1-x)] and (1-x)^(a Epsilon - 2) in exp by -1/(a Epsilon) \
DeltaFunctionPrime[1-x] + 1/(1-x)^2 + (a Epsilon) Log[1-x]/(1-x)^2 + a^2 \
Epsilon^2/2 Log[1-x]^2/(1-x)^2 + a^3 Epsilon^3/6 Log[1-x]^3/(1-x)^2.\
\>", "Text",
  CellTags->"ToDistribution"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "ToDistribution", "]"}]], "Input",
  CellLabel->"In[1593]:=  (21:56:59 on 5/16/01)",
  CellTags->"ToDistribution"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"PlusDistribution", "\[Rule]", "Identity"}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1593]=  (21:56:59 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["PlusDistribution",
    ButtonData:>"PlusDistribution",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"PlusDistribution"],
  "."
}], "Text",
  CellTags->"ToDistribution"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"ToDistribution"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SetOptions", "[", 
      RowBox[{"ToDistribution", ",", 
        RowBox[{"PlusDistribution", "\[Rule]", "PlusDistribution"}]}], 
      "]"}]], "Input",
  CellLabel->"In[1594]:=  (21:56:59 on 5/16/01)",
  CellTags->"ToDistribution"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"PlusDistribution", "\[Rule]", "PlusDistribution"}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1594]=  (21:56:59 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ToDistribution", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "-", "x"}], ")"}], "^", 
          RowBox[{"(", 
            RowBox[{"Epsilon", "-", "1"}], ")"}]}], ",", "x"}], 
      "]"}]], "Input",
  CellLabel->"In[1595]:=  (21:56:59 on 5/16/01)",
  CellTags->"ToDistribution"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox["1", "6"], " ", 
          SubscriptBox[
            RowBox[{"(", 
              FractionBox[
                RowBox[{
                  SuperscriptBox["log", "3"], "(", 
                  RowBox[{"1", "-", "x"}], ")"}], 
                RowBox[{"1", "-", "x"}]], ")"}], "+"], " ", 
          SuperscriptBox[
            TagBox["\[CurlyEpsilon]",
              TraditionalForm], "3"]}], "+", 
        RowBox[{
          FractionBox["1", "2"], " ", 
          SubscriptBox[
            RowBox[{"(", 
              FractionBox[
                RowBox[{
                  SuperscriptBox["log", "2"], "(", 
                  RowBox[{"1", "-", "x"}], ")"}], 
                RowBox[{"1", "-", "x"}]], ")"}], "+"], " ", 
          SuperscriptBox[
            TagBox["\[CurlyEpsilon]",
              TraditionalForm], "2"]}], "+", 
        RowBox[{
          SubscriptBox[
            RowBox[{"(", 
              FractionBox[
                RowBox[{"log", "(", 
                  RowBox[{"1", "-", "x"}], ")"}], 
                RowBox[{"1", "-", "x"}]], ")"}], "+"], " ", 
          TagBox["\[CurlyEpsilon]",
            TraditionalForm]}], "+", 
        SubscriptBox[
          RowBox[{"(", 
            FractionBox["1", 
              RowBox[{"1", "-", "x"}]], ")"}], "+"], "+", 
        FractionBox[
          RowBox[{"\[Delta]", "(", 
            FormBox[
              RowBox[{"1", "-", "x"}],
              "TraditionalForm"], ")"}], 
          TagBox["\[CurlyEpsilon]",
            TraditionalForm]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1595]=  (21:56:59 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SetOptions", "[", 
      RowBox[{"ToDistribution", ",", 
        RowBox[{"PlusDistribution", "\[Rule]", "Identity"}]}], "]"}]], "Input",\

  CellLabel->"In[1596]:=  (21:57:00 on 5/16/01)",
  CellTags->"ToDistribution"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"PlusDistribution", "\[Rule]", "Identity"}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1596]=  (21:57:00 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ToDistribution", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "-", "x"}], ")"}], "^", 
          RowBox[{"(", 
            RowBox[{"Epsilon", "-", "2"}], ")"}]}], ",", "x"}], 
      "]"}]], "Input",
  CellLabel->"In[1597]:=  (21:57:00 on 5/16/01)",
  CellTags->"ToDistribution"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{
            SuperscriptBox[
              TagBox["\[CurlyEpsilon]",
                TraditionalForm], "3"], " ", 
            RowBox[{
              SuperscriptBox["log", "3"], "(", 
              RowBox[{"1", "-", "x"}], ")"}]}], 
          RowBox[{"6", " ", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"1", "-", "x"}], ")"}], "2"]}]], "+", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              TagBox["\[CurlyEpsilon]",
                TraditionalForm], "2"], " ", 
            RowBox[{
              SuperscriptBox["log", "2"], "(", 
              RowBox[{"1", "-", "x"}], ")"}]}], 
          RowBox[{"2", " ", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"1", "-", "x"}], ")"}], "2"]}]], "+", 
        FractionBox[
          RowBox[{
            TagBox["\[CurlyEpsilon]",
              TraditionalForm], " ", 
            RowBox[{"log", "(", 
              RowBox[{"1", "-", "x"}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"1", "-", "x"}], ")"}], "2"]], "-", 
        FractionBox[
          RowBox[{
            SuperscriptBox["\[Delta]", "\[Prime]"], "(", 
            FormBox[
              RowBox[{"1", "-", "x"}],
              "TraditionalForm"], ")"}], 
          TagBox["\[CurlyEpsilon]",
            TraditionalForm]], "+", 
        FractionBox["1", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"1", "-", "x"}], ")"}], "2"]]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1597]=  (21:57:00 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Series2", "[", 
      RowBox[{
        RowBox[{"Integrate", "[", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"1", "-", "x"}], ")"}], 
              RowBox[{"Epsilon", "-", "2"}]], ",", 
            RowBox[{"{", 
              RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", 
            RowBox[{"GenerateConditions", "\[Rule]", "False"}]}], "]"}], ",", 
        "Epsilon", ",", "3"}], "]"}]], "Input",
  CellLabel->"In[1598]:=  (21:57:00 on 5/16/01)",
  CellTags->"ToDistribution"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          SuperscriptBox[
            TagBox["\[CurlyEpsilon]",
              TraditionalForm], "3"]}], "-", 
        SuperscriptBox[
          TagBox["\[CurlyEpsilon]",
            TraditionalForm], "2"], "-", 
        TagBox["\[CurlyEpsilon]",
          TraditionalForm], "-", "1"}], TraditionalForm]], "Output",
  CellLabel->"Out[1598]=  (21:57:01 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "@", "Integrate"}]], "Input",
  CellLabel->"In[1599]:=  (21:57:01 on 5/16/01)",
  CellTags->"ToDistribution"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"Assumptions", "\[Rule]", 
            RowBox[{"{", "}"}]}], ",", 
          RowBox[{"GenerateConditions", "\[Rule]", "Automatic"}], ",", 
          RowBox[{"PrincipalValue", "\[Rule]", "False"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1599]=  (21:57:01 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Integrate2", "[", 
      RowBox[{
        RowBox[{"ToDistribution", "[", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{"1", "-", "x"}], ")"}], "^", 
              RowBox[{"(", 
                RowBox[{"Epsilon", "-", "2"}], ")"}]}], ",", "x"}], "]"}], 
        ",", 
        RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[1600]:=  (21:57:01 on 5/16/01)",
  CellTags->"ToDistribution"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          SuperscriptBox[
            TagBox["\[CurlyEpsilon]",
              TraditionalForm], "3"]}], "-", 
        SuperscriptBox[
          TagBox["\[CurlyEpsilon]",
            TraditionalForm], "2"], "-", 
        TagBox["\[CurlyEpsilon]",
          TraditionalForm], "-", "1"}], TraditionalForm]], "Output",
  CellLabel->"Out[1600]=  (21:57:01 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["ToHypergeometric", "ObjectName",
  CellTags->"ToHypergeometric"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"ToHypergeometric"],

Cell[TextData[{
  "ToHypergeometric[",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox["t", "b"], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"1", "-", "t"}], ")"}], "c"], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"t", " ", "z"}]}], ")"}], "a"]}], TraditionalForm]]],
  ", t] returns ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"b", "+", "1"}], ")"}], " ", 
          RowBox[{
            RowBox[{"\[CapitalGamma]", "(", 
              RowBox[{"c", "+", "1"}], ")"}], "/", 
            RowBox[{"\[CapitalGamma]", "(", 
              RowBox[{"b", "+", "c", "+", "2"}], ")"}]}], " ", 
          FormBox[
            RowBox[{
              SubscriptBox["\[Null]", "2"], 
              RowBox[{
                SubscriptBox["F", "1"], "(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"-", "a"}], ",", 
                    RowBox[{"b", "+", "1"}]}], ";", 
                  RowBox[{"b", "+", "c", "+", "2"}], ";", 
                  RowBox[{"-", "z"}]}], ")"}]}],
            "TraditionalForm"]}], TraditionalForm]]],
  ". Remember that Re b >0 and Re (c-b) > 0 should hold (need not be set in \
",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ")."
}], "Text",
  CellTags->"ToHypergeometric"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["HypergeometricAC",
    ButtonData:>"HypergeometricAC",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"HypergeometricAC"],
  ", ",
  ButtonBox["HypergeometricIR",
    ButtonData:>"HypergeometricIR",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"HypergeometricIR"],
  ", ",
  ButtonBox["HypergeometricSE",
    ButtonData:>"HypergeometricSE",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"HypergeometricSE"],
  "."
}], "Text",
  CellTags->"ToHypergeometric"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"ToHypergeometric"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ToHypergeometric", "[", 
      RowBox[{
        RowBox[{
          SuperscriptBox["t", "b"], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"1", "-", "t"}], ")"}], "c"], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"t", " ", "z"}]}], ")"}], "a"]}], ",", "t"}], 
      "]"}]], "Input",
  CellLabel->"In[1601]:=  (21:57:01 on 5/16/01)",
  CellTags->"ToHypergeometric"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"b", "+", "1"}], ")"}], " ", 
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"c", "+", "1"}], ")"}], " ", 
          TagBox[
            TagBox[
              RowBox[{
                RowBox[{
                  SubscriptBox["\[InvisiblePrefixScriptBase]", 
                    FormBox["2",
                      "TraditionalForm"]], 
                  SubscriptBox["F", 
                    FormBox["1",
                      "TraditionalForm"]]}], "\[InvisibleApplication]", 
                RowBox[{"(", 
                  RowBox[{
                    TagBox[
                      TagBox[
                        RowBox[{
                          TagBox[
                            RowBox[{"-", "a"}],
                            Hypergeometric2F1,
                            Editable->True], ",", 
                          TagBox[
                            RowBox[{"b", "+", "1"}],
                            Hypergeometric2F1,
                            Editable->True]}],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      TagBox[
                        TagBox[
                          RowBox[{"b", "+", "c", "+", "2"}],
                          Hypergeometric2F1,
                          Editable->True],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      RowBox[{"-", "z"}],
                      Hypergeometric2F1,
                      Editable->True]}], ")"}]}],
              InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
              Editable->False],
            Hypergeometric2F1]}], 
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"b", "+", "c", "+", "2"}], ")"}]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1601]=  (21:57:02 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ToHypergeometric", "[", 
      RowBox[{
        RowBox[{"w", " ", 
          SuperscriptBox["t", 
            RowBox[{"b", "-", "1"}]], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"1", "-", "t"}], ")"}], 
            RowBox[{"c", "-", "b", "-", "1"}]], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"1", "-", 
                RowBox[{"t", " ", "z"}]}], ")"}], 
            RowBox[{"-", "a"}]]}], ",", "t"}], "]"}]], "Input",
  CellLabel->"In[1602]:=  (21:57:02 on 5/16/01)",
  CellTags->"ToHypergeometric"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{"w", " ", 
          RowBox[{"\[CapitalGamma]", "(", "b", ")"}], " ", 
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"c", "-", "b"}], ")"}], " ", 
          TagBox[
            TagBox[
              RowBox[{
                RowBox[{
                  SubscriptBox["\[InvisiblePrefixScriptBase]", 
                    FormBox["2",
                      "TraditionalForm"]], 
                  SubscriptBox["F", 
                    FormBox["1",
                      "TraditionalForm"]]}], "\[InvisibleApplication]", 
                RowBox[{"(", 
                  RowBox[{
                    TagBox[
                      TagBox[
                        RowBox[{
                          TagBox["a",
                            Hypergeometric2F1,
                            Editable->True], ",", 
                          TagBox["b",
                            Hypergeometric2F1,
                            Editable->True]}],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      TagBox[
                        TagBox["c",
                          Hypergeometric2F1,
                          Editable->True],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox["z",
                      Hypergeometric2F1,
                      Editable->True]}], ")"}]}],
              InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
              Editable->False],
            Hypergeometric2F1]}], 
        RowBox[{"\[CapitalGamma]", "(", "c", ")"}]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1602]=  (21:57:02 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ToHypergeometric", "[", 
      RowBox[{
        RowBox[{
          SuperscriptBox["t", "b"], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"1", "-", "t"}], ")"}], "c"], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"u", "+", 
                RowBox[{"t", " ", "z"}]}], ")"}], "a"]}], ",", "t"}], 
      "]"}]], "Input",
  CellLabel->"In[1603]:=  (21:57:02 on 5/16/01)",
  CellTags->"ToHypergeometric"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{
          SuperscriptBox["u", "a"], " ", 
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"b", "+", "1"}], ")"}], " ", 
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"c", "+", "1"}], ")"}], " ", 
          TagBox[
            TagBox[
              RowBox[{
                RowBox[{
                  SubscriptBox["\[InvisiblePrefixScriptBase]", 
                    FormBox["2",
                      "TraditionalForm"]], 
                  SubscriptBox["F", 
                    FormBox["1",
                      "TraditionalForm"]]}], "\[InvisibleApplication]", 
                RowBox[{"(", 
                  RowBox[{
                    TagBox[
                      TagBox[
                        RowBox[{
                          TagBox[
                            RowBox[{"-", "a"}],
                            Hypergeometric2F1,
                            Editable->True], ",", 
                          TagBox[
                            RowBox[{"b", "+", "1"}],
                            Hypergeometric2F1,
                            Editable->True]}],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      TagBox[
                        TagBox[
                          RowBox[{"b", "+", "c", "+", "2"}],
                          Hypergeometric2F1,
                          Editable->True],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      RowBox[{"-", 
                        FractionBox["z", "u"]}],
                      Hypergeometric2F1,
                      Editable->True]}], ")"}]}],
              InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
              Editable->False],
            Hypergeometric2F1]}], 
        RowBox[{"\[CapitalGamma]", "(", 
          RowBox[{"b", "+", "c", "+", "2"}], ")"}]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1603]=  (21:57:02 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ToHypergeometric", "[", 
      RowBox[{
        RowBox[{"w", " ", 
          SuperscriptBox["t", 
            RowBox[{"b", "-", "1"}]], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"1", "-", "t"}], ")"}], 
            RowBox[{"c", "-", "b", "-", "1"}]], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"u", "-", 
                RowBox[{"t", " ", "z"}]}], ")"}], 
            RowBox[{"-", "a"}]]}], ",", "t"}], "]"}]], "Input",
  CellLabel->"In[1604]:=  (21:57:02 on 5/16/01)",
  CellTags->"ToHypergeometric"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{
          SuperscriptBox["u", 
            RowBox[{"-", "a"}]], " ", "w", " ", 
          RowBox[{"\[CapitalGamma]", "(", "b", ")"}], " ", 
          RowBox[{"\[CapitalGamma]", "(", 
            RowBox[{"c", "-", "b"}], ")"}], " ", 
          TagBox[
            TagBox[
              RowBox[{
                RowBox[{
                  SubscriptBox["\[InvisiblePrefixScriptBase]", 
                    FormBox["2",
                      "TraditionalForm"]], 
                  SubscriptBox["F", 
                    FormBox["1",
                      "TraditionalForm"]]}], "\[InvisibleApplication]", 
                RowBox[{"(", 
                  RowBox[{
                    TagBox[
                      TagBox[
                        RowBox[{
                          TagBox["a",
                            Hypergeometric2F1,
                            Editable->True], ",", 
                          TagBox["b",
                            Hypergeometric2F1,
                            Editable->True]}],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      TagBox[
                        TagBox["c",
                          Hypergeometric2F1,
                          Editable->True],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      Hypergeometric2F1,
                      Editable->False], ";", 
                    TagBox[
                      FractionBox["z", "u"],
                      Hypergeometric2F1,
                      Editable->True]}], ")"}]}],
              InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
              Editable->False],
            Hypergeometric2F1]}], 
        RowBox[{"\[CapitalGamma]", "(", "c", ")"}]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1604]=  (21:57:02 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["ToLarin", "ObjectName",
  CellTags->"ToLarin"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"ToLarin"],

Cell[TextData[{
  "ToLarin[exp] translates all ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox["\[Gamma]", "\[Mu]"], " ", 
          SuperscriptBox["\[Gamma]", "5"]}], TraditionalForm]]],
  " in exp into ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], "/", "6"}], " ", 
          SuperscriptBox["\[CurlyEpsilon]", "\[Mu]\[Nu]\[Lambda]\[Sigma]"], 
          SuperscriptBox["\[Gamma]", "\[Nu]"], " ", 
          SuperscriptBox["\[Gamma]", "\[Lambda]"], " ", 
          RowBox[{
            SuperscriptBox["\[Gamma]", "\[Sigma]"], "."}]}], 
        TraditionalForm]]]
}], "Text",
  CellTags->"ToLarin"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["Eps",
    ButtonData:>"Eps",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Eps"],
  "."
}], "Text",
  CellTags->"ToLarin"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"ToLarin"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"DiracMatrix", "[", "\[Nu]", "]"}], ".", 
      RowBox[{"DiracMatrix", "[", "\[Mu]", "]"}], ".", 
      RowBox[{"DiracMatrix", "[", "5", "]"}]}]], "Input",
  CellLabel->"In[1605]:=  (21:57:02 on 5/16/01)",
  CellTags->"ToLarin"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Nu]",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]], ".", 
        SuperscriptBox["\[Gamma]", "5"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1605]=  (21:57:02 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ToLarin", "[", "%", "]"}]], "Input",
  CellLabel->"In[1606]:=  (21:57:02 on 5/16/01)",
  CellTags->"ToLarin"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          FractionBox["1", "6"]}], " ", "\[ImaginaryI]", " ", 
        RowBox[{
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"]], ".", 
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox["du1",
                "TraditionalForm"],
              "TraditionalForm"]], ".", 
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox["du2",
                "TraditionalForm"],
              "TraditionalForm"]], ".", 
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox["du3",
                "TraditionalForm"],
              "TraditionalForm"]]}], " ", 
        SuperscriptBox["\[Epsilon]", 
          RowBox[{
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["du1",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["du2",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["du3",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1606]=  (21:57:02 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["ToTFi", "ObjectName",
  CellTags->"ToTFi"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"ToTFi"],

Cell["\<\
ToTFi[expr, q1, q2, p] translates FeynCalc 2-loop self energy type integrals \
into the TFi notatation, which can be used as input for the function \
TarcerRecurse from the TARCER package. See TFi for details on the \
conventions.\
\>", "Text",
  CellTags->"ToTFi"],

Cell[TextData[{
  "See also: ",
  ButtonBox["TFi",
    ButtonData:>"TFi",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"TFi"],
  ", ",
  ButtonBox["FromTFi",
    ButtonData:>"FromTFi",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FromTFi"],
  "."
}], "Text",
  CellTags->"ToTFi"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"ToTFi"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FAD", "[", 
      RowBox[{"q1", ",", 
        RowBox[{"q1", "-", "p"}], ",", 
        RowBox[{"{", 
          RowBox[{"q2", ",", "M"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"q2", "-", "p"}], ",", "m"}], "}"}], ",", 
        RowBox[{"q1", "-", "q2"}]}], "]"}]], "Input",
  CellLabel->"In[1607]:=  (21:57:02 on 5/16/01)",
  CellTags->"ToTFi"],

Cell[BoxData[
    FormBox[
      FractionBox["1", 
        RowBox[{
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
                SubsuperscriptBox[
                  StyleBox["\<\"q\"\>",
                    FontSlant->"Italic"], "1", "2"], 
                "\[InvisibleSpace]", "\<\"]\"\>"}],
              SequenceForm[ "[", 
                Power[ q1, 2], "]"],
              Editable->False], ")"}], " ", 
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{
                      SubscriptBox[
                        StyleBox["\<\"q\"\>",
                          FontSlant->"Italic"], "1"], "-", "p"}], ")"}], "2"],
                 "\[InvisibleSpace]", "\<\"]\"\>"}],
              SequenceForm[ "[", 
                Power[ 
                  Plus[ 
                    Times[ -1, p], q1], 2], "]"],
              Editable->False], ")"}], " ", 
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{
                      SubscriptBox[
                        StyleBox["\<\"q\"\>",
                          FontSlant->"Italic"], "1"], "-", 
                      SubscriptBox[
                        StyleBox["\<\"q\"\>",
                          FontSlant->"Italic"], "2"]}], ")"}], "2"], 
                "\[InvisibleSpace]", "\<\"]\"\>"}],
              SequenceForm[ "[", 
                Power[ 
                  Plus[ q1, 
                    Times[ -1, q2]], 2], "]"],
              Editable->False], ")"}], " ", 
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
                SubsuperscriptBox[
                  StyleBox["\<\"q\"\>",
                    FontSlant->"Italic"], "2", "2"], 
                "\[InvisibleSpace]", "\<\"-\"\>", "\[InvisibleSpace]", 
                SuperscriptBox["M", "2"], "\[InvisibleSpace]", "\<\"]\"\>"}],
              SequenceForm[ "[", 
                Power[ q2, 2], "-", 
                Power[ M, 2], "]"],
              Editable->False], ")"}], " ", 
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{
                      SubscriptBox[
                        StyleBox["\<\"q\"\>",
                          FontSlant->"Italic"], "2"], "-", "p"}], ")"}], "2"],
                 "\[InvisibleSpace]", "\<\"-\"\>", "\[InvisibleSpace]", 
                SuperscriptBox["m", "2"], "\[InvisibleSpace]", "\<\"]\"\>"}],
              SequenceForm[ "[", 
                Power[ 
                  Plus[ 
                    Times[ -1, p], q2], 2], "-", 
                Power[ m, 2], "]"],
              Editable->False], ")"}]}]], TraditionalForm]], "Output",
  CellLabel->"Out[1607]=  (21:57:02 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ToTFi", "[", 
      RowBox[{"%", ",", "q1", ",", "q2", ",", "p"}], "]"}]], "Input",
  CellLabel->"In[1608]:=  (21:57:02 on 5/16/01)",
  CellTags->"ToTFi"],

Cell[BoxData[
    FormBox[
      InterpretationBox[
        SubsuperscriptBox[
          StyleBox["F",
            SingleLetterItalics->False,
            FontWeight->"Bold"], 
          RowBox[{
            FormBox[
              RowBox[{"{", 
                RowBox[{"1", ",", "0"}], "}"}],
              "TraditionalForm"], 
            FormBox[
              RowBox[{"{", 
                RowBox[{"1", ",", "M"}], "}"}],
              "TraditionalForm"], 
            FormBox[
              RowBox[{"{", 
                RowBox[{"1", ",", "0"}], "}"}],
              "TraditionalForm"], 
            FormBox[
              RowBox[{"{", 
                RowBox[{"1", ",", "m"}], "}"}],
              "TraditionalForm"], 
            FormBox[
              RowBox[{"{", 
                RowBox[{"1", ",", "0"}], "}"}],
              "TraditionalForm"]}], 
          RowBox[{"(", 
            FormBox["D",
              "TraditionalForm"], ")"}]],
        TFi[ D, 
          SPD[ p, p], {{1, 0}, {1, M}, {1, 0}, {1, m}, {1, 0}}],
        Editable->True], TraditionalForm]], "Output",
  CellLabel->"Out[1608]=  (21:57:02 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "StandardForm"}]], "Input",
  CellLabel->"In[1609]:=  (21:57:02 on 5/16/01)",
  CellTags->"ToTFi"],

Cell[BoxData[
    RowBox[{"TFi", "[", 
      RowBox[{"D", ",", 
        RowBox[{"SPD", "[", 
          RowBox[{"p", ",", "p"}], "]"}], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"1", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"1", ",", "M"}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"1", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"1", ",", "m"}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"1", ",", "0"}], "}"}]}], "}"}]}], "]"}]], "Output",
  CellLabel->"Out[1609]//StandardForm=  (21:57:02 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"SOD", "[", "q1", "]"}], " ", 
        RowBox[{"SOD", "[", "q2", "]"}], 
        RowBox[{"FAD", "[", 
          RowBox[{"q1", ",", 
            RowBox[{"q1", "-", "p"}], ",", 
            RowBox[{"{", 
              RowBox[{"q2", ",", "M"}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{"q2", "-", "p"}], ",", "m"}], "}"}], ",", 
            RowBox[{"q1", "-", "q2"}]}], "]"}]}], "//", "FCI"}]], "Input",
  CellLabel->"In[1610]:=  (21:57:02 on 5/16/01)",
  CellTags->"ToTFi"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{
          RowBox[{
            FormBox["\[CapitalDelta]",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox[
              SubscriptBox[
                StyleBox["\<\"q\"\>",
                  FontSlant->"Italic"], "1"],
              "TraditionalForm"]}], " ", 
          RowBox[{
            FormBox["\[CapitalDelta]",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox[
              SubscriptBox[
                StyleBox["\<\"q\"\>",
                  FontSlant->"Italic"], "2"],
              "TraditionalForm"]}]}], 
        RowBox[{
          SubsuperscriptBox[
            StyleBox["\<\"q\"\>",
              FontSlant->"Italic"], "1", "2"], ".", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                SubscriptBox[
                  StyleBox["\<\"q\"\>",
                    FontSlant->"Italic"], "1"], "-", "p"}], ")"}], "2"], ".", 
          
          RowBox[{"(", 
            RowBox[{
              SubsuperscriptBox[
                StyleBox["\<\"q\"\>",
                  FontSlant->"Italic"], "2", "2"], "-", 
              SuperscriptBox["M", "2"]}], ")"}], ".", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["\<\"q\"\>",
                        FontSlant->"Italic"], "2"], "-", "p"}], ")"}], "2"], 
              "-", 
              SuperscriptBox["m", "2"]}], ")"}], ".", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                SubscriptBox[
                  StyleBox["\<\"q\"\>",
                    FontSlant->"Italic"], "1"], "-", 
                SubscriptBox[
                  StyleBox["\<\"q\"\>",
                    FontSlant->"Italic"], "2"]}], ")"}], "2"]}]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1610]=  (21:57:02 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ToTFi", "[", "%", "]"}]], "Input",
  CellLabel->"In[1611]:=  (21:57:02 on 5/16/01)",
  CellTags->"ToTFi"],

Cell[BoxData[
    FormBox[
      InterpretationBox[
        SubsuperscriptBox[
          StyleBox["F",
            SingleLetterItalics->False,
            FontWeight->"Bold"], 
          RowBox[{
            FormBox[
              RowBox[{"{", 
                RowBox[{"1", ",", "0"}], "}"}],
              "TraditionalForm"], 
            FormBox[
              RowBox[{"{", 
                RowBox[{"1", ",", "M"}], "}"}],
              "TraditionalForm"], 
            FormBox[
              RowBox[{"{", 
                RowBox[{"1", ",", "0"}], "}"}],
              "TraditionalForm"], 
            FormBox[
              RowBox[{"{", 
                RowBox[{"1", ",", "m"}], "}"}],
              "TraditionalForm"], 
            FormBox[
              RowBox[{"{", 
                RowBox[{"1", ",", "0"}], "}"}],
              "TraditionalForm"]}], 
          RowBox[{"(", 
            FormBox["D",
              "TraditionalForm"], ")", " ", "1", "1"}]],
        TFi[ D, 
          SPD[ p, p], 
          SOD[ p], {1, 1}, {{1, 0}, {1, M}, {1, 0}, {1, m}, {1, 0}}],
        Editable->True], TraditionalForm]], "Output",
  CellLabel->"Out[1611]=  (21:57:02 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "StandardForm"}]], "Input",
  CellLabel->"In[1612]:=  (21:57:02 on 5/16/01)",
  CellTags->"ToTFi"],

Cell[BoxData[
    RowBox[{"TFi", "[", 
      RowBox[{"D", ",", 
        RowBox[{"SPD", "[", 
          RowBox[{"p", ",", "p"}], "]"}], ",", 
        RowBox[{"SOD", "[", "p", "]"}], ",", 
        RowBox[{"{", 
          RowBox[{"1", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"1", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"1", ",", "M"}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"1", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"1", ",", "m"}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"1", ",", "0"}], "}"}]}], "}"}]}], "]"}]], "Output",
  CellLabel->"Out[1612]//StandardForm=  (21:57:02 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Tr", "ObjectName",
  CellTags->"Tr"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"Tr"],

Cell["\<\
Tr[exp] calculates the Dirac trace of exp. Depending on the setting of the \
option SUNTrace also a trace over SU(N) objects is performed. Tr is identical \
toDiracTrace, up to the default setting of DiracTraceEvaluate.\
\>", "Text",
  CellTags->"Tr"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "Tr", "]"}]], "Input",
  CellLabel->"In[1613]:=  (21:57:02 on 5/16/01)",
  CellTags->"Tr"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"DiracTraceEvaluate", "\[Rule]", "True"}], ",", 
          RowBox[{"Factoring", "\[Rule]", "False"}], ",", 
          RowBox[{"FeynCalcExternal", "\[Rule]", "False"}], ",", 
          RowBox[{"LeviCivitaSign", "\[Rule]", 
            RowBox[{"-", "1"}]}], ",", 
          RowBox[{"Mandelstam", "\[Rule]", 
            RowBox[{"{", "}"}]}], ",", 
          RowBox[{"PairCollect", "\[Rule]", "False"}], ",", 
          RowBox[{"Schouten", "\[Rule]", "442"}], ",", 
          RowBox[{"SUNTrace", "\[Rule]", "True"}], ",", 
          RowBox[{"TraceOfOne", "\[Rule]", "4"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1613]=  (21:57:02 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  ButtonBox["DiracSimplify",
    ButtonData:>"DiracSimplify",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracSimplify"],
  ", ",
  ButtonBox["DiracTrace",
    ButtonData:>"DiracTrace",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracTrace"],
  ", ",
  ButtonBox["FermionSpinSum",
    ButtonData:>"FermionSpinSum",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FermionSpinSum"],
  ", ",
  ButtonBox["SUNTrace",
    ButtonData:>"SUNTrace",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SUNTrace"],
  "."
}], "Text",
  CellTags->"Tr"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"Tr"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GA", "[", 
      RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}]], "Input",
  CellLabel->"In[1614]:=  (21:57:02 on 5/16/01)",
  CellTags->"Tr"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
        SuperscriptBox["\[Gamma]", "\[Nu]"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1614]=  (21:57:03 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Tr", "[", "%", "]"}]], "Input",
  CellLabel->"In[1615]:=  (21:57:03 on 5/16/01)",
  CellTags->"Tr"],

Cell[BoxData[
    FormBox[
      RowBox[{"4", " ", 
        SuperscriptBox["g", 
          RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1615]=  (21:57:03 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Tr", "[", 
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{"GSD", "[", "p", "]"}], "+", "m"}], ")"}], ".", 
        RowBox[{"GAD", "[", "\[Mu]", "]"}], ".", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"GSD", "[", "q", "]"}], "-", "m"}], ")"}], ".", 
        RowBox[{"GAD", "[", "\[Nu]", "]"}]}], "]"}]], "Input",
  CellLabel->"In[1616]:=  (21:57:03 on 5/16/01)",
  CellTags->"Tr"],

Cell[BoxData[
    FormBox[
      RowBox[{"4", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                SuperscriptBox["g", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"]}]]}], " ", 
              SuperscriptBox["m", "2"]}], "+", 
            RowBox[{
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], "+", 
            RowBox[{
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], "-", 
            RowBox[{
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}]}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1616]=  (21:57:03 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Tr", "[", 
      RowBox[{"GA", "[", 
        RowBox[{
        "\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Sigma]", ",", "5"}], 
        "]"}], "]"}]], "Input",
  CellLabel->"In[1617]:=  (21:57:03 on 5/16/01)",
  CellTags->"Tr"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", "4"}], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[Epsilon]", 
          RowBox[{
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["\[Rho]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["\[Sigma]",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1617]=  (21:57:03 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Tr", "[", 
      RowBox[{"GAD", "[", 
        RowBox[{
        "\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Sigma]", ",", "\[Tau]", 
          ",", "\[Xi]", ",", "5"}], "]"}], "]"}]], "Input",
  CellLabel->"In[1618]:=  (21:57:03 on 5/16/01)",
  CellTags->"Tr"],

Cell[BoxData[
    FormBox[
      RowBox[{"4", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"\[ImaginaryI]", " ", 
              SuperscriptBox["\[Epsilon]", 
                RowBox[{
                  FormBox[
                    FormBox["\[Xi]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Tau]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}], "-", 
            RowBox[{"\[ImaginaryI]", " ", 
              SuperscriptBox["\[Epsilon]", 
                RowBox[{
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Tau]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Xi]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}], "+", 
            RowBox[{"\[ImaginaryI]", " ", 
              SuperscriptBox["\[Epsilon]", 
                RowBox[{
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Xi]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Tau]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}], "-", 
            RowBox[{"\[ImaginaryI]", " ", 
              SuperscriptBox["\[Epsilon]", 
                RowBox[{
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Xi]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Tau]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}], "+", 
            RowBox[{"\[ImaginaryI]", " ", 
              SuperscriptBox["\[Epsilon]", 
                RowBox[{
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Xi]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Tau]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}], "+", 
            RowBox[{"\[ImaginaryI]", " ", 
              SuperscriptBox["\[Epsilon]", 
                RowBox[{
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Tau]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Xi]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}], "-", 
            RowBox[{"\[ImaginaryI]", " ", 
              SuperscriptBox["\[Epsilon]", 
                RowBox[{
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Xi]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Tau]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}], "+", 
            RowBox[{"\[ImaginaryI]", " ", 
              SuperscriptBox["\[Epsilon]", 
                RowBox[{
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Xi]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Tau]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}], "-", 
            RowBox[{"\[ImaginaryI]", " ", 
              SuperscriptBox["\[Epsilon]", 
                RowBox[{
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Xi]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Tau]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}], "-", 
            RowBox[{"\[ImaginaryI]", " ", 
              SuperscriptBox["\[Epsilon]", 
                RowBox[{
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Tau]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Xi]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}], "+", 
            RowBox[{"\[ImaginaryI]", " ", 
              SuperscriptBox["\[Epsilon]", 
                RowBox[{
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Tau]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Xi]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}], "-", 
            RowBox[{"\[ImaginaryI]", " ", 
              SuperscriptBox["\[Epsilon]", 
                RowBox[{
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Xi]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Tau]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}], "+", 
            RowBox[{"\[ImaginaryI]", " ", 
              SuperscriptBox["\[Epsilon]", 
                RowBox[{
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Xi]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Tau]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}], "-", 
            RowBox[{"\[ImaginaryI]", " ", 
              SuperscriptBox["\[Epsilon]", 
                RowBox[{
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Xi]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Tau]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}], "+", 
            RowBox[{"\[ImaginaryI]", " ", 
              SuperscriptBox["\[Epsilon]", 
                RowBox[{
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Xi]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Tau]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1618]=  (21:57:03 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData["$West"], "Input",
  CellLabel->"In[1619]:=  (21:57:03 on 5/16/01)",
  CellTags->"Tr"],

Cell[BoxData[
    FormBox["True", TraditionalForm]], "Output",
  CellLabel->"Out[1619]=  (21:57:03 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"?", "$West"}]], "Input",
  CellLabel->"In[1620]:=  (21:57:03 on 5/16/01)",
  CellTags->"Tr"],

Cell[BoxData[
    FormBox["\<\"If $West is set to True (which is the default), traces \
involving more than 4 Dirac matrices and gamma5 are calculated recursively \
according to formula (A.5) from Comp. Phys. Comm 77 (1993) 286-298, which is \
based on the Breitenlohner Maison gamma5 - scheme.\"\>", 
      TraditionalForm]], "Print"]
}, Closed]],

Cell["\<\
$West=False should be set before any calculation is done (because \
intermediate results from trace calculations are cached).\
\>", "Text",
  CellTags->"Tr"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"$West", "=", "False"}]], "Input",
  CellLabel->"In[1621]:=  (21:57:03 on 5/16/01)",
  CellTags->"Tr"],

Cell[BoxData[
    FormBox["False", TraditionalForm]], "Output",
  CellLabel->"Out[1621]=  (21:57:03 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Tr", "[", 
      RowBox[{
        RowBox[{"GAD", "[", 
          RowBox[{
            SubscriptBox["\[Nu]", "1"], ",", 
            SubscriptBox["\[Nu]", "2"], ",", 
            SubscriptBox["\[Nu]", "3"], ",", 
            SubscriptBox["\[Nu]", "4"], ",", 
            SubscriptBox["\[Nu]", "5"], ",", 
            SubscriptBox["\[Nu]", "6"]}], "]"}], ".", 
        RowBox[{"GA", "[", "5", "]"}]}], "]"}]], "Input",
  CellLabel->"In[1622]:=  (21:57:04 on 5/16/01)",
  CellTags->"Tr"],

Cell[BoxData[
    FormBox[
      RowBox[{"4", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"-", "\[ImaginaryI]"}], " ", 
              SuperscriptBox["\[Epsilon]", 
                RowBox[{
                  FormBox[
                    FormBox[
                      SubscriptBox["\[Nu]", "3"],
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox[
                      SubscriptBox["\[Nu]", "4"],
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox[
                      SubscriptBox["\[Nu]", "5"],
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox[
                      SubscriptBox["\[Nu]", "6"],
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox[
                      SubscriptBox["\[Nu]", "1"],
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox[
                      SubscriptBox["\[Nu]", "2"],
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}], "+", 
            RowBox[{"\[ImaginaryI]", " ", 
              SuperscriptBox["\[Epsilon]", 
                RowBox[{
                  FormBox[
                    FormBox[
                      SubscriptBox["\[Nu]", "2"],
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox[
                      SubscriptBox["\[Nu]", "4"],
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox[
                      SubscriptBox["\[Nu]", "5"],
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox[
                      SubscriptBox["\[Nu]", "6"],
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox[
                      SubscriptBox["\[Nu]", "1"],
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox[
                      SubscriptBox["\[Nu]", "3"],
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}], "-", 
            RowBox[{"\[ImaginaryI]", " ", 
              SuperscriptBox["\[Epsilon]", 
                RowBox[{
                  FormBox[
                    FormBox[
                      SubscriptBox["\[Nu]", "1"],
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox[
                      SubscriptBox["\[Nu]", "4"],
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox[
                      SubscriptBox["\[Nu]", "5"],
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox[
                      SubscriptBox["\[Nu]", "6"],
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox[
                      SubscriptBox["\[Nu]", "2"],
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox[
                      SubscriptBox["\[Nu]", "3"],
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}], "-", 
            RowBox[{"\[ImaginaryI]", " ", 
              SuperscriptBox["\[Epsilon]", 
                RowBox[{
                  FormBox[
                    FormBox[
                      SubscriptBox["\[Nu]", "1"],
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox[
                      SubscriptBox["\[Nu]", "2"],
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox[
                      SubscriptBox["\[Nu]", "3"],
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox[
                      SubscriptBox["\[Nu]", "6"],
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox[
                      SubscriptBox["\[Nu]", "4"],
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox[
                      SubscriptBox["\[Nu]", "5"],
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}], "+", 
            RowBox[{"\[ImaginaryI]", " ", 
              SuperscriptBox["\[Epsilon]", 
                RowBox[{
                  FormBox[
                    FormBox[
                      SubscriptBox["\[Nu]", "1"],
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox[
                      SubscriptBox["\[Nu]", "2"],
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox[
                      SubscriptBox["\[Nu]", "3"],
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox[
                      SubscriptBox["\[Nu]", "5"],
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox[
                      SubscriptBox["\[Nu]", "4"],
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox[
                      SubscriptBox["\[Nu]", "6"],
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}], "-", 
            RowBox[{"\[ImaginaryI]", " ", 
              SuperscriptBox["\[Epsilon]", 
                RowBox[{
                  FormBox[
                    FormBox[
                      SubscriptBox["\[Nu]", "1"],
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox[
                      SubscriptBox["\[Nu]", "2"],
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox[
                      SubscriptBox["\[Nu]", "3"],
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox[
                      SubscriptBox["\[Nu]", "4"],
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox[
                      SubscriptBox["\[Nu]", "5"],
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox[
                      SubscriptBox["\[Nu]", "6"],
                      "TraditionalForm"],
                    "TraditionalForm"]}]]}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1622]=  (21:57:04 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Tr", "[", 
      RowBox[{"GS", "[", 
        RowBox[{"p", ",", "q", ",", "r", ",", "s"}], "]"}], "]"}]], "Input",
  CellLabel->"In[1623]:=  (21:57:04 on 5/16/01)",
  CellTags->"Tr"],

Cell[BoxData[
    FormBox[
      RowBox[{"4", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["s",
                  "TraditionalForm"]}], " ", 
              RowBox[{
                FormBox["q",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["r",
                  "TraditionalForm"]}]}], "-", 
            RowBox[{
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["r",
                  "TraditionalForm"]}], " ", 
              RowBox[{
                FormBox["q",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["s",
                  "TraditionalForm"]}]}], "+", 
            RowBox[{
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}], " ", 
              RowBox[{
                FormBox["r",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["s",
                  "TraditionalForm"]}]}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1623]=  (21:57:04 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Tr", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"GS", "[", "p", "]"}], "+", "m"}], ")"}], ".", 
          RowBox[{"GA", "[", "\[Mu]", "]"}], ".", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"GS", "[", "q", "]"}], "+", "m"}], ")"}], ".", 
          RowBox[{"GA", "[", "\[Mu]", "]"}]}], ",", 
        RowBox[{"Factoring", "\[Rule]", "True"}]}], "]"}]], "Input",
  CellLabel->"In[1624]:=  (21:57:04 on 5/16/01)",
  CellTags->"Tr"],

Cell[BoxData[
    FormBox[
      RowBox[{"8", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"2", " ", 
              SuperscriptBox["m", "2"]}], "-", 
            RowBox[{
              FormBox["p",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox["q",
                "TraditionalForm"]}]}], ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1624]=  (21:57:04 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Tr", "[", 
      RowBox[{
        RowBox[{"GA", "[", 
          RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], ",", 
        RowBox[{"FCE", "\[Rule]", "True"}]}], "]"}]], "Input",
  CellLabel->"In[1625]:=  (21:57:04 on 5/16/01)",
  CellTags->"Tr"],

Cell[BoxData[
    FormBox[
      RowBox[{"4", " ", 
        SuperscriptBox["g", 
          RowBox[{"\[Alpha]", "\[NoBreak]", "\[Beta]"}]]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1625]=  (21:57:04 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "StandardForm"}]], "Input",
  CellLabel->"In[1626]:=  (21:57:04 on 5/16/01)",
  CellTags->"Tr"],

Cell[BoxData[
    RowBox[{"4", " ", 
      RowBox[{"MT", "[", 
        RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}]}]], "Output",
  CellLabel->"Out[1626]//StandardForm=  (21:57:04 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Tr", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"GAD", "[", "\[Mu]", "]"}], ".", 
          RowBox[{"GA", "[", "\[Alpha]", "]"}], ".", 
          RowBox[{"GA", "[", "\[Beta]", "]"}], ".", 
          RowBox[{"GAD", "[", "\[Mu]", "]"}]}], ",", 
        RowBox[{"FCE", "\[Rule]", "True"}]}], "]"}]], "Input",
  CellLabel->"In[1627]:=  (21:57:04 on 5/16/01)",
  CellTags->"Tr"],

Cell[BoxData[
    FormBox[
      RowBox[{"4", " ", "D", " ", 
        SuperscriptBox["g", 
          RowBox[{"\[Alpha]", "\[NoBreak]", "\[Beta]"}]]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1627]=  (21:57:05 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "StandardForm"}]], "Input",
  CellLabel->"In[1628]:=  (21:57:05 on 5/16/01)",
  CellTags->"Tr"],

Cell[BoxData[
    RowBox[{"4", " ", "D", " ", 
      RowBox[{"MT", "[", 
        RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}]}]], "Output",
  CellLabel->"Out[1628]//StandardForm=  (21:57:05 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["TrickMandelstam", "ObjectName",
  CellTags->"TrickMandelstam"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"TrickMandelstam"],

Cell[TextData[{
  "TrickMandelstam[expr, {s, t, u, ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["m", "1", "2"], TraditionalForm]]],
  " + ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["m", "2", "2"], TraditionalForm]]],
  "+ ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["m", "3", "2"], TraditionalForm]]],
  "+ ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["m", "4", "2"], TraditionalForm]]],
  "}] simplifies all sums in expr so that one of the Mandelstam variables s, \
t or u is eliminated by the relation s + t + u = ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["m", "1", "2"], TraditionalForm]]],
  " + ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["m", "2", "2"], TraditionalForm]]],
  "+ ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["m", "3", "2"], TraditionalForm]]],
  "+ ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["m", "4", "2"], TraditionalForm]]],
  " . The trick is that the resulting sum has the most short number of \
terms."
}], "Text",
  CellTags->"TrickMandelstam"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"TrickMandelstam"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"TrickMandelstam", "[", 
        RowBox[{
          RowBox[{
            RowBox[{"(", 
              RowBox[{"s", "+", "t", "-", "u"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"2", 
                  SubsuperscriptBox["M", "W", "2"]}], "-", "t", "-", "u"}], 
              ")"}]}], ",", 
          RowBox[{"{", 
            RowBox[{"s", ",", "t", ",", "u", ",", 
              RowBox[{"2", 
                SubsuperscriptBox["M", "W", "2"]}]}], "}"}]}], "]"}], "//", 
      "Factor2"}]], "Input",
  CellLabel->"In[1629]:=  (21:57:05 on 5/16/01)",
  CellTags->"TrickMandelstam"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", "2"}], " ", "s", " ", 
        RowBox[{"(", 
          RowBox[{"u", "-", 
            SubsuperscriptBox["M", "W", "2"]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1629]=  (21:57:05 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"TrickMandelstam", "[", 
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{"M", "^", "2"}], " ", "s"}], " ", "-", " ", 
          RowBox[{"s", "^", "2"}], " ", "+", " ", 
          RowBox[{
            RowBox[{"M", "^", "2"}], " ", "t"}], " ", "-", " ", 
          RowBox[{"s", "t"}], " ", "+", " ", 
          RowBox[{
            RowBox[{"M", "^", "2"}], " ", "u"}], " ", "-", " ", 
          RowBox[{"s", "u"}]}], ",", " ", 
        RowBox[{"{", 
          RowBox[{"s", ",", "t", ",", "u", ",", 
            RowBox[{"2", 
              RowBox[{"M", "^", "2"}]}]}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[1630]:=  (21:57:05 on 5/16/01)",
  CellTags->"TrickMandelstam"],

Cell[BoxData[
    FormBox[
      RowBox[{"2", " ", 
        SuperscriptBox["M", "2"], " ", 
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox["M", "2"], "-", "s"}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1630]=  (21:57:05 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Trick", "ObjectName",
  CellTags->"Trick"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"Trick"],

Cell["\<\
Trick[exp] performs several basic simplifications without expansion. \
Trick[exp] uses Contract, DotSimplify and SUNDeltaContract.\
\>", "Text",
  CellTags->"Trick"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["Calc",
    ButtonData:>"Calc",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Calc"],
  ", ",
  ButtonBox["Contract",
    ButtonData:>"Contract",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Contract"],
  ", ",
  ButtonBox["DiracTrick",
    ButtonData:>"DiracTrick",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracTrick"],
  ", ",
  ButtonBox["DotSimplify",
    ButtonData:>"DotSimplify",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DotSimplify"],
  ", ",
  ButtonBox["DiracTrick",
    ButtonData:>"DiracTrick",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiracTrick"],
  "."
}], "Text",
  CellTags->"Trick"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData["Examples"], "Subsubsection",
  CellTags->"Trick"],

Cell[TextData[{
  "This calculates ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox["g", 
            RowBox[{"\[Mu]", " ", "\[Nu]"}]], 
          SubscriptBox["\[Gamma]", "\[Mu]"]}], TraditionalForm]]],
  "and ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["g", "\[Nu]", "\[Nu]"], TraditionalForm]]],
  " in D dimensions."
}], "Text",
  ZeroWidthTimes->True,
  CellTags->"Trick"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Trick", "[", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{
            RowBox[{"GA", "[", "\[Mu]", "]"}], " ", 
            RowBox[{"MT", "[", 
              RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}]}], ",", " ", 
          RowBox[{"MTD", "[", 
            RowBox[{"\[Nu]", ",", "\[Nu]"}], "]"}]}], "}"}], "]"}]], "Input",
  CellLabel->"In[1631]:=  (21:57:05 on 5/16/01)",
  CellTags->"Trick"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"]], ",", "D"}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1631]=  (21:57:05 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"FV", "[", 
        RowBox[{
          RowBox[{"p", "+", "r"}], ",", "\[Mu]"}], "]"}], " ", 
      RowBox[{"MT", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], " ", 
      RowBox[{"FV", "[", 
        RowBox[{
          RowBox[{"q", "-", "p"}], ",", "\[Nu]"}], "]"}]}]], "Input",
  CellLabel->"In[1632]:=  (21:57:05 on 5/16/01)",
  CellTags->"Trick"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"(", 
          SuperscriptBox[
            RowBox[{"(", 
              FormBox[
                RowBox[{"q", "-", "p"}],
                "TraditionalForm"], ")"}], "\[Nu]"], ")"}], " ", 
        RowBox[{"(", 
          SuperscriptBox[
            RowBox[{"(", 
              FormBox[
                RowBox[{"p", "+", "r"}],
                "TraditionalForm"], ")"}], "\[Mu]"], ")"}], " ", 
        SuperscriptBox["g", 
          RowBox[{"\[Mu]", "\[NoBreak]", "\[Nu]"}]]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1632]=  (21:57:05 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Trick", "[", "%", "]"}]], "Input",
  CellLabel->"In[1633]:=  (21:57:05 on 5/16/01)",
  CellTags->"Trick"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          SuperscriptBox[
            FormBox["p",
              "TraditionalForm"], "2"]}], "+", 
        RowBox[{
          FormBox["p",
            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
          FormBox["q",
            "TraditionalForm"]}], "-", 
        RowBox[{
          FormBox["p",
            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
          FormBox["r",
            "TraditionalForm"]}], "+", 
        RowBox[{
          FormBox["q",
            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
          FormBox["r",
            "TraditionalForm"]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1633]=  (21:57:05 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Trick", "[", 
      RowBox[{"c", ".", "b", ".", "a", " ", ".", " ", 
        RowBox[{"GA", "[", "d", "]"}], ".", 
        RowBox[{"GA", "[", "e", "]"}]}], "]"}]], "Input",
  CellLabel->"In[1634]:=  (21:57:05 on 5/16/01)",
  CellTags->"Trick"],

Cell[BoxData[
    FormBox[
      RowBox[{"a", " ", "b", " ", "c", " ", 
        RowBox[{
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox["d",
                "TraditionalForm"],
              "TraditionalForm"]], ".", 
          SuperscriptBox["\[Gamma]", 
            FormBox[
              FormBox["e",
                "TraditionalForm"],
              "TraditionalForm"]]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1634]=  (21:57:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"%", "//", "FCE"}], "//", "StandardForm"}]], "Input",
  CellLabel->"In[1635]:=  (21:57:06 on 5/16/01)",
  CellTags->"Trick"],

Cell[BoxData[
    RowBox[{"a", " ", "b", " ", "c", " ", 
      RowBox[{
        RowBox[{"GA", "[", "d", "]"}], ".", 
        RowBox[{"GA", "[", "e", "]"}]}]}]], "Output",
  CellLabel->"Out[1635]//StandardForm=  (21:57:06 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Twist2GluonOperator", "ObjectName",
  CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"Twist2GluonOperator"],

Cell["\<\
Twist2GluonOperator[{p, mu, a}, {nu, b}] or Twist2GluonOperator[p, {mu, a}, \
{nu, b}] or Twist2GluonOperator[p, mu,a, nu,b] yields the 2-gluon operator (p \
is ingoing momentum corresponding to Lorentz index mu). \
Twist2GluonOperator[{p,mu,a}, {q,nu,b}, {k,la,c}] or Twist2GluonOperator[ \
p,mu,a , q,nu,b , k,la,c ] gives the 3-gluon operator. \
Twist2GluonOperator[{p,mu,a}, {q,nu,b}, {k,la,c}, {s,si,d}] or \
Twist2GluonOperator[p,mu,a , q,nu,b , k,la,c , s,si,d] yields the 4-Gluon \
operator. The dimension is determined by the option and Dimension. The \
setting of the option Polarization (unpolarized: 0; polarized: 1) determines \
whether the unpolarized or polarized feynman rule is returned. With the \
setting Explicit to False the color-structure and the (1+(-1)^OPEm) (for \
polarized: (1-(-1)^OPEm)) is extracted and the color indices are omitted in \
the arguments of Twist2GluonOperator.\
\>", "Text",
  CellTags->"Twist2GluonOperator"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["Twist2QuarkOperator",
    ButtonData:>"Twist2QuarkOperator",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Twist2QuarkOperator"],
  "."
}], "Text",
  CellTags->"Twist2GluonOperator"]
}, Closed]],

Cell[CellGroupData[{

Cell["Polarized case, zero-momentum insertion ", "Subsubsection",
  CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SetOptions", "[", 
      RowBox[{"Twist2GluonOperator", ",", " ", 
        RowBox[{"Polarization", " ", "->", " ", "1"}], ",", 
        RowBox[{"Explicit", "->", "False"}], ",", " ", 
        RowBox[{"ZeroMomentumInsertion", " ", "->", " ", "True"}]}], 
      "]"}]], "Input",
  CellLabel->"In[1636]:=  (21:57:06 on 5/16/01)",
  CellTags->"Twist2GluonOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"CouplingConstant", "\[Rule]", 
            SubscriptBox["g", "s"]}], ",", 
          RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
          RowBox[{"Polarization", "\[Rule]", "1"}], ",", 
          RowBox[{"Explicit", "\[Rule]", "False"}], ",", 
          RowBox[{"ZeroMomentumInsertion", "\[Rule]", "True"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1636]=  (21:57:06 on 5/16/01)"]
}, Closed]],

Cell["2-gluon legs", "Text",
  CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Twist2GluonOperator", "[", 
      RowBox[{"p", ",", 
        RowBox[{"{", 
          RowBox[{"\[Mu]", ",", "a"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"\[Nu]", ",", "b"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[1637]:=  (21:57:06 on 5/16/01)",
  CellTags->"Twist2GluonOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"(", 
          RowBox[{"1", "-", 
            FormBox[
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"-", "1"}], ")"}], "m"],
              "TraditionalForm"]}], ")"}], " ", 
        SubscriptBox["\[Delta]", 
          RowBox[{
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"]}]], " ", 
        RowBox[{"(", 
          RowBox[{
            SubsuperscriptBox["O", 
              RowBox[{
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"], "\[VeryThinSpace]", 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]}], "G2"], "(", 
            FormBox["p",
              "TraditionalForm"], ")"}], ")"}]}], TraditionalForm]], "Output",\

  CellLabel->"Out[1637]=  (21:57:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Twist2GluonOperator", "[", 
      RowBox[{"p", ",", 
        RowBox[{"{", 
          RowBox[{"\[Mu]", ",", "a"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"\[Nu]", ",", "b"}], "}"}], ",", 
        RowBox[{"Explicit", "->", "True"}]}], "]"}]], "Input",
  CellLabel->"In[1638]:=  (21:57:06 on 5/16/01)",
  CellTags->"Twist2GluonOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Epsilon]", 
          RowBox[{
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox["\[CapitalDelta]",
              "TraditionalForm"], "\[NoBreak]", 
            FormBox["p",
              "TraditionalForm"]}]], " ", 
        RowBox[{"(", 
          RowBox[{"1", "-", 
            FormBox[
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"-", "1"}], ")"}], "m"],
              "TraditionalForm"]}], ")"}], " ", 
        FormBox[
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["p",
                  "TraditionalForm"]}], ")"}], 
            RowBox[{"m", "-", "1"}]],
          "TraditionalForm"], " ", 
        SubscriptBox["\[Delta]", 
          RowBox[{
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1638]=  (21:57:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Twist2GluonOperator", "[", 
      RowBox[{"p", ",", 
        RowBox[{"{", "\[Mu]", "}"}], ",", 
        RowBox[{"{", "\[Nu]", "}"}]}], "]"}]], "Input",
  CellLabel->"In[1639]:=  (21:57:06 on 5/16/01)",
  CellTags->"Twist2GluonOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubsuperscriptBox["O", 
          RowBox[{
            FormBox["\[Mu]",
              "TraditionalForm"], "\[VeryThinSpace]", 
            FormBox["\[Nu]",
              "TraditionalForm"]}], "G2"], "(", 
        FormBox["p",
          "TraditionalForm"], ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[1639]=  (21:57:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Twist2GluonOperator", "[", 
      RowBox[{"p", ",", 
        RowBox[{"{", "\[Mu]", "}"}], ",", 
        RowBox[{"{", "\[Nu]", "}"}], ",", 
        RowBox[{"Explicit", "->", "True"}]}], "]"}]], "Input",
  CellLabel->"In[1640]:=  (21:57:06 on 5/16/01)",
  CellTags->"Twist2GluonOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Epsilon]", 
          RowBox[{
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox["\[CapitalDelta]",
              "TraditionalForm"], "\[NoBreak]", 
            FormBox["p",
              "TraditionalForm"]}]], " ", 
        FormBox[
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["p",
                  "TraditionalForm"]}], ")"}], 
            RowBox[{"m", "-", "1"}]],
          "TraditionalForm"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1640]=  (21:57:06 on 5/16/01)"]
}, Closed]],

Cell["3-gluon legs", "Text",
  CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Twist2GluonOperator", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"q", ",", "\[Nu]", ",", "b"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"r", ",", "\[Rho]", ",", "c"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[1641]:=  (21:57:06 on 5/16/01)",
  CellTags->"Twist2GluonOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["g", "s"], " ", 
        RowBox[{"(", 
          RowBox[{"1", "-", 
            FormBox[
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"-", "1"}], ")"}], "m"],
              "TraditionalForm"]}], ")"}], " ", 
        SubscriptBox["f", 
          RowBox[{
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["c",
                "TraditionalForm"],
              "TraditionalForm"]}]], " ", 
        RowBox[{"(", 
          RowBox[{
            SubsuperscriptBox["O", 
              RowBox[{
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"], "\[VeryThinSpace]", 
                FormBox[
                  FormBox["\[Rho]",
                    "TraditionalForm"],
                  "TraditionalForm"], "\[VeryThinSpace]", 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]}], "G3"], "(", 
            FormBox["q",
              "TraditionalForm"], ",", 
            FormBox["r",
              "TraditionalForm"], ",", 
            FormBox["p",
              "TraditionalForm"], ")"}], ")"}]}], TraditionalForm]], "Output",\

  CellLabel->"Out[1641]=  (21:57:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Twist2GluonOperator", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"p", ",", "\[Mu]"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"q", ",", "\[Nu]"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"r", ",", "\[Rho]"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[1642]:=  (21:57:06 on 5/16/01)",
  CellTags->"Twist2GluonOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubsuperscriptBox["O", 
          RowBox[{
            FormBox["\[Nu]",
              "TraditionalForm"], "\[VeryThinSpace]", 
            FormBox["\[Rho]",
              "TraditionalForm"], "\[VeryThinSpace]", 
            FormBox["\[Mu]",
              "TraditionalForm"]}], "G3"], "(", 
        FormBox["q",
          "TraditionalForm"], ",", 
        FormBox["r",
          "TraditionalForm"], ",", 
        FormBox["p",
          "TraditionalForm"], ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[1642]=  (21:57:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Twist2GluonOperator", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"p", ",", "\[Mu]"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"q", ",", "\[Nu]"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"r", ",", "\[Rho]"}], "}"}], ",", 
        RowBox[{"Explicit", "->", "True"}]}], "]"}]], "Input",
  CellLabel->"In[1643]:=  (21:57:06 on 5/16/01)",
  CellTags->"Twist2GluonOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"-", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  SuperscriptBox["\[Epsilon]", 
                    RowBox[{
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["\[Rho]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox["p",
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox["\[CapitalDelta]",
                        "TraditionalForm"]}]], " ", 
                  SuperscriptBox[
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"]]}], "-", 
                RowBox[{
                  SuperscriptBox["\[Epsilon]", 
                    RowBox[{
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox["p",
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox["\[CapitalDelta]",
                        "TraditionalForm"]}]], " ", 
                  SuperscriptBox[
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["\[Rho]",
                        "TraditionalForm"],
                      "TraditionalForm"]]}]}], ")"}]}], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["p",
                  "TraditionalForm"]}], ")"}], 
            RowBox[{"m", "-", "2"}]]}], "-", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SuperscriptBox["\[Epsilon]", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Rho]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], "+", 
              RowBox[{
                SuperscriptBox["\[Epsilon]", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}]}], ")"}], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}], ")"}], 
            RowBox[{"m", "-", "2"}]]}], "-", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SuperscriptBox["\[Epsilon]", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Rho]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["r",
                      "TraditionalForm"]}]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], "-", 
              RowBox[{
                SuperscriptBox["\[Epsilon]", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Rho]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["r",
                      "TraditionalForm"]}]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}]}], ")"}], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["r",
                  "TraditionalForm"]}], ")"}], 
            RowBox[{"m", "-", "2"}]]}], "+", 
        RowBox[{
          RowBox[{"(", 
            FormBox[
              TagBox[
                RowBox[{
                  UnderoverscriptBox["\[Sum]", 
                    RowBox[{"i", "=", "0"}], 
                    RowBox[{"m", "-", "3"}]], 
                  RowBox[{
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{"-", "1"}], ")"}], "i"], " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["p",
                            "TraditionalForm"]}], ")"}], "i"], " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["q",
                            "TraditionalForm"]}], ")"}], 
                      RowBox[{
                        RowBox[{"-", "i"}], "+", "m", "-", "3"}]]}]}],
                HoldForm],
              "TraditionalForm"], ")"}], " ", 
          SuperscriptBox[
            FormBox["\[CapitalDelta]",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Rho]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SuperscriptBox["\[Epsilon]", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], "+", 
              RowBox[{
                SuperscriptBox["\[Epsilon]", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["p",
                    "TraditionalForm"]}]}]}], ")"}]}], "-", 
        RowBox[{
          RowBox[{"(", 
            FormBox[
              TagBox[
                RowBox[{
                  UnderoverscriptBox["\[Sum]", 
                    RowBox[{"i", "=", "0"}], 
                    RowBox[{"m", "-", "3"}]], 
                  RowBox[{
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{"-", "1"}], ")"}], "i"], " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["p",
                            "TraditionalForm"]}], ")"}], "i"], " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["r",
                            "TraditionalForm"]}], ")"}], 
                      RowBox[{
                        RowBox[{"-", "i"}], "+", "m", "-", "3"}]]}]}],
                HoldForm],
              "TraditionalForm"], ")"}], " ", 
          SuperscriptBox[
            FormBox["\[CapitalDelta]",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SuperscriptBox["\[Epsilon]", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Rho]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["r",
                      "TraditionalForm"]}]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], "+", 
              RowBox[{
                SuperscriptBox["\[Epsilon]", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Rho]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["r",
                      "TraditionalForm"]}]], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["p",
                    "TraditionalForm"]}]}]}], ")"}]}], "-", 
        RowBox[{
          RowBox[{"(", 
            FormBox[
              TagBox[
                RowBox[{
                  UnderoverscriptBox["\[Sum]", 
                    RowBox[{"i", "=", "0"}], 
                    RowBox[{"m", "-", "3"}]], 
                  RowBox[{
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{"-", "1"}], ")"}], "i"], " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["q",
                            "TraditionalForm"]}], ")"}], "i"], " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["r",
                            "TraditionalForm"]}], ")"}], 
                      RowBox[{
                        RowBox[{"-", "i"}], "+", "m", "-", "3"}]]}]}],
                HoldForm],
              "TraditionalForm"], ")"}], " ", 
          SuperscriptBox[
            FormBox["\[CapitalDelta]",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SuperscriptBox["\[Epsilon]", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Rho]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["r",
                      "TraditionalForm"]}]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], "-", 
              RowBox[{
                SuperscriptBox["\[Epsilon]", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Rho]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["r",
                      "TraditionalForm"]}]], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}]}], ")"}]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1643]=  (21:57:06 on 5/16/01)"]
}, Closed]],

Cell["4-gluon legs", "Text",
  CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Twist2GluonOperator", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"q", ",", "\[Nu]", ",", "b"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"r", ",", "\[Rho]", ",", "c"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"s", ",", "\[Sigma]", ",", "d"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[1644]:=  (21:57:06 on 5/16/01)",
  CellTags->"Twist2GluonOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"(", 
          RowBox[{"1", "-", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "m"]}], ")"}], " ", 
        SubsuperscriptBox["g", "s", "2"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                SubscriptBox["f", 
                  RowBox[{
                    FormBox[
                      FormBox["a",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["b",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["c112",
                        "TraditionalForm"],
                      "TraditionalForm"]}]]}], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["c",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["c112",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["d",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              RowBox[{"(", 
                RowBox[{
                  SubsuperscriptBox["O", 
                    RowBox[{
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[VeryThinSpace]", 
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[VeryThinSpace]", 
                      FormBox[
                        FormBox["\[Rho]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[VeryThinSpace]", 
                      FormBox[
                        FormBox["\[Sigma]",
                          "TraditionalForm"],
                        "TraditionalForm"]}], "G4"], "(", 
                  FormBox["p",
                    "TraditionalForm"], ",", 
                  FormBox["q",
                    "TraditionalForm"], ",", 
                  FormBox["r",
                    "TraditionalForm"], ",", 
                  FormBox["s",
                    "TraditionalForm"], ")"}], ")"}]}], "-", 
            RowBox[{
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["a",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["c",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["c112",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["b",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["c112",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["d",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              RowBox[{"(", 
                RowBox[{
                  SubsuperscriptBox["O", 
                    RowBox[{
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[VeryThinSpace]", 
                      FormBox[
                        FormBox["\[Rho]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[VeryThinSpace]", 
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[VeryThinSpace]", 
                      FormBox[
                        FormBox["\[Sigma]",
                          "TraditionalForm"],
                        "TraditionalForm"]}], "G4"], "(", 
                  FormBox["p",
                    "TraditionalForm"], ",", 
                  FormBox["r",
                    "TraditionalForm"], ",", 
                  FormBox["q",
                    "TraditionalForm"], ",", 
                  FormBox["s",
                    "TraditionalForm"], ")"}], ")"}]}], "+", 
            RowBox[{
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["a",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["c112",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["d",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["b",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["c",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["c112",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              RowBox[{"(", 
                RowBox[{
                  SubsuperscriptBox["O", 
                    RowBox[{
                      FormBox[
                        FormBox["\[Rho]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[VeryThinSpace]", 
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[VeryThinSpace]", 
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[VeryThinSpace]", 
                      FormBox[
                        FormBox["\[Sigma]",
                          "TraditionalForm"],
                        "TraditionalForm"]}], "G4"], "(", 
                  FormBox["r",
                    "TraditionalForm"], ",", 
                  FormBox["q",
                    "TraditionalForm"], ",", 
                  FormBox["p",
                    "TraditionalForm"], ",", 
                  FormBox["s",
                    "TraditionalForm"], ")"}], ")"}]}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1644]=  (21:57:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Twist2GluonOperator", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"p", ",", "\[Mu]"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"q", ",", "\[Nu]"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"r", ",", "\[Rho]"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"s", ",", "\[Sigma]"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[1645]:=  (21:57:06 on 5/16/01)",
  CellTags->"Twist2GluonOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubsuperscriptBox["O", 
          RowBox[{
            FormBox["\[Mu]",
              "TraditionalForm"], "\[VeryThinSpace]", 
            FormBox["\[Nu]",
              "TraditionalForm"], "\[VeryThinSpace]", 
            FormBox["\[Rho]",
              "TraditionalForm"], "\[VeryThinSpace]", 
            FormBox["\[Sigma]",
              "TraditionalForm"]}], "G4"], "(", 
        FormBox["p",
          "TraditionalForm"], ",", 
        FormBox["q",
          "TraditionalForm"], ",", 
        FormBox["r",
          "TraditionalForm"], ",", 
        FormBox["s",
          "TraditionalForm"], ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[1645]=  (21:57:06 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Twist2GluonOperator", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"p", ",", "\[Mu]"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"q", ",", "\[Nu]"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"r", ",", "\[Rho]"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"s", ",", "\[Sigma]"}], "}"}], ",", 
        RowBox[{"Explicit", "->", "True"}]}], "]"}]], "Input",
  CellLabel->"In[1646]:=  (21:57:06 on 5/16/01)",
  CellTags->"Twist2GluonOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SuperscriptBox["\[Epsilon]", 
                  RowBox[{
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Rho]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Sigma]",
                        "TraditionalForm"],
                      "TraditionalForm"]}]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], "-", 
              RowBox[{
                SuperscriptBox["\[Epsilon]", 
                  RowBox[{
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Rho]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Sigma]",
                        "TraditionalForm"],
                      "TraditionalForm"]}]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}]}], ")"}], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["r",
                    "TraditionalForm"]}], "+", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["s",
                    "TraditionalForm"]}]}], ")"}], 
            RowBox[{"m", "-", "2"}]]}], "-", 
        RowBox[{
          RowBox[{"(", 
            FormBox[
              TagBox[
                RowBox[{
                  UnderoverscriptBox["\[Sum]", 
                    RowBox[{"i", "=", "0"}], 
                    RowBox[{"m", "-", "3"}]], 
                  RowBox[{
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{"-", 
                            RowBox[{"(", 
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["p",
                                  "TraditionalForm"]}], ")"}]}], "-", 
                          RowBox[{
                            FormBox["\[CapitalDelta]",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], ")"}], "i"], " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["s",
                            "TraditionalForm"]}], ")"}], 
                      RowBox[{
                        RowBox[{"-", "i"}], "+", "m", "-", "3"}]]}]}],
                HoldForm],
              "TraditionalForm"], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SuperscriptBox["\[Epsilon]", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Sigma]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["s",
                      "TraditionalForm"]}]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], "-", 
              RowBox[{
                SuperscriptBox["\[Epsilon]", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Sigma]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["s",
                      "TraditionalForm"]}]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}]}], ")"}], " ", 
          SuperscriptBox[
            FormBox["\[CapitalDelta]",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Rho]",
                "TraditionalForm"],
              "TraditionalForm"]]}], "+", 
        RowBox[{
          RowBox[{"(", 
            FormBox[
              TagBox[
                RowBox[{
                  UnderoverscriptBox["\[Sum]", 
                    RowBox[{"i", "=", "0"}], 
                    RowBox[{"m", "-", "3"}]], 
                  RowBox[{
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            FormBox["\[CapitalDelta]",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["p",
                              "TraditionalForm"]}], "+", 
                          RowBox[{
                            FormBox["\[CapitalDelta]",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], ")"}], 
                      RowBox[{
                        RowBox[{"-", "i"}], "+", "m", "-", "3"}]], " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{"-", 
                          RowBox[{"(", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["r",
                                "TraditionalForm"]}], ")"}]}], ")"}], 
                      "i"]}]}],
                HoldForm],
              "TraditionalForm"], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SuperscriptBox["\[Epsilon]", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Rho]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["r",
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"]}]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], "-", 
              RowBox[{
                SuperscriptBox["\[Epsilon]", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Rho]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["r",
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"]}]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}]}], ")"}], " ", 
          SuperscriptBox[
            FormBox["\[CapitalDelta]",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Sigma]",
                "TraditionalForm"],
              "TraditionalForm"]]}], "-", 
        RowBox[{
          RowBox[{"(", 
            FormBox[
              TagBox[
                RowBox[{
                  UnderoverscriptBox["\[Sum]", 
                    RowBox[{"i", "=", "0"}], 
                    RowBox[{"m", "-", "3"}]], 
                  RowBox[{
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{"-", 
                          RowBox[{"(", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["p",
                                "TraditionalForm"]}], ")"}]}], ")"}], "i"], 
                    " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            FormBox["\[CapitalDelta]",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["r",
                              "TraditionalForm"]}], "+", 
                          RowBox[{
                            FormBox["\[CapitalDelta]",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["s",
                              "TraditionalForm"]}]}], ")"}], 
                      RowBox[{
                        RowBox[{"-", "i"}], "+", "m", "-", "3"}]]}]}],
                HoldForm],
              "TraditionalForm"], ")"}], " ", 
          SuperscriptBox[
            FormBox["\[CapitalDelta]",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SuperscriptBox["\[Epsilon]", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Sigma]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["p",
                      "TraditionalForm"]}]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], "-", 
              RowBox[{
                SuperscriptBox["\[Epsilon]", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Rho]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["p",
                      "TraditionalForm"]}]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}]}], ")"}]}], "+", 
        RowBox[{
          RowBox[{"(", 
            FormBox[
              TagBox[
                RowBox[{
                  UnderoverscriptBox["\[Sum]", 
                    RowBox[{"i", "=", "0"}], 
                    RowBox[{"m", "-", "3"}]], 
                  RowBox[{
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{"-", 
                          RowBox[{"(", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["q",
                                "TraditionalForm"]}], ")"}]}], ")"}], "i"], 
                    " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            FormBox["\[CapitalDelta]",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["r",
                              "TraditionalForm"]}], "+", 
                          RowBox[{
                            FormBox["\[CapitalDelta]",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["s",
                              "TraditionalForm"]}]}], ")"}], 
                      RowBox[{
                        RowBox[{"-", "i"}], "+", "m", "-", "3"}]]}]}],
                HoldForm],
              "TraditionalForm"], ")"}], " ", 
          SuperscriptBox[
            FormBox["\[CapitalDelta]",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SuperscriptBox["\[Epsilon]", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Sigma]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], "-", 
              RowBox[{
                SuperscriptBox["\[Epsilon]", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Rho]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}]}], ")"}]}], "-", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              FormBox[
                TagBox[
                  RowBox[{
                    UnderoverscriptBox["\[Sum]", 
                      RowBox[{"j", "=", "0"}], 
                      RowBox[{"m", "-", "4"}]], "\<\"\"\>"}],
                  HoldForm],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                RowBox[{
                  UnderoverscriptBox["\[Sum]", 
                    RowBox[{"i", "=", "0"}], "j"], "\<\"\"\>"}],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["p",
                          "TraditionalForm"]}], ")"}], 
                    RowBox[{
                      RowBox[{"-", "j"}], "+", "m", "-", "4"}]], " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{"-", 
                          RowBox[{"(", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["r",
                                "TraditionalForm"]}], ")"}]}], "-", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["s",
                            "TraditionalForm"]}]}], ")"}], 
                    RowBox[{"j", "-", "i"}]], " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{"-", 
                        RowBox[{"(", 
                          RowBox[{
                            FormBox["\[CapitalDelta]",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["s",
                              "TraditionalForm"]}], ")"}]}], ")"}], "i"]}],
                "TraditionalForm"]}], ")"}], " ", 
          SuperscriptBox[
            FormBox["\[CapitalDelta]",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SuperscriptBox[
            FormBox["\[CapitalDelta]",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Rho]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  SuperscriptBox["\[Epsilon]", 
                    RowBox[{
                      FormBox["\[CapitalDelta]",
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["\[Sigma]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox["p",
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox["s",
                        "TraditionalForm"]}]]}], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], "-", 
              RowBox[{
                SuperscriptBox["\[Epsilon]", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Sigma]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["s",
                      "TraditionalForm"]}]], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["p",
                    "TraditionalForm"]}]}]}], ")"}]}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              FormBox[
                TagBox[
                  RowBox[{
                    UnderoverscriptBox["\[Sum]", 
                      RowBox[{"j", "=", "0"}], 
                      RowBox[{"m", "-", "4"}]], "\<\"\"\>"}],
                  HoldForm],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                RowBox[{
                  UnderoverscriptBox["\[Sum]", 
                    RowBox[{"i", "=", "0"}], "j"], "\<\"\"\>"}],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}], ")"}], 
                    RowBox[{
                      RowBox[{"-", "j"}], "+", "m", "-", "4"}]], " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{"-", 
                          RowBox[{"(", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["r",
                                "TraditionalForm"]}], ")"}]}], "-", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["s",
                            "TraditionalForm"]}]}], ")"}], 
                    RowBox[{"j", "-", "i"}]], " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{"-", 
                        RowBox[{"(", 
                          RowBox[{
                            FormBox["\[CapitalDelta]",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["s",
                              "TraditionalForm"]}], ")"}]}], ")"}], "i"]}],
                "TraditionalForm"]}], ")"}], " ", 
          SuperscriptBox[
            FormBox["\[CapitalDelta]",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SuperscriptBox[
            FormBox["\[CapitalDelta]",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Rho]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  SuperscriptBox["\[Epsilon]", 
                    RowBox[{
                      FormBox["\[CapitalDelta]",
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["\[Sigma]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox["q",
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox["s",
                        "TraditionalForm"]}]]}], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], "-", 
              RowBox[{
                SuperscriptBox["\[Epsilon]", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Sigma]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["s",
                      "TraditionalForm"]}]], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}]}], ")"}]}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              FormBox[
                TagBox[
                  RowBox[{
                    UnderoverscriptBox["\[Sum]", 
                      RowBox[{"j", "=", "0"}], 
                      RowBox[{"m", "-", "4"}]], "\<\"\"\>"}],
                  HoldForm],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                RowBox[{
                  UnderoverscriptBox["\[Sum]", 
                    RowBox[{"i", "=", "0"}], "j"], "\<\"\"\>"}],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["p",
                          "TraditionalForm"]}], ")"}], 
                    RowBox[{
                      RowBox[{"-", "j"}], "+", "m", "-", "4"}]], " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{"-", 
                        RowBox[{"(", 
                          RowBox[{
                            FormBox["\[CapitalDelta]",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["r",
                              "TraditionalForm"]}], ")"}]}], ")"}], "i"], " ",
                   
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{"-", 
                          RowBox[{"(", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["r",
                                "TraditionalForm"]}], ")"}]}], "-", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["s",
                            "TraditionalForm"]}]}], ")"}], 
                    RowBox[{"j", "-", "i"}]]}],
                "TraditionalForm"]}], ")"}], " ", 
          SuperscriptBox[
            FormBox["\[CapitalDelta]",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SuperscriptBox[
            FormBox["\[CapitalDelta]",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Sigma]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  SuperscriptBox["\[Epsilon]", 
                    RowBox[{
                      FormBox["\[CapitalDelta]",
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox["p",
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox["r",
                        "TraditionalForm"]}]]}], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], "-", 
              RowBox[{
                SuperscriptBox["\[Epsilon]", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Rho]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["p",
                      "TraditionalForm"]}]], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["r",
                    "TraditionalForm"]}]}]}], ")"}]}], "-", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              FormBox[
                TagBox[
                  RowBox[{
                    UnderoverscriptBox["\[Sum]", 
                      RowBox[{"j", "=", "0"}], 
                      RowBox[{"m", "-", "4"}]], "\<\"\"\>"}],
                  HoldForm],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                RowBox[{
                  UnderoverscriptBox["\[Sum]", 
                    RowBox[{"i", "=", "0"}], "j"], "\<\"\"\>"}],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}], ")"}], 
                    RowBox[{
                      RowBox[{"-", "j"}], "+", "m", "-", "4"}]], " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{"-", 
                        RowBox[{"(", 
                          RowBox[{
                            FormBox["\[CapitalDelta]",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["r",
                              "TraditionalForm"]}], ")"}]}], ")"}], "i"], " ",
                   
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{"-", 
                          RowBox[{"(", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["r",
                                "TraditionalForm"]}], ")"}]}], "-", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["s",
                            "TraditionalForm"]}]}], ")"}], 
                    RowBox[{"j", "-", "i"}]]}],
                "TraditionalForm"]}], ")"}], " ", 
          SuperscriptBox[
            FormBox["\[CapitalDelta]",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SuperscriptBox[
            FormBox["\[CapitalDelta]",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Sigma]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  SuperscriptBox["\[Epsilon]", 
                    RowBox[{
                      FormBox["\[CapitalDelta]",
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox["q",
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox["r",
                        "TraditionalForm"]}]]}], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], "-", 
              RowBox[{
                SuperscriptBox["\[Epsilon]", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Rho]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["r",
                    "TraditionalForm"]}]}]}], ")"}]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1646]=  (21:57:06 on 5/16/01)"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Unpolarized case, zero-momentum insertion", "Subsubsection",
  CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SetOptions", "[", 
      RowBox[{"Twist2GluonOperator", ",", 
        RowBox[{"Polarization", "\[Rule]", "0"}], ",", 
        RowBox[{"ZeroMomentumInsertion", "\[Rule]", "True"}]}], 
      "]"}]], "Input",
  CellLabel->"In[1647]:=  (21:57:07 on 5/16/01)",
  CellTags->"Twist2GluonOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"CouplingConstant", "\[Rule]", 
            SubscriptBox["g", "s"]}], ",", 
          RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
          RowBox[{"Polarization", "\[Rule]", "0"}], ",", 
          RowBox[{"Explicit", "\[Rule]", "False"}], ",", 
          RowBox[{"ZeroMomentumInsertion", "\[Rule]", "True"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1647]=  (21:57:07 on 5/16/01)"]
}, Closed]],

Cell["2-gluon legs", "Text",
  CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Twist2GluonOperator", "[", 
      RowBox[{"p", ",", 
        RowBox[{"{", 
          RowBox[{"\[Mu]", ",", "a"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"\[Nu]", ",", "b"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[1648]:=  (21:57:07 on 5/16/01)",
  CellTags->"Twist2GluonOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
          RowBox[{
            FormBox[
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"-", "1"}], ")"}], "m"],
              "TraditionalForm"], "+", "1"}], ")"}], " ", 
        SubscriptBox["\[Delta]", 
          RowBox[{
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"]}]], " ", 
        RowBox[{"(", 
          RowBox[{
            SubsuperscriptBox["O", 
              RowBox[{
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"], "\[VeryThinSpace]", 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]}], "G2"], "(", 
            FormBox["p",
              "TraditionalForm"], ")"}], ")"}]}], TraditionalForm]], "Output",\

  CellLabel->"Out[1648]=  (21:57:07 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Twist2GluonOperator", "[", 
      RowBox[{"p", ",", 
        RowBox[{"{", 
          RowBox[{"\[Mu]", ",", "a"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"\[Nu]", ",", "b"}], "}"}], ",", 
        RowBox[{"Explicit", "->", "True"}]}], "]"}]], "Input",
  CellLabel->"In[1649]:=  (21:57:07 on 5/16/01)",
  CellTags->"Twist2GluonOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  FormBox[
                    RowBox[{
                      FormBox["\[CapitalDelta]",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["p",
                        "TraditionalForm"]}],
                    "TraditionalForm"], ")"}], "2"]}], "-", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"]], " ", 
                    SuperscriptBox[
                      FormBox["\[CapitalDelta]",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"]]}], "+", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["\[CapitalDelta]",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"]], " ", 
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"]]}]}], ")"}], " ", 
              RowBox[{
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["p",
                  "TraditionalForm"]}]}], "+", 
            RowBox[{
              SuperscriptBox[
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"]}]}], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{
            FormBox[
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"-", "1"}], ")"}], "m"],
              "TraditionalForm"], "+", "1"}], ")"}], " ", 
        FormBox[
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["p",
                  "TraditionalForm"]}], ")"}], 
            RowBox[{"m", "-", "2"}]],
          "TraditionalForm"], " ", 
        SubscriptBox["\[Delta]", 
          RowBox[{
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1649]=  (21:57:07 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Twist2GluonOperator", "[", 
      RowBox[{"p", ",", 
        RowBox[{"{", "\[Mu]", "}"}], ",", 
        RowBox[{"{", "\[Nu]", "}"}]}], "]"}]], "Input",
  CellLabel->"In[1650]:=  (21:57:07 on 5/16/01)",
  CellTags->"Twist2GluonOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubsuperscriptBox["O", 
          RowBox[{
            FormBox["\[Mu]",
              "TraditionalForm"], "\[VeryThinSpace]", 
            FormBox["\[Nu]",
              "TraditionalForm"]}], "G2"], "(", 
        FormBox["p",
          "TraditionalForm"], ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[1650]=  (21:57:07 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Twist2GluonOperator", "[", 
      RowBox[{"p", ",", 
        RowBox[{"{", "\[Mu]", "}"}], ",", 
        RowBox[{"{", "\[Nu]", "}"}], ",", 
        RowBox[{"Explicit", "->", "True"}]}], "]"}]], "Input",
  CellLabel->"In[1651]:=  (21:57:07 on 5/16/01)",
  CellTags->"Twist2GluonOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  FormBox[
                    RowBox[{
                      FormBox["\[CapitalDelta]",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["p",
                        "TraditionalForm"]}],
                    "TraditionalForm"], ")"}], "2"]}], "-", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"]], " ", 
                    SuperscriptBox[
                      FormBox["\[CapitalDelta]",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"]]}], "+", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["\[CapitalDelta]",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"]], " ", 
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"]]}]}], ")"}], " ", 
              RowBox[{
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["p",
                  "TraditionalForm"]}]}], "+", 
            RowBox[{
              SuperscriptBox[
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"]}]}], ")"}], " ", 
        FormBox[
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["p",
                  "TraditionalForm"]}], ")"}], 
            RowBox[{"m", "-", "2"}]],
          "TraditionalForm"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1651]=  (21:57:07 on 5/16/01)"]
}, Closed]],

Cell["3-gluon legs", "Text",
  CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Twist2GluonOperator", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"q", ",", "\[Nu]", ",", "b"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"r", ",", "\[Rho]", ",", "c"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[1652]:=  (21:57:07 on 5/16/01)",
  CellTags->"Twist2GluonOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
        SubscriptBox["g", "s"], " ", 
        RowBox[{"(", 
          RowBox[{
            FormBox[
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"-", "1"}], ")"}], "m"],
              "TraditionalForm"], "+", "1"}], ")"}], " ", 
        SubscriptBox["f", 
          RowBox[{
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["c",
                "TraditionalForm"],
              "TraditionalForm"]}]], " ", 
        RowBox[{"(", 
          RowBox[{
            SubsuperscriptBox["O", 
              RowBox[{
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"], "\[VeryThinSpace]", 
                FormBox[
                  FormBox["\[Rho]",
                    "TraditionalForm"],
                  "TraditionalForm"], "\[VeryThinSpace]", 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]}], "G3"], "(", 
            FormBox["q",
              "TraditionalForm"], ",", 
            FormBox["r",
              "TraditionalForm"], ",", 
            FormBox["p",
              "TraditionalForm"], ")"}], ")"}]}], TraditionalForm]], "Output",\

  CellLabel->"Out[1652]=  (21:57:07 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Twist2GluonOperator", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"p", ",", "\[Mu]"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"q", ",", "\[Nu]"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"r", ",", "\[Rho]"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[1653]:=  (21:57:07 on 5/16/01)",
  CellTags->"Twist2GluonOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubsuperscriptBox["O", 
          RowBox[{
            FormBox["\[Nu]",
              "TraditionalForm"], "\[VeryThinSpace]", 
            FormBox["\[Rho]",
              "TraditionalForm"], "\[VeryThinSpace]", 
            FormBox["\[Mu]",
              "TraditionalForm"]}], "G3"], "(", 
        FormBox["q",
          "TraditionalForm"], ",", 
        FormBox["r",
          "TraditionalForm"], ",", 
        FormBox["p",
          "TraditionalForm"], ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[1653]=  (21:57:07 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Twist2GluonOperator", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"p", ",", "\[Mu]"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"q", ",", "\[Nu]"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"r", ",", "\[Rho]"}], "}"}], ",", 
        RowBox[{"Explicit", "->", "True"}]}], "]"}]], "Input",
  CellLabel->"In[1654]:=  (21:57:07 on 5/16/01)",
  CellTags->"Twist2GluonOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            FormBox[
              TagBox[
                RowBox[{
                  UnderoverscriptBox["\[Sum]", 
                    RowBox[{"i", "=", "0"}], 
                    RowBox[{"m", "-", "3"}]], 
                  RowBox[{
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{"-", 
                          RowBox[{"(", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["p",
                                "TraditionalForm"]}], ")"}]}], ")"}], "i"], 
                    " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["q",
                            "TraditionalForm"]}], ")"}], 
                      RowBox[{
                        RowBox[{"-", "i"}], "+", "m", "-", "3"}]]}]}],
                HoldForm],
              "TraditionalForm"], ")"}], " ", 
          SuperscriptBox[
            FormBox["\[CapitalDelta]",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Rho]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["p",
                    "TraditionalForm"]}]}], "-", 
              RowBox[{
                SuperscriptBox["g", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"]}]], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["p",
                    "TraditionalForm"]}]}], "+", 
              RowBox[{
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], "-", 
              RowBox[{
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}]}], ")"}]}], "+", 
        RowBox[{
          RowBox[{"(", 
            FormBox[
              TagBox[
                RowBox[{
                  UnderoverscriptBox["\[Sum]", 
                    RowBox[{"i", "=", "0"}], 
                    RowBox[{"m", "-", "3"}]], 
                  RowBox[{
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["p",
                            "TraditionalForm"]}], ")"}], 
                      RowBox[{
                        RowBox[{"-", "i"}], "+", "m", "-", "3"}]], " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{"-", 
                          RowBox[{"(", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["r",
                                "TraditionalForm"]}], ")"}]}], ")"}], 
                      "i"]}]}],
                HoldForm],
              "TraditionalForm"], ")"}], " ", 
          SuperscriptBox[
            FormBox["\[CapitalDelta]",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SuperscriptBox[
                  FormBox["r",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["p",
                    "TraditionalForm"]}]}], "-", 
              RowBox[{
                SuperscriptBox["g", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Rho]",
                        "TraditionalForm"],
                      "TraditionalForm"]}]], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["r",
                    "TraditionalForm"]}], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["p",
                    "TraditionalForm"]}]}], "+", 
              RowBox[{
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["r",
                    "TraditionalForm"]}]}], "-", 
              RowBox[{
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["r",
                    "TraditionalForm"]}]}]}], ")"}]}], "+", 
        RowBox[{
          RowBox[{"(", 
            FormBox[
              TagBox[
                RowBox[{
                  UnderoverscriptBox["\[Sum]", 
                    RowBox[{"i", "=", "0"}], 
                    RowBox[{"m", "-", "3"}]], 
                  RowBox[{
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{"-", 
                          RowBox[{"(", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["q",
                                "TraditionalForm"]}], ")"}]}], ")"}], "i"], 
                    " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["r",
                            "TraditionalForm"]}], ")"}], 
                      RowBox[{
                        RowBox[{"-", "i"}], "+", "m", "-", "3"}]]}]}],
                HoldForm],
              "TraditionalForm"], ")"}], " ", 
          SuperscriptBox[
            FormBox["\[CapitalDelta]",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SuperscriptBox[
                  FormBox["r",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], "-", 
              RowBox[{
                SuperscriptBox["g", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Rho]",
                        "TraditionalForm"],
                      "TraditionalForm"]}]], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["r",
                    "TraditionalForm"]}], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], "+", 
              RowBox[{
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["r",
                    "TraditionalForm"]}]}], "-", 
              RowBox[{
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["q",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["r",
                    "TraditionalForm"]}]}]}], ")"}]}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      SuperscriptBox[
                        FormBox["p",
                          "TraditionalForm"], 
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"]], " ", 
                      SuperscriptBox[
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], 
                        FormBox[
                          FormBox["\[Rho]",
                            "TraditionalForm"],
                          "TraditionalForm"]]}], "-", 
                    RowBox[{
                      SuperscriptBox[
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], 
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"]], " ", 
                      SuperscriptBox[
                        FormBox["p",
                          "TraditionalForm"], 
                        FormBox[
                          FormBox["\[Rho]",
                            "TraditionalForm"],
                          "TraditionalForm"]]}]}], ")"}]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      SuperscriptBox["g", 
                        RowBox[{
                          FormBox[
                            FormBox["\[Mu]",
                              "TraditionalForm"],
                            "TraditionalForm"], "\[NoBreak]", 
                          FormBox[
                            FormBox["\[Rho]",
                              "TraditionalForm"],
                            "TraditionalForm"]}]], " ", 
                      SuperscriptBox[
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], 
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"]]}], "-", 
                    RowBox[{
                      SuperscriptBox["g", 
                        RowBox[{
                          FormBox[
                            FormBox["\[Mu]",
                              "TraditionalForm"],
                            "TraditionalForm"], "\[NoBreak]", 
                          FormBox[
                            FormBox["\[Nu]",
                              "TraditionalForm"],
                            "TraditionalForm"]}]], " ", 
                      SuperscriptBox[
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], 
                        FormBox[
                          FormBox["\[Rho]",
                            "TraditionalForm"],
                          "TraditionalForm"]]}]}], ")"}], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["p",
                    "TraditionalForm"]}]}]}], ")"}], " ", 
          FormBox[
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["p",
                    "TraditionalForm"]}], ")"}], 
              RowBox[{"m", "-", "2"}]],
            "TraditionalForm"]}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      SuperscriptBox[
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], 
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"]], " ", 
                      SuperscriptBox[
                        FormBox["q",
                          "TraditionalForm"], 
                        FormBox[
                          FormBox["\[Rho]",
                            "TraditionalForm"],
                          "TraditionalForm"]]}], "-", 
                    RowBox[{
                      SuperscriptBox[
                        FormBox["q",
                          "TraditionalForm"], 
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"]], " ", 
                      SuperscriptBox[
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], 
                        FormBox[
                          FormBox["\[Rho]",
                            "TraditionalForm"],
                          "TraditionalForm"]]}]}], ")"}]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      SuperscriptBox["g", 
                        RowBox[{
                          FormBox[
                            FormBox["\[Mu]",
                              "TraditionalForm"],
                            "TraditionalForm"], "\[NoBreak]", 
                          FormBox[
                            FormBox["\[Nu]",
                              "TraditionalForm"],
                            "TraditionalForm"]}]], " ", 
                      SuperscriptBox[
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], 
                        FormBox[
                          FormBox["\[Rho]",
                            "TraditionalForm"],
                          "TraditionalForm"]]}], "-", 
                    RowBox[{
                      SuperscriptBox[
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], 
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"]], " ", 
                      SuperscriptBox["g", 
                        RowBox[{
                          FormBox[
                            FormBox["\[Nu]",
                              "TraditionalForm"],
                            "TraditionalForm"], "\[NoBreak]", 
                          FormBox[
                            FormBox["\[Rho]",
                              "TraditionalForm"],
                            "TraditionalForm"]}]]}]}], ")"}], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}]}], ")"}], " ", 
          FormBox[
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}], ")"}], 
              RowBox[{"m", "-", "2"}]],
            "TraditionalForm"]}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      SuperscriptBox[
                        FormBox["r",
                          "TraditionalForm"], 
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"]], " ", 
                      SuperscriptBox[
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], 
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"]]}], "-", 
                    RowBox[{
                      SuperscriptBox[
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], 
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"]], " ", 
                      SuperscriptBox[
                        FormBox["r",
                          "TraditionalForm"], 
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"]]}]}], ")"}], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      SuperscriptBox[
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], 
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"]], " ", 
                      SuperscriptBox["g", 
                        RowBox[{
                          FormBox[
                            FormBox["\[Nu]",
                              "TraditionalForm"],
                            "TraditionalForm"], "\[NoBreak]", 
                          FormBox[
                            FormBox["\[Rho]",
                              "TraditionalForm"],
                            "TraditionalForm"]}]]}], "-", 
                    RowBox[{
                      SuperscriptBox["g", 
                        RowBox[{
                          FormBox[
                            FormBox["\[Mu]",
                              "TraditionalForm"],
                            "TraditionalForm"], "\[NoBreak]", 
                          FormBox[
                            FormBox["\[Rho]",
                              "TraditionalForm"],
                            "TraditionalForm"]}]], " ", 
                      SuperscriptBox[
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], 
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"]]}]}], ")"}], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["r",
                    "TraditionalForm"]}]}]}], ")"}], " ", 
          FormBox[
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["r",
                    "TraditionalForm"]}], ")"}], 
              RowBox[{"m", "-", "2"}]],
            "TraditionalForm"]}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1654]=  (21:57:08 on 5/16/01)"]
}, Closed]],

Cell["4-gluon legs", "Text",
  CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Twist2GluonOperator", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"q", ",", "\[Nu]", ",", "b"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"r", ",", "\[Rho]", ",", "c"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"s", ",", "\[Sigma]", ",", "d"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[1655]:=  (21:57:08 on 5/16/01)",
  CellTags->"Twist2GluonOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
          RowBox[{"1", "+", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "m"]}], ")"}], " ", 
        SubsuperscriptBox["g", "s", "2"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                SubscriptBox["f", 
                  RowBox[{
                    FormBox[
                      FormBox["a",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["b",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["c113",
                        "TraditionalForm"],
                      "TraditionalForm"]}]]}], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["c",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["c113",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["d",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              RowBox[{"(", 
                RowBox[{
                  SubsuperscriptBox["O", 
                    RowBox[{
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[VeryThinSpace]", 
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[VeryThinSpace]", 
                      FormBox[
                        FormBox["\[Rho]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[VeryThinSpace]", 
                      FormBox[
                        FormBox["\[Sigma]",
                          "TraditionalForm"],
                        "TraditionalForm"]}], "G4"], "(", 
                  FormBox["p",
                    "TraditionalForm"], ",", 
                  FormBox["q",
                    "TraditionalForm"], ",", 
                  FormBox["r",
                    "TraditionalForm"], ",", 
                  FormBox["s",
                    "TraditionalForm"], ")"}], ")"}]}], "-", 
            RowBox[{
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["a",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["c",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["c113",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["b",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["c113",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["d",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              RowBox[{"(", 
                RowBox[{
                  SubsuperscriptBox["O", 
                    RowBox[{
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[VeryThinSpace]", 
                      FormBox[
                        FormBox["\[Rho]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[VeryThinSpace]", 
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[VeryThinSpace]", 
                      FormBox[
                        FormBox["\[Sigma]",
                          "TraditionalForm"],
                        "TraditionalForm"]}], "G4"], "(", 
                  FormBox["p",
                    "TraditionalForm"], ",", 
                  FormBox["r",
                    "TraditionalForm"], ",", 
                  FormBox["q",
                    "TraditionalForm"], ",", 
                  FormBox["s",
                    "TraditionalForm"], ")"}], ")"}]}], "+", 
            RowBox[{
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["a",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["c113",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["d",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["b",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["c",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["c113",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              RowBox[{"(", 
                RowBox[{
                  SubsuperscriptBox["O", 
                    RowBox[{
                      FormBox[
                        FormBox["\[Rho]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[VeryThinSpace]", 
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[VeryThinSpace]", 
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[VeryThinSpace]", 
                      FormBox[
                        FormBox["\[Sigma]",
                          "TraditionalForm"],
                        "TraditionalForm"]}], "G4"], "(", 
                  FormBox["r",
                    "TraditionalForm"], ",", 
                  FormBox["q",
                    "TraditionalForm"], ",", 
                  FormBox["p",
                    "TraditionalForm"], ",", 
                  FormBox["s",
                    "TraditionalForm"], ")"}], ")"}]}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1655]=  (21:57:08 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Twist2GluonOperator", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"p", ",", "\[Mu]"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"q", ",", "\[Nu]"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"r", ",", "\[Rho]"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"s", ",", "\[Sigma]"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[1656]:=  (21:57:08 on 5/16/01)",
  CellTags->"Twist2GluonOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubsuperscriptBox["O", 
          RowBox[{
            FormBox["\[Mu]",
              "TraditionalForm"], "\[VeryThinSpace]", 
            FormBox["\[Nu]",
              "TraditionalForm"], "\[VeryThinSpace]", 
            FormBox["\[Rho]",
              "TraditionalForm"], "\[VeryThinSpace]", 
            FormBox["\[Sigma]",
              "TraditionalForm"]}], "G4"], "(", 
        FormBox["p",
          "TraditionalForm"], ",", 
        FormBox["q",
          "TraditionalForm"], ",", 
        FormBox["r",
          "TraditionalForm"], ",", 
        FormBox["s",
          "TraditionalForm"], ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[1656]=  (21:57:08 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Twist2GluonOperator", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"p", ",", "\[Mu]"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"q", ",", "\[Nu]"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"r", ",", "\[Rho]"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"s", ",", "\[Sigma]"}], "}"}], ",", 
        RowBox[{"Explicit", "->", "True"}]}], "]"}]], "Input",
  CellLabel->"In[1657]:=  (21:57:08 on 5/16/01)",
  CellTags->"Twist2GluonOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox["g", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Sigma]",
                        "TraditionalForm"],
                      "TraditionalForm"]}]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], "-", 
              RowBox[{
                SuperscriptBox["g", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Sigma]",
                        "TraditionalForm"],
                      "TraditionalForm"]}]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], "-", 
              RowBox[{
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox["g", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Rho]",
                        "TraditionalForm"],
                      "TraditionalForm"]}]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], "+", 
              RowBox[{
                SuperscriptBox["g", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Rho]",
                        "TraditionalForm"],
                      "TraditionalForm"]}]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}]}], ")"}], " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["r",
                    "TraditionalForm"]}], "+", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["s",
                    "TraditionalForm"]}]}], ")"}], 
            RowBox[{"m", "-", "2"}]]}], "+", 
        RowBox[{
          RowBox[{"(", 
            FormBox[
              TagBox[
                RowBox[{
                  UnderoverscriptBox["\[Sum]", 
                    RowBox[{"i", "=", "0"}], 
                    RowBox[{"m", "-", "3"}]], 
                  RowBox[{
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{"-", 
                          RowBox[{"(", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["p",
                                "TraditionalForm"]}], ")"}]}], ")"}], "i"], 
                    " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            FormBox["\[CapitalDelta]",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["r",
                              "TraditionalForm"]}], "+", 
                          RowBox[{
                            FormBox["\[CapitalDelta]",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["s",
                              "TraditionalForm"]}]}], ")"}], 
                      RowBox[{
                        RowBox[{"-", "i"}], "+", "m", "-", "3"}]]}]}],
                HoldForm],
              "TraditionalForm"], ")"}], " ", 
          SuperscriptBox[
            FormBox["\[CapitalDelta]",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], "-", 
              RowBox[{
                SuperscriptBox["g", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Rho]",
                        "TraditionalForm"],
                      "TraditionalForm"]}]], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["p",
                    "TraditionalForm"]}], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], "-", 
              RowBox[{
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], "+", 
              RowBox[{
                SuperscriptBox["g", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Sigma]",
                        "TraditionalForm"],
                      "TraditionalForm"]}]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["p",
                    "TraditionalForm"]}]}]}], ")"}]}], "-", 
        RowBox[{
          RowBox[{"(", 
            FormBox[
              TagBox[
                RowBox[{
                  UnderoverscriptBox["\[Sum]", 
                    RowBox[{"i", "=", "0"}], 
                    RowBox[{"m", "-", "3"}]], 
                  RowBox[{
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{"-", 
                          RowBox[{"(", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["q",
                                "TraditionalForm"]}], ")"}]}], ")"}], "i"], 
                    " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            FormBox["\[CapitalDelta]",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["r",
                              "TraditionalForm"]}], "+", 
                          RowBox[{
                            FormBox["\[CapitalDelta]",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["s",
                              "TraditionalForm"]}]}], ")"}], 
                      RowBox[{
                        RowBox[{"-", "i"}], "+", "m", "-", "3"}]]}]}],
                HoldForm],
              "TraditionalForm"], ")"}], " ", 
          SuperscriptBox[
            FormBox["\[CapitalDelta]",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], "-", 
              RowBox[{
                SuperscriptBox["g", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Rho]",
                        "TraditionalForm"],
                      "TraditionalForm"]}]], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], "-", 
              RowBox[{
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], "+", 
              RowBox[{
                SuperscriptBox["g", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Sigma]",
                        "TraditionalForm"],
                      "TraditionalForm"]}]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}]}], ")"}]}], "+", 
        RowBox[{
          RowBox[{"(", 
            FormBox[
              TagBox[
                RowBox[{
                  UnderoverscriptBox["\[Sum]", 
                    RowBox[{"i", "=", "0"}], 
                    RowBox[{"m", "-", "3"}]], 
                  RowBox[{
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            FormBox["\[CapitalDelta]",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["p",
                              "TraditionalForm"]}], "+", 
                          RowBox[{
                            FormBox["\[CapitalDelta]",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], ")"}], 
                      RowBox[{
                        RowBox[{"-", "i"}], "+", "m", "-", "3"}]], " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{"-", 
                          RowBox[{"(", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["r",
                                "TraditionalForm"]}], ")"}]}], ")"}], 
                      "i"]}]}],
                HoldForm],
              "TraditionalForm"], ")"}], " ", 
          SuperscriptBox[
            FormBox["\[CapitalDelta]",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Sigma]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SuperscriptBox[
                  FormBox["r",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], "-", 
              RowBox[{
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["r",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], "+", 
              RowBox[{
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox["g", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Rho]",
                        "TraditionalForm"],
                      "TraditionalForm"]}]], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["r",
                    "TraditionalForm"]}]}], "-", 
              RowBox[{
                SuperscriptBox["g", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Rho]",
                        "TraditionalForm"],
                      "TraditionalForm"]}]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["r",
                    "TraditionalForm"]}]}]}], ")"}]}], "+", 
        RowBox[{
          RowBox[{"(", 
            FormBox[
              TagBox[
                RowBox[{
                  UnderoverscriptBox["\[Sum]", 
                    RowBox[{"i", "=", "0"}], 
                    RowBox[{"m", "-", "3"}]], 
                  RowBox[{
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{"-", 
                            RowBox[{"(", 
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["p",
                                  "TraditionalForm"]}], ")"}]}], "-", 
                          RowBox[{
                            FormBox["\[CapitalDelta]",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], ")"}], "i"], " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["s",
                            "TraditionalForm"]}], ")"}], 
                      RowBox[{
                        RowBox[{"-", "i"}], "+", "m", "-", "3"}]]}]}],
                HoldForm],
              "TraditionalForm"], ")"}], " ", 
          SuperscriptBox[
            FormBox["\[CapitalDelta]",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Rho]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SuperscriptBox[
                  FormBox["s",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], "-", 
              RowBox[{
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["s",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], "+", 
              RowBox[{
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox["g", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Sigma]",
                        "TraditionalForm"],
                      "TraditionalForm"]}]], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["s",
                    "TraditionalForm"]}]}], "-", 
              RowBox[{
                SuperscriptBox["g", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Sigma]",
                        "TraditionalForm"],
                      "TraditionalForm"]}]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["s",
                    "TraditionalForm"]}]}]}], ")"}]}], "-", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              FormBox[
                TagBox[
                  RowBox[{
                    UnderoverscriptBox["\[Sum]", 
                      RowBox[{"j", "=", "0"}], 
                      RowBox[{"m", "-", "4"}]], "\<\"\"\>"}],
                  HoldForm],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                RowBox[{
                  UnderoverscriptBox["\[Sum]", 
                    RowBox[{"i", "=", "0"}], "j"], "\<\"\"\>"}],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["p",
                          "TraditionalForm"]}], ")"}], 
                    RowBox[{
                      RowBox[{"-", "j"}], "+", "m", "-", "4"}]], " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{"-", 
                        RowBox[{"(", 
                          RowBox[{
                            FormBox["\[CapitalDelta]",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["r",
                              "TraditionalForm"]}], ")"}]}], ")"}], "i"], " ",
                   
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{"-", 
                          RowBox[{"(", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["r",
                                "TraditionalForm"]}], ")"}]}], "-", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["s",
                            "TraditionalForm"]}]}], ")"}], 
                    RowBox[{"j", "-", "i"}]]}],
                "TraditionalForm"]}], ")"}], " ", 
          SuperscriptBox[
            FormBox["\[CapitalDelta]",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SuperscriptBox[
            FormBox["\[CapitalDelta]",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Sigma]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  SuperscriptBox[
                    FormBox["r",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"]]}], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["p",
                    "TraditionalForm"]}]}], "+", 
              RowBox[{
                SuperscriptBox["g", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Rho]",
                        "TraditionalForm"],
                      "TraditionalForm"]}]], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["r",
                    "TraditionalForm"]}], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["p",
                    "TraditionalForm"]}]}], "-", 
              RowBox[{
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["r",
                    "TraditionalForm"]}]}], "+", 
              RowBox[{
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["r",
                    "TraditionalForm"]}]}]}], ")"}]}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              FormBox[
                TagBox[
                  RowBox[{
                    UnderoverscriptBox["\[Sum]", 
                      RowBox[{"j", "=", "0"}], 
                      RowBox[{"m", "-", "4"}]], "\<\"\"\>"}],
                  HoldForm],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                RowBox[{
                  UnderoverscriptBox["\[Sum]", 
                    RowBox[{"i", "=", "0"}], "j"], "\<\"\"\>"}],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["p",
                          "TraditionalForm"]}], ")"}], 
                    RowBox[{
                      RowBox[{"-", "j"}], "+", "m", "-", "4"}]], " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{"-", 
                          RowBox[{"(", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["r",
                                "TraditionalForm"]}], ")"}]}], "-", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["s",
                            "TraditionalForm"]}]}], ")"}], 
                    RowBox[{"j", "-", "i"}]], " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{"-", 
                        RowBox[{"(", 
                          RowBox[{
                            FormBox["\[CapitalDelta]",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["s",
                              "TraditionalForm"]}], ")"}]}], ")"}], "i"]}],
                "TraditionalForm"]}], ")"}], " ", 
          SuperscriptBox[
            FormBox["\[CapitalDelta]",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SuperscriptBox[
            FormBox["\[CapitalDelta]",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Rho]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  SuperscriptBox[
                    FormBox["s",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"]]}], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["p",
                    "TraditionalForm"]}]}], "+", 
              RowBox[{
                SuperscriptBox["g", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Sigma]",
                        "TraditionalForm"],
                      "TraditionalForm"]}]], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["s",
                    "TraditionalForm"]}], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["p",
                    "TraditionalForm"]}]}], "-", 
              RowBox[{
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["s",
                    "TraditionalForm"]}]}], "+", 
              RowBox[{
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["s",
                    "TraditionalForm"]}]}]}], ")"}]}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              FormBox[
                TagBox[
                  RowBox[{
                    UnderoverscriptBox["\[Sum]", 
                      RowBox[{"j", "=", "0"}], 
                      RowBox[{"m", "-", "4"}]], "\<\"\"\>"}],
                  HoldForm],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                RowBox[{
                  UnderoverscriptBox["\[Sum]", 
                    RowBox[{"i", "=", "0"}], "j"], "\<\"\"\>"}],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}], ")"}], 
                    RowBox[{
                      RowBox[{"-", "j"}], "+", "m", "-", "4"}]], " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{"-", 
                        RowBox[{"(", 
                          RowBox[{
                            FormBox["\[CapitalDelta]",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["r",
                              "TraditionalForm"]}], ")"}]}], ")"}], "i"], " ",
                   
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{"-", 
                          RowBox[{"(", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["r",
                                "TraditionalForm"]}], ")"}]}], "-", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["s",
                            "TraditionalForm"]}]}], ")"}], 
                    RowBox[{"j", "-", "i"}]]}],
                "TraditionalForm"]}], ")"}], " ", 
          SuperscriptBox[
            FormBox["\[CapitalDelta]",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SuperscriptBox[
            FormBox["\[CapitalDelta]",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Sigma]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  SuperscriptBox[
                    FormBox["r",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"]]}], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], "+", 
              RowBox[{
                SuperscriptBox["g", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Rho]",
                        "TraditionalForm"],
                      "TraditionalForm"]}]], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["r",
                    "TraditionalForm"]}], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], "-", 
              RowBox[{
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["r",
                    "TraditionalForm"]}]}], "+", 
              RowBox[{
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["q",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["r",
                    "TraditionalForm"]}]}]}], ")"}]}], "-", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              FormBox[
                TagBox[
                  RowBox[{
                    UnderoverscriptBox["\[Sum]", 
                      RowBox[{"j", "=", "0"}], 
                      RowBox[{"m", "-", "4"}]], "\<\"\"\>"}],
                  HoldForm],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                RowBox[{
                  UnderoverscriptBox["\[Sum]", 
                    RowBox[{"i", "=", "0"}], "j"], "\<\"\"\>"}],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}], ")"}], 
                    RowBox[{
                      RowBox[{"-", "j"}], "+", "m", "-", "4"}]], " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{"-", 
                          RowBox[{"(", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["r",
                                "TraditionalForm"]}], ")"}]}], "-", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["s",
                            "TraditionalForm"]}]}], ")"}], 
                    RowBox[{"j", "-", "i"}]], " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{"-", 
                        RowBox[{"(", 
                          RowBox[{
                            FormBox["\[CapitalDelta]",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["s",
                              "TraditionalForm"]}], ")"}]}], ")"}], "i"]}],
                "TraditionalForm"]}], ")"}], " ", 
          SuperscriptBox[
            FormBox["\[CapitalDelta]",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          SuperscriptBox[
            FormBox["\[CapitalDelta]",
              "TraditionalForm"], 
            FormBox[
              FormBox["\[Rho]",
                "TraditionalForm"],
              "TraditionalForm"]], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  SuperscriptBox[
                    FormBox["s",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"]]}], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], "+", 
              RowBox[{
                SuperscriptBox["g", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Sigma]",
                        "TraditionalForm"],
                      "TraditionalForm"]}]], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["s",
                    "TraditionalForm"]}], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], "-", 
              RowBox[{
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["s",
                    "TraditionalForm"]}]}], "+", 
              RowBox[{
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Sigma]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["q",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["s",
                    "TraditionalForm"]}]}]}], ")"}]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1657]=  (21:57:08 on 5/16/01)"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Advanced Examples", "Subsubsection",
  CellTags->"Twist2GluonOperator"],

Cell["The setting All for Explicit performs the sums.", "Text",
  CellTags->"Twist2GluonOperator"],

Cell[BoxData[
    RowBox[{
      RowBox[{"SetOptions", "[", 
        RowBox[{"Twist2GluonOperator", ",", " ", 
          RowBox[{"Polarization", " ", "->", " ", "1"}], ",", " ", 
          RowBox[{"Explicit", "->", "All"}]}], "]"}], ";"}]], "Input",
  CellLabel->"In[1658]:=  (21:57:09 on 5/16/01)",
  CellTags->"Twist2GluonOperator"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Twist2GluonOperator", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{"q", ",", "\[Nu]", ",", "b"}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{"r", ",", "\[Rho]", ",", "c"}], "}"}]}], "]"}], 
      ";"}]], "Input",
  CellLabel->"In[1659]:=  (21:57:09 on 5/16/01)",
  CellTags->"Twist2GluonOperator"]
}, Closed]],

Cell[CellGroupData[{

Cell["Polarized case, non-zero-momentum insertion", "Subsubsection",
  CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SetOptions", "[", 
      RowBox[{"Twist2GluonOperator", ",", " ", 
        RowBox[{"Polarization", " ", "->", " ", "1"}], ",", 
        RowBox[{"ZeroMomentumInsertion", "->", "False"}]}], "]"}]], "Input",
  CellLabel->"In[1660]:=  (21:57:09 on 5/16/01)",
  CellTags->"Twist2GluonOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"CouplingConstant", "\[Rule]", 
            SubscriptBox["g", "s"]}], ",", 
          RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
          RowBox[{"Polarization", "\[Rule]", "1"}], ",", 
          RowBox[{"Explicit", "\[Rule]", "All"}], ",", 
          RowBox[{"ZeroMomentumInsertion", "\[Rule]", "False"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1660]=  (21:57:09 on 5/16/01)"]
}, Closed]],

Cell["2-gluon legs", "Text",
  CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Twist2GluonOperator", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"p", ",", "q"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"\[Mu]", ",", "a"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"\[Nu]", ",", "b"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[1661]:=  (21:57:09 on 5/16/01)",
  CellTags->"Twist2GluonOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
        RowBox[{"(", 
          RowBox[{"1", "-", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "m"]}], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox["\[Epsilon]", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox[
                      FormBox["\[CapitalDelta]",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"]]}], "-", 
                  RowBox[{
                    SuperscriptBox["\[Epsilon]", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]], " ", 
                    RowBox[{
                      FormBox["\[CapitalDelta]",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["p",
                        "TraditionalForm"]}]}]}], ")"}], " ", 
              FormBox[
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{
                      FormBox["\[CapitalDelta]",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["p",
                        "TraditionalForm"]}], ")"}], 
                  RowBox[{"m", "-", "2"}]],
                "TraditionalForm"]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox["\[Epsilon]", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox["p",
                          "TraditionalForm"]}]], " ", 
                    RowBox[{
                      FormBox["\[CapitalDelta]",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["q",
                        "TraditionalForm"]}]}], "-", 
                  RowBox[{
                    SuperscriptBox["\[Epsilon]", 
                      RowBox[{
                        FormBox[
                          FormBox["\[Mu]",
                            "TraditionalForm"],
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]], " ", 
                    SuperscriptBox[
                      FormBox["\[CapitalDelta]",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"]]}]}], ")"}], " ", 
              FormBox[
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{
                      FormBox["\[CapitalDelta]",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["q",
                        "TraditionalForm"]}], ")"}], 
                  RowBox[{"m", "-", "2"}]],
                "TraditionalForm"]}]}], ")"}], " ", 
        SubscriptBox["\[Delta]", 
          RowBox[{
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1661]=  (21:57:09 on 5/16/01)"]
}, Closed]],

Cell["3-gluon legs", "Text",
  CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Twist2GluonOperator", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"q", ",", "\[Nu]", ",", "b"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"r", ",", "\[Rho]", ",", "c"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[1662]:=  (21:57:09 on 5/16/01)",
  CellTags->"Twist2GluonOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["g", "s"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                SuperscriptBox["\[Epsilon]", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Rho]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["p",
                      "TraditionalForm"]}]]}], " ", 
              SuperscriptBox[
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["p",
                      "TraditionalForm"]}], ")"}], 
                RowBox[{"m", "-", "2"}]]}], "+", 
            RowBox[{
              SuperscriptBox["\[Epsilon]", 
                RowBox[{
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox[
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}], ")"}], 
                RowBox[{"m", "-", "2"}]]}], "-", 
            RowBox[{
              SuperscriptBox["\[Epsilon]", 
                RowBox[{
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox["r",
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox[
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Rho]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["r",
                      "TraditionalForm"]}], ")"}], 
                RowBox[{"m", "-", "2"}]]}], "-", 
            RowBox[{
              SuperscriptBox["\[Epsilon]", 
                RowBox[{
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox["r",
                    "TraditionalForm"]}]], " ", 
              RowBox[{"(", 
                FormBox[
                  TagBox[
                    RowBox[{
                      UnderoverscriptBox["\[Sum]", 
                        RowBox[{"i", "=", "0"}], 
                        RowBox[{"m", "-", "3"}]], 
                      RowBox[{
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["p",
                                "TraditionalForm"]}], ")"}], 
                          RowBox[{
                            RowBox[{"-", "i"}], "+", "m", "-", "3"}]], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["p",
                                  "TraditionalForm"]}], "+", 
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["q",
                                  "TraditionalForm"]}]}], ")"}], "i"]}]}],
                    HoldForm],
                  "TraditionalForm"], ")"}], " ", 
              SuperscriptBox[
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], "+", 
            RowBox[{
              SuperscriptBox["\[Epsilon]", 
                RowBox[{
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox["r",
                    "TraditionalForm"]}]], " ", 
              RowBox[{"(", 
                FormBox[
                  TagBox[
                    RowBox[{
                      UnderoverscriptBox["\[Sum]", 
                        RowBox[{"i", "=", "0"}], 
                        RowBox[{"m", "-", "3"}]], 
                      RowBox[{
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["q",
                                "TraditionalForm"]}], ")"}], 
                          RowBox[{
                            RowBox[{"-", "i"}], "+", "m", "-", "3"}]], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["p",
                                  "TraditionalForm"]}], "+", 
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["q",
                                  "TraditionalForm"]}]}], ")"}], "i"]}]}],
                    HoldForm],
                  "TraditionalForm"], ")"}], " ", 
              SuperscriptBox[
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], "+", 
            RowBox[{
              SuperscriptBox["\[Epsilon]", 
                RowBox[{
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]], " ", 
              RowBox[{"(", 
                FormBox[
                  TagBox[
                    RowBox[{
                      UnderoverscriptBox["\[Sum]", 
                        RowBox[{"i", "=", "0"}], 
                        RowBox[{"m", "-", "3"}]], 
                      RowBox[{
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["p",
                                "TraditionalForm"]}], ")"}], 
                          RowBox[{
                            RowBox[{"-", "i"}], "+", "m", "-", "3"}]], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["p",
                                  "TraditionalForm"]}], "+", 
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["r",
                                  "TraditionalForm"]}]}], ")"}], "i"]}]}],
                    HoldForm],
                  "TraditionalForm"], ")"}], " ", 
              SuperscriptBox[
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Rho]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], "+", 
            RowBox[{
              SuperscriptBox["\[Epsilon]", 
                RowBox[{
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox["r",
                    "TraditionalForm"]}]], " ", 
              RowBox[{"(", 
                FormBox[
                  TagBox[
                    RowBox[{
                      UnderoverscriptBox["\[Sum]", 
                        RowBox[{"i", "=", "0"}], 
                        RowBox[{"m", "-", "3"}]], 
                      RowBox[{
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["r",
                                "TraditionalForm"]}], ")"}], 
                          RowBox[{
                            RowBox[{"-", "i"}], "+", "m", "-", "3"}]], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["p",
                                  "TraditionalForm"]}], "+", 
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["r",
                                  "TraditionalForm"]}]}], ")"}], "i"]}]}],
                    HoldForm],
                  "TraditionalForm"], ")"}], " ", 
              SuperscriptBox[
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Rho]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], "+", 
            RowBox[{
              SuperscriptBox["\[Epsilon]", 
                RowBox[{
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]], " ", 
              RowBox[{"(", 
                FormBox[
                  TagBox[
                    RowBox[{
                      UnderoverscriptBox["\[Sum]", 
                        RowBox[{"i", "=", "0"}], 
                        RowBox[{"m", "-", "3"}]], 
                      RowBox[{
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["q",
                                "TraditionalForm"]}], ")"}], 
                          RowBox[{
                            RowBox[{"-", "i"}], "+", "m", "-", "3"}]], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["q",
                                  "TraditionalForm"]}], "+", 
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["r",
                                  "TraditionalForm"]}]}], ")"}], "i"]}]}],
                    HoldForm],
                  "TraditionalForm"], ")"}], " ", 
              SuperscriptBox[
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Rho]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], "-", 
            RowBox[{
              SuperscriptBox["\[Epsilon]", 
                RowBox[{
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox["r",
                    "TraditionalForm"]}]], " ", 
              RowBox[{"(", 
                FormBox[
                  TagBox[
                    RowBox[{
                      UnderoverscriptBox["\[Sum]", 
                        RowBox[{"i", "=", "0"}], 
                        RowBox[{"m", "-", "3"}]], 
                      RowBox[{
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["r",
                                "TraditionalForm"]}], ")"}], 
                          RowBox[{
                            RowBox[{"-", "i"}], "+", "m", "-", "3"}]], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["q",
                                  "TraditionalForm"]}], "+", 
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["r",
                                  "TraditionalForm"]}]}], ")"}], "i"]}]}],
                    HoldForm],
                  "TraditionalForm"], ")"}], " ", 
              SuperscriptBox[
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Rho]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], "+", 
            RowBox[{
              FractionBox["1", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["p",
                          "TraditionalForm"]}], "+", 
                      RowBox[{
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], ")"}], "2"]], 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox["\[Epsilon]", 
                    RowBox[{
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["\[Rho]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox["\[CapitalDelta]",
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox["r",
                        "TraditionalForm"]}]], " ", 
                  SuperscriptBox[
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"]], " ", 
                  RowBox[{"(", 
                    RowBox[{
                      SuperscriptBox[
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["p",
                                "TraditionalForm"]}], "+", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["q",
                                "TraditionalForm"]}]}], ")"}], "m"], "+", 
                      RowBox[{
                        RowBox[{"(", 
                          FormBox[
                            TagBox[
                              RowBox[{
                                UnderoverscriptBox["\[Sum]", 
                                  RowBox[{"i", "=", "0"}], 
                                  RowBox[{"m", "-", "3"}]], 
                                RowBox[{
                                  SuperscriptBox[
                                    RowBox[{"(", 
                                      RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["p",
                                        "TraditionalForm"]}], ")"}], 
                                    RowBox[{
                                      RowBox[{"-", "i"}], "+", "m", "-", 
                                      "3"}]], " ", 
                                  SuperscriptBox[
                                    RowBox[{"(", 
                                      RowBox[{
                                        RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["p",
                                        "TraditionalForm"]}], "+", 
                                        RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["q",
                                        "TraditionalForm"]}]}], ")"}], 
                                    "i"]}]}],
                              HoldForm],
                            "TraditionalForm"], ")"}], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            FormBox[
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["p",
                                  "TraditionalForm"]}],
                              "TraditionalForm"], ")"}], "3"]}], "+", 
                      RowBox[{
                        RowBox[{"(", 
                          FormBox[
                            TagBox[
                              RowBox[{
                                UnderoverscriptBox["\[Sum]", 
                                  RowBox[{"i", "=", "0"}], 
                                  RowBox[{"m", "-", "3"}]], 
                                RowBox[{
                                  SuperscriptBox[
                                    RowBox[{"(", 
                                      RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["p",
                                        "TraditionalForm"]}], ")"}], 
                                    RowBox[{
                                      RowBox[{"-", "i"}], "+", "m", "-", 
                                      "3"}]], " ", 
                                  SuperscriptBox[
                                    RowBox[{"(", 
                                      RowBox[{
                                        RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["p",
                                        "TraditionalForm"]}], "+", 
                                        RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["q",
                                        "TraditionalForm"]}]}], ")"}], 
                                    "i"]}]}],
                              HoldForm],
                            "TraditionalForm"], ")"}], " ", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["p",
                            "TraditionalForm"]}], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            FormBox[
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["q",
                                  "TraditionalForm"]}],
                              "TraditionalForm"], ")"}], "2"]}], "+", 
                      RowBox[{"2", " ", 
                        RowBox[{"(", 
                          FormBox[
                            TagBox[
                              RowBox[{
                                UnderoverscriptBox["\[Sum]", 
                                  RowBox[{"i", "=", "0"}], 
                                  RowBox[{"m", "-", "3"}]], 
                                RowBox[{
                                  SuperscriptBox[
                                    RowBox[{"(", 
                                      RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["p",
                                        "TraditionalForm"]}], ")"}], 
                                    RowBox[{
                                      RowBox[{"-", "i"}], "+", "m", "-", 
                                      "3"}]], " ", 
                                  SuperscriptBox[
                                    RowBox[{"(", 
                                      RowBox[{
                                        RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["p",
                                        "TraditionalForm"]}], "+", 
                                        RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["q",
                                        "TraditionalForm"]}]}], ")"}], 
                                    "i"]}]}],
                              HoldForm],
                            "TraditionalForm"], ")"}], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            FormBox[
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["p",
                                  "TraditionalForm"]}],
                              "TraditionalForm"], ")"}], "2"], " ", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["q",
                            "TraditionalForm"]}]}]}], ")"}]}], ")"}]}], "-", 
            RowBox[{
              FractionBox["1", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["p",
                          "TraditionalForm"]}], "+", 
                      RowBox[{
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], ")"}], "2"]], 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox["\[Epsilon]", 
                    RowBox[{
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["\[Rho]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox["\[CapitalDelta]",
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox["r",
                        "TraditionalForm"]}]], " ", 
                  SuperscriptBox[
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"]], " ", 
                  RowBox[{"(", 
                    RowBox[{
                      SuperscriptBox[
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["p",
                                "TraditionalForm"]}], "+", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["q",
                                "TraditionalForm"]}]}], ")"}], "m"], "+", 
                      RowBox[{
                        RowBox[{"(", 
                          FormBox[
                            TagBox[
                              RowBox[{
                                UnderoverscriptBox["\[Sum]", 
                                  RowBox[{"i", "=", "0"}], 
                                  RowBox[{"m", "-", "3"}]], 
                                RowBox[{
                                  SuperscriptBox[
                                    RowBox[{"(", 
                                      RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["q",
                                        "TraditionalForm"]}], ")"}], 
                                    RowBox[{
                                      RowBox[{"-", "i"}], "+", "m", "-", 
                                      "3"}]], " ", 
                                  SuperscriptBox[
                                    RowBox[{"(", 
                                      RowBox[{
                                        RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["p",
                                        "TraditionalForm"]}], "+", 
                                        RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["q",
                                        "TraditionalForm"]}]}], ")"}], 
                                    "i"]}]}],
                              HoldForm],
                            "TraditionalForm"], ")"}], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            FormBox[
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["q",
                                  "TraditionalForm"]}],
                              "TraditionalForm"], ")"}], "3"]}], "+", 
                      RowBox[{"2", " ", 
                        RowBox[{"(", 
                          FormBox[
                            TagBox[
                              RowBox[{
                                UnderoverscriptBox["\[Sum]", 
                                  RowBox[{"i", "=", "0"}], 
                                  RowBox[{"m", "-", "3"}]], 
                                RowBox[{
                                  SuperscriptBox[
                                    RowBox[{"(", 
                                      RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["q",
                                        "TraditionalForm"]}], ")"}], 
                                    RowBox[{
                                      RowBox[{"-", "i"}], "+", "m", "-", 
                                      "3"}]], " ", 
                                  SuperscriptBox[
                                    RowBox[{"(", 
                                      RowBox[{
                                        RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["p",
                                        "TraditionalForm"]}], "+", 
                                        RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["q",
                                        "TraditionalForm"]}]}], ")"}], 
                                    "i"]}]}],
                              HoldForm],
                            "TraditionalForm"], ")"}], " ", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["p",
                            "TraditionalForm"]}], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            FormBox[
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["q",
                                  "TraditionalForm"]}],
                              "TraditionalForm"], ")"}], "2"]}], "+", 
                      RowBox[{
                        RowBox[{"(", 
                          FormBox[
                            TagBox[
                              RowBox[{
                                UnderoverscriptBox["\[Sum]", 
                                  RowBox[{"i", "=", "0"}], 
                                  RowBox[{"m", "-", "3"}]], 
                                RowBox[{
                                  SuperscriptBox[
                                    RowBox[{"(", 
                                      RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["q",
                                        "TraditionalForm"]}], ")"}], 
                                    RowBox[{
                                      RowBox[{"-", "i"}], "+", "m", "-", 
                                      "3"}]], " ", 
                                  SuperscriptBox[
                                    RowBox[{"(", 
                                      RowBox[{
                                        RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["p",
                                        "TraditionalForm"]}], "+", 
                                        RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["q",
                                        "TraditionalForm"]}]}], ")"}], 
                                    "i"]}]}],
                              HoldForm],
                            "TraditionalForm"], ")"}], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            FormBox[
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["p",
                                  "TraditionalForm"]}],
                              "TraditionalForm"], ")"}], "2"], " ", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["q",
                            "TraditionalForm"]}]}]}], ")"}]}], ")"}]}], "-", 
            RowBox[{
              FractionBox["1", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["p",
                          "TraditionalForm"]}], "+", 
                      RowBox[{
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["r",
                          "TraditionalForm"]}]}], ")"}], "2"]], 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox["\[Epsilon]", 
                    RowBox[{
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox["\[CapitalDelta]",
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox["q",
                        "TraditionalForm"]}]], " ", 
                  SuperscriptBox[
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["\[Rho]",
                        "TraditionalForm"],
                      "TraditionalForm"]], " ", 
                  RowBox[{"(", 
                    RowBox[{
                      SuperscriptBox[
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["p",
                                "TraditionalForm"]}], "+", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["r",
                                "TraditionalForm"]}]}], ")"}], "m"], "+", 
                      RowBox[{
                        RowBox[{"(", 
                          FormBox[
                            TagBox[
                              RowBox[{
                                UnderoverscriptBox["\[Sum]", 
                                  RowBox[{"i", "=", "0"}], 
                                  RowBox[{"m", "-", "3"}]], 
                                RowBox[{
                                  SuperscriptBox[
                                    RowBox[{"(", 
                                      RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["p",
                                        "TraditionalForm"]}], ")"}], 
                                    RowBox[{
                                      RowBox[{"-", "i"}], "+", "m", "-", 
                                      "3"}]], " ", 
                                  SuperscriptBox[
                                    RowBox[{"(", 
                                      RowBox[{
                                        RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["p",
                                        "TraditionalForm"]}], "+", 
                                        RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["r",
                                        "TraditionalForm"]}]}], ")"}], 
                                    "i"]}]}],
                              HoldForm],
                            "TraditionalForm"], ")"}], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            FormBox[
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["p",
                                  "TraditionalForm"]}],
                              "TraditionalForm"], ")"}], "3"]}], "+", 
                      RowBox[{
                        RowBox[{"(", 
                          FormBox[
                            TagBox[
                              RowBox[{
                                UnderoverscriptBox["\[Sum]", 
                                  RowBox[{"i", "=", "0"}], 
                                  RowBox[{"m", "-", "3"}]], 
                                RowBox[{
                                  SuperscriptBox[
                                    RowBox[{"(", 
                                      RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["p",
                                        "TraditionalForm"]}], ")"}], 
                                    RowBox[{
                                      RowBox[{"-", "i"}], "+", "m", "-", 
                                      "3"}]], " ", 
                                  SuperscriptBox[
                                    RowBox[{"(", 
                                      RowBox[{
                                        RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["p",
                                        "TraditionalForm"]}], "+", 
                                        RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["r",
                                        "TraditionalForm"]}]}], ")"}], 
                                    "i"]}]}],
                              HoldForm],
                            "TraditionalForm"], ")"}], " ", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["p",
                            "TraditionalForm"]}], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            FormBox[
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["r",
                                  "TraditionalForm"]}],
                              "TraditionalForm"], ")"}], "2"]}], "+", 
                      RowBox[{"2", " ", 
                        RowBox[{"(", 
                          FormBox[
                            TagBox[
                              RowBox[{
                                UnderoverscriptBox["\[Sum]", 
                                  RowBox[{"i", "=", "0"}], 
                                  RowBox[{"m", "-", "3"}]], 
                                RowBox[{
                                  SuperscriptBox[
                                    RowBox[{"(", 
                                      RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["p",
                                        "TraditionalForm"]}], ")"}], 
                                    RowBox[{
                                      RowBox[{"-", "i"}], "+", "m", "-", 
                                      "3"}]], " ", 
                                  SuperscriptBox[
                                    RowBox[{"(", 
                                      RowBox[{
                                        RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["p",
                                        "TraditionalForm"]}], "+", 
                                        RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["r",
                                        "TraditionalForm"]}]}], ")"}], 
                                    "i"]}]}],
                              HoldForm],
                            "TraditionalForm"], ")"}], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            FormBox[
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["p",
                                  "TraditionalForm"]}],
                              "TraditionalForm"], ")"}], "2"], " ", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["r",
                            "TraditionalForm"]}]}]}], ")"}]}], ")"}]}], "-", 
            RowBox[{
              FractionBox["1", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["p",
                          "TraditionalForm"]}], "+", 
                      RowBox[{
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["r",
                          "TraditionalForm"]}]}], ")"}], "2"]], 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox["\[Epsilon]", 
                    RowBox[{
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["\[Rho]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox["\[CapitalDelta]",
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox["q",
                        "TraditionalForm"]}]], " ", 
                  SuperscriptBox[
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"]], " ", 
                  RowBox[{"(", 
                    RowBox[{
                      SuperscriptBox[
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["p",
                                "TraditionalForm"]}], "+", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["r",
                                "TraditionalForm"]}]}], ")"}], "m"], "+", 
                      RowBox[{
                        RowBox[{"(", 
                          FormBox[
                            TagBox[
                              RowBox[{
                                UnderoverscriptBox["\[Sum]", 
                                  RowBox[{"i", "=", "0"}], 
                                  RowBox[{"m", "-", "3"}]], 
                                RowBox[{
                                  SuperscriptBox[
                                    RowBox[{"(", 
                                      RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["r",
                                        "TraditionalForm"]}], ")"}], 
                                    RowBox[{
                                      RowBox[{"-", "i"}], "+", "m", "-", 
                                      "3"}]], " ", 
                                  SuperscriptBox[
                                    RowBox[{"(", 
                                      RowBox[{
                                        RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["p",
                                        "TraditionalForm"]}], "+", 
                                        RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["r",
                                        "TraditionalForm"]}]}], ")"}], 
                                    "i"]}]}],
                              HoldForm],
                            "TraditionalForm"], ")"}], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            FormBox[
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["r",
                                  "TraditionalForm"]}],
                              "TraditionalForm"], ")"}], "3"]}], "+", 
                      RowBox[{"2", " ", 
                        RowBox[{"(", 
                          FormBox[
                            TagBox[
                              RowBox[{
                                UnderoverscriptBox["\[Sum]", 
                                  RowBox[{"i", "=", "0"}], 
                                  RowBox[{"m", "-", "3"}]], 
                                RowBox[{
                                  SuperscriptBox[
                                    RowBox[{"(", 
                                      RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["r",
                                        "TraditionalForm"]}], ")"}], 
                                    RowBox[{
                                      RowBox[{"-", "i"}], "+", "m", "-", 
                                      "3"}]], " ", 
                                  SuperscriptBox[
                                    RowBox[{"(", 
                                      RowBox[{
                                        RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["p",
                                        "TraditionalForm"]}], "+", 
                                        RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["r",
                                        "TraditionalForm"]}]}], ")"}], 
                                    "i"]}]}],
                              HoldForm],
                            "TraditionalForm"], ")"}], " ", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["p",
                            "TraditionalForm"]}], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            FormBox[
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["r",
                                  "TraditionalForm"]}],
                              "TraditionalForm"], ")"}], "2"]}], "+", 
                      RowBox[{
                        RowBox[{"(", 
                          FormBox[
                            TagBox[
                              RowBox[{
                                UnderoverscriptBox["\[Sum]", 
                                  RowBox[{"i", "=", "0"}], 
                                  RowBox[{"m", "-", "3"}]], 
                                RowBox[{
                                  SuperscriptBox[
                                    RowBox[{"(", 
                                      RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["r",
                                        "TraditionalForm"]}], ")"}], 
                                    RowBox[{
                                      RowBox[{"-", "i"}], "+", "m", "-", 
                                      "3"}]], " ", 
                                  SuperscriptBox[
                                    RowBox[{"(", 
                                      RowBox[{
                                        RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["p",
                                        "TraditionalForm"]}], "+", 
                                        RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["r",
                                        "TraditionalForm"]}]}], ")"}], 
                                    "i"]}]}],
                              HoldForm],
                            "TraditionalForm"], ")"}], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            FormBox[
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["p",
                                  "TraditionalForm"]}],
                              "TraditionalForm"], ")"}], "2"], " ", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["r",
                            "TraditionalForm"]}]}]}], ")"}]}], ")"}]}], "-", 
            RowBox[{
              FractionBox["1", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}], "+", 
                      RowBox[{
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["r",
                          "TraditionalForm"]}]}], ")"}], "2"]], 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox["\[Epsilon]", 
                    RowBox[{
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox["\[CapitalDelta]",
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox["p",
                        "TraditionalForm"]}]], " ", 
                  SuperscriptBox[
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["\[Rho]",
                        "TraditionalForm"],
                      "TraditionalForm"]], " ", 
                  RowBox[{"(", 
                    RowBox[{
                      SuperscriptBox[
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["q",
                                "TraditionalForm"]}], "+", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["r",
                                "TraditionalForm"]}]}], ")"}], "m"], "+", 
                      RowBox[{
                        RowBox[{"(", 
                          FormBox[
                            TagBox[
                              RowBox[{
                                UnderoverscriptBox["\[Sum]", 
                                  RowBox[{"i", "=", "0"}], 
                                  RowBox[{"m", "-", "3"}]], 
                                RowBox[{
                                  SuperscriptBox[
                                    RowBox[{"(", 
                                      RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["q",
                                        "TraditionalForm"]}], ")"}], 
                                    RowBox[{
                                      RowBox[{"-", "i"}], "+", "m", "-", 
                                      "3"}]], " ", 
                                  SuperscriptBox[
                                    RowBox[{"(", 
                                      RowBox[{
                                        RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["q",
                                        "TraditionalForm"]}], "+", 
                                        RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["r",
                                        "TraditionalForm"]}]}], ")"}], 
                                    "i"]}]}],
                              HoldForm],
                            "TraditionalForm"], ")"}], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            FormBox[
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["q",
                                  "TraditionalForm"]}],
                              "TraditionalForm"], ")"}], "3"]}], "+", 
                      RowBox[{
                        RowBox[{"(", 
                          FormBox[
                            TagBox[
                              RowBox[{
                                UnderoverscriptBox["\[Sum]", 
                                  RowBox[{"i", "=", "0"}], 
                                  RowBox[{"m", "-", "3"}]], 
                                RowBox[{
                                  SuperscriptBox[
                                    RowBox[{"(", 
                                      RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["q",
                                        "TraditionalForm"]}], ")"}], 
                                    RowBox[{
                                      RowBox[{"-", "i"}], "+", "m", "-", 
                                      "3"}]], " ", 
                                  SuperscriptBox[
                                    RowBox[{"(", 
                                      RowBox[{
                                        RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["q",
                                        "TraditionalForm"]}], "+", 
                                        RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["r",
                                        "TraditionalForm"]}]}], ")"}], 
                                    "i"]}]}],
                              HoldForm],
                            "TraditionalForm"], ")"}], " ", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["q",
                            "TraditionalForm"]}], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            FormBox[
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["r",
                                  "TraditionalForm"]}],
                              "TraditionalForm"], ")"}], "2"]}], "+", 
                      RowBox[{"2", " ", 
                        RowBox[{"(", 
                          FormBox[
                            TagBox[
                              RowBox[{
                                UnderoverscriptBox["\[Sum]", 
                                  RowBox[{"i", "=", "0"}], 
                                  RowBox[{"m", "-", "3"}]], 
                                RowBox[{
                                  SuperscriptBox[
                                    RowBox[{"(", 
                                      RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["q",
                                        "TraditionalForm"]}], ")"}], 
                                    RowBox[{
                                      RowBox[{"-", "i"}], "+", "m", "-", 
                                      "3"}]], " ", 
                                  SuperscriptBox[
                                    RowBox[{"(", 
                                      RowBox[{
                                        RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["q",
                                        "TraditionalForm"]}], "+", 
                                        RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["r",
                                        "TraditionalForm"]}]}], ")"}], 
                                    "i"]}]}],
                              HoldForm],
                            "TraditionalForm"], ")"}], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            FormBox[
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["q",
                                  "TraditionalForm"]}],
                              "TraditionalForm"], ")"}], "2"], " ", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["r",
                            "TraditionalForm"]}]}]}], ")"}]}], ")"}]}], "+", 
            RowBox[{
              FractionBox["1", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}], "+", 
                      RowBox[{
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["r",
                          "TraditionalForm"]}]}], ")"}], "2"]], 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox["\[Epsilon]", 
                    RowBox[{
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["\[Rho]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox["\[CapitalDelta]",
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox["p",
                        "TraditionalForm"]}]], " ", 
                  SuperscriptBox[
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"]], " ", 
                  RowBox[{"(", 
                    RowBox[{
                      SuperscriptBox[
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["q",
                                "TraditionalForm"]}], "+", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["r",
                                "TraditionalForm"]}]}], ")"}], "m"], "+", 
                      RowBox[{
                        RowBox[{"(", 
                          FormBox[
                            TagBox[
                              RowBox[{
                                UnderoverscriptBox["\[Sum]", 
                                  RowBox[{"i", "=", "0"}], 
                                  RowBox[{"m", "-", "3"}]], 
                                RowBox[{
                                  SuperscriptBox[
                                    RowBox[{"(", 
                                      RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["r",
                                        "TraditionalForm"]}], ")"}], 
                                    RowBox[{
                                      RowBox[{"-", "i"}], "+", "m", "-", 
                                      "3"}]], " ", 
                                  SuperscriptBox[
                                    RowBox[{"(", 
                                      RowBox[{
                                        RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["q",
                                        "TraditionalForm"]}], "+", 
                                        RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["r",
                                        "TraditionalForm"]}]}], ")"}], 
                                    "i"]}]}],
                              HoldForm],
                            "TraditionalForm"], ")"}], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            FormBox[
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["r",
                                  "TraditionalForm"]}],
                              "TraditionalForm"], ")"}], "3"]}], "+", 
                      RowBox[{"2", " ", 
                        RowBox[{"(", 
                          FormBox[
                            TagBox[
                              RowBox[{
                                UnderoverscriptBox["\[Sum]", 
                                  RowBox[{"i", "=", "0"}], 
                                  RowBox[{"m", "-", "3"}]], 
                                RowBox[{
                                  SuperscriptBox[
                                    RowBox[{"(", 
                                      RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["r",
                                        "TraditionalForm"]}], ")"}], 
                                    RowBox[{
                                      RowBox[{"-", "i"}], "+", "m", "-", 
                                      "3"}]], " ", 
                                  SuperscriptBox[
                                    RowBox[{"(", 
                                      RowBox[{
                                        RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["q",
                                        "TraditionalForm"]}], "+", 
                                        RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["r",
                                        "TraditionalForm"]}]}], ")"}], 
                                    "i"]}]}],
                              HoldForm],
                            "TraditionalForm"], ")"}], " ", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["q",
                            "TraditionalForm"]}], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            FormBox[
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["r",
                                  "TraditionalForm"]}],
                              "TraditionalForm"], ")"}], "2"]}], "+", 
                      RowBox[{
                        RowBox[{"(", 
                          FormBox[
                            TagBox[
                              RowBox[{
                                UnderoverscriptBox["\[Sum]", 
                                  RowBox[{"i", "=", "0"}], 
                                  RowBox[{"m", "-", "3"}]], 
                                RowBox[{
                                  SuperscriptBox[
                                    RowBox[{"(", 
                                      RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["r",
                                        "TraditionalForm"]}], ")"}], 
                                    RowBox[{
                                      RowBox[{"-", "i"}], "+", "m", "-", 
                                      "3"}]], " ", 
                                  SuperscriptBox[
                                    RowBox[{"(", 
                                      RowBox[{
                                        RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["q",
                                        "TraditionalForm"]}], "+", 
                                        RowBox[{
                                        FormBox["\[CapitalDelta]",
                                        "TraditionalForm"], "\[NoBreak]", 
                                        "\[CenterDot]", "\[NoBreak]", 
                                        FormBox["r",
                                        "TraditionalForm"]}]}], ")"}], 
                                    "i"]}]}],
                              HoldForm],
                            "TraditionalForm"], ")"}], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            FormBox[
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["q",
                                  "TraditionalForm"]}],
                              "TraditionalForm"], ")"}], "2"], " ", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["r",
                            "TraditionalForm"]}]}]}], ")"}]}], ")"}]}], "-", 
            FractionBox[
              RowBox[{
                SuperscriptBox["\[Epsilon]", 
                  RowBox[{
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["\[Rho]",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"]}]], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      RowBox[{
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}], " ", 
                      RowBox[{
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["r",
                          "TraditionalForm"]}], " ", 
                      SuperscriptBox[
                        RowBox[{"(", 
                          RowBox[{
                            FormBox["\[CapitalDelta]",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["p",
                              "TraditionalForm"]}], ")"}], "m"]}], "+", 
                    RowBox[{
                      RowBox[{
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}], " ", 
                      SuperscriptBox[
                        RowBox[{"(", 
                          RowBox[{
                            FormBox["\[CapitalDelta]",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["r",
                              "TraditionalForm"]}], ")"}], "m"], " ", 
                      RowBox[{
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["p",
                          "TraditionalForm"]}]}], "+", 
                    RowBox[{
                      SuperscriptBox[
                        RowBox[{"(", 
                          RowBox[{
                            FormBox["\[CapitalDelta]",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}], ")"}], "m"], " ", 
                      RowBox[{
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["r",
                          "TraditionalForm"]}], " ", 
                      RowBox[{
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["p",
                          "TraditionalForm"]}]}]}], ")"}]}], 
              RowBox[{
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["r",
                    "TraditionalForm"]}], " ", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["p",
                    "TraditionalForm"]}]}]]}], ")"}], " ", 
        SubscriptBox["f", 
          RowBox[{
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["c",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1662]=  (21:57:10 on 5/16/01)"]
}, Closed]],

Cell["4-gluon legs", "Text",
  CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Twist2GluonOperator", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"q", ",", "\[Nu]", ",", "b"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"r", ",", "\[Rho]", ",", "c"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"s", ",", "\[Sigma]", ",", "d"}], "}"}], ",", 
        RowBox[{"Explicit", "\[Rule]", "False"}]}], "]"}]], "Input",
  CellLabel->"In[1663]:=  (21:57:10 on 5/16/01)",
  CellTags->"Twist2GluonOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"(", 
          RowBox[{"1", "-", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "m"]}], ")"}], " ", 
        SubsuperscriptBox["g", "s", "2"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                SubscriptBox["f", 
                  RowBox[{
                    FormBox[
                      FormBox["a",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["b",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["c114",
                        "TraditionalForm"],
                      "TraditionalForm"]}]]}], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["c",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["c114",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["d",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              RowBox[{"(", 
                RowBox[{
                  SubsuperscriptBox["O", 
                    RowBox[{
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[VeryThinSpace]", 
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[VeryThinSpace]", 
                      FormBox[
                        FormBox["\[Rho]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[VeryThinSpace]", 
                      FormBox[
                        FormBox["\[Sigma]",
                          "TraditionalForm"],
                        "TraditionalForm"]}], "G4"], "(", 
                  FormBox["p",
                    "TraditionalForm"], ",", 
                  FormBox["q",
                    "TraditionalForm"], ",", 
                  FormBox["r",
                    "TraditionalForm"], ",", 
                  FormBox["s",
                    "TraditionalForm"], ")"}], ")"}]}], "-", 
            RowBox[{
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["a",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["c",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["c114",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["b",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["c114",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["d",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              RowBox[{"(", 
                RowBox[{
                  SubsuperscriptBox["O", 
                    RowBox[{
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[VeryThinSpace]", 
                      FormBox[
                        FormBox["\[Rho]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[VeryThinSpace]", 
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[VeryThinSpace]", 
                      FormBox[
                        FormBox["\[Sigma]",
                          "TraditionalForm"],
                        "TraditionalForm"]}], "G4"], "(", 
                  FormBox["p",
                    "TraditionalForm"], ",", 
                  FormBox["r",
                    "TraditionalForm"], ",", 
                  FormBox["q",
                    "TraditionalForm"], ",", 
                  FormBox["s",
                    "TraditionalForm"], ")"}], ")"}]}], "+", 
            RowBox[{
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["a",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["c114",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["d",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["b",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["c",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["c114",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              RowBox[{"(", 
                RowBox[{
                  SubsuperscriptBox["O", 
                    RowBox[{
                      FormBox[
                        FormBox["\[Rho]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[VeryThinSpace]", 
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[VeryThinSpace]", 
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[VeryThinSpace]", 
                      FormBox[
                        FormBox["\[Sigma]",
                          "TraditionalForm"],
                        "TraditionalForm"]}], "G4"], "(", 
                  FormBox["r",
                    "TraditionalForm"], ",", 
                  FormBox["q",
                    "TraditionalForm"], ",", 
                  FormBox["p",
                    "TraditionalForm"], ",", 
                  FormBox["s",
                    "TraditionalForm"], ")"}], ")"}]}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1663]=  (21:57:10 on 5/16/01)"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Unpolarized case, non-zero-momentum insertion", "Subsubsection",
  CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SetOptions", "[", 
      RowBox[{"Twist2GluonOperator", ",", " ", 
        RowBox[{"Polarization", " ", "->", " ", "0"}], ",", 
        RowBox[{"ZeroMomentumInsertion", "->", "False"}]}], "]"}]], "Input",
  CellLabel->"In[1664]:=  (21:57:10 on 5/16/01)",
  CellTags->"Twist2GluonOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"CouplingConstant", "\[Rule]", 
            SubscriptBox["g", "s"]}], ",", 
          RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
          RowBox[{"Polarization", "\[Rule]", "0"}], ",", 
          RowBox[{"Explicit", "\[Rule]", "All"}], ",", 
          RowBox[{"ZeroMomentumInsertion", "\[Rule]", "False"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1664]=  (21:57:11 on 5/16/01)"]
}, Closed]],

Cell["2-gluon legs", "Text",
  CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Twist2GluonOperator", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"p", ",", "q"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"\[Mu]", ",", "a"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"\[Nu]", ",", "b"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[1665]:=  (21:57:11 on 5/16/01)",
  CellTags->"Twist2GluonOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          FractionBox["1", "2"]}], " ", 
        RowBox[{"(", 
          RowBox[{"1", "+", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "m"]}], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["p",
                  "TraditionalForm"]}]}], "-", 
            RowBox[{
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              RowBox[{
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}], " ", 
              RowBox[{
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["p",
                  "TraditionalForm"]}]}], "+", 
            RowBox[{
              SuperscriptBox[
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"]], " ", 
                    RowBox[{
                      FormBox["\[CapitalDelta]",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["q",
                        "TraditionalForm"]}]}], "-", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["\[CapitalDelta]",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"]], " ", 
                    RowBox[{
                      FormBox["p",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["q",
                        "TraditionalForm"]}]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{
            FormBox[
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["p",
                      "TraditionalForm"]}], ")"}], 
                RowBox[{"m", "-", "2"}]],
              "TraditionalForm"], "+", 
            FormBox[
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}], ")"}], 
                RowBox[{"m", "-", "2"}]],
              "TraditionalForm"]}], ")"}], " ", 
        SubscriptBox["\[Delta]", 
          RowBox[{
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["b",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1665]=  (21:57:11 on 5/16/01)"]
}, Closed]],

Cell["3-gluon legs", "Text",
  CellTags->"Twist2GluonOperator"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Twist2GluonOperator", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{"q", ",", "\[Nu]", ",", "b"}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{"r", ",", "\[Rho]", ",", "c"}], "}"}]}], "]"}], 
      ";"}]], "Input",
  CellLabel->"In[1666]:=  (21:57:11 on 5/16/01)",
  CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Twist2GluonOperator", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"p", ",", "\[Mu]"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"q", ",", "\[Nu]"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"r", ",", "\[Rho]"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[1667]:=  (21:57:12 on 5/16/01)",
  CellTags->"Twist2GluonOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          FractionBox["1", "2"]}], " ", 
        RowBox[{"(", 
          RowBox[{"1", "+", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "m"]}], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                FormBox["\[Mu]",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["q",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["r",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["p",
                  "TraditionalForm"]}]}], "-", 
            RowBox[{
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["q",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["r",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              RowBox[{
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["\[Mu]",
                  "TraditionalForm"]}], " ", 
              RowBox[{
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["p",
                  "TraditionalForm"]}]}], "+", 
            RowBox[{
              SuperscriptBox[
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["q",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["r",
                          "TraditionalForm"],
                        "TraditionalForm"]], " ", 
                    RowBox[{
                      FormBox["\[CapitalDelta]",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["\[Mu]",
                        "TraditionalForm"]}]}], "-", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["\[CapitalDelta]",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["r",
                          "TraditionalForm"],
                        "TraditionalForm"]], " ", 
                    RowBox[{
                      FormBox["p",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["\[Mu]",
                        "TraditionalForm"]}]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{
            FormBox[
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["p",
                      "TraditionalForm"]}], ")"}], 
                RowBox[{"m", "-", "2"}]],
              "TraditionalForm"], "+", 
            FormBox[
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["\[Mu]",
                      "TraditionalForm"]}], ")"}], 
                RowBox[{"m", "-", "2"}]],
              "TraditionalForm"]}], ")"}], " ", 
        SubscriptBox["\[Delta]", 
          RowBox[{
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["\[Rho]",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1667]=  (21:57:12 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Twist2GluonOperator", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"p", ",", "\[Mu]"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"q", ",", "\[Nu]"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"r", ",", "\[Rho]"}], "}"}], ",", 
        RowBox[{"Explicit", "->", "True"}]}], "]"}]], "Input",
  CellLabel->"In[1668]:=  (21:57:12 on 5/16/01)",
  CellTags->"Twist2GluonOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          FractionBox["1", "2"]}], " ", 
        RowBox[{"(", 
          RowBox[{"1", "+", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "m"]}], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                FormBox["\[Mu]",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["q",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["r",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["p",
                  "TraditionalForm"]}]}], "-", 
            RowBox[{
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["q",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["r",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              RowBox[{
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["\[Mu]",
                  "TraditionalForm"]}], " ", 
              RowBox[{
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["p",
                  "TraditionalForm"]}]}], "+", 
            RowBox[{
              SuperscriptBox[
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["q",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["r",
                          "TraditionalForm"],
                        "TraditionalForm"]], " ", 
                    RowBox[{
                      FormBox["\[CapitalDelta]",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["\[Mu]",
                        "TraditionalForm"]}]}], "-", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["\[CapitalDelta]",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["r",
                          "TraditionalForm"],
                        "TraditionalForm"]], " ", 
                    RowBox[{
                      FormBox["p",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["\[Mu]",
                        "TraditionalForm"]}]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{
            FormBox[
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["p",
                      "TraditionalForm"]}], ")"}], 
                RowBox[{"m", "-", "2"}]],
              "TraditionalForm"], "+", 
            FormBox[
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["\[Mu]",
                      "TraditionalForm"]}], ")"}], 
                RowBox[{"m", "-", "2"}]],
              "TraditionalForm"]}], ")"}], " ", 
        SubscriptBox["\[Delta]", 
          RowBox[{
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["\[Rho]",
                "TraditionalForm"],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1668]=  (21:57:12 on 5/16/01)"]
}, Closed]],

Cell["4-gluon legs", "Text",
  CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Twist2GluonOperator", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"q", ",", "\[Nu]", ",", "b"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"r", ",", "\[Rho]", ",", "c"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"s", ",", "\[Sigma]", ",", "d"}], "}"}], ",", 
        RowBox[{"Explicit", "\[Rule]", "False"}]}], "]"}]], "Input",
  CellLabel->"In[1669]:=  (21:57:12 on 5/16/01)",
  CellTags->"Twist2GluonOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
          RowBox[{"1", "+", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "m"]}], ")"}], " ", 
        SubsuperscriptBox["g", "s", "2"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                SubscriptBox["f", 
                  RowBox[{
                    FormBox[
                      FormBox["a",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["b",
                        "TraditionalForm"],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      FormBox["c115",
                        "TraditionalForm"],
                      "TraditionalForm"]}]]}], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["c",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["c115",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["d",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              RowBox[{"(", 
                RowBox[{
                  SubsuperscriptBox["O", 
                    RowBox[{
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[VeryThinSpace]", 
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[VeryThinSpace]", 
                      FormBox[
                        FormBox["\[Rho]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[VeryThinSpace]", 
                      FormBox[
                        FormBox["\[Sigma]",
                          "TraditionalForm"],
                        "TraditionalForm"]}], "G4"], "(", 
                  FormBox["p",
                    "TraditionalForm"], ",", 
                  FormBox["q",
                    "TraditionalForm"], ",", 
                  FormBox["r",
                    "TraditionalForm"], ",", 
                  FormBox["s",
                    "TraditionalForm"], ")"}], ")"}]}], "-", 
            RowBox[{
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["a",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["c",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["c115",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["b",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["c115",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["d",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              RowBox[{"(", 
                RowBox[{
                  SubsuperscriptBox["O", 
                    RowBox[{
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[VeryThinSpace]", 
                      FormBox[
                        FormBox["\[Rho]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[VeryThinSpace]", 
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[VeryThinSpace]", 
                      FormBox[
                        FormBox["\[Sigma]",
                          "TraditionalForm"],
                        "TraditionalForm"]}], "G4"], "(", 
                  FormBox["p",
                    "TraditionalForm"], ",", 
                  FormBox["r",
                    "TraditionalForm"], ",", 
                  FormBox["q",
                    "TraditionalForm"], ",", 
                  FormBox["s",
                    "TraditionalForm"], ")"}], ")"}]}], "+", 
            RowBox[{
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["a",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["c115",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["d",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SubscriptBox["f", 
                RowBox[{
                  FormBox[
                    FormBox["b",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["c",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["c115",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              RowBox[{"(", 
                RowBox[{
                  SubsuperscriptBox["O", 
                    RowBox[{
                      FormBox[
                        FormBox["\[Rho]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[VeryThinSpace]", 
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[VeryThinSpace]", 
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[VeryThinSpace]", 
                      FormBox[
                        FormBox["\[Sigma]",
                          "TraditionalForm"],
                        "TraditionalForm"]}], "G4"], "(", 
                  FormBox["r",
                    "TraditionalForm"], ",", 
                  FormBox["q",
                    "TraditionalForm"], ",", 
                  FormBox["p",
                    "TraditionalForm"], ",", 
                  FormBox["s",
                    "TraditionalForm"], ")"}], ")"}]}]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1669]=  (21:57:12 on 5/16/01)"]
}, Closed]],

Cell["Suppress the lengthy output.", "Text",
  CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Short", "[", 
      RowBox[{
        RowBox[{"Twist2GluonOperator", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"p", ",", "\[Mu]"}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"q", ",", "\[Nu]"}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"r", ",", "\[Rho]"}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"s", ",", "\[Sigma]"}], "}"}], ",", 
            RowBox[{"Explicit", "->", "True"}]}], "]"}], ",", "6"}], 
      "]"}]], "Input",
  CellLabel->"In[1670]:=  (21:57:12 on 5/16/01)",
  CellTags->"Twist2GluonOperator"],

Cell[BoxData[
    FormBox[
      TagBox[
        RowBox[{
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  SuperscriptBox[
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"]], " ", 
                  SuperscriptBox["g", 
                    RowBox[{
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["\[Sigma]",
                          "TraditionalForm"],
                        "TraditionalForm"]}]], " ", 
                  SuperscriptBox[
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["\[Rho]",
                        "TraditionalForm"],
                      "TraditionalForm"]]}], "-", 
                RowBox[{
                  SuperscriptBox["g", 
                    RowBox[{
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["\[Sigma]",
                          "TraditionalForm"],
                        "TraditionalForm"]}]], " ", 
                  SuperscriptBox[
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"]], " ", 
                  SuperscriptBox[
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["\[Rho]",
                        "TraditionalForm"],
                      "TraditionalForm"]]}], "-", 
                RowBox[{
                  SuperscriptBox[
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["\[Mu]",
                        "TraditionalForm"],
                      "TraditionalForm"]], " ", 
                  SuperscriptBox["g", 
                    RowBox[{
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["\[Rho]",
                          "TraditionalForm"],
                        "TraditionalForm"]}]], " ", 
                  SuperscriptBox[
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["\[Sigma]",
                        "TraditionalForm"],
                      "TraditionalForm"]]}], "+", 
                RowBox[{
                  SuperscriptBox["g", 
                    RowBox[{
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["\[Rho]",
                          "TraditionalForm"],
                        "TraditionalForm"]}]], " ", 
                  SuperscriptBox[
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"]], " ", 
                  SuperscriptBox[
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["\[Sigma]",
                        "TraditionalForm"],
                      "TraditionalForm"]]}]}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["r",
                      "TraditionalForm"]}], "+", 
                  RowBox[{
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["s",
                      "TraditionalForm"]}]}], ")"}], 
              RowBox[{"m", "-", "2"}]]}], "+", 
          RowBox[{"\[LeftSkeleton]", "8", "\[RightSkeleton]"}], "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], ")"}], 
            " ", 
            SuperscriptBox[
              FormBox["\[CapitalDelta]",
                "TraditionalForm"], 
              RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]], " ", 
            SuperscriptBox[
              RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], 
              RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]], " ", 
            RowBox[{"(", 
              RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], ")"}]}], 
          "-", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                FormBox[
                  RowBox[{
                    UnderoverscriptBox["\[Sum]", 
                      RowBox[{"j", "=", "0"}], 
                      RowBox[{"m", "-", "4"}]], "\<\"\"\>"}],
                  "TraditionalForm"], "\[NoBreak]", 
                FormBox[
                  RowBox[{
                    UnderoverscriptBox["\[Sum]", 
                      RowBox[{"i", "=", "0"}], "j"], "\<\"\"\>"}],
                  "TraditionalForm"], "\[NoBreak]", 
                FormBox[
                  RowBox[{
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["q",
                            "TraditionalForm"]}], ")"}], 
                      RowBox[{
                        RowBox[{"-", "j"}], "+", "m", "-", "4"}]], " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{"-", 
                            RowBox[{"(", 
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["r",
                                  "TraditionalForm"]}], ")"}]}], "-", 
                          RowBox[{
                            FormBox["\[CapitalDelta]",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["s",
                              "TraditionalForm"]}]}], ")"}], 
                      RowBox[{"j", "-", "i"}]], " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        RowBox[{"-", 
                          RowBox[{"(", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["s",
                                "TraditionalForm"]}], ")"}]}], ")"}], "i"]}],
                  "TraditionalForm"]}], ")"}], " ", 
            SuperscriptBox[
              FormBox["\[CapitalDelta]",
                "TraditionalForm"], 
              FormBox[
                FormBox["\[Mu]",
                  "TraditionalForm"],
                "TraditionalForm"]], " ", 
            SuperscriptBox[
              FormBox["\[CapitalDelta]",
                "TraditionalForm"], 
              FormBox[
                FormBox["\[Rho]",
                  "TraditionalForm"],
                "TraditionalForm"]], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"-", 
                    SuperscriptBox[
                      FormBox["s",
                        "TraditionalForm"], 
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"]]}], " ", 
                  SuperscriptBox[
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["\[Sigma]",
                        "TraditionalForm"],
                      "TraditionalForm"]], " ", 
                  RowBox[{
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                RowBox[{
                  SuperscriptBox["g", 
                    RowBox[{
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["\[Sigma]",
                          "TraditionalForm"],
                        "TraditionalForm"]}]], " ", 
                  RowBox[{
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["s",
                      "TraditionalForm"]}], " ", 
                  RowBox[{
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "-", 
                RowBox[{
                  SuperscriptBox[
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"]], " ", 
                  SuperscriptBox[
                    FormBox["q",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["\[Sigma]",
                        "TraditionalForm"],
                      "TraditionalForm"]], " ", 
                  RowBox[{
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["s",
                      "TraditionalForm"]}]}], "+", 
                RowBox[{
                  SuperscriptBox[
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"]], " ", 
                  SuperscriptBox[
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["\[Sigma]",
                        "TraditionalForm"],
                      "TraditionalForm"]], " ", 
                  RowBox[{
                    FormBox["q",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["s",
                      "TraditionalForm"]}]}]}], ")"}]}]}],
        (Short[ #, 6]&)], TraditionalForm]], "Output",
  CellLabel->"Out[1670]//Short=  (21:57:13 on 5/16/01)"]
}, Closed]],

Cell["The setting Explicit -> All performs the sums.", "Text",
  CellTags->"Twist2GluonOperator"],

Cell[BoxData[
    RowBox[{
      RowBox[{"SetOptions", "[", 
        RowBox[{"Twist2GluonOperator", ",", " ", 
          RowBox[{"Polarization", " ", "->", " ", "1"}], ",", " ", 
          RowBox[{"Explicit", "->", "All"}]}], "]"}], ";"}]], "Input",
  CellLabel->"In[1671]:=  (21:57:13 on 5/16/01)",
  CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Short", "[", 
      RowBox[{
        RowBox[{"Twist2GluonOperator", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"q", ",", "\[Nu]", ",", "b"}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"r", ",", "\[Rho]", ",", "c"}], "}"}]}], "]"}], ",", 
        "5"}], "]"}]], "Input",
  CellLabel->"In[1672]:=  (21:57:13 on 5/16/01)",
  CellTags->"Twist2GluonOperator"],

Cell[BoxData[
    FormBox[
      TagBox[
        RowBox[{
          SubscriptBox["g", "s"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  SuperscriptBox["\[Epsilon]", 
                    RowBox[{
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["\[Rho]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox["\[CapitalDelta]",
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox["p",
                        "TraditionalForm"]}]]}], " ", 
                SuperscriptBox[
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{
                      FormBox["\[CapitalDelta]",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["p",
                        "TraditionalForm"]}], ")"}], 
                  RowBox[{"m", "-", "2"}]]}], "+", 
              RowBox[{"\[LeftSkeleton]", "20", "\[RightSkeleton]"}], "+", 
              FractionBox[
                RowBox[{
                  SuperscriptBox["\[Epsilon]", 
                    RowBox[{
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["\[Rho]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox["\[CapitalDelta]",
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox["p",
                        "TraditionalForm"]}]], " ", 
                  SuperscriptBox[
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], 
                    FormBox[
                      FormBox["\[Nu]",
                        "TraditionalForm"],
                      "TraditionalForm"]], " ", 
                  RowBox[{"(", 
                    RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], 
                    ")"}]}], 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}], "+", 
                      RowBox[{
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["r",
                          "TraditionalForm"]}]}], ")"}], "2"]], "-", 
              FractionBox[
                RowBox[{
                  SuperscriptBox["\[Epsilon]", 
                    RowBox[{
                      FormBox[
                        FormBox["\[Mu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["\[Nu]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox[
                        FormBox["\[Rho]",
                          "TraditionalForm"],
                        "TraditionalForm"], "\[NoBreak]", 
                      FormBox["\[CapitalDelta]",
                        "TraditionalForm"]}]], " ", 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["q",
                            "TraditionalForm"]}], " ", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["r",
                            "TraditionalForm"]}], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["p",
                                "TraditionalForm"]}], ")"}], "m"]}], "+", 
                      RowBox[{
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["q",
                            "TraditionalForm"]}], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["r",
                                "TraditionalForm"]}], ")"}], "m"], " ", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["p",
                            "TraditionalForm"]}]}], "+", 
                      RowBox[{
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["q",
                                "TraditionalForm"]}], ")"}], "m"], " ", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["r",
                            "TraditionalForm"]}], " ", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["p",
                            "TraditionalForm"]}]}]}], ")"}]}], 
                RowBox[{
                  RowBox[{
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}], " ", 
                  RowBox[{
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["r",
                      "TraditionalForm"]}], " ", 
                  RowBox[{
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["p",
                      "TraditionalForm"]}]}]]}], ")"}], " ", 
          SubscriptBox["f", 
            RowBox[{
              FormBox[
                FormBox["a",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["b",
                  "TraditionalForm"],
                "TraditionalForm"], "\[NoBreak]", 
              FormBox[
                FormBox["c",
                  "TraditionalForm"],
                "TraditionalForm"]}]]}],
        (Short[ #, 5]&)], TraditionalForm]], "Output",
  CellLabel->"Out[1672]//Short=  (21:57:13 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Twist2QuarkOperator", "ObjectName",
  CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"Twist2QuarkOperator"],

Cell["\<\
Twist2QuarkOperator[p] or Twist2QuarkOperator[p,_,_] yields the \
quark-antiquark operator (p is momentum in the direction of the incoming \
quark). Twist2QuarkOperator[{p,q}] yields the 2-quark operator for non-zero \
momentum insertion (p is momentum in the direction of the incoming quark). \
Twist2QuarkOperator[{p1,___}, {p2,___}, {p3, mu, a}] or \
Twist2QuarkOperator[p1,_,_, p2,_,_, p3,mu,a] is the quark-antiquark-gluon \
operator, where p1 is the incoming quark, p2 the incoming antiquark and p3 \
denotes the incoming gluon momentum. Twist2QuarkOperator[{p1}, {p2}, {p3, mu, \
a}, {p4, nu, b}] or Twist2QuarkOperator[{p1,___}, {p2,___}, {p3, mu, a}, {p4, \
nu, b}] or Twist2QuarkOperator[p1,_,_, p2,_,_, p3,mu,a, p4, nu, b] gives the \
Quark-Quark-Gluon-Gluon-operator. The setting of the option Polarization \
(unpolarized: 0; polarized: 1) determines whether the unpolarized or \
polarized operator is returned\
\>", "Text",
  CellTags->"Twist2QuarkOperator"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["Twist2GluonOperator",
    ButtonData:>"Twist2GluonOperator",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Twist2GluonOperator"],
  "."
}], "Text",
  CellTags->"Twist2QuarkOperator"]
}, Closed]],

Cell["Examples", "Subsubsection",
  CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{

Cell["Polarized case, zero-momentum insertion", "Subsubsection",
  CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SetOptions", "[", 
      RowBox[{"Twist2QuarkOperator", ",", 
        RowBox[{"Polarization", "\[Rule]", "1"}], ",", 
        RowBox[{"ZeroMomentumInsertion", "\[Rule]", "True"}]}], 
      "]"}]], "Input",
  CellLabel->"In[1673]:=  (21:57:13 on 5/16/01)",
  CellTags->"Twist2QuarkOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"CouplingConstant", "\[Rule]", 
            SubscriptBox["g", "s"]}], ",", 
          RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
          RowBox[{"Explicit", "\[Rule]", "True"}], ",", 
          RowBox[{"Polarization", "\[Rule]", "1"}], ",", 
          RowBox[{"ZeroMomentumInsertion", "\[Rule]", "True"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1673]=  (21:57:13 on 5/16/01)"]
}, Closed]],

Cell["Quark-antiquark operator.", "Text",
  CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t1", "=", 
      RowBox[{"Twist2QuarkOperator", "[", "p", "]"}]}]], "Input",
  CellLabel->"In[1674]:=  (21:57:13 on 5/16/01)",
  CellTags->"Twist2QuarkOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                FormBox["\<\"\[Gamma]\"\>",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"]}], ")"}], ".", 
            SuperscriptBox["\[Gamma]", "5"]}]}], " ", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              FormBox["\[CapitalDelta]",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox["p",
                "TraditionalForm"]}], ")"}], 
          RowBox[{"m", "-", "1"}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1674]=  (21:57:14 on 5/16/01)"]
}, Closed]],

Cell["Quark-antiquark-gluon operator.", "Text",
  CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t2", "=", 
      RowBox[{"Twist2QuarkOperator", "[", 
        RowBox[{
          RowBox[{"{", "p", "}"}], ",", 
          RowBox[{"{", "q", "}"}], ",", 
          RowBox[{"{", 
            RowBox[{"k", ",", "\[Mu]", ",", "a"}], "}"}]}], "]"}]}]], "Input",\

  CellLabel->"In[1675]:=  (21:57:14 on 5/16/01)",
  CellTags->"Twist2QuarkOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          SubscriptBox["g", "s"]}], " ", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              FormBox["\<\"\[Gamma]\"\>",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"]}], ")"}], ".", 
          SuperscriptBox["\[Gamma]", "5"], ".", 
          SubscriptBox["T", 
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"]]}], " ", 
        RowBox[{"(", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", 
                  RowBox[{"i", "=", "0"}], 
                  RowBox[{"m", "-", "2"}]], 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{"-", "1"}], ")"}], "i"], " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["p",
                          "TraditionalForm"]}], ")"}], 
                    RowBox[{
                      RowBox[{"-", "i"}], "+", "m", "-", "2"}]], " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}], ")"}], "i"]}]}],
              HoldForm],
            "TraditionalForm"], ")"}], " ", 
        SuperscriptBox[
          FormBox["\[CapitalDelta]",
            "TraditionalForm"], 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1675]=  (21:57:14 on 5/16/01)"]
}, Closed]],

Cell["Quark-antiquark-gluon-gluon operator.", "Text",
  CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t3", "=", 
      RowBox[{"Twist2QuarkOperator", "[", 
        RowBox[{
          RowBox[{"{", "p", "}"}], ",", 
          RowBox[{"{", "q", "}"}], ",", 
          RowBox[{"{", 
            RowBox[{"k", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{"r", ",", "\[Nu]", ",", "b"}], "}"}]}], "]"}]}]], "Input",\

  CellLabel->"In[1676]:=  (21:57:14 on 5/16/01)",
  CellTags->"Twist2QuarkOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          SubsuperscriptBox["g", "s", "2"]}], " ", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              FormBox["\<\"\[Gamma]\"\>",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"]}], ")"}], ".", 
          SuperscriptBox["\[Gamma]", "5"], ".", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{
                  SubscriptBox["T", 
                    FormBox[
                      FormBox["b",
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SubscriptBox["T", 
                    FormBox[
                      FormBox["a",
                        "TraditionalForm"],
                      "TraditionalForm"]]}], " ", 
                RowBox[{"(", 
                  RowBox[{
                    FormBox[
                      TagBox[
                        RowBox[{
                          UnderoverscriptBox["\[Sum]", 
                            RowBox[{"j", "=", "0"}], 
                            RowBox[{"m", "-", "3"}]], "\<\"\"\>"}],
                        HoldForm],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      RowBox[{
                        UnderoverscriptBox["\[Sum]", 
                          RowBox[{"i", "=", "0"}], "j"], "\<\"\"\>"}],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      RowBox[{
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{"-", "1"}], ")"}], "j"], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["p",
                                "TraditionalForm"]}], ")"}], "i"], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["q",
                                "TraditionalForm"]}], ")"}], 
                          RowBox[{
                            RowBox[{"-", "j"}], "+", "m", "-", "3"}]], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["p",
                                  "TraditionalForm"]}], "+", 
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["r",
                                  "TraditionalForm"]}]}], ")"}], 
                          RowBox[{"j", "-", "i"}]]}],
                      "TraditionalForm"]}], ")"}]}], "-", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"-", "1"}], ")"}], "m"], " ", 
                RowBox[{
                  SubscriptBox["T", 
                    FormBox[
                      FormBox["a",
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SubscriptBox["T", 
                    FormBox[
                      FormBox["b",
                        "TraditionalForm"],
                      "TraditionalForm"]]}], " ", 
                RowBox[{"(", 
                  RowBox[{
                    FormBox[
                      TagBox[
                        RowBox[{
                          UnderoverscriptBox["\[Sum]", 
                            RowBox[{"j", "=", "0"}], 
                            RowBox[{"m", "-", "3"}]], "\<\"\"\>"}],
                        HoldForm],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      RowBox[{
                        UnderoverscriptBox["\[Sum]", 
                          RowBox[{"i", "=", "0"}], "j"], "\<\"\"\>"}],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      RowBox[{
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{"-", "1"}], ")"}], "j"], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["p",
                                "TraditionalForm"]}], ")"}], 
                          RowBox[{
                            RowBox[{"-", "j"}], "+", "m", "-", "3"}]], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["q",
                                "TraditionalForm"]}], ")"}], "i"], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["q",
                                  "TraditionalForm"]}], "+", 
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["r",
                                  "TraditionalForm"]}]}], ")"}], 
                          RowBox[{"j", "-", "i"}]]}],
                      "TraditionalForm"]}], ")"}]}]}], ")"}]}], " ", 
        SuperscriptBox[
          FormBox["\[CapitalDelta]",
            "TraditionalForm"], 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]], " ", 
        SuperscriptBox[
          FormBox["\[CapitalDelta]",
            "TraditionalForm"], 
          FormBox[
            FormBox["\[Nu]",
              "TraditionalForm"],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1676]=  (21:57:14 on 5/16/01)"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Unpolarized case, zero-momentum insertion", "Subsubsection",
  CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SetOptions", "[", 
      RowBox[{"Twist2QuarkOperator", ",", " ", 
        RowBox[{"Polarization", "->", "0"}], ",", 
        RowBox[{"ZeroMomentumInsertion", "->", "True"}]}], "]"}]], "Input",
  CellLabel->"In[1677]:=  (21:57:14 on 5/16/01)",
  CellTags->"Twist2QuarkOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"CouplingConstant", "\[Rule]", 
            SubscriptBox["g", "s"]}], ",", 
          RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
          RowBox[{"Explicit", "\[Rule]", "True"}], ",", 
          RowBox[{"Polarization", "\[Rule]", "0"}], ",", 
          RowBox[{"ZeroMomentumInsertion", "\[Rule]", "True"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1677]=  (21:57:14 on 5/16/01)"]
}, Closed]],

Cell["Quark-antiquark operator.", "Text",
  CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t4", "=", 
      RowBox[{"Twist2QuarkOperator", "[", "p", "]"}]}]], "Input",
  CellLabel->"In[1678]:=  (21:57:14 on 5/16/01)",
  CellTags->"Twist2QuarkOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FormBox["\<\"\[Gamma]\"\>",
            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
          FormBox["\[CapitalDelta]",
            "TraditionalForm"]}], " ", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              FormBox["\[CapitalDelta]",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox["p",
                "TraditionalForm"]}], ")"}], 
          RowBox[{"m", "-", "1"}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1678]=  (21:57:14 on 5/16/01)"]
}, Closed]],

Cell["Quark-antiquark-gluon operator.", "Text",
  CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t5", "=", 
      RowBox[{"Twist2QuarkOperator", "[", 
        RowBox[{
          RowBox[{"{", "p", "}"}], ",", 
          RowBox[{"{", "q", "}"}], ",", 
          RowBox[{"{", 
            RowBox[{"k", ",", "\[Mu]", ",", "a"}], "}"}]}], "]"}]}]], "Input",\

  CellLabel->"In[1679]:=  (21:57:14 on 5/16/01)",
  CellTags->"Twist2QuarkOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox["g", "s"], " ", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              FormBox["\<\"\[Gamma]\"\>",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"]}], ")"}], ".", 
          SubscriptBox["T", 
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"]]}], " ", 
        RowBox[{"(", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", 
                  RowBox[{"i", "=", "0"}], 
                  RowBox[{"m", "-", "2"}]], 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{"-", "1"}], ")"}], "i"], " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["p",
                          "TraditionalForm"]}], ")"}], 
                    RowBox[{
                      RowBox[{"-", "i"}], "+", "m", "-", "2"}]], " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{
                        FormBox["\[CapitalDelta]",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}], ")"}], "i"]}]}],
              HoldForm],
            "TraditionalForm"], ")"}], " ", 
        SuperscriptBox[
          FormBox["\[CapitalDelta]",
            "TraditionalForm"], 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1679]=  (21:57:14 on 5/16/01)"]
}, Closed]],

Cell["Quark-antiquark-gluon-gluon operator.", "Text",
  CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t6", "=", 
      RowBox[{"Twist2QuarkOperator", "[", 
        RowBox[{
          RowBox[{"{", "p", "}"}], ",", 
          RowBox[{"{", "q", "}"}], ",", 
          RowBox[{"{", 
            RowBox[{"k", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{"r", ",", "\[Nu]", ",", "b"}], "}"}]}], "]"}]}]], "Input",\

  CellLabel->"In[1680]:=  (21:57:14 on 5/16/01)",
  CellTags->"Twist2QuarkOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "m"]}], " ", 
        SubsuperscriptBox["g", "s", "2"], " ", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              FormBox["\<\"\[Gamma]\"\>",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"]}], ")"}], ".", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{
                  SubscriptBox["T", 
                    FormBox[
                      FormBox["a",
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SubscriptBox["T", 
                    FormBox[
                      FormBox["b",
                        "TraditionalForm"],
                      "TraditionalForm"]]}], " ", 
                RowBox[{"(", 
                  RowBox[{
                    FormBox[
                      TagBox[
                        RowBox[{
                          UnderoverscriptBox["\[Sum]", 
                            RowBox[{"i", "=", "0"}], 
                            RowBox[{"m", "-", "3"}]], "\<\"\"\>"}],
                        HoldForm],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      RowBox[{
                        UnderoverscriptBox["\[Sum]", 
                          RowBox[{"j", "=", "0"}], "i"], "\<\"\"\>"}],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      RowBox[{
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{"-", 
                              RowBox[{"(", 
                                RowBox[{
                                  FormBox["\[CapitalDelta]",
                                    "TraditionalForm"], "\[NoBreak]", 
                                  "\[CenterDot]", "\[NoBreak]", 
                                  FormBox["p",
                                    "TraditionalForm"]}], ")"}]}], ")"}], 
                          RowBox[{
                            RowBox[{"-", "i"}], "+", "m", "-", "3"}]], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["q",
                                "TraditionalForm"]}], ")"}], "j"], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{
                                FormBox[
                                  FormBox[
                                    TagBox[
                                      StyleBox["\<\"k\"\>",
                                        FontSlant->"Italic"],
                                      (
                                      StyleForm[ #, FontSlant -> "Italic"]&)],
                                    
                                    "TraditionalForm"],
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"]}], "+", 
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["q",
                                  "TraditionalForm"]}]}], ")"}], 
                          RowBox[{"i", "-", "j"}]]}],
                      "TraditionalForm"]}], ")"}]}], "+", 
              RowBox[{
                RowBox[{
                  SubscriptBox["T", 
                    FormBox[
                      FormBox["b",
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SubscriptBox["T", 
                    FormBox[
                      FormBox["a",
                        "TraditionalForm"],
                      "TraditionalForm"]]}], " ", 
                RowBox[{"(", 
                  RowBox[{
                    FormBox[
                      TagBox[
                        RowBox[{
                          UnderoverscriptBox["\[Sum]", 
                            RowBox[{"i", "=", "0"}], 
                            RowBox[{"m", "-", "3"}]], "\<\"\"\>"}],
                        HoldForm],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      RowBox[{
                        UnderoverscriptBox["\[Sum]", 
                          RowBox[{"j", "=", "0"}], "i"], "\<\"\"\>"}],
                      "TraditionalForm"], "\[NoBreak]", 
                    FormBox[
                      RowBox[{
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{"-", 
                              RowBox[{"(", 
                                RowBox[{
                                  FormBox["\[CapitalDelta]",
                                    "TraditionalForm"], "\[NoBreak]", 
                                  "\[CenterDot]", "\[NoBreak]", 
                                  FormBox["p",
                                    "TraditionalForm"]}], ")"}]}], ")"}], 
                          RowBox[{
                            RowBox[{"-", "i"}], "+", "m", "-", "3"}]], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["q",
                                "TraditionalForm"]}], ")"}], "j"], " ", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["q",
                                  "TraditionalForm"]}], "+", 
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["r",
                                  "TraditionalForm"]}]}], ")"}], 
                          RowBox[{"i", "-", "j"}]]}],
                      "TraditionalForm"]}], ")"}]}]}], ")"}]}], " ", 
        SuperscriptBox[
          FormBox["\[CapitalDelta]",
            "TraditionalForm"], 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]], " ", 
        SuperscriptBox[
          FormBox["\[CapitalDelta]",
            "TraditionalForm"], 
          FormBox[
            FormBox["\[Nu]",
              "TraditionalForm"],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1680]=  (21:57:14 on 5/16/01)"]
}, Closed]],

Cell["This shows the FeynCalcExternal (FCE) form.", "Text",
  CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"Twist2QuarkOperator", "[", "p", "]"}], "//", "FCE"}], "//", 
      "StandardForm"}]], "Input",
  CellLabel->"In[1681]:=  (21:57:14 on 5/16/01)",
  CellTags->"Twist2QuarkOperator"],

Cell[BoxData[
    RowBox[{
      RowBox[{"GSD", "[", "OPEDelta", "]"}], " ", 
      SuperscriptBox[
        RowBox[{"SOD", "[", "p", "]"}], 
        RowBox[{
          RowBox[{"-", "1"}], "+", "OPEm"}]]}]], "Output",
  CellLabel->"Out[1681]//StandardForm=  (21:57:14 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Twist2QuarkOperator", "[", 
      RowBox[{
        RowBox[{"{", "p", "}"}], ",", 
        RowBox[{"{", "q", "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"k", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
        RowBox[{"Explicit", "\[Rule]", "All"}], ",", 
        RowBox[{"Polarization", "\[Rule]", "0"}]}], "]"}]], "Input",
  CellLabel->"In[1682]:=  (21:57:14 on 5/16/01)",
  CellTags->"Twist2QuarkOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          SubscriptBox["g", "s"]}], " ", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              FormBox["\<\"\[Gamma]\"\>",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"]}], ")"}], ".", 
          SubscriptBox["T", 
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"]]}], " ", 
        SuperscriptBox[
          FormBox["\[CapitalDelta]",
            "TraditionalForm"], 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]], " ", 
        RowBox[{"(", 
          RowBox[{
            FractionBox[
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    FormBox["\[CapitalDelta]",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["p",
                      "TraditionalForm"]}], ")"}], 
                RowBox[{"m", "-", "1"}]], 
              RowBox[{
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["p",
                    "TraditionalForm"]}], "+", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}]], "+", 
            FractionBox[
              RowBox[{
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"-", "1"}], ")"}], "m"], " ", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{
                      FormBox["\[CapitalDelta]",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["q",
                        "TraditionalForm"]}], ")"}], 
                  RowBox[{"m", "-", "1"}]]}], 
              RowBox[{
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["p",
                    "TraditionalForm"]}], "+", 
                RowBox[{
                  FormBox["\[CapitalDelta]",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}]]}], ")"}]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1682]=  (21:57:14 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Twist2QuarkOperator", "[", 
      RowBox[{
        RowBox[{"{", "p", "}"}], ",", 
        RowBox[{"{", "q", "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"k", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"r", ",", "\[Nu]", ",", "b"}], "}"}], ",", 
        RowBox[{"Explicit", "\[Rule]", "All"}], ",", 
        RowBox[{"Polarization", "\[Rule]", "0"}]}], "]"}]], "Input",
  CellLabel->"In[1683]:=  (21:57:15 on 5/16/01)",
  CellTags->"Twist2QuarkOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          SubsuperscriptBox["g", "s", "2"]}], " ", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              FormBox["\<\"\[Gamma]\"\>",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"]}], ")"}], ".", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{
                  SubscriptBox["T", 
                    FormBox[
                      FormBox["a",
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SubscriptBox["T", 
                    FormBox[
                      FormBox["b",
                        "TraditionalForm"],
                      "TraditionalForm"]]}], " ", 
                RowBox[{"(", 
                  RowBox[{
                    FractionBox[
                      RowBox[{
                        FormBox[
                          SuperscriptBox[
                            RowBox[{"(", 
                              RowBox[{"-", "1"}], ")"}], 
                            RowBox[{"m", "-", "1"}]],
                          "TraditionalForm"], " ", 
                        FormBox[
                          SuperscriptBox[
                            RowBox[{"(", 
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["p",
                                  "TraditionalForm"]}], ")"}], 
                            RowBox[{"m", "-", "1"}]],
                          "TraditionalForm"]}], 
                      RowBox[{
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["p",
                                "TraditionalForm"]}], "+", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["q",
                                "TraditionalForm"]}]}], ")"}], " ", 
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              FormBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["\<\"k\"\>",
                                      FontSlant->"Italic"],
                                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                                  "TraditionalForm"],
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"]}], "+", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["p",
                                "TraditionalForm"]}], "+", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["q",
                                "TraditionalForm"]}]}], ")"}]}]], "-", 
                    FractionBox[
                      FormBox[
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["q",
                                "TraditionalForm"]}], ")"}], 
                          RowBox[{"m", "-", "1"}]],
                        "TraditionalForm"], 
                      RowBox[{
                        RowBox[{
                          FormBox[
                            FormBox[
                              TagBox[
                                StyleBox["\<\"k\"\>",
                                  FontSlant->"Italic"],
                                (StyleForm[ #, FontSlant -> "Italic"]&)],
                              "TraditionalForm"],
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"]}], " ", 
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["p",
                                "TraditionalForm"]}], "+", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["q",
                                "TraditionalForm"]}]}], ")"}]}]], "+", 
                    FractionBox[
                      FormBox[
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{
                                FormBox[
                                  FormBox[
                                    TagBox[
                                      StyleBox["\<\"k\"\>",
                                        FontSlant->"Italic"],
                                      (
                                      StyleForm[ #, FontSlant -> "Italic"]&)],
                                    
                                    "TraditionalForm"],
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"]}], "+", 
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["q",
                                  "TraditionalForm"]}]}], ")"}], 
                          RowBox[{"m", "-", "1"}]],
                        "TraditionalForm"], 
                      RowBox[{
                        RowBox[{
                          FormBox[
                            FormBox[
                              TagBox[
                                StyleBox["\<\"k\"\>",
                                  FontSlant->"Italic"],
                                (StyleForm[ #, FontSlant -> "Italic"]&)],
                              "TraditionalForm"],
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"]}], " ", 
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              FormBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["\<\"k\"\>",
                                      FontSlant->"Italic"],
                                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                                  "TraditionalForm"],
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"]}], "+", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["p",
                                "TraditionalForm"]}], "+", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["q",
                                "TraditionalForm"]}]}], ")"}]}]]}], ")"}]}], 
              "+", 
              RowBox[{
                RowBox[{
                  SubscriptBox["T", 
                    FormBox[
                      FormBox["b",
                        "TraditionalForm"],
                      "TraditionalForm"]], ".", 
                  SubscriptBox["T", 
                    FormBox[
                      FormBox["a",
                        "TraditionalForm"],
                      "TraditionalForm"]]}], " ", 
                RowBox[{"(", 
                  RowBox[{
                    FractionBox[
                      RowBox[{
                        FormBox[
                          SuperscriptBox[
                            RowBox[{"(", 
                              RowBox[{"-", "1"}], ")"}], 
                            RowBox[{"m", "-", "1"}]],
                          "TraditionalForm"], " ", 
                        FormBox[
                          SuperscriptBox[
                            RowBox[{"(", 
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["p",
                                  "TraditionalForm"]}], ")"}], 
                            RowBox[{"m", "-", "1"}]],
                          "TraditionalForm"]}], 
                      RowBox[{
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["p",
                                "TraditionalForm"]}], "+", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["q",
                                "TraditionalForm"]}]}], ")"}], " ", 
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["p",
                                "TraditionalForm"]}], "+", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["q",
                                "TraditionalForm"]}], "+", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["r",
                                "TraditionalForm"]}]}], ")"}]}]], "-", 
                    FractionBox[
                      FormBox[
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["q",
                                "TraditionalForm"]}], ")"}], 
                          RowBox[{"m", "-", "1"}]],
                        "TraditionalForm"], 
                      RowBox[{
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["p",
                                "TraditionalForm"]}], "+", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["q",
                                "TraditionalForm"]}]}], ")"}], " ", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["r",
                            "TraditionalForm"]}]}]], "+", 
                    FractionBox[
                      FormBox[
                        SuperscriptBox[
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["q",
                                  "TraditionalForm"]}], "+", 
                              RowBox[{
                                FormBox["\[CapitalDelta]",
                                  "TraditionalForm"], "\[NoBreak]", 
                                "\[CenterDot]", "\[NoBreak]", 
                                FormBox["r",
                                  "TraditionalForm"]}]}], ")"}], 
                          RowBox[{"m", "-", "1"}]],
                        "TraditionalForm"], 
                      RowBox[{
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["r",
                            "TraditionalForm"]}], " ", 
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["p",
                                "TraditionalForm"]}], "+", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["q",
                                "TraditionalForm"]}], "+", 
                            RowBox[{
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["r",
                                "TraditionalForm"]}]}], ")"}]}]]}], ")"}]}]}],
             ")"}]}], " ", 
        SuperscriptBox[
          FormBox["\[CapitalDelta]",
            "TraditionalForm"], 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]], " ", 
        SuperscriptBox[
          FormBox["\[CapitalDelta]",
            "TraditionalForm"], 
          FormBox[
            FormBox["\[Nu]",
              "TraditionalForm"],
            "TraditionalForm"]], " ", 
        FormBox[
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "m"],
          "TraditionalForm"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1683]=  (21:57:15 on 5/16/01)"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Polarized case, non-zero momentum insertion", "Subsubsection",
  CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SetOptions", "[", 
      RowBox[{"Twist2QuarkOperator", ",", 
        RowBox[{"Polarization", "\[Rule]", "1"}], ",", 
        RowBox[{"ZeroMomentumInsertion", "\[Rule]", "False"}]}], 
      "]"}]], "Input",
  CellLabel->"In[1684]:=  (21:57:15 on 5/16/01)",
  CellTags->"Twist2QuarkOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"CouplingConstant", "\[Rule]", 
            SubscriptBox["g", "s"]}], ",", 
          RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
          RowBox[{"Explicit", "\[Rule]", "True"}], ",", 
          RowBox[{"Polarization", "\[Rule]", "1"}], ",", 
          RowBox[{"ZeroMomentumInsertion", "\[Rule]", "False"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1684]=  (21:57:15 on 5/16/01)"]
}, Closed]],

Cell["\<\
With the setting ZeroMomentumInsertion \[Rule] False a non-zero momentum is \
assumed to flow into the operator vertex. \
\>", "Text",
  CellTags->"Twist2QuarkOperator"],

Cell["\<\
This is the Feynman rule associated with the quark-antiquark operator, where \
p is the momentum of the incoming quark and q the momentum of the antiquark. \
The momentum flowing into the operator vertex is thus -p-q.\
\>", "Text",
  CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t1", "=", 
      RowBox[{"Twist2QuarkOperator", "[", 
        RowBox[{"{", 
          RowBox[{"p", ",", "q"}], "}"}], "]"}]}]], "Input",
  CellLabel->"In[1685]:=  (21:57:15 on 5/16/01)",
  CellTags->"Twist2QuarkOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["2", 
          RowBox[{"1", "-", "m"}]], " ", 
        RowBox[{
          SuperscriptBox["\[Gamma]", "5"], ".", 
          RowBox[{"(", 
            RowBox[{
              FormBox["\<\"\[Gamma]\"\>",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"]}], ")"}]}], " ", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["p",
                  "TraditionalForm"]}], "-", 
              RowBox[{
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}]}], ")"}], 
          RowBox[{"m", "-", "1"}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1685]=  (21:57:15 on 5/16/01)"]
}, Closed]],

Cell["This is the quark-antiquark-gluon operator vertex.", "Text",
  CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t2", "=", 
      RowBox[{"Twist2QuarkOperator", "[", 
        RowBox[{
          RowBox[{"{", "p", "}"}], ",", 
          RowBox[{"{", "q", "}"}], ",", 
          RowBox[{"{", 
            RowBox[{"k", ",", "\[Mu]", ",", "a"}], "}"}]}], "]"}]}]], "Input",\

  CellLabel->"In[1686]:=  (21:57:15 on 5/16/01)",
  CellTags->"Twist2QuarkOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["2", 
          RowBox[{"2", "-", "m"}]], " ", 
        SubscriptBox["g", "s"], " ", 
        RowBox[{
          SubscriptBox["T", 
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"]], ".", 
          SuperscriptBox["\[Gamma]", "5"], ".", 
          RowBox[{"(", 
            RowBox[{
              FormBox["\<\"\[Gamma]\"\>",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"]}], ")"}]}], " ", 
        RowBox[{"(", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", 
                  RowBox[{"i", "=", "0"}], 
                  RowBox[{"m", "-", "2"}]], 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{"-", 
                          RowBox[{"(", 
                            RowBox[{
                              FormBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["\<\"k\"\>",
                                      FontSlant->"Italic"],
                                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                                  "TraditionalForm"],
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"]}], ")"}]}], "+", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["p",
                            "TraditionalForm"]}], "-", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["q",
                            "TraditionalForm"]}]}], ")"}], 
                    RowBox[{
                      RowBox[{"-", "i"}], "+", "m", "-", "2"}]], " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          FormBox[
                            FormBox[
                              TagBox[
                                StyleBox["\<\"k\"\>",
                                  FontSlant->"Italic"],
                                (StyleForm[ #, FontSlant -> "Italic"]&)],
                              "TraditionalForm"],
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"]}], "+", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["p",
                            "TraditionalForm"]}], "-", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["q",
                            "TraditionalForm"]}]}], ")"}], "i"]}]}],
              HoldForm],
            "TraditionalForm"], ")"}], " ", 
        SuperscriptBox[
          FormBox["\[CapitalDelta]",
            "TraditionalForm"], 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1686]=  (21:57:15 on 5/16/01)"]
}, Closed]],

Cell["This shows the FeynCalcExternal form.", "Text",
  CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StandardForm", "[", 
      RowBox[{"FCE", "[", "t2", "]"}], "]"}]], "Input",
  CellLabel->"In[1687]:=  (21:57:15 on 5/16/01)",
  CellTags->"Twist2QuarkOperator"],

Cell[BoxData[
    RowBox[{
      SuperscriptBox["2", 
        RowBox[{"2", "-", "OPEm"}]], " ", "Gstrong", " ", 
      RowBox[{
        RowBox[{"SUNT", "[", "a", "]"}], ".", 
        RowBox[{"GA", "[", "5", "]"}], ".", 
        RowBox[{"GSD", "[", "OPEDelta", "]"}]}], " ", 
      RowBox[{"FVD", "[", 
        RowBox[{"OPEDelta", ",", "\[Mu]"}], "]"}], " ", 
      RowBox[{"OPESum", "[", 
        RowBox[{
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"-", 
                    RowBox[{"SOD", "[", "k", "]"}]}], "+", 
                  RowBox[{"SOD", "[", "p", "]"}], "-", 
                  RowBox[{"SOD", "[", "q", "]"}]}], ")"}], 
              RowBox[{
                RowBox[{"-", "2"}], "-", "OPEi", "+", "OPEm"}]], " ", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"SOD", "[", "k", "]"}], "+", 
                  RowBox[{"SOD", "[", "p", "]"}], "-", 
                  RowBox[{"SOD", "[", "q", "]"}]}], ")"}], "OPEi"]}], ",", 
          RowBox[{"{", 
            RowBox[{"OPEi", ",", "0", ",", 
              RowBox[{
                RowBox[{"-", "2"}], "+", "OPEm"}]}], "}"}]}], 
        "]"}]}]], "Output",
  CellLabel->"Out[1687]//StandardForm=  (21:57:15 on 5/16/01)"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Unpolarized case, non-zero momentum insertion", "Subsubsection",
  CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SetOptions", "[", 
      RowBox[{"Twist2QuarkOperator", ",", 
        RowBox[{"Polarization", "\[Rule]", "1"}], ",", 
        RowBox[{"ZeroMomentumInsertion", "\[Rule]", "False"}]}], 
      "]"}]], "Input",
  CellLabel->"In[1688]:=  (21:57:15 on 5/16/01)",
  CellTags->"Twist2QuarkOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"CouplingConstant", "\[Rule]", 
            SubscriptBox["g", "s"]}], ",", 
          RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
          RowBox[{"Explicit", "\[Rule]", "True"}], ",", 
          RowBox[{"Polarization", "\[Rule]", "1"}], ",", 
          RowBox[{"ZeroMomentumInsertion", "\[Rule]", "False"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1688]=  (21:57:15 on 5/16/01)"]
}, Closed]],

Cell["Quark-antiquark operator.", "Text",
  CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t4", "=", 
      RowBox[{"Twist2QuarkOperator", "[", 
        RowBox[{"{", 
          RowBox[{"p", ",", "q"}], "}"}], "]"}]}]], "Input",
  CellLabel->"In[1689]:=  (21:57:15 on 5/16/01)",
  CellTags->"Twist2QuarkOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["2", 
          RowBox[{"1", "-", "m"}]], " ", 
        RowBox[{
          SuperscriptBox["\[Gamma]", "5"], ".", 
          RowBox[{"(", 
            RowBox[{
              FormBox["\<\"\[Gamma]\"\>",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"]}], ")"}]}], " ", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["p",
                  "TraditionalForm"]}], "-", 
              RowBox[{
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}]}], ")"}], 
          RowBox[{"m", "-", "1"}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1689]=  (21:57:15 on 5/16/01)"]
}, Closed]],

Cell["Quark-antiquark-gluon operator.", "Text",
  CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t5", "=", 
      RowBox[{"Twist2QuarkOperator", "[", 
        RowBox[{
          RowBox[{"{", "p", "}"}], ",", 
          RowBox[{"{", "q", "}"}], ",", 
          RowBox[{"{", 
            RowBox[{"k", ",", "\[Mu]", ",", "a"}], "}"}]}], "]"}]}]], "Input",\

  CellLabel->"In[1690]:=  (21:57:15 on 5/16/01)",
  CellTags->"Twist2QuarkOperator"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["2", 
          RowBox[{"2", "-", "m"}]], " ", 
        SubscriptBox["g", "s"], " ", 
        RowBox[{
          SubscriptBox["T", 
            FormBox[
              FormBox["a",
                "TraditionalForm"],
              "TraditionalForm"]], ".", 
          SuperscriptBox["\[Gamma]", "5"], ".", 
          RowBox[{"(", 
            RowBox[{
              FormBox["\<\"\[Gamma]\"\>",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox["\[CapitalDelta]",
                "TraditionalForm"]}], ")"}]}], " ", 
        RowBox[{"(", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", 
                  RowBox[{"i", "=", "0"}], 
                  RowBox[{"m", "-", "2"}]], 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{"-", 
                          RowBox[{"(", 
                            RowBox[{
                              FormBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["\<\"k\"\>",
                                      FontSlant->"Italic"],
                                    (StyleForm[ #, FontSlant -> "Italic"]&)],
                                  "TraditionalForm"],
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["\[CapitalDelta]",
                                "TraditionalForm"]}], ")"}]}], "+", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["p",
                            "TraditionalForm"]}], "-", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["q",
                            "TraditionalForm"]}]}], ")"}], 
                    RowBox[{
                      RowBox[{"-", "i"}], "+", "m", "-", "2"}]], " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          FormBox[
                            FormBox[
                              TagBox[
                                StyleBox["\<\"k\"\>",
                                  FontSlant->"Italic"],
                                (StyleForm[ #, FontSlant -> "Italic"]&)],
                              "TraditionalForm"],
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"]}], "+", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["p",
                            "TraditionalForm"]}], "-", 
                        RowBox[{
                          FormBox["\[CapitalDelta]",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["q",
                            "TraditionalForm"]}]}], ")"}], "i"]}]}],
              HoldForm],
            "TraditionalForm"], ")"}], " ", 
        SuperscriptBox[
          FormBox["\[CapitalDelta]",
            "TraditionalForm"], 
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1690]=  (21:57:15 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      RowBox[{"Clear", "[", 
        RowBox[{"t1", ",", "t2", ",", "t3", ",", "t4", ",", "t5", ",", "t6"}],
         "]"}], ";"}]], "Input",
  CellLabel->"In[1691]:=  (21:57:15 on 5/16/01)",
  CellTags->"Twist2QuarkOperator"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Uncontract", "ObjectName",
  CellTags->"Uncontract"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"Uncontract"],

Cell["\<\
Uncontract[exp, q1, q2, ...] uncontracts Eps and DiracGamma. Uncontract[exp, \
q1, q2, Pair -> {p}] uncontracts also p.q1 and p.q2; the option Pair -> All \
uncontracts all momenta except OPEDelta.\
\>", "Text",
  CellTags->"Uncontract"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "Uncontract", "]"}]], "Input",
  CellLabel->"In[1692]:=  (21:57:15 on 5/16/01)",
  CellTags->"Uncontract"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
          RowBox[{"DimensionalReduction", "\[Rule]", "False"}], ",", 
          RowBox[{"Pair", "\[Rule]", 
            RowBox[{"{", "}"}]}], ",", 
          RowBox[{"Unique", "\[Rule]", "True"}]}], "}"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1692]=  (21:57:15 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["Contract",
    ButtonData:>"Contract",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Contract"],
  "."
}], "Text",
  CellTags->"Uncontract"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"Uncontract"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t1", " ", "=", " ", 
      RowBox[{
        RowBox[{"LeviCivita", "[", 
          RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], "[", 
        RowBox[{"p", ",", "q"}], "]"}]}]], "Input",
  CellLabel->"In[1693]:=  (21:57:15 on 5/16/01)",
  CellTags->"Uncontract"],

Cell[BoxData[
    FormBox[
      SuperscriptBox["\[Epsilon]", 
        RowBox[{
          FormBox[
            FormBox["\[Mu]",
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", 
          FormBox[
            FormBox["\[Nu]",
              "TraditionalForm"],
            "TraditionalForm"], "\[NoBreak]", 
          FormBox["p",
            "TraditionalForm"], "\[NoBreak]", 
          FormBox["q",
            "TraditionalForm"]}]], TraditionalForm]], "Output",
  CellLabel->"Out[1693]=  (21:57:15 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Uncontract", "[", 
      RowBox[{"t1", ",", " ", "p"}], "]"}]], "Input",
  CellLabel->"In[1694]:=  (21:57:15 on 5/16/01)",
  CellTags->"Uncontract"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Epsilon]", 
          RowBox[{
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox[
                RowBox[{"$AL$4040", "\[InvisibleApplication]", 
                  RowBox[{"(", "1", ")"}]}],
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox["q",
              "TraditionalForm"]}]], " ", 
        SuperscriptBox[
          FormBox["p",
            "TraditionalForm"], 
          FormBox[
            FormBox[
              RowBox[{"$AL$4040", "\[InvisibleApplication]", 
                RowBox[{"(", "1", ")"}]}],
              "TraditionalForm"],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1694]=  (21:57:15 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t2", "=", 
      RowBox[{"DiracSlash", "[", "p", "]"}]}]], "Input",
  CellLabel->"In[1695]:=  (21:57:15 on 5/16/01)",
  CellTags->"Uncontract"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox["\<\"\[Gamma]\"\>",
          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
        FormBox["p",
          "TraditionalForm"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1695]=  (21:57:15 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Uncontract", "[", 
      RowBox[{"t2", ",", " ", "p"}], "]"}]], "Input",
  CellLabel->"In[1696]:=  (21:57:15 on 5/16/01)",
  CellTags->"Uncontract"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", 
          FormBox[
            FormBox[
              RowBox[{"$AL$4041", "\[InvisibleApplication]", 
                RowBox[{"(", "1", ")"}]}],
              "TraditionalForm"],
            "TraditionalForm"]], " ", 
        SuperscriptBox[
          FormBox["p",
            "TraditionalForm"], 
          FormBox[
            FormBox[
              RowBox[{"$AL$4041", "\[InvisibleApplication]", 
                RowBox[{"(", "1", ")"}]}],
              "TraditionalForm"],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1696]=  (21:57:15 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Uncontract", "[", 
      RowBox[{"t1", ",", " ", "p", ",", "q"}], "]"}]], "Input",
  CellLabel->"In[1697]:=  (21:57:16 on 5/16/01)",
  CellTags->"Uncontract"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Epsilon]", 
          RowBox[{
            FormBox[
              FormBox["\[Mu]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox["\[Nu]",
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox[
                RowBox[{"$AL$4043", "\[InvisibleApplication]", 
                  RowBox[{"(", "1", ")"}]}],
                "TraditionalForm"],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              FormBox[
                RowBox[{"$AL$4042", "\[InvisibleApplication]", 
                  RowBox[{"(", "1", ")"}]}],
                "TraditionalForm"],
              "TraditionalForm"]}]], " ", 
        SuperscriptBox[
          FormBox["q",
            "TraditionalForm"], 
          FormBox[
            FormBox[
              RowBox[{"$AL$4042", "\[InvisibleApplication]", 
                RowBox[{"(", "1", ")"}]}],
              "TraditionalForm"],
            "TraditionalForm"]], " ", 
        SuperscriptBox[
          FormBox["p",
            "TraditionalForm"], 
          FormBox[
            FormBox[
              RowBox[{"$AL$4043", "\[InvisibleApplication]", 
                RowBox[{"(", "1", ")"}]}],
              "TraditionalForm"],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1697]=  (21:57:16 on 5/16/01)"]
}, Closed]],

Cell["By default scalar products are not uncontracted.", "Text",
  CellTags->"Uncontract"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Uncontract", "[", 
      RowBox[{
        RowBox[{"ScalarProduct", "[", 
          RowBox[{"p", ",", "q"}], "]"}], ",", " ", "q"}], "]"}]], "Input",
  CellLabel->"In[1698]:=  (21:57:16 on 5/16/01)",
  CellTags->"Uncontract"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox["p",
          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
        FormBox["q",
          "TraditionalForm"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1698]=  (21:57:16 on 5/16/01)"]
}, Closed]],

Cell["\<\
With the option Pair\[Rule]All they are \[OpenCurlyDoubleQuote]uncontracted \
\[CloseCurlyDoubleQuote].\
\>", "Text",
  CellTags->"Uncontract"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Uncontract", "[", 
      RowBox[{
        RowBox[{"ScalarProduct", "[", 
          RowBox[{"p", ",", "q"}], "]"}], ",", "q", ",", 
        RowBox[{"Pair", "\[Rule]", "All"}]}], "]"}]], "Input",
  CellLabel->"In[1699]:=  (21:57:16 on 5/16/01)",
  CellTags->"Uncontract"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox[
          FormBox["p",
            "TraditionalForm"], 
          FormBox[
            FormBox[
              RowBox[{"$AL$4045", "\[InvisibleApplication]", 
                RowBox[{"(", "1", ")"}]}],
              "TraditionalForm"],
            "TraditionalForm"]], " ", 
        SuperscriptBox[
          FormBox["q",
            "TraditionalForm"], 
          FormBox[
            FormBox[
              RowBox[{"$AL$4045", "\[InvisibleApplication]", 
                RowBox[{"(", "1", ")"}]}],
              "TraditionalForm"],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1699]=  (21:57:16 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Uncontract", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"ScalarProduct", "[", 
            RowBox[{"p", ",", "q"}], "]"}], "^", "2"}], ",", "q", ",", 
        RowBox[{"Pair", "\[Rule]", "All"}]}], "]"}]], "Input",
  CellLabel->"In[1700]:=  (21:57:16 on 5/16/01)",
  CellTags->"Uncontract"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox[
          FormBox["p",
            "TraditionalForm"], 
          FormBox[
            FormBox[
              RowBox[{"$AL$4046", "\[InvisibleApplication]", 
                RowBox[{"(", "1", ")"}]}],
              "TraditionalForm"],
            "TraditionalForm"]], " ", 
        SuperscriptBox[
          FormBox["q",
            "TraditionalForm"], 
          FormBox[
            FormBox[
              RowBox[{"$AL$4046", "\[InvisibleApplication]", 
                RowBox[{"(", "1", ")"}]}],
              "TraditionalForm"],
            "TraditionalForm"]], " ", 
        SuperscriptBox[
          FormBox["p",
            "TraditionalForm"], 
          FormBox[
            FormBox[
              RowBox[{"$AL$4046", "\[InvisibleApplication]", 
                RowBox[{"(", "2", ")"}]}],
              "TraditionalForm"],
            "TraditionalForm"]], " ", 
        SuperscriptBox[
          FormBox["q",
            "TraditionalForm"], 
          FormBox[
            FormBox[
              RowBox[{"$AL$4046", "\[InvisibleApplication]", 
                RowBox[{"(", "2", ")"}]}],
              "TraditionalForm"],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1700]=  (21:57:16 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{"Clear", "[", 
      RowBox[{"t1", ",", "t2"}], "]"}]], "Input",
  CellLabel->"In[1701]:=  (21:57:16 on 5/16/01)",
  CellTags->"Uncontract"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["UnDeclareNonCommutative", "ObjectName",
  CellTags->"UnDeclareNonCommutative"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"UnDeclareNonCommutative"],

Cell["\<\
UnDeclareNonCommutative[a, b, ...] undeclares a,b, ... to be noncommutative, \
i.e., DataType[a,b, ..., NonCommutative] is set to False.\
\>", "Text",
  CellTags->"UnDeclareNonCommutative"],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["DataType",
    ButtonData:>"DataType",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DataType"],
  ", ",
  ButtonBox["DeclareNonCommutative",
    ButtonData:>"DeclareNonCommutative",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DeclareNonCommutative"],
  "."
}], "Text",
  CellTags->"UnDeclareNonCommutative"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"UnDeclareNonCommutative"],

Cell[BoxData[
    RowBox[{"DeclareNonCommutative", "[", "x", "]"}]], "Input",
  CellLabel->"In[1702]:=  (21:57:16 on 5/16/01)",
  CellTags->"UnDeclareNonCommutative"],

Cell["\<\
As a side-effect of DeclareNonCommutative x is declared to be of DataType \
NonCommutative.\
\>", "Text",
  CellTags->"UnDeclareNonCommutative"],

Cell[CellGroupData[{

Cell["DataType[x,NonCommutative]", "Input",
  CellLabel->"In[1703]:=  (21:57:16 on 5/16/01)",
  CellTags->"UnDeclareNonCommutative"],

Cell[BoxData[
    FormBox["True", TraditionalForm]], "Output",
  CellLabel->"Out[1703]=  (21:57:16 on 5/16/01)"]
}, Closed]],

Cell["The inverse operation is UnDeclareNonCommutative.", "Text",
  CellTags->"UnDeclareNonCommutative"],

Cell[BoxData[
    RowBox[{"UnDeclareNonCommutative", "[", "x", "]"}]], "Input",
  CellLabel->"In[1704]:=  (21:57:16 on 5/16/01)",
  CellTags->"UnDeclareNonCommutative"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DataType", "[", 
      RowBox[{"x", ",", "NonCommutative"}], "]"}]], "Input",
  CellLabel->"In[1705]:=  (21:57:16 on 5/16/01)",
  CellTags->"UnDeclareNonCommutative"],

Cell[BoxData[
    FormBox["False", TraditionalForm]], "Output",
  CellLabel->"Out[1705]=  (21:57:16 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{"DeclareNonCommutative", "[", 
      RowBox[{"y", ",", "z"}], "]"}]], "Input",
  CellLabel->"In[1706]:=  (21:57:16 on 5/16/01)",
  CellTags->"UnDeclareNonCommutative"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DataType", "[", 
      RowBox[{"y", ",", "z", ",", "NonCommutative"}], "]"}]], "Input",
  CellLabel->"In[1707]:=  (21:57:16 on 5/16/01)",
  CellTags->"UnDeclareNonCommutative"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"True", ",", "True"}], "}"}], TraditionalForm]], "Output",
  CellLabel->"Out[1707]=  (21:57:16 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{"UnDeclareNonCommutative", "[", 
      RowBox[{"y", ",", "z"}], "]"}]], "Input",
  CellLabel->"In[1708]:=  (21:57:16 on 5/16/01)",
  CellTags->"UnDeclareNonCommutative"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DataType", "[", 
      RowBox[{"y", ",", "z", ",", "NonCommutative"}], "]"}]], "Input",
  CellLabel->"In[1709]:=  (21:57:17 on 5/16/01)",
  CellTags->"UnDeclareNonCommutative"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"False", ",", "False"}], "}"}], TraditionalForm]], "Output",
  CellLabel->"Out[1709]=  (21:57:17 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Write2", "ObjectName",
  CellTags->"Write2"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"Write2"],

Cell["\<\
Write2[file, val1 = expr1, val2 = expr2, ...] writes the settings val1 = \
expr1, val2 = expr2 in sequence followed by a newline, to the specified \
output file. Setting the option FormatType of Write2 to FortranForm results \
in FORTRAN syntax output.\
\>", "Text",
  CellTags->"Write2"],

Cell["\<\
The continuation character for FORTRAN output can be controlled by changing \
$FortranContinuationCharacter.\
\>", "Text",
  CellTags->"Write2"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FullForm", "[", "$FortranContinuationCharacter", "]"}]], "Input",\

  CellLabel->"In[1710]:=  (21:57:17 on 5/16/01)",
  CellTags->"Write2"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox["\"\<&\>\"",
          ShowSpecialCharacters->False,
          ShowStringCharacters->True,
          NumberMarks->True],
        FullForm], TraditionalForm]], "Output",
  CellLabel->"Out[1710]//FullForm=  (21:57:17 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Options", "[", "Write2", "]"}]], "Input",
  CellLabel->"In[1711]:=  (21:57:17 on 5/16/01)",
  CellTags->"Write2"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"FinalSubstitutions", "\[Rule]", 
            RowBox[{"{", "}"}]}], ",", 
          RowBox[{"FormatType", "\[Rule]", "InputForm"}], ",", 
          RowBox[{"D0Convention", "\[Rule]", "0"}], ",", 
          RowBox[{"PageWidth", "\[Rule]", "62"}], ",", 
          RowBox[{"PreFortranFile", "\[Rule]", "\<\"\"\>"}], ",", 
          RowBox[{"PostFortranFile", "\[Rule]", "\<\"\"\>"}], ",", 
          RowBox[{"StringReplace", "\[Rule]", 
            RowBox[{"{", "}"}]}]}], "}"}], TraditionalForm]], "Output",
  CellLabel->"Out[1711]=  (21:57:17 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Attributes", "[", "Write2", "]"}]], "Input",
  CellLabel->"In[1712]:=  (21:57:17 on 5/16/01)",
  CellTags->"Write2"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", "HoldRest", "}"}], TraditionalForm]], "Output",
  CellLabel->"Out[1712]=  (21:57:17 on 5/16/01)"]
}, Closed]],

Cell[TextData[{
  "See also: ",
  " ",
  ButtonBox["Isolate",
    ButtonData:>"Isolate",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Isolate"],
  ", ",
  ButtonBox["PaVeReduce",
    ButtonData:>"PaVeReduce",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"PaVeReduce"],
  "."
}], "Text",
  CellTags->"Write2"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"Write2"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t", "=", 
      RowBox[{"Collect", "[", 
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"a", "-", "c"}], ")"}], "2"], "+", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"a", "-", "b"}], ")"}], "2"]}], ")"}], "2"], ",", 
          "a", ",", "Factor"}], "]"}]}]], "Input",
  CellLabel->"In[1713]:=  (21:57:17 on 5/16/01)",
  CellTags->"Write2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"4", " ", 
          SuperscriptBox["a", "4"]}], "-", 
        RowBox[{"8", " ", 
          RowBox[{"(", 
            RowBox[{"b", "+", "c"}], ")"}], " ", 
          SuperscriptBox["a", "3"]}], "+", 
        RowBox[{"8", " ", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox["b", "2"], "+", 
              RowBox[{"c", " ", "b"}], "+", 
              SuperscriptBox["c", "2"]}], ")"}], " ", 
          SuperscriptBox["a", "2"]}], "-", 
        RowBox[{"4", " ", 
          RowBox[{"(", 
            RowBox[{"b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox["b", "2"], "+", 
              SuperscriptBox["c", "2"]}], ")"}], " ", "a"}], "+", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox["b", "2"], "+", 
              SuperscriptBox["c", "2"]}], ")"}], "2"]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1713]=  (21:57:17 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      RowBox[{"tempfilename", "=", 
        RowBox[{
          RowBox[{"ToString", "[", "$SessionID", "]"}], "<>", 
          "\"\<.s\>\""}]}], ";"}]], "Input",
  CellLabel->"In[1714]:=  (21:57:17 on 5/16/01)",
  CellTags->"Write2"],

Cell["This writes the assignment r=t to a file.", "Text",
  CellTags->"Write2"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Write2", "[", 
        RowBox[{"tempfilename", ",", 
          RowBox[{"r", "=", "t"}]}], "]"}], ";"}]], "Input",
  CellLabel->"In[1715]:=  (21:57:17 on 5/16/01)",
  CellTags->"Write2"],

Cell["This shows the contents of the file.", "Text",
  CellTags->"Write2"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"TableForm", "[", 
      RowBox[{"ReadList", "[", 
        RowBox[{
          RowBox[{
            RowBox[{"If", "[", 
              RowBox[{
                RowBox[{"$OperatingSystem", "===", "\"\<MacOS\>\""}], ",", 
                "\"\<:\>\"", ",", "\"\<\>\""}], "]"}], "<>", "tempfilename"}],
           ",", "String"}], "]"}], "]"}]], "Input",
  CellLabel->"In[1716]:=  (21:57:17 on 5/16/01)",
  CellTags->"Write2"],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {"\<\"r = ( 4*a^4 - 8*a^3*(b + c) - 4*a*(b + c)*(b^2 + c^2) + \
\"\>"},
            {"\<\" (b^2 + c^2)^2 + 8*a^2*(b^2 + b*c + c^2)\"\>"},
            {"\<\"       );\"\>"}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        TableForm[ {
          "r = ( 4*a^4 - 8*a^3*(b + c) - 4*a*(b + c)*(b^2 + c^2) + ", 
          " (b^2 + c^2)^2 + 8*a^2*(b^2 + b*c + c^2)", "       );"}]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1716]//TableForm=  (21:57:17 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{"DeleteFile", "[", 
      RowBox[{
        RowBox[{"If", "[", 
          RowBox[{
            RowBox[{"$OperatingSystem", "===", "\"\<MacOS\>\""}], ",", 
            "\"\<:\>\"", ",", "\"\<\>\""}], "]"}], "<>", "tempfilename"}], 
      "]"}]], "Input",
  CellLabel->"In[1717]:=  (21:57:17 on 5/16/01)",
  CellTags->"Write2"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"t2", "=", 
      RowBox[{"x", "+", 
        RowBox[{"Isolate", "[", 
          RowBox[{"t", ",", "a", ",", 
            RowBox[{"IsolateNames", "\[Rule]", "W"}]}], "]"}]}]}]], "Input",
  CellLabel->"In[1718]:=  (21:57:17 on 5/16/01)",
  CellTags->"Write2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"4", " ", 
          SuperscriptBox["a", "4"]}], "-", 
        RowBox[{"8", " ", 
          TagBox[
            RowBox[{"W", "(", "1", ")"}],
            HoldForm], " ", 
          SuperscriptBox["a", "3"]}], "+", 
        RowBox[{"8", " ", 
          TagBox[
            RowBox[{"W", "(", "3", ")"}],
            HoldForm], " ", 
          SuperscriptBox["a", "2"]}], "-", 
        RowBox[{"4", " ", 
          TagBox[
            RowBox[{"W", "(", "1", ")"}],
            HoldForm], " ", 
          TagBox[
            RowBox[{"W", "(", "2", ")"}],
            HoldForm], " ", "a"}], "+", 
        SuperscriptBox[
          TagBox[
            RowBox[{"W", "(", "2", ")"}],
            HoldForm], "2"], "+", "x"}], TraditionalForm]], "Output",
  CellLabel->"Out[1718]=  (21:57:17 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      RowBox[{"Write2", "[", 
        RowBox[{"tempfilename", ",", 
          RowBox[{"r", "=", "t2"}]}], "]"}], ";"}]], "Input",
  CellLabel->"In[1719]:=  (21:57:17 on 5/16/01)",
  CellTags->"Write2"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"TableForm", "[", 
      RowBox[{"ReadList", "[", 
        RowBox[{
          RowBox[{
            RowBox[{"If", "[", 
              RowBox[{
                RowBox[{"$OperatingSystem", "===", "\"\<MacOS\>\""}], ",", 
                "\"\<:\>\"", ",", "\"\<\>\""}], "]"}], "<>", "tempfilename"}],
           ",", "String"}], "]"}], "]"}]], "Input",
  CellLabel->"In[1720]:=  (21:57:17 on 5/16/01)",
  CellTags->"Write2"],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {"\<\"W[1] = (b + c\"\>"},
            {"\<\"       );\"\>"},
            {"\<\"W[2] = (b^2 + c^2\"\>"},
            {"\<\"       );\"\>"},
            {"\<\"W[3] = (b^2 + b*c + c^2\"\>"},
            {"\<\"       );\"\>"},
            {"\<\"r = ( 4*a^4 + x - 8*a^3*HoldForm[W[1]] - \
4*a*HoldForm[W[1]]*\"\>"},
            {"\<\"  HoldForm[W[2]] + HoldForm[W[2]]^2 + \
8*a^2*HoldForm[W[3]]\"\>"},
            {"\<\"       );\"\>"}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        TableForm[ {"W[1] = (b + c", "       );", "W[2] = (b^2 + c^2", 
          "       );", "W[3] = (b^2 + b*c + c^2", "       );", 
          "r = ( 4*a^4 + x - 8*a^3*HoldForm[W[1]] - 4*a*HoldForm[W[1]]*", 
          "  HoldForm[W[2]] + HoldForm[W[2]]^2 + 8*a^2*HoldForm[W[3]]", 
          "       );"}]], TraditionalForm]], "Output",
  CellLabel->"Out[1720]//TableForm=  (21:57:18 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{"DeleteFile", "[", 
      RowBox[{
        RowBox[{"If", "[", 
          RowBox[{
            RowBox[{"$OperatingSystem", "===", "\"\<MacOS\>\""}], ",", 
            "\"\<:\>\"", ",", "\"\<\>\""}], "]"}], "<>", "tempfilename"}], 
      "]"}]], "Input",
  CellLabel->"In[1721]:=  (21:57:18 on 5/16/01)",
  CellTags->"Write2"],

Cell["\<\
This is how to write out the expression t2 in Fortran format.\
\>", "Text",
  CellTags->"Write2"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Write2", "[", 
        RowBox[{"tempfilename", ",", 
          RowBox[{"r", "=", "t2"}], ",", 
          RowBox[{"FormatType", "->", "FortranForm"}]}], "]"}], 
      ";"}]], "Input",
  CellLabel->"In[1722]:=  (21:57:18 on 5/16/01)",
  CellTags->"Write2"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"TableForm", "[", 
      RowBox[{"ReadList", "[", 
        RowBox[{
          RowBox[{
            RowBox[{"If", "[", 
              RowBox[{
                RowBox[{"$OperatingSystem", "===", "\"\<MacOS\>\""}], ",", 
                "\"\<:\>\"", ",", "\"\<\>\""}], "]"}], "<>", "tempfilename"}],
           ",", "String"}], "]"}], "]"}]], "Input",
  CellLabel->"In[1723]:=  (21:57:18 on 5/16/01)",
  CellTags->"Write2"],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {"\<\"        W(1)= b + c\"\>"},
            {"\<\"        W(2)= b**2 + c**2\"\>"},
            {"\<\"        W(3)= b**2 + b*c + c**2\"\>"},
            {"\<\"        r = 4*a**4 + x - 8*a**3*W(1) - 4*a*W(1)*W(2) + \
W(2)**2 + \"\>"},
            {"\<\"     &  8*a**2*W(3)\"\>"},
            {"\<\"                  \"\>"}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        TableForm[ {"        W(1)= b + c", "        W(2)= b**2 + c**2", 
          "        W(3)= b**2 + b*c + c**2", 
          "        r = 4*a**4 + x - 8*a**3*W(1) - 4*a*W(1)*W(2) + W(2)**2 + ",
           "     &  8*a**2*W(3)", "                  "}]], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1723]//TableForm=  (21:57:18 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      RowBox[{"DeleteFile", "[", 
        RowBox[{
          RowBox[{"If", "[", 
            RowBox[{
              RowBox[{"$OperatingSystem", "===", "\"\<MacOS\>\""}], ",", 
              "\"\<:\>\"", ",", "\"\<\>\""}], "]"}], "<>", "tempfilename"}], 
        "]"}], ";", 
      RowBox[{"Clear", "[", 
        RowBox[{"t", ",", "t2", ",", "tempfilename"}], "]"}], ";"}]], "Input",\

  CellLabel->"In[1724]:=  (21:57:18 on 5/16/01)",
  CellTags->"Write2"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Zeta2", "ObjectName",
  CellTags->"Zeta2"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"Zeta2"],

Cell["Zeta2 denotes Zeta[2]. N[Zeta[2]] evaluates to N[Zeta[2]].", "Text",
  CellTags->"Zeta2"],

Cell[TextData[{
  "See also: ",
  ButtonBox["SimplifyPolyLog",
    ButtonData:>"SimplifyPolyLog",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"SimplifyPolyLog"],
  "."
}], "Text",
  CellTags->"Zeta2"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  CellTags->"Zeta2"],

Cell[CellGroupData[{

Cell[BoxData["Zeta2"], "Input",
  CellLabel->"In[1725]:=  (21:57:18 on 5/16/01)",
  CellTags->"Zeta2"],

Cell[BoxData[
    FormBox[
      RowBox[{"\[Zeta]", "(", "2", ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[1725]=  (21:57:18 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"N", "[", "Zeta2", "]"}]], "Input",
  CellLabel->"In[1726]:=  (21:57:18 on 5/16/01)",
  CellTags->"Zeta2"],

Cell[BoxData[
    FormBox["1.6449340668482262`", TraditionalForm]], "Output",
  CellLabel->"Out[1726]=  (21:57:18 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SimplifyPolyLog", "[", 
      RowBox[{"Pi", "^", "2"}], "]"}]], "Input",
  CellLabel->"In[1727]:=  (21:57:18 on 5/16/01)",
  CellTags->"Zeta2"],

Cell[BoxData[
    FormBox[
      RowBox[{"6", " ", 
        RowBox[{"\[Zeta]", "(", "2", ")"}]}], TraditionalForm]], "Output",
  CellLabel->"Out[1727]=  (21:57:18 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["$FCT", "ObjectName",
  CellTags->"$FCT"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"$FCT"],

Cell["\<\
Setting the global variable $FCT to True changes the default typesetting \
rules for the noncommutative multiplication operator Dot[].\
\>", "Text",
  CellTags->"$FCT"],

Cell[BoxData[
    RowBox[{
      RowBox[{"$FCT", " ", "=", " ", "True"}], ";"}]], "Input",
  CellLabel->"In[1728]:=  (21:57:18 on 5/16/01)",
  CellTags->"$FCT"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"GA", "[", "\[Mu]", "]"}], " ", ".", " ", 
      RowBox[{"GA", "[", "\[Nu]", "]"}]}]], "Input",
  CellLabel->"In[1729]:=  (21:57:18 on 5/16/01)",
  CellTags->"$FCT"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", "\[Mu]"], " ", 
        SuperscriptBox["\[Gamma]", "\[Nu]"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1729]=  (21:57:18 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      RowBox[{"$FCT", " ", "=", " ", "False"}], ";"}]], "Input",
  CellLabel->"In[1730]:=  (21:57:18 on 5/16/01)",
  CellTags->"$FCT"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"GA", "[", "\[Mu]", "]"}], " ", ".", " ", 
      RowBox[{"GA", "[", "\[Nu]", "]"}]}]], "Input",
  CellLabel->"In[1731]:=  (21:57:18 on 5/16/01)",
  CellTags->"$FCT"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
        SuperscriptBox["\[Gamma]", "\[Nu]"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1731]=  (21:57:18 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["$LorentzIndices", "ObjectName",
  CellTags->"$LorentzIndices"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"$LorentzIndices"],

Cell["\<\
$LorentzIndices is a global variable. If set to True the dimension of \
LorentzIndex is displayed as an index.\
\>", "Text",
  CellTags->"$LorentzIndices"],

Cell[BoxData[
    RowBox[{
      RowBox[{"$LorentzIndices", "=", "True"}], ";"}]], "Input",
  CellLabel->"In[1732]:=  (21:57:18 on 5/16/01)",
  CellTags->"$LorentzIndices"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"MetricTensor", "[", 
        RowBox[{"\[Alpha]", ",", "\[Beta]", ",", 
          RowBox[{"Dimension", "\[Rule]", "n"}]}], "]"}], 
      RowBox[{"DiracMatrix", "[", 
        RowBox[{"\[Alpha]", ",", 
          RowBox[{"Dimension", "\[Rule]", "n"}]}], "]"}]}]], "Input",
  CellLabel->"In[1733]:=  (21:57:18 on 5/16/01)",
  CellTags->"$LorentzIndices"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", 
          FormBox[
            SubscriptBox[
              FormBox["\[Alpha]",
                "TraditionalForm"], 
              FormBox["n",
                "TraditionalForm"]],
            "TraditionalForm"]], " ", 
        SuperscriptBox["g", 
          RowBox[{
            FormBox[
              SubscriptBox[
                FormBox["\[Alpha]",
                  "TraditionalForm"], 
                FormBox["n",
                  "TraditionalForm"]],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              SubscriptBox[
                FormBox["\[Beta]",
                  "TraditionalForm"], 
                FormBox["n",
                  "TraditionalForm"]],
              "TraditionalForm"]}]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1733]=  (21:57:18 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "StandardForm"}]], "Input",
  CellLabel->"In[1734]:=  (21:57:18 on 5/16/01)",
  CellTags->"$LorentzIndices"],

Cell[BoxData[
    RowBox[{
      RowBox[{"DiracGamma", "[", 
        RowBox[{
          RowBox[{"LorentzIndex", "[", 
            RowBox[{"\[Alpha]", ",", "n"}], "]"}], ",", "n"}], "]"}], " ", 
      RowBox[{"Pair", "[", 
        RowBox[{
          RowBox[{"LorentzIndex", "[", 
            RowBox[{"\[Alpha]", ",", "n"}], "]"}], ",", 
          RowBox[{"LorentzIndex", "[", 
            RowBox[{"\[Beta]", ",", "n"}], "]"}]}], "]"}]}]], "Output",
  CellLabel->"Out[1734]//StandardForm=  (21:57:18 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"MTD", "[", 
          RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], " ", 
        RowBox[{"FVD", "[", 
          RowBox[{"p", ",", "\[Beta]"}], "]"}], 
        RowBox[{"GAD", "[", "\[Mu]", "]"}]}], "//", "FCI"}]], "Input",
  CellLabel->"In[1735]:=  (21:57:18 on 5/16/01)",
  CellTags->"$LorentzIndices"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["\[Gamma]", 
          FormBox[
            SubscriptBox[
              FormBox["\[Mu]",
                "TraditionalForm"], 
              FormBox["D",
                "TraditionalForm"]],
            "TraditionalForm"]], " ", 
        SuperscriptBox["g", 
          RowBox[{
            FormBox[
              SubscriptBox[
                FormBox["\[Alpha]",
                  "TraditionalForm"], 
                FormBox["D",
                  "TraditionalForm"]],
              "TraditionalForm"], "\[NoBreak]", 
            FormBox[
              SubscriptBox[
                FormBox["\[Beta]",
                  "TraditionalForm"], 
                FormBox["D",
                  "TraditionalForm"]],
              "TraditionalForm"]}]], " ", 
        SuperscriptBox[
          FormBox["p",
            "TraditionalForm"], 
          FormBox[
            SubscriptBox[
              FormBox["\[Beta]",
                "TraditionalForm"], 
              FormBox["D",
                "TraditionalForm"]],
            "TraditionalForm"]]}], TraditionalForm]], "Output",
  CellLabel->"Out[1735]=  (21:57:18 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"%", "//", "StandardForm"}]], "Input",
  CellLabel->"In[1736]:=  (21:57:18 on 5/16/01)",
  CellTags->"$LorentzIndices"],

Cell[BoxData[
    RowBox[{
      RowBox[{"DiracGamma", "[", 
        RowBox[{
          RowBox[{"LorentzIndex", "[", 
            RowBox[{"\[Mu]", ",", "D"}], "]"}], ",", "D"}], "]"}], " ", 
      RowBox[{"Pair", "[", 
        RowBox[{
          RowBox[{"LorentzIndex", "[", 
            RowBox[{"\[Alpha]", ",", "D"}], "]"}], ",", 
          RowBox[{"LorentzIndex", "[", 
            RowBox[{"\[Beta]", ",", "D"}], "]"}]}], "]"}], " ", 
      RowBox[{"Pair", "[", 
        RowBox[{
          RowBox[{"LorentzIndex", "[", 
            RowBox[{"\[Beta]", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
            RowBox[{"p", ",", "D"}], "]"}]}], "]"}]}]], "Output",
  CellLabel->"Out[1736]//StandardForm=  (21:57:18 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      RowBox[{"$LorentzIndices", "=", "False"}], ";"}]], "Input",
  CellLabel->"In[1737]:=  (21:57:18 on 5/16/01)",
  CellTags->"$LorentzIndices"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["$PairBrackets", "ObjectName",
  CellTags->"$PairBrackets"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"$PairBrackets"],

Cell["\<\
$PairBrackets determines whether brackets are drawn around scalar products in \
the notebook interface.\
\>", "Text",
  CellTags->"$PairBrackets"],

Cell[CellGroupData[{

Cell[BoxData["$PairBrackets"], "Input",
  CellLabel->"In[1738]:=  (21:57:18 on 5/16/01)",
  CellTags->"$PairBrackets"],

Cell[BoxData[
    FormBox["False", TraditionalForm]], "Output",
  CellLabel->"Out[1738]=  (21:57:18 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"SP", "[", 
        RowBox[{"p", ",", "q"}], "]"}], 
      RowBox[{"SP", "[", 
        RowBox[{"r", ",", "s"}], "]"}]}]], "Input",
  CellLabel->"In[1739]:=  (21:57:18 on 5/16/01)",
  CellTags->"$PairBrackets"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          RowBox[{
            FormBox["p",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["q",
              "TraditionalForm"]}],
          "TraditionalForm"], " ", 
        FormBox[
          RowBox[{
            FormBox["r",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["s",
              "TraditionalForm"]}],
          "TraditionalForm"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1739]=  (21:57:18 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"$PairBrackets", "=", "True"}]], "Input",
  CellLabel->"In[1740]:=  (21:57:18 on 5/16/01)",
  CellTags->"$PairBrackets"],

Cell[BoxData[
    FormBox["True", TraditionalForm]], "Output",
  CellLabel->"Out[1740]=  (21:57:18 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"SP", "[", 
        RowBox[{"p", ",", "q"}], "]"}], 
      RowBox[{"SP", "[", 
        RowBox[{"r", ",", "s"}], "]"}]}]], "Input",
  CellLabel->"In[1741]:=  (21:57:18 on 5/16/01)",
  CellTags->"$PairBrackets"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          RowBox[{"(", "\[NoBreak]", 
            FormBox["p",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["q",
              "TraditionalForm"], "\[NoBreak]", ")"}],
          "TraditionalForm"], " ", 
        FormBox[
          RowBox[{"(", "\[NoBreak]", 
            FormBox["r",
              "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
            
            FormBox["s",
              "TraditionalForm"], "\[NoBreak]", ")"}],
          "TraditionalForm"]}], TraditionalForm]], "Output",
  CellLabel->"Out[1741]=  (21:57:19 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"$PairBrackets", "=", "False"}]], "Input",
  CellLabel->"In[1742]:=  (21:57:19 on 5/16/01)",
  CellTags->"$PairBrackets"],

Cell[BoxData[
    FormBox["False", TraditionalForm]], "Output",
  CellLabel->"Out[1742]=  (21:57:19 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["$VeryVerbose", "ObjectName",
  CellTags->"$VeryVerbose"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"$VeryVerbose"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"?", "$VeryVerbose"}]], "Input",
  CellLabel->"In[1743]:=  (21:57:19 on 5/16/01)",
  CellTags->"$VeryVerbose"],

Cell[BoxData[
    FormBox["\<\"$VeryVerbose is a global variable with default setting 0. If \
set to 1, 2, ..., less and more intermediate comments and informations are \
displayed during calculations.\"\>", TraditionalForm]], "Print"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData["$VeryVerbose"], "Input",
  CellLabel->"In[1744]:=  (21:57:19 on 5/16/01)",
  CellTags->"$VeryVerbose"],

Cell[BoxData[
    FormBox["0", TraditionalForm]], "Output",
  CellLabel->"Out[1744]=  (21:57:19 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      RowBox[{"$VeryVerbose", " ", "=", " ", "3"}], ";"}]], "Input",
  CellLabel->"In[1745]:=  (21:57:19 on 5/16/01)",
  CellTags->"$VeryVerbose"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Collect2", "[", 
      RowBox[{
        RowBox[{"Expand", "[", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"x", "-", "y", "-", "z"}], ")"}], "^", "6"}], "]"}], 
        ",", "x"}], "]"}]], "Input",
  CellLabel->"In[1746]:=  (21:57:19 on 5/16/01)",
  CellTags->"$VeryVerbose"],

Cell["\<\
expanding. inhomogeneous part; LeafCount = 43; factored. #1#2#3#4#5#6\
\>", "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[
        RowBox[{"\<\"length \"\>", "\[InvisibleSpace]", "21", 
          "\[InvisibleSpace]", "\<\".\"\>"}],
        SequenceForm[ "length ", 21, "."],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[
        RowBox[{"\<\"collecting \"\>", "\[InvisibleSpace]", "6", 
          "\[InvisibleSpace]", "\<\" terms.\"\>"}],
        SequenceForm[ "collecting ", 6, " terms."],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["x", "6"], "-", 
        RowBox[{"6", " ", 
          RowBox[{"(", 
            RowBox[{"y", "+", "z"}], ")"}], " ", 
          SuperscriptBox["x", "5"]}], "+", 
        RowBox[{"15", " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"y", "+", "z"}], ")"}], "2"], " ", 
          SuperscriptBox["x", "4"]}], "-", 
        RowBox[{"20", " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"y", "+", "z"}], ")"}], "3"], " ", 
          SuperscriptBox["x", "3"]}], "+", 
        RowBox[{"15", " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"y", "+", "z"}], ")"}], "4"], " ", 
          SuperscriptBox["x", "2"]}], "-", 
        RowBox[{"6", " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{"y", "+", "z"}], ")"}], "5"], " ", "x"}], "+", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{"y", "+", "z"}], ")"}], "6"]}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[1746]=  (21:57:19 on 5/16/01)"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      RowBox[{"$VeryVerbose", "=", "0"}], ";"}]], "Input",
  CellLabel->"In[1747]:=  (21:57:19 on 5/16/01)",
  CellTags->"$VeryVerbose"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["$West", "ObjectName",
  CellTags->"$West"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
  CellTags->"$West"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"?", "$West"}]], "Input",
  CellLabel->"In[1748]:=  (21:57:19 on 5/16/01)",
  CellTags->"$West"],

Cell[BoxData[
    FormBox["\<\"If $West is set to True (which is the default), traces \
involving more than 4 Dirac matrices and gamma5 are calculated recursively \
according to formula (A.5) from Comp. Phys. Comm 77 (1993) 286-298, which is \
based on the Breitenlohner Maison gamma5 - scheme.\"\>", 
      TraditionalForm]], "Print"]
}, Closed]],

Cell[TextData[{
  "See examples in ",
  ButtonBox["Tr",
    ButtonData:>"Tr",
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Tr"],
  "."
}], "Text",
  CellTags->"$West"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Evaluation time and memory usage", "Commentary"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"AbsoluteTime", "[", "]"}], "-", "absolutestarttime"}]], "Input",\

  CellLabel->"In[1749]:=  (21:57:19 on 5/16/01)"],

Cell[BoxData[
    FormBox["330.`8.2381", TraditionalForm]], "Output",
  CellLabel->"Out[1749]=  (21:57:19 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"MemoryInUse", "[", "]"}]], "Input",
  CellLabel->"In[1750]:=  (21:57:19 on 5/16/01)"],

Cell[BoxData[
    FormBox["15181296", TraditionalForm]], "Output",
  CellLabel->"Out[1750]=  (21:57:19 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"MaxMemoryUsed", "[", "]"}]], "Input",
  CellLabel->"In[1751]:=  (21:57:19 on 5/16/01)"],

Cell[BoxData[
    FormBox["19141128", TraditionalForm]], "Output",
  CellLabel->"Out[1751]=  (21:57:19 on 5/16/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"TimeUsed", "[", "]"}]], "Input",
  CellLabel->"In[1752]:=  (21:57:20 on 5/16/01)"],

Cell[BoxData[
    FormBox["219.15599999999986`", TraditionalForm]], "Output",
  CellLabel->"Out[1752]=  (21:57:20 on 5/16/01)"]
}, Closed]]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 723}},
ScreenStyleEnvironment->"AllBrackets",
ShowPageBreaks->False,
WindowToolbars->"EditBar",
CellGrouping->Manual,
WindowSize->{664, 592},
WindowMargins->{{144, Automatic}, {Automatic, 5}},
PrintingStartingPageNumber->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Inherited, Cell[ 
        TextData[ 
          ValueBox[ "FileName"]], "Header"], Inherited}, {Inherited, Cell[ 
        TextData[ 
          ValueBox[ "FileName"]], "Header"], Inherited}},
PageFooters->{{Inherited, Cell[ 
        TextData[ 
          ValueBox[ "DateLong"]], "Footer"], Inherited}, {Inherited, Cell[ 
        TextData[ 
          ValueBox[ "DateLong"]], "Footer"], Inherited}},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {72, 72}},
"PaperSize"->{597.563, 842.375},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintSelectionHighlighting"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False,
"FirstPageFooter"->True,
"FacingPages"->True,
"FirstPageFace"->Left,
"GraphicsPrintingFormat"->"Automatic",
"Magnification"->1},
PrivateNotebookOptions->{"ShortBoxForm"->False},
TaggingRules:>{"MakeContentsNonDefaultOptions" -> {AutomaticCellTagging -> \
FromContent, PageNumbers -> False, SaveOptions -> True, SelectCellStyles -> \
{"Section", "Subsection"}, TOCCellStyles -> {"Contents", "Index"}}},
CellLabelAutoDelete->True,
ShowCellTags->True,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Short Overview"->{
    Cell[2346, 78, 96, 2, 70, "Section",
      PageBreakAbove->True,
      CellTags->{"Short Overview", "intro"}]},
  "intro"->{
    Cell[2346, 78, 96, 2, 70, "Section",
      PageBreakAbove->True,
      CellTags->{"Short Overview", "intro"}],
    Cell[2445, 82, 1200, 30, 124, "Text",
      CellTags->"intro"],
    Cell[3648, 114, 1953, 76, 73, "Text",
      CellTags->"intro"],
    Cell[5604, 192, 88, 1, 39, "Text",
      CellTags->"intro"],
    Cell[5695, 195, 1708, 71, 73, "Text",
      CellTags->"intro"],
    Cell[7406, 268, 1149, 22, 158, "Text",
      CellTags->"intro"],
    Cell[8558, 292, 272, 7, 56, "Text",
      CellTags->"intro"],
    Cell[8833, 301, 391, 10, 56, "Text",
      CellTags->"intro"],
    Cell[9227, 313, 569, 10, 107, "Text",
      CellTags->"intro"],
    Cell[9799, 325, 570, 19, 39, "Text",
      CellTags->"intro"],
    Cell[10372, 346, 94, 1, 39, "Text",
      CellTags->"intro"]},
  "Load FeynCalc"->{
    Cell[10722, 361, 76, 1, 56, "Section",
      CellTags->{"Load FeynCalc", "start"}]},
  "start"->{
    Cell[10722, 361, 76, 1, 56, "Section",
      CellTags->{"Load FeynCalc", "start"}],
    Cell[10801, 364, 357, 10, 56, "Text",
      CellTags->"start"],
    Cell[11161, 376, 64, 1, 45, "MathCaption",
      CellTags->"start"],
    Cell[11228, 379, 142, 3, 56, "Input",
      CellTags->"start"],
    Cell[11373, 384, 241, 7, 56, "Text",
      CellTags->"start"],
    Cell[11617, 393, 626, 17, 98, "Text",
      CellTags->"start"],
    Cell[12246, 412, 246, 9, 45, "MathCaption",
      CellTags->"start"],
    Cell[12495, 423, 416, 11, 56, "Input",
      CellTags->"start"],
    Cell[12914, 436, 416, 11, 56, "Input",
      CellTags->"start"],
    Cell[13333, 449, 224, 9, 45, "MathCaption",
      CellTags->"start"],
    Cell[13582, 462, 149, 4, 56, "Input",
      CellTags->"start"],
    Cell[14067, 481, 142, 4, 45, "MathCaption",
      CellTags->"start"],
    Cell[14234, 489, 132, 3, 56, "Input",
      CellTags->"start"]},
  "About Extras"->{
    Cell[14561, 503, 77, 2, 56, "Section",
      PageBreakAbove->True,
      CellTags->"About Extras"],
    Cell[14641, 507, 484, 13, 73, "Text",
      CellTags->"About Extras"],
    Cell[15128, 522, 152, 4, 45, "MathCaption",
      CellTags->"About Extras"],
    Cell[15283, 528, 115, 3, 43, "Input",
      CellTags->"About Extras"],
    Cell[15401, 533, 119, 3, 39, "Text",
      CellTags->"About Extras"],
    Cell[15523, 538, 1149, 28, 87, "Text",
      CellTags->"About Extras"],
    Cell[16675, 568, 105, 1, 31, "Caption",
      CellTags->"About Extras"]},
  "tarcer"->{
    Cell[16805, 573, 195, 7, 74, "Subsection",
      CellTags->"tarcer"],
    Cell[17003, 582, 69, 1, 70, "InspectorLevel2",
      CellTags->"tarcer"],
    Cell[17075, 585, 240, 8, 70, "Text",
      CellTags->"tarcer"],
    Cell[17318, 595, 141, 4, 70, "Text",
      CellTags->"tarcer"],
    Cell[17462, 601, 61, 1, 70, "Subsubsection",
      CellTags->"tarcer"],
    Cell[17526, 604, 626, 15, 70, "Text",
      CellTags->"tarcer"],
    Cell[18155, 621, 76, 1, 70, "Text",
      CellTags->"tarcer"],
    Cell[18234, 624, 109, 3, 70, "Input",
      CellTags->"tarcer"],
    Cell[18346, 629, 271, 8, 70, "Text",
      CellTags->"tarcer"],
    Cell[18620, 639, 300, 9, 70, "Text",
      CellTags->"tarcer"]},
  "phi"->{
    Cell[18957, 653, 154, 6, 74, "Subsection",
      CellTags->"phi"],
    Cell[19114, 661, 60, 1, 70, "InspectorLevel2",
      CellTags->"phi"],
    Cell[19177, 664, 422, 9, 70, "Text",
      CellTags->"phi"],
    Cell[19602, 675, 70, 1, 70, "Text",
      CellTags->"phi"],
    Cell[19675, 678, 103, 3, 70, "Input",
      CellTags->"phi"],
    Cell[19781, 683, 268, 8, 70, "Text",
      CellTags->"phi"],
    Cell[20052, 693, 280, 9, 70, "Text",
      CellTags->"phi"]},
  "fa"->{
    Cell[20369, 707, 48, 1, 53, "Subsection",
      CellTags->"fa"],
    Cell[20420, 710, 206, 5, 70, "Text",
      CellTags->"fa"],
    Cell[20629, 717, 293, 6, 70, "Text",
      CellTags->"fa"],
    Cell[20925, 725, 598, 17, 70, "Text",
      CellTags->"fa"],
    Cell[21526, 744, 102, 3, 70, "Input",
      CellTags->"fa"],
    Cell[21631, 749, 267, 8, 70, "Text",
      CellTags->"fa"],
    Cell[21901, 759, 545, 16, 70, "Text",
      CellTags->"fa"]},
  "Example Calculations"->{
    Cell[22495, 781, 107, 2, 56, "Section",
      PageBreakAbove->True,
      CellTags->{"Example Calculations", "ex"}]},
  "ex"->{
    Cell[22495, 781, 107, 2, 56, "Section",
      PageBreakAbove->True,
      CellTags->{"Example Calculations", "ex"}],
    Cell[22605, 785, 540, 15, 66, "Commentary",
      CellTags->"ex"],
    Cell[23148, 802, 345, 10, 39, "Text",
      CellTags->"ex"]},
  "Tree level"->{
    Cell[23518, 816, 342, 11, 53, "Subsection",
      CellTags->"Tree level"],
    Cell[23863, 829, 324, 10, 39, "Text",
      CellTags->"Tree level"],
    Cell[24190, 841, 85, 1, 39, "Text",
      CellTags->"Tree level"],
    Cell[24278, 844, 168, 4, 58, "Input",
      CellTags->"Tree level"],
    Cell[24449, 850, 168, 4, 58, "Input",
      CellTags->"Tree level"],
    Cell[24620, 856, 168, 4, 58, "Input",
      CellTags->"Tree level"],
    Cell[24791, 862, 168, 4, 58, "Input",
      CellTags->"Tree level"],
    Cell[24962, 868, 99, 1, 39, "Text",
      CellTags->"Tree level"],
    Cell[25086, 873, 337, 9, 56, "Input",
      CellTags->"Tree level"],
    Cell[26852, 927, 2399, 77, 70, "Text",
      CellTags->"Tree level"],
    Cell[29254, 1006, 371, 10, 70, "Input",
      CellTags->"Tree level"],
    Cell[29628, 1018, 339, 9, 70, "Input",
      CellTags->"Tree level"],
    Cell[29970, 1029, 371, 10, 70, "Input",
      CellTags->"Tree level"],
    Cell[30344, 1041, 306, 8, 70, "Input",
      CellTags->"Tree level"],
    Cell[30653, 1051, 306, 8, 70, "Input",
      CellTags->"Tree level"],
    Cell[30962, 1061, 464, 12, 70, "Input",
      CellTags->"Tree level"],
    Cell[31429, 1075, 64, 1, 70, "Text",
      CellTags->"Tree level"],
    Cell[31518, 1080, 336, 8, 70, "Input",
      CellTags->"Tree level"],
    Cell[33052, 1128, 336, 8, 70, "Input",
      CellTags->"Tree level"],
    Cell[34586, 1176, 336, 8, 70, "Input",
      CellTags->"Tree level"],
    Cell[36120, 1224, 336, 8, 70, "Input",
      CellTags->"Tree level"],
    Cell[37632, 1270, 74, 1, 70, "Text",
      CellTags->"Tree level"],
    Cell[37731, 1275, 134, 2, 70, "Input",
      CellTags->"Tree level"],
    Cell[39654, 1332, 134, 2, 70, "Input",
      CellTags->"Tree level"],
    Cell[41174, 1378, 134, 2, 70, "Input",
      CellTags->"Tree level"],
    Cell[42694, 1424, 134, 2, 70, "Input",
      CellTags->"Tree level"],
    Cell[44595, 1479, 91, 1, 70, "Text",
      CellTags->"Tree level"],
    Cell[44711, 1484, 883, 24, 108, "Input",
      CellTags->"Tree level"],
    Cell[52405, 1697, 78, 1, 39, "Text",
      CellTags->"Tree level"],
    Cell[52508, 1702, 201, 5, 56, "Input",
      CellTags->"Tree level"],
    Cell[59783, 1894, 118, 3, 39, "Text",
      CellTags->"Tree level"],
    Cell[59926, 1901, 423, 11, 56, "Input",
      CellTags->"Tree level"],
    Cell[60474, 1919, 135, 4, 39, "Text",
      CellTags->"Tree level"],
    Cell[60612, 1925, 260, 6, 56, "Input",
      CellTags->"Tree level"],
    Cell[60875, 1933, 649, 27, 39, "Text",
      CellTags->"Tree level"]},
  "A moment integral"->{
    Cell[61561, 1965, 72, 1, 53, "Subsection",
      CellTags->"A moment integral"],
    Cell[61636, 1968, 504, 17, 70, "Text",
      CellTags->"A moment integral"],
    Cell[62143, 1987, 127, 3, 70, "Text",
      CellTags->"A moment integral"],
    Cell[62273, 1992, 409, 13, 70, "Text",
      CellTags->"A moment integral"],
    Cell[62685, 2007, 94, 1, 70, "Text",
      CellTags->"A moment integral"],
    Cell[62782, 2010, 288, 10, 70, "Text",
      CellTags->"A moment integral"],
    Cell[63095, 2024, 149, 3, 70, "Input",
      CellTags->"A moment integral"],
    Cell[63423, 2036, 222, 5, 70, "Text",
      CellTags->"A moment integral"],
    Cell[63648, 2043, 2187, 46, 70, "Input",
      CellTags->"A moment integral"],
    Cell[65838, 2091, 167, 4, 70, "Text",
      CellTags->"A moment integral"],
    Cell[66008, 2097, 17184, 630, 70, "Input",
      CellTags->"A moment integral"],
    Cell[83217, 2731, 144, 3, 70, "Input",
      CellTags->"A moment integral"],
    Cell[85032, 2781, 154, 4, 70, "Commentary",
      CellTags->"A moment integral"],
    Cell[85211, 2789, 126, 2, 70, "Input",
      CellTags->"A moment integral"],
    Cell[85645, 2806, 144, 3, 70, "Input",
      CellTags->"A moment integral"],
    Cell[86025, 2820, 66, 1, 70, "Text",
      CellTags->"A moment integral"],
    Cell[86094, 2823, 251, 5, 70, "Text",
      CellTags->"A moment integral"],
    Cell[86348, 2830, 644, 19, 70, "Text",
      CellTags->"A moment integral"],
    Cell[87017, 2853, 438, 12, 70, "Input",
      CellTags->"A moment integral"],
    Cell[87696, 2876, 198, 4, 70, "Text",
      CellTags->"A moment integral"],
    Cell[87919, 2884, 547, 14, 70, "Input",
      CellTags->"A moment integral"],
    Cell[88707, 2909, 90, 1, 70, "Text",
      CellTags->"A moment integral"],
    Cell[88800, 2912, 711, 18, 70, "Input",
      CellTags->"A moment integral"],
    Cell[89514, 2932, 93, 1, 70, "Text",
      CellTags->"A moment integral"],
    Cell[89632, 2937, 1538, 38, 70, "Input",
      CellTags->"A moment integral"],
    Cell[94812, 3068, 148, 4, 70, "Text",
      CellTags->"A moment integral"],
    Cell[94963, 3074, 653, 17, 70, "Input",
      CellTags->"A moment integral"],
    Cell[95641, 3095, 141, 3, 70, "Input",
      CellTags->"A moment integral"],
    Cell[95909, 3105, 152, 4, 70, "Text",
      CellTags->"A moment integral"],
    Cell[96064, 3111, 317, 9, 70, "Input",
      CellTags->"A moment integral"],
    Cell[96384, 3122, 218, 5, 70, "Text",
      CellTags->"A moment integral"],
    Cell[96627, 3131, 217, 5, 70, "Input",
      CellTags->"A moment integral"],
    Cell[101482, 3256, 268, 8, 70, "Text",
      CellTags->"A moment integral"],
    Cell[101775, 3268, 497, 13, 70, "Input",
      CellTags->"A moment integral"],
    Cell[105840, 3376, 131, 3, 70, "Text",
      CellTags->"A moment integral"],
    Cell[105974, 3381, 213, 5, 70, "Input",
      CellTags->"A moment integral"],
    Cell[106190, 3388, 281, 7, 70, "Input",
      CellTags->"A moment integral"],
    Cell[106474, 3397, 1240, 55, 70, "Text",
      CellTags->"A moment integral"]},
  "Reference Guide"->{
    Cell[107763, 3458, 65, 1, 56, "Section",
      CellTags->"Reference Guide"]},
  "A0"->{
    Cell[108356, 3484, 66, 2, 70, "ObjectName",
      PageBreakAbove->True,
      CellTags->"A0"],
    Cell[108447, 3490, 54, 1, 70, "Subsubsection",
      CellTags->"A0"],
    Cell[108504, 3493, 381, 10, 70, "Text",
      CellTags->"A0"],
    Cell[108910, 3507, 135, 3, 70, "Input",
      CellTags->"A0"],
    Cell[109247, 3520, 480, 24, 70, "Text",
      CellTags->"A0"],
    Cell[109764, 3549, 51, 1, 70, "Subsubsection",
      CellTags->"A0"],
    Cell[109818, 3552, 272, 11, 70, "Text",
      CellTags->"A0"],
    Cell[110115, 3567, 152, 4, 70, "Input",
      CellTags->"A0"],
    Cell[110688, 3588, 225, 6, 70, "Input",
      CellTags->"A0"],
    Cell[111312, 3609, 241, 8, 70, "Text",
      CellTags->"A0"],
    Cell[111578, 3621, 124, 3, 70, "Input",
      CellTags->"A0"],
    Cell[111849, 3633, 197, 5, 70, "Input",
      CellTags->"A0"]},
  "Amplitudes"->{
    Cell[112217, 3649, 58, 1, 70, "ObjectName",
      CellTags->"Amplitudes"],
    Cell[112300, 3654, 62, 1, 70, "Subsubsection",
      CellTags->"Amplitudes"],
    Cell[112365, 3657, 258, 5, 70, "Text",
      CellTags->"Amplitudes"],
    Cell[112648, 3666, 146, 3, 70, "Input",
      CellTags->"Amplitudes"],
    Cell[113181, 3683, 191, 9, 70, "Text",
      CellTags->"Amplitudes"],
    Cell[113409, 3697, 59, 1, 70, "Subsubsection",
      CellTags->"Amplitudes"],
    Cell[113471, 3700, 95, 1, 70, "Text",
      CellTags->"Amplitudes"],
    Cell[113591, 3705, 152, 3, 70, "Input",
      CellTags->"Amplitudes"],
    Cell[118603, 3846, 138, 3, 70, "Input",
      CellTags->"Amplitudes"],
    Cell[131048, 4157, 221, 8, 70, "Text",
      CellTags->"Amplitudes"],
    Cell[131294, 4169, 375, 9, 70, "Input",
      CellTags->"Amplitudes"]},
  "Amputate"->{
    Cell[164234, 4918, 54, 1, 70, "ObjectName",
      CellTags->"Amputate"],
    Cell[164313, 4923, 60, 1, 70, "Subsubsection",
      CellTags->"Amputate"],
    Cell[164376, 4926, 216, 5, 70, "Text",
      CellTags->"Amputate"],
    Cell[164617, 4935, 142, 3, 70, "Input",
      CellTags->"Amputate"],
    Cell[165115, 4952, 708, 28, 70, "Text",
      CellTags->"Amputate"],
    Cell[165860, 4985, 57, 1, 70, "Subsubsection",
      CellTags->"Amputate"],
    Cell[165942, 4990, 206, 5, 70, "Input",
      CellTags->"Amputate"],
    Cell[166796, 5019, 163, 4, 70, "Input",
      CellTags->"Amputate"]},
  "AnomalousDimension"->{
    Cell[167979, 5059, 74, 1, 70, "ObjectName",
      CellTags->"AnomalousDimension"],
    Cell[168078, 5064, 70, 1, 70, "Subsubsection",
      CellTags->"AnomalousDimension"],
    Cell[168151, 5067, 155, 4, 70, "Text",
      CellTags->"AnomalousDimension"],
    Cell[168331, 5075, 162, 3, 70, "Input",
      CellTags->"AnomalousDimension"],
    Cell[168784, 5090, 438, 18, 70, "Text",
      CellTags->"AnomalousDimension"],
    Cell[169259, 5113, 67, 1, 70, "Subsubsection",
      CellTags->"AnomalousDimension"],
    Cell[169329, 5116, 64, 1, 70, "Text",
      CellTags->"AnomalousDimension"],
    Cell[169418, 5121, 243, 5, 70, "Input",
      CellTags->"AnomalousDimension"],
    Cell[169952, 5138, 249, 8, 70, "Text",
      CellTags->"AnomalousDimension"],
    Cell[170226, 5150, 161, 3, 70, "Input",
      CellTags->"AnomalousDimension"],
    Cell[170962, 5174, 248, 8, 70, "Text",
      CellTags->"AnomalousDimension"],
    Cell[171235, 5186, 160, 3, 70, "Input",
      CellTags->"AnomalousDimension"],
    Cell[171733, 5203, 248, 8, 70, "Text",
      CellTags->"AnomalousDimension"],
    Cell[172006, 5215, 160, 3, 70, "Input",
      CellTags->"AnomalousDimension"],
    Cell[172503, 5232, 248, 8, 70, "Text",
      CellTags->"AnomalousDimension"],
    Cell[172776, 5244, 160, 3, 70, "Input",
      CellTags->"AnomalousDimension"],
    Cell[173684, 5273, 249, 8, 70, "Text",
      CellTags->"AnomalousDimension"],
    Cell[173958, 5285, 161, 3, 70, "Input",
      CellTags->"AnomalousDimension"],
    Cell[174965, 5315, 249, 8, 70, "Text",
      CellTags->"AnomalousDimension"],
    Cell[175239, 5327, 161, 3, 70, "Input",
      CellTags->"AnomalousDimension"],
    Cell[183941, 5549, 248, 8, 70, "Text",
      CellTags->"AnomalousDimension"],
    Cell[184214, 5561, 160, 3, 70, "Input",
      CellTags->"AnomalousDimension"],
    Cell[189808, 5707, 248, 8, 70, "Text",
      CellTags->"AnomalousDimension"],
    Cell[190081, 5719, 160, 3, 70, "Input",
      CellTags->"AnomalousDimension"],
    Cell[198582, 5938, 248, 8, 70, "Text",
      CellTags->"AnomalousDimension"],
    Cell[198855, 5950, 160, 3, 70, "Input",
      CellTags->"AnomalousDimension"],
    Cell[205536, 6124, 275, 8, 70, "Text",
      CellTags->"AnomalousDimension"],
    Cell[205836, 6136, 160, 3, 70, "Input",
      CellTags->"AnomalousDimension"],
    Cell[212147, 6288, 341, 9, 70, "Text",
      CellTags->"AnomalousDimension"],
    Cell[212513, 6301, 362, 10, 70, "Input",
      CellTags->"AnomalousDimension"]},
  "Anti5"->{
    Cell[213192, 6326, 48, 1, 70, "ObjectName",
      CellTags->"Anti5"],
    Cell[213265, 6331, 57, 1, 70, "Subsubsection",
      CellTags->"Anti5"],
    Cell[213325, 6334, 528, 16, 70, "Text",
      CellTags->"Anti5"],
    Cell[213856, 6352, 176, 7, 70, "Text",
      CellTags->"Anti5"],
    Cell[214035, 6361, 456, 19, 70, "Text",
      CellTags->"Anti5"],
    Cell[214528, 6385, 54, 1, 70, "Subsubsection",
      CellTags->"Anti5"],
    Cell[214607, 6390, 191, 5, 70, "Input",
      CellTags->"Anti5"],
    Cell[215045, 6407, 130, 3, 70, "Input",
      CellTags->"Anti5"],
    Cell[215569, 6427, 181, 5, 70, "Input",
      CellTags->"Anti5"],
    Cell[216108, 6448, 236, 6, 70, "Input",
      CellTags->"Anti5"],
    Cell[216742, 6470, 157, 4, 70, "Input",
      CellTags->"Anti5"],
    Cell[217739, 6505, 165, 4, 70, "Input",
      CellTags->"Anti5"],
    Cell[218744, 6540, 188, 5, 70, "Input",
      CellTags->"Anti5"],
    Cell[219750, 6574, 381, 14, 70, "Text",
      CellTags->"Anti5"],
    Cell[220156, 6592, 159, 4, 70, "Input",
      CellTags->"Anti5"],
    Cell[220567, 6608, 130, 3, 70, "Input",
      CellTags->"Anti5"]},
  "AntiCommutator"->{
    Cell[221115, 6630, 66, 1, 70, "ObjectName",
      CellTags->"AntiCommutator"],
    Cell[221206, 6635, 66, 1, 70, "Subsubsection",
      CellTags->"AntiCommutator"],
    Cell[221275, 6638, 146, 4, 70, "Text",
      CellTags->"AntiCommutator"],
    Cell[221424, 6644, 642, 24, 70, "Text",
      CellTags->"AntiCommutator"],
    Cell[222103, 6673, 63, 1, 70, "Subsubsection",
      CellTags->"AntiCommutator"],
    Cell[222169, 6676, 210, 9, 70, "Text",
      CellTags->"AntiCommutator"],
    Cell[222382, 6687, 182, 4, 70, "Input",
      CellTags->"AntiCommutator"],
    Cell[222589, 6695, 176, 4, 70, "Input",
      CellTags->"AntiCommutator"],
    Cell[223061, 6712, 153, 3, 70, "Input",
      CellTags->"AntiCommutator"],
    Cell[223447, 6727, 347, 9, 70, "Input",
      CellTags->"AntiCommutator"],
    Cell[224360, 6759, 340, 9, 70, "Input",
      CellTags->"AntiCommutator"],
    Cell[225053, 6782, 261, 6, 70, "Input",
      CellTags->"AntiCommutator"],
    Cell[225317, 6790, 105, 1, 70, "Text",
      CellTags->"AntiCommutator"],
    Cell[225447, 6795, 215, 5, 70, "Input",
      CellTags->"AntiCommutator"],
    Cell[225810, 6809, 220, 5, 70, "Input",
      CellTags->"AntiCommutator"],
    Cell[226297, 6828, 304, 8, 70, "Input",
      CellTags->"AntiCommutator"],
    Cell[226776, 6846, 300, 7, 70, "Input",
      CellTags->"AntiCommutator"],
    Cell[227445, 6868, 283, 6, 70, "Input",
      CellTags->"AntiCommutator"],
    Cell[227731, 6876, 214, 5, 70, "Input",
      CellTags->"AntiCommutator"],
    Cell[227948, 6883, 276, 7, 70, "Input",
      CellTags->"AntiCommutator"]},
  "AntiQuarkField"->{
    Cell[228273, 6896, 66, 1, 70, "ObjectName",
      CellTags->"AntiQuarkField"],
    Cell[228364, 6901, 66, 1, 70, "Subsubsection",
      CellTags->"AntiQuarkField"],
    Cell[228433, 6904, 198, 4, 70, "Text",
      CellTags->"AntiQuarkField"],
    Cell[228634, 6910, 336, 14, 70, "Text",
      CellTags->"AntiQuarkField"],
    Cell[229007, 6929, 63, 1, 70, "Subsubsection",
      CellTags->"AntiQuarkField"],
    Cell[229095, 6934, 119, 2, 70, "Input",
      CellTags->"AntiQuarkField"]},
  "AntiSymmetrize"->{
    Cell[229418, 6948, 66, 1, 70, "ObjectName",
      CellTags->"AntiSymmetrize"],
    Cell[229509, 6953, 66, 1, 70, "Subsubsection",
      CellTags->"AntiSymmetrize"],
    Cell[229578, 6956, 154, 4, 70, "Text",
      CellTags->"AntiSymmetrize"],
    Cell[229735, 6962, 197, 8, 70, "Text",
      CellTags->"AntiSymmetrize"],
    Cell[229969, 6975, 63, 1, 70, "Subsubsection",
      CellTags->"AntiSymmetrize"],
    Cell[230057, 6980, 301, 8, 70, "Input",
      CellTags->"AntiSymmetrize"],
    Cell[230773, 7006, 321, 8, 70, "Input",
      CellTags->"AntiSymmetrize"]},
  "Apart1"->{
    Cell[231925, 7042, 50, 1, 70, "ObjectName",
      CellTags->"Apart1"],
    Cell[232000, 7047, 58, 1, 70, "Subsubsection",
      CellTags->"Apart1"],
    Cell[232061, 7050, 170, 4, 70, "Text",
      CellTags->"Apart1"],
    Cell[232234, 7056, 298, 14, 70, "Text",
      CellTags->"Apart1"],
    Cell[232569, 7075, 55, 1, 70, "Subsubsection",
      CellTags->"Apart1"],
    Cell[232627, 7078, 10585, 269, 70, "Input",
      CellTags->"Apart1"],
    Cell[243237, 7351, 259, 7, 70, "Input",
      CellTags->"Apart1"],
    Cell[243767, 7371, 258, 7, 70, "Input",
      CellTags->"Apart1"],
    Cell[244295, 7391, 158, 4, 70, "Input",
      CellTags->"Apart1"],
    Cell[244579, 7402, 171, 4, 70, "Input",
      CellTags->"Apart1"]},
  "Apart2"->{
    Cell[244799, 7412, 50, 1, 70, "ObjectName",
      CellTags->"Apart2"],
    Cell[244874, 7417, 58, 1, 70, "Subsubsection",
      CellTags->"Apart2"],
    Cell[244935, 7420, 109, 3, 70, "Text",
      CellTags->"Apart2"],
    Cell[245047, 7425, 325, 14, 70, "Text",
      CellTags->"Apart2"],
    Cell[245409, 7444, 55, 1, 70, "Subsubsection",
      CellTags->"Apart2"],
    Cell[245489, 7449, 316, 9, 70, "Input",
      CellTags->"Apart2"],
    Cell[247363, 7501, 133, 3, 70, "Input",
      CellTags->"Apart2"],
    Cell[248443, 7536, 173, 4, 70, "Input",
      CellTags->"Apart2"]},
  "Apart3"->{
    Cell[249304, 7567, 50, 1, 70, "ObjectName",
      CellTags->"Apart3"],
    Cell[249379, 7572, 58, 1, 70, "Subsubsection",
      CellTags->"Apart3"],
    Cell[249440, 7575, 121, 3, 70, "Text",
      CellTags->"Apart3"],
    Cell[249564, 7580, 184, 9, 70, "Text",
      CellTags->"Apart3"],
    Cell[249785, 7594, 55, 1, 70, "Subsubsection",
      CellTags->"Apart3"],
    Cell[249843, 7597, 10593, 269, 70, "Input",
      CellTags->"Apart3"],
    Cell[260461, 7870, 259, 7, 70, "Input",
      CellTags->"Apart3"],
    Cell[260991, 7890, 258, 7, 70, "Input",
      CellTags->"Apart3"],
    Cell[261516, 7910, 158, 4, 70, "Input",
      CellTags->"Apart3"],
    Cell[261800, 7921, 171, 4, 70, "Input",
      CellTags->"Apart3"]},
  "B00"->{
    Cell[262020, 7931, 44, 1, 70, "ObjectName",
      CellTags->"B00"],
    Cell[262089, 7936, 55, 1, 70, "Subsubsection",
      CellTags->"B00"],
    Cell[262147, 7939, 210, 5, 70, "Text",
      CellTags->"B00"],
    Cell[262382, 7948, 133, 3, 70, "Input",
      CellTags->"B00"],
    Cell[262719, 7961, 379, 19, 70, "Text",
      CellTags->"B00"],
    Cell[263135, 7985, 52, 1, 70, "Subsubsection",
      CellTags->"B00"],
    Cell[263190, 7988, 215, 7, 70, "Text",
      CellTags->"B00"],
    Cell[263430, 7999, 126, 3, 70, "Input",
      CellTags->"B00"],
    Cell[263779, 8014, 259, 7, 70, "Input",
      CellTags->"B00"],
    Cell[267802, 8118, 259, 7, 70, "Input",
      CellTags->"B00"],
    Cell[270062, 8186, 314, 8, 70, "Input",
      CellTags->"B00"],
    Cell[271167, 8223, 224, 6, 70, "Input",
      CellTags->"B00"],
    Cell[272309, 8260, 302, 8, 70, "Input",
      CellTags->"B00"]},
  "B0"->{
    Cell[273587, 8302, 42, 1, 70, "ObjectName",
      CellTags->"B0"],
    Cell[273654, 8307, 54, 1, 70, "Subsubsection",
      CellTags->"B0"],
    Cell[273711, 8310, 312, 6, 70, "Text",
      CellTags->"B0"],
    Cell[274048, 8320, 131, 3, 70, "Input",
      CellTags->"B0"],
    Cell[274519, 8336, 486, 24, 70, "Text",
      CellTags->"B0"],
    Cell[275042, 8365, 51, 1, 70, "Subsubsection",
      CellTags->"B0"],
    Cell[275118, 8370, 288, 8, 70, "Input",
      CellTags->"B0"],
    Cell[275806, 8394, 287, 7, 70, "Input",
      CellTags->"B0"],
    Cell[276118, 8405, 192, 5, 70, "Input",
      CellTags->"B0"],
    Cell[276640, 8425, 222, 6, 70, "Input",
      CellTags->"B0"],
    Cell[277192, 8446, 220, 6, 70, "Input",
      CellTags->"B0"]},
  "B11"->{
    Cell[277724, 8467, 44, 1, 70, "ObjectName",
      CellTags->"B11"],
    Cell[277793, 8472, 55, 1, 70, "Subsubsection",
      CellTags->"B11"],
    Cell[277851, 8475, 544, 17, 70, "Text",
      CellTags->"B11"],
    Cell[278420, 8496, 133, 3, 70, "Input",
      CellTags->"B11"],
    Cell[278757, 8509, 484, 24, 70, "Text",
      CellTags->"B11"],
    Cell[279278, 8538, 52, 1, 70, "Subsubsection",
      CellTags->"B11"],
    Cell[279333, 8541, 233, 7, 70, "Text",
      CellTags->"B11"],
    Cell[279591, 8552, 126, 3, 70, "Input",
      CellTags->"B11"],
    Cell[279940, 8567, 259, 7, 70, "Input",
      CellTags->"B11"],
    Cell[284154, 8677, 259, 7, 70, "Input",
      CellTags->"B11"],
    Cell[286089, 8737, 208, 5, 70, "Input",
      CellTags->"B11"],
    Cell[286524, 8754, 259, 7, 70, "Input",
      CellTags->"B11"],
    Cell[287574, 8790, 207, 5, 70, "Input",
      CellTags->"B11"],
    Cell[288007, 8807, 224, 6, 70, "Input",
      CellTags->"B11"],
    Cell[288581, 8828, 302, 8, 70, "Input",
      CellTags->"B11"]},
  "B1"->{
    Cell[289289, 8854, 42, 1, 70, "ObjectName",
      CellTags->"B1"],
    Cell[289356, 8859, 54, 1, 70, "Subsubsection",
      CellTags->"B1"],
    Cell[289413, 8862, 245, 7, 70, "Text",
      CellTags->"B1"],
    Cell[289683, 8873, 131, 3, 70, "Input",
      CellTags->"B1"],
    Cell[290018, 8886, 612, 29, 70, "Text",
      CellTags->"B1"],
    Cell[290667, 8920, 51, 1, 70, "Subsubsection",
      CellTags->"B1"],
    Cell[290743, 8925, 257, 7, 70, "Input",
      CellTags->"B1"],
    Cell[292542, 8980, 312, 8, 70, "Input",
      CellTags->"B1"],
    Cell[293254, 9004, 231, 6, 70, "Input",
      CellTags->"B1"],
    Cell[293510, 9014, 257, 7, 70, "Input",
      CellTags->"B1"],
    Cell[294287, 9042, 222, 6, 70, "Input",
      CellTags->"B1"],
    Cell[295052, 9069, 192, 5, 70, "Input",
      CellTags->"B1"],
    Cell[295787, 9095, 287, 7, 70, "Input",
      CellTags->"B1"],
    Cell[297080, 9133, 336, 9, 70, "Input",
      CellTags->"B1"]},
  "BackgroundGluonVertex"->{
    Cell[298003, 9165, 80, 1, 70, "ObjectName",
      CellTags->"BackgroundGluonVertex"],
    Cell[298108, 9170, 73, 1, 70, "Subsubsection",
      CellTags->"BackgroundGluonVertex"],
    Cell[298184, 9173, 1050, 19, 70, "Text",
      CellTags->"BackgroundGluonVertex"],
    Cell[299259, 9196, 169, 3, 70, "Input",
      CellTags->"BackgroundGluonVertex"],
    Cell[299797, 9213, 214, 9, 70, "Text",
      CellTags->"BackgroundGluonVertex"],
    Cell[300048, 9227, 70, 1, 70, "Subsubsection",
      CellTags->"BackgroundGluonVertex"],
    Cell[300143, 9232, 428, 11, 70, "Input",
      CellTags->"BackgroundGluonVertex"],
    Cell[304511, 9352, 513, 12, 70, "Input",
      CellTags->"BackgroundGluonVertex"],
    Cell[315993, 9640, 482, 11, 70, "Input",
      CellTags->"BackgroundGluonVertex"],
    Cell[320663, 9765, 569, 13, 70, "Input",
      CellTags->"BackgroundGluonVertex"]},
  "C0"->{
    Cell[332397, 10058, 42, 1, 70, "ObjectName",
      CellTags->"C0"],
    Cell[332464, 10063, 54, 1, 70, "Subsubsection",
      CellTags->"C0"],
    Cell[332521, 10066, 463, 10, 70, "Text",
      CellTags->"C0"],
    Cell[332987, 10078, 501, 24, 70, "Text",
      CellTags->"C0"],
    Cell[333525, 10107, 51, 1, 70, "Subsubsection",
      CellTags->"C0"],
    Cell[333601, 10112, 217, 6, 70, "Input",
      CellTags->"C0"],
    Cell[334365, 10135, 245, 6, 70, "Input",
      CellTags->"C0"],
    Cell[335157, 10158, 399, 11, 70, "Input",
      CellTags->"C0"]},
  "Calc"->{
    Cell[336127, 10188, 46, 1, 70, "ObjectName",
      CellTags->"Calc"],
    Cell[336198, 10193, 56, 1, 70, "Subsubsection",
      CellTags->"Calc"],
    Cell[336257, 10196, 228, 5, 70, "Text",
      CellTags->"Calc"],
    Cell[336488, 10203, 440, 19, 70, "Text",
      CellTags->"Calc"],
    Cell[336965, 10227, 62, 1, 70, "Subsubsection",
      CellTags->"Calc"],
    Cell[337030, 10230, 382, 13, 70, "Text",
      CellTags->"Calc"],
    Cell[337437, 10247, 347, 9, 70, "Input",
      CellTags->"Calc"],
    Cell[337966, 10265, 244, 9, 70, "Text",
      CellTags->"Calc"],
    Cell[338235, 10278, 312, 8, 70, "Input",
      CellTags->"Calc"],
    Cell[339053, 10307, 395, 11, 70, "Input",
      CellTags->"Calc"],
    Cell[340106, 10343, 129, 3, 70, "Input",
      CellTags->"Calc"],
    Cell[341051, 10375, 258, 6, 70, "Input",
      CellTags->"Calc"],
    Cell[342841, 10432, 476, 14, 70, "Input",
      CellTags->"Calc"]},
  "CA"->{
    Cell[343489, 10457, 42, 1, 70, "ObjectName",
      CellTags->"CA"],
    Cell[343556, 10462, 54, 1, 70, "Subsubsection",
      CellTags->"CA"],
    Cell[343613, 10465, 87, 1, 70, "Text",
      CellTags->"CA"],
    Cell[343703, 10468, 297, 14, 70, "Text",
      CellTags->"CA"],
    Cell[344037, 10487, 51, 1, 70, "Subsubsection",
      CellTags->"CA"],
    Cell[344113, 10492, 95, 2, 70, "Input",
      CellTags->"CA"],
    Cell[344382, 10504, 210, 5, 70, "Input",
      CellTags->"CA"],
    Cell[344740, 10518, 97, 2, 70, "Input",
      CellTags->"CA"]},
  "Cases2"->{
    Cell[345009, 10531, 50, 1, 70, "ObjectName",
      CellTags->"Cases2"],
    Cell[345084, 10536, 58, 1, 70, "Subsubsection",
      CellTags->"Cases2"],
    Cell[345145, 10539, 294, 6, 70, "Text",
      CellTags->"Cases2"],
    Cell[345476, 10550, 64, 1, 70, "Subsubsection",
      CellTags->"Cases2"],
    Cell[345565, 10555, 374, 10, 70, "Input",
      CellTags->"Cases2"],
    Cell[346301, 10581, 390, 11, 70, "Input",
      CellTags->"Cases2"],
    Cell[347057, 10608, 522, 14, 70, "Input",
      CellTags->"Cases2"],
    Cell[348034, 10640, 397, 10, 70, "Input",
      CellTags->"Cases2"]},
  "CF"->{
    Cell[349168, 10678, 42, 1, 70, "ObjectName",
      CellTags->"CF"],
    Cell[349235, 10683, 54, 1, 70, "Subsubsection",
      CellTags->"CF"],
    Cell[349292, 10686, 107, 3, 70, "Text",
      CellTags->"CF"],
    Cell[349402, 10691, 297, 14, 70, "Text",
      CellTags->"CF"],
    Cell[349736, 10710, 51, 1, 70, "Subsubsection",
      CellTags->"CF"],
    Cell[349812, 10715, 95, 2, 70, "Input",
      CellTags->"CF"],
    Cell[350081, 10727, 220, 5, 70, "Input",
      CellTags->"CF"],
    Cell[350564, 10745, 97, 2, 70, "Input",
      CellTags->"CF"],
    Cell[350809, 10756, 214, 5, 70, "Input",
      CellTags->"CF"]},
  "ChangeDimension"->{
    Cell[351221, 10773, 68, 1, 70, "ObjectName",
      CellTags->"ChangeDimension"],
    Cell[351314, 10778, 67, 1, 70, "Subsubsection",
      CellTags->"ChangeDimension"],
    Cell[351384, 10781, 211, 5, 70, "Text",
      CellTags->"ChangeDimension"],
    Cell[351598, 10788, 562, 24, 70, "Text",
      CellTags->"ChangeDimension"],
    Cell[352197, 10817, 64, 1, 70, "Subsubsection",
      CellTags->"ChangeDimension"],
    Cell[352264, 10820, 220, 5, 70, "Text",
      CellTags->"ChangeDimension"],
    Cell[352509, 10829, 254, 6, 70, "Input",
      CellTags->"ChangeDimension"],
    Cell[353024, 10849, 183, 4, 70, "Input",
      CellTags->"ChangeDimension"],
    Cell[353468, 10867, 144, 3, 70, "Input",
      CellTags->"ChangeDimension"],
    Cell[353925, 10882, 120, 3, 70, "Text",
      CellTags->"ChangeDimension"],
    Cell[354070, 10889, 242, 6, 70, "Input",
      CellTags->"ChangeDimension"],
    Cell[354563, 10905, 106, 1, 70, "Text",
      CellTags->"ChangeDimension"],
    Cell[354694, 10910, 582, 15, 70, "Input",
      CellTags->"ChangeDimension"],
    Cell[356023, 10950, 185, 4, 70, "Input",
      CellTags->"ChangeDimension"],
    Cell[356488, 10968, 265, 6, 70, "Input",
      CellTags->"ChangeDimension"],
    Cell[357011, 10986, 135, 4, 70, "Text",
      CellTags->"ChangeDimension"],
    Cell[357149, 10992, 251, 6, 70, "Input",
      CellTags->"ChangeDimension"],
    Cell[357403, 11000, 215, 5, 70, "Text",
      CellTags->"ChangeDimension"],
    Cell[357621, 11007, 244, 6, 70, "Input",
      CellTags->"ChangeDimension"],
    Cell[357890, 11017, 262, 6, 70, "Input",
      CellTags->"ChangeDimension"],
    Cell[358857, 11050, 219, 5, 70, "Input",
      CellTags->"ChangeDimension"],
    Cell[359781, 11082, 213, 5, 70, "Input",
      CellTags->"ChangeDimension"],
    Cell[360376, 11104, 173, 4, 70, "Input",
      CellTags->"ChangeDimension"],
    Cell[360698, 11116, 244, 6, 70, "Input",
      CellTags->"ChangeDimension"],
    Cell[360945, 11124, 194, 5, 70, "Input",
      CellTags->"ChangeDimension"]},
  "ChargeConjugationMatrixInv"->{
    Cell[361188, 11135, 90, 1, 70, "ObjectName",
      CellTags->"ChargeConjugationMatrixInv"],
    Cell[361303, 11140, 78, 1, 70, "Subsubsection",
      CellTags->"ChargeConjugationMatrixInv"],
    Cell[361384, 11143, 196, 4, 70, "Text",
      CellTags->"ChargeConjugationMatrixInv"],
    Cell[361583, 11149, 255, 9, 70, "Text",
      CellTags->"ChargeConjugationMatrixInv"],
    Cell[361875, 11163, 75, 1, 70, "Subsubsection",
      CellTags->"ChargeConjugationMatrixInv"],
    Cell[361975, 11168, 253, 5, 70, "Input",
      CellTags->"ChargeConjugationMatrixInv"],
    Cell[362615, 11190, 151, 3, 70, "Input",
      CellTags->"ChargeConjugationMatrixInv"],
    Cell[363091, 11208, 248, 5, 70, "Input",
      CellTags->"ChargeConjugationMatrixInv"],
    Cell[363616, 11226, 151, 3, 70, "Input",
      CellTags->"ChargeConjugationMatrixInv"],
    Cell[364005, 11241, 195, 4, 70, "Input",
      CellTags->"ChargeConjugationMatrixInv"],
    Cell[364430, 11257, 147, 3, 70, "Input",
      CellTags->"ChargeConjugationMatrixInv"],
    Cell[364725, 11269, 168, 3, 70, "Input",
      CellTags->"ChargeConjugationMatrixInv"]},
  "ChargeConjugationMatrix"->{
    Cell[365087, 11284, 84, 1, 70, "ObjectName",
      CellTags->"ChargeConjugationMatrix"],
    Cell[365196, 11289, 75, 1, 70, "Subsubsection",
      CellTags->"ChargeConjugationMatrix"],
    Cell[365274, 11292, 182, 6, 70, "Text",
      CellTags->"ChargeConjugationMatrix"],
    Cell[365459, 11300, 261, 9, 70, "Text",
      CellTags->"ChargeConjugationMatrix"],
    Cell[365757, 11314, 72, 1, 70, "Subsubsection",
      CellTags->"ChargeConjugationMatrix"],
    Cell[365854, 11319, 250, 5, 70, "Input",
      CellTags->"ChargeConjugationMatrix"],
    Cell[366491, 11341, 148, 3, 70, "Input",
      CellTags->"ChargeConjugationMatrix"],
    Cell[366964, 11359, 245, 5, 70, "Input",
      CellTags->"ChargeConjugationMatrix"],
    Cell[367486, 11377, 148, 3, 70, "Input",
      CellTags->"ChargeConjugationMatrix"],
    Cell[367872, 11392, 162, 3, 70, "Input",
      CellTags->"ChargeConjugationMatrix"]},
  "ChiralityProjector"->{
    Cell[368228, 11407, 74, 1, 70, "ObjectName",
      CellTags->"ChiralityProjector"],
    Cell[368327, 11412, 70, 1, 70, "Subsubsection",
      CellTags->"ChiralityProjector"],
    Cell[368400, 11415, 577, 19, 70, "Text",
      CellTags->"ChiralityProjector"],
    Cell[368980, 11436, 442, 19, 70, "Text",
      CellTags->"ChiralityProjector"],
    Cell[369459, 11460, 67, 1, 70, "Subsubsection",
      CellTags->"ChiralityProjector"],
    Cell[369551, 11465, 316, 8, 70, "Input",
      CellTags->"ChiralityProjector"],
    Cell[370156, 11487, 142, 3, 70, "Input",
      CellTags->"ChiralityProjector"],
    Cell[370587, 11504, 233, 5, 70, "Input",
      CellTags->"ChiralityProjector"]},
  "Chisholm"->{
    Cell[371327, 11531, 54, 1, 70, "ObjectName",
      CellTags->"Chisholm"],
    Cell[371406, 11536, 60, 1, 70, "Subsubsection",
      CellTags->"Chisholm"],
    Cell[371469, 11539, 143, 4, 70, "Text",
      CellTags->"Chisholm"],
    Cell[371615, 11545, 201, 9, 70, "Text",
      CellTags->"Chisholm"],
    Cell[371853, 11559, 57, 1, 70, "Subsubsection",
      CellTags->"Chisholm"],
    Cell[371935, 11564, 249, 6, 70, "Input",
      CellTags->"Chisholm"],
    Cell[374954, 11655, 220, 5, 70, "Input",
      CellTags->"Chisholm"],
    Cell[375473, 11673, 171, 4, 70, "Input",
      CellTags->"Chisholm"],
    Cell[377549, 11736, 78, 1, 70, "Text",
      CellTags->"Chisholm"],
    Cell[377652, 11741, 162, 4, 70, "Input",
      CellTags->"Chisholm"],
    Cell[377963, 11754, 171, 4, 70, "Input",
      CellTags->"Chisholm"],
    Cell[380061, 11819, 162, 4, 70, "Input",
      CellTags->"Chisholm"],
    Cell[380372, 11832, 206, 5, 70, "Input",
      CellTags->"Chisholm"],
    Cell[381474, 11868, 138, 3, 70, "Input",
      CellTags->"Chisholm"],
    Cell[383839, 11941, 280, 7, 70, "Input",
      CellTags->"Chisholm"],
    Cell[384590, 11965, 171, 4, 70, "Input",
      CellTags->"Chisholm"],
    Cell[400775, 12415, 171, 4, 70, "Input",
      CellTags->"Chisholm"],
    Cell[416938, 12863, 86, 1, 70, "Text",
      CellTags->"Chisholm"],
    Cell[417049, 12868, 162, 4, 70, "Input",
      CellTags->"Chisholm"],
    Cell[417384, 12882, 162, 4, 70, "Input",
      CellTags->"Chisholm"],
    Cell[417697, 12894, 234, 6, 70, "Input",
      CellTags->"Chisholm"]},
  "ClearScalarProducts"->{
    Cell[417980, 12906, 76, 1, 70, "ObjectName",
      CellTags->"ClearScalarProducts"],
    Cell[418081, 12911, 71, 1, 70, "Subsubsection",
      CellTags->"ClearScalarProducts"],
    Cell[418155, 12914, 146, 4, 70, "Text",
      CellTags->"ClearScalarProducts"],
    Cell[418304, 12920, 526, 23, 70, "Text",
      CellTags->"ClearScalarProducts"],
    Cell[418867, 12948, 68, 1, 70, "Subsubsection",
      CellTags->"ClearScalarProducts"],
    Cell[418960, 12953, 236, 6, 70, "Input",
      CellTags->"ClearScalarProducts"],
    Cell[419372, 12969, 253, 6, 70, "Input",
      CellTags->"ClearScalarProducts"],
    Cell[419779, 12983, 129, 2, 70, "Input",
      CellTags->"ClearScalarProducts"],
    Cell[419933, 12989, 253, 6, 70, "Input",
      CellTags->"ClearScalarProducts"],
    Cell[420409, 13007, 180, 4, 70, "Input",
      CellTags->"ClearScalarProducts"]},
  "Collect2"->{
    Cell[420836, 13025, 54, 1, 70, "ObjectName",
      CellTags->"Collect2"],
    Cell[420915, 13030, 60, 1, 70, "Subsubsection",
      CellTags->"Collect2"],
    Cell[420978, 13033, 614, 10, 70, "Text",
      CellTags->"Collect2"],
    Cell[421617, 13047, 143, 3, 70, "Input",
      CellTags->"Collect2"],
    Cell[422224, 13065, 189, 9, 70, "Text",
      CellTags->"Collect2"],
    Cell[422450, 13079, 57, 1, 70, "Subsubsection",
      CellTags->"Collect2"],
    Cell[422532, 13084, 542, 14, 70, "Input",
      CellTags->"Collect2"],
    Cell[424064, 13132, 217, 5, 70, "Input",
      CellTags->"Collect2"],
    Cell[425242, 13169, 218, 5, 70, "Input",
      CellTags->"Collect2"],
    Cell[426450, 13208, 652, 18, 70, "Input",
      CellTags->"Collect2"],
    Cell[427741, 13249, 388, 10, 70, "Input",
      CellTags->"Collect2"],
    Cell[429167, 13296, 140, 3, 70, "Input",
      CellTags->"Collect2"],
    Cell[430308, 13331, 162, 4, 70, "Input",
      CellTags->"Collect2"],
    Cell[430495, 13339, 377, 10, 70, "Input",
      CellTags->"Collect2"],
    Cell[432044, 13386, 176, 4, 70, "Input",
      CellTags->"Collect2"]},
  "Combine"->{
    Cell[433068, 13420, 52, 1, 70, "ObjectName",
      CellTags->"Combine"],
    Cell[433145, 13425, 59, 1, 70, "Subsubsection",
      CellTags->"Combine"],
    Cell[433207, 13428, 316, 6, 70, "Text",
      CellTags->"Combine"],
    Cell[433548, 13438, 141, 3, 70, "Input",
      CellTags->"Combine"],
    Cell[433896, 13451, 188, 9, 70, "Text",
      CellTags->"Combine"],
    Cell[434121, 13465, 56, 1, 70, "Subsubsection",
      CellTags->"Combine"],
    Cell[434202, 13470, 363, 11, 70, "Input",
      CellTags->"Combine"],
    Cell[434943, 13496, 125, 4, 70, "Text",
      CellTags->"Combine"],
    Cell[435093, 13504, 364, 11, 70, "Input",
      CellTags->"Combine"],
    Cell[435822, 13529, 176, 4, 70, "Text",
      CellTags->"Combine"],
    Cell[436023, 13537, 443, 12, 70, "Input",
      CellTags->"Combine"]},
  "CommutatorExplicit"->{
    Cell[436877, 13567, 74, 1, 70, "ObjectName",
      CellTags->"CommutatorExplicit"],
    Cell[436976, 13572, 70, 1, 70, "Subsubsection",
      CellTags->"CommutatorExplicit"],
    Cell[437049, 13575, 158, 4, 70, "Text",
      CellTags->"CommutatorExplicit"],
    Cell[437210, 13581, 319, 14, 70, "Text",
      CellTags->"CommutatorExplicit"],
    Cell[437566, 13600, 67, 1, 70, "Subsubsection",
      CellTags->"CommutatorExplicit"],
    Cell[437636, 13603, 207, 4, 70, "Input",
      CellTags->"CommutatorExplicit"],
    Cell[437868, 13611, 176, 4, 70, "Input",
      CellTags->"CommutatorExplicit"],
    Cell[438285, 13627, 157, 3, 70, "Input",
      CellTags->"CommutatorExplicit"],
    Cell[438675, 13642, 238, 6, 70, "Input",
      CellTags->"CommutatorExplicit"],
    Cell[439353, 13666, 157, 3, 70, "Input",
      CellTags->"CommutatorExplicit"],
    Cell[439999, 13689, 203, 5, 70, "Input",
      CellTags->"CommutatorExplicit"],
    Cell[440647, 13710, 209, 4, 70, "Input",
      CellTags->"CommutatorExplicit"]},
  "Commutator"->{
    Cell[440905, 13720, 58, 1, 70, "ObjectName",
      CellTags->"Commutator"],
    Cell[440988, 13725, 62, 1, 70, "Subsubsection",
      CellTags->"Commutator"],
    Cell[441053, 13728, 139, 4, 70, "Text",
      CellTags->"Commutator"],
    Cell[441195, 13734, 650, 24, 70, "Text",
      CellTags->"Commutator"],
    Cell[441882, 13763, 59, 1, 70, "Subsubsection",
      CellTags->"Commutator"],
    Cell[441944, 13766, 199, 4, 70, "Input",
      CellTags->"Commutator"],
    Cell[442168, 13774, 168, 4, 70, "Input",
      CellTags->"Commutator"],
    Cell[442577, 13790, 149, 3, 70, "Input",
      CellTags->"Commutator"],
    Cell[442959, 13805, 304, 8, 70, "Input",
      CellTags->"Commutator"],
    Cell[443708, 13829, 201, 4, 70, "Input",
      CellTags->"Commutator"],
    Cell[443912, 13835, 69, 1, 70, "Text",
      CellTags->"Commutator"],
    Cell[443984, 13838, 269, 6, 70, "Input",
      CellTags->"Commutator"],
    Cell[444278, 13848, 557, 15, 70, "Input",
      CellTags->"Commutator"],
    Cell[445762, 13892, 142, 3, 70, "Input",
      CellTags->"Commutator"],
    Cell[446030, 13902, 141, 3, 70, "Input",
      CellTags->"Commutator"],
    Cell[446174, 13907, 191, 4, 70, "Input",
      CellTags->"Commutator"]},
  "ComplexConjugate"->{
    Cell[446414, 13917, 70, 1, 70, "ObjectName",
      CellTags->"ComplexConjugate"],
    Cell[446509, 13922, 68, 1, 70, "Subsubsection",
      CellTags->"ComplexConjugate"],
    Cell[446580, 13925, 415, 7, 70, "Text",
      CellTags->"ComplexConjugate"],
    Cell[446998, 13934, 482, 19, 70, "Text",
      CellTags->"ComplexConjugate"],
    Cell[447517, 13958, 65, 1, 70, "Subsubsection",
      CellTags->"ComplexConjugate"],
    Cell[447607, 13963, 233, 5, 70, "Input",
      CellTags->"ComplexConjugate"],
    Cell[448232, 13985, 149, 3, 70, "Input",
      CellTags->"ComplexConjugate"],
    Cell[448771, 14003, 184, 4, 70, "Input",
      CellTags->"ComplexConjugate"],
    Cell[449259, 14020, 153, 3, 70, "Input",
      CellTags->"ComplexConjugate"],
    Cell[450050, 14047, 219, 5, 70, "Input",
      CellTags->"ComplexConjugate"],
    Cell[451044, 14081, 153, 3, 70, "Input",
      CellTags->"ComplexConjugate"],
    Cell[451972, 14113, 227, 5, 70, "Input",
      CellTags->"ComplexConjugate"],
    Cell[452748, 14141, 327, 8, 70, "Input",
      CellTags->"ComplexConjugate"],
    Cell[453362, 14161, 323, 8, 70, "Input",
      CellTags->"ComplexConjugate"],
    Cell[454275, 14189, 153, 3, 70, "Input",
      CellTags->"ComplexConjugate"],
    Cell[455152, 14214, 167, 4, 70, "Text",
      CellTags->"ComplexConjugate"]},
  "ComplexIndex"->{
    Cell[455368, 14224, 62, 1, 70, "ObjectName",
      CellTags->"ComplexIndex"],
    Cell[455455, 14229, 64, 1, 70, "Subsubsection",
      CellTags->"ComplexIndex"],
    Cell[455522, 14232, 155, 4, 70, "Text",
      CellTags->"ComplexIndex"],
    Cell[455680, 14238, 208, 9, 70, "Text",
      CellTags->"ComplexIndex"],
    Cell[455925, 14252, 61, 1, 70, "Subsubsection",
      CellTags->"ComplexIndex"],
    Cell[456011, 14257, 149, 3, 70, "Input",
      CellTags->"ComplexIndex"],
    Cell[456312, 14269, 149, 3, 70, "Input",
      CellTags->"ComplexIndex"],
    Cell[456641, 14282, 141, 3, 70, "Input",
      CellTags->"ComplexIndex"],
    Cell[457001, 14295, 174, 4, 70, "Input",
      CellTags->"ComplexIndex"],
    Cell[457353, 14309, 149, 3, 70, "Input",
      CellTags->"ComplexIndex"],
    Cell[457861, 14329, 141, 3, 70, "Input",
      CellTags->"ComplexIndex"],
    Cell[458330, 14345, 149, 3, 70, "Input",
      CellTags->"ComplexIndex"]},
  "Contract"->{
    Cell[458828, 14366, 54, 1, 70, "ObjectName",
      CellTags->"Contract"],
    Cell[458907, 14371, 60, 1, 70, "Subsubsection",
      CellTags->"Contract"],
    Cell[458970, 14374, 412, 7, 70, "Text",
      CellTags->"Contract"],
    Cell[459407, 14385, 143, 3, 70, "Input",
      CellTags->"Contract"],
    Cell[460196, 14406, 456, 19, 70, "Text",
      CellTags->"Contract"],
    Cell[460689, 14430, 57, 1, 70, "Subsubsection",
      CellTags->"Contract"],
    Cell[460771, 14435, 279, 7, 70, "Input",
      CellTags->"Contract"],
    Cell[461342, 14456, 137, 3, 70, "Input",
      CellTags->"Contract"],
    Cell[461804, 14475, 240, 6, 70, "Input",
      CellTags->"Contract"],
    Cell[462398, 14497, 137, 3, 70, "Input",
      CellTags->"Contract"],
    Cell[462858, 14514, 176, 4, 70, "Input",
      CellTags->"Contract"],
    Cell[463236, 14528, 84, 1, 70, "Text",
      CellTags->"Contract"],
    Cell[463345, 14533, 137, 3, 70, "Input",
      CellTags->"Contract"],
    Cell[463608, 14543, 209, 5, 70, "Text",
      CellTags->"Contract"],
    Cell[463842, 14552, 277, 7, 70, "Input",
      CellTags->"Contract"],
    Cell[464457, 14574, 137, 3, 70, "Input",
      CellTags->"Contract"],
    Cell[464742, 14586, 277, 7, 70, "Input",
      CellTags->"Contract"],
    Cell[465357, 14608, 273, 7, 70, "Input",
      CellTags->"Contract"],
    Cell[465869, 14627, 142, 3, 70, "Input",
      CellTags->"Contract"],
    Cell[466319, 14644, 335, 9, 70, "Input",
      CellTags->"Contract"],
    Cell[467300, 14678, 137, 3, 70, "Input",
      CellTags->"Contract"],
    Cell[468312, 14711, 323, 8, 70, "Input",
      CellTags->"Contract"],
    Cell[469440, 14748, 137, 3, 70, "Input",
      CellTags->"Contract"],
    Cell[470222, 14776, 400, 10, 70, "Input",
      CellTags->"Contract"],
    Cell[471986, 14832, 137, 3, 70, "Input",
      CellTags->"Contract"],
    Cell[472412, 14849, 508, 13, 70, "Input",
      CellTags->"Contract"],
    Cell[473420, 14880, 171, 4, 70, "Input",
      CellTags->"Contract"],
    Cell[474255, 14908, 237, 6, 70, "Input",
      CellTags->"Contract"]},
  "Convolute"->{
    Cell[474541, 14920, 56, 1, 70, "ObjectName",
      CellTags->"Convolute"],
    Cell[474600, 14923, 52, 1, 70, "Text",
      CellTags->"Convolute"],
    Cell[474655, 14926, 1136, 28, 70, "Text",
      CellTags->"Convolute"],
    Cell[475816, 14958, 145, 3, 70, "Input",
      CellTags->"Convolute"],
    Cell[476448, 14978, 217, 9, 70, "Text",
      CellTags->"Convolute"],
    Cell[476690, 14991, 58, 1, 70, "Subsubsection",
      CellTags->"Convolute"],
    Cell[476773, 14996, 166, 4, 70, "Input",
      CellTags->"Convolute"],
    Cell[477145, 15011, 166, 4, 70, "Input",
      CellTags->"Convolute"],
    Cell[477546, 15027, 166, 4, 70, "Input",
      CellTags->"Convolute"],
    Cell[477887, 15041, 224, 6, 70, "Input",
      CellTags->"Convolute"],
    Cell[478389, 15060, 277, 7, 70, "Input",
      CellTags->"Convolute"],
    Cell[478944, 15080, 224, 6, 70, "Input",
      CellTags->"Convolute"],
    Cell[479537, 15102, 282, 8, 70, "Input",
      CellTags->"Convolute"],
    Cell[480496, 15135, 233, 6, 70, "Input",
      CellTags->"Convolute"],
    Cell[481168, 15159, 266, 7, 70, "Input",
      CellTags->"Convolute"],
    Cell[481790, 15182, 291, 8, 70, "Input",
      CellTags->"Convolute"],
    Cell[482543, 15208, 324, 9, 70, "Input",
      CellTags->"Convolute"],
    Cell[483606, 15243, 295, 8, 70, "Input",
      CellTags->"Convolute"],
    Cell[484789, 15281, 233, 6, 70, "Input",
      CellTags->"Convolute"],
    Cell[485311, 15301, 233, 6, 70, "Input",
      CellTags->"Convolute"],
    Cell[485950, 15324, 320, 9, 70, "Input",
      CellTags->"Convolute"],
    Cell[486849, 15356, 202, 5, 70, "Input",
      CellTags->"Convolute"],
    Cell[487354, 15376, 238, 6, 70, "Input",
      CellTags->"Convolute"],
    Cell[487905, 15397, 260, 7, 70, "Input",
      CellTags->"Convolute"],
    Cell[488742, 15426, 262, 7, 70, "Input",
      CellTags->"Convolute"],
    Cell[489433, 15451, 291, 8, 70, "Input",
      CellTags->"Convolute"],
    Cell[490460, 15485, 262, 7, 70, "Input",
      CellTags->"Convolute"],
    Cell[491269, 15513, 233, 6, 70, "Input",
      CellTags->"Convolute"],
    Cell[491791, 15533, 202, 5, 70, "Input",
      CellTags->"Convolute"],
    Cell[492245, 15551, 353, 10, 70, "Input",
      CellTags->"Convolute"]},
  "CovariantD"->{
    Cell[493716, 15600, 58, 1, 70, "ObjectName",
      CellTags->"CovariantD"],
    Cell[493799, 15605, 62, 1, 70, "Subsubsection",
      CellTags->"CovariantD"],
    Cell[493864, 15608, 735, 12, 70, "Text",
      CellTags->"CovariantD"],
    Cell[494624, 15624, 147, 3, 70, "Input",
      CellTags->"CovariantD"],
    Cell[495280, 15643, 186, 4, 70, "Text",
      CellTags->"CovariantD"],
    Cell[495469, 15649, 488, 19, 70, "Text",
      CellTags->"CovariantD"],
    Cell[495994, 15673, 59, 1, 70, "Subsubsection",
      CellTags->"CovariantD"],
    Cell[496078, 15678, 145, 3, 70, "Input",
      CellTags->"CovariantD"],
    Cell[496401, 15691, 182, 4, 70, "Input",
      CellTags->"CovariantD"],
    Cell[496809, 15706, 217, 5, 70, "Input",
      CellTags->"CovariantD"],
    Cell[498343, 15754, 165, 4, 70, "Text",
      CellTags->"CovariantD"],
    Cell[498533, 15762, 148, 3, 70, "Input",
      CellTags->"CovariantD"],
    Cell[498916, 15777, 185, 4, 70, "Input",
      CellTags->"CovariantD"],
    Cell[499384, 15794, 235, 5, 70, "Input",
      CellTags->"CovariantD"],
    Cell[500891, 15841, 215, 5, 70, "Input",
      CellTags->"CovariantD"],
    Cell[502347, 15887, 224, 5, 70, "Input",
      CellTags->"CovariantD"],
    Cell[504434, 15946, 675, 22, 70, "Text",
      CellTags->"CovariantD"],
    Cell[505134, 15972, 258, 6, 70, "Input",
      CellTags->"CovariantD"],
    Cell[506071, 16002, 372, 11, 70, "Text",
      CellTags->"CovariantD"],
    Cell[506468, 16017, 258, 6, 70, "Input",
      CellTags->"CovariantD"],
    Cell[509925, 16107, 207, 7, 70, "Text",
      CellTags->"CovariantD"],
    Cell[510157, 16118, 258, 6, 70, "Input",
      CellTags->"CovariantD"],
    Cell[519273, 16330, 218, 5, 70, "Input",
      CellTags->"CovariantD"],
    Cell[519854, 16351, 238, 6, 70, "Input",
      CellTags->"CovariantD"],
    Cell[526475, 16509, 265, 7, 70, "Input",
      CellTags->"CovariantD"],
    Cell[527708, 16546, 282, 7, 70, "Input",
      CellTags->"CovariantD"]},
  "D0"->{
    Cell[528988, 16586, 42, 1, 70, "ObjectName",
      CellTags->"D0"],
    Cell[529055, 16591, 54, 1, 70, "Subsubsection",
      CellTags->"D0"],
    Cell[529112, 16594, 537, 12, 70, "Text",
      CellTags->"D0"],
    Cell[529652, 16608, 501, 24, 70, "Text",
      CellTags->"D0"],
    Cell[530190, 16637, 51, 1, 70, "Subsubsection",
      CellTags->"D0"],
    Cell[530266, 16642, 380, 10, 70, "Input",
      CellTags->"D0"],
    Cell[531948, 16691, 587, 15, 70, "Input",
      CellTags->"D0"],
    Cell[533846, 16746, 132, 3, 70, "Input",
      CellTags->"D0"]},
  "DataType"->{
    Cell[535304, 16790, 54, 1, 70, "ObjectName",
      CellTags->"DataType"],
    Cell[535383, 16795, 60, 1, 70, "Subsubsection",
      CellTags->"DataType"],
    Cell[535446, 16798, 345, 6, 70, "Text",
      CellTags->"DataType"],
    Cell[535794, 16806, 231, 9, 70, "Text",
      CellTags->"DataType"],
    Cell[536062, 16820, 57, 1, 70, "Subsubsection",
      CellTags->"DataType"],
    Cell[536122, 16823, 75, 1, 70, "Text",
      CellTags->"DataType"],
    Cell[536200, 16826, 269, 7, 70, "Input",
      CellTags->"DataType"],
    Cell[536494, 16837, 279, 8, 70, "Input",
      CellTags->"DataType"],
    Cell[537065, 16858, 180, 4, 70, "Text",
      CellTags->"DataType"],
    Cell[537270, 16866, 140, 3, 70, "Input",
      CellTags->"DataType"],
    Cell[537662, 16880, 339, 10, 70, "Input",
      CellTags->"DataType"],
    Cell[538004, 16892, 518, 14, 70, "Input",
      CellTags->"DataType"],
    Cell[538525, 16908, 504, 14, 70, "Input",
      CellTags->"DataType"],
    Cell[539054, 16926, 426, 13, 70, "Input",
      CellTags->"DataType"],
    Cell[539932, 16958, 135, 3, 70, "Input",
      CellTags->"DataType"],
    Cell[540454, 16978, 135, 3, 70, "Input",
      CellTags->"DataType"],
    Cell[540798, 16991, 234, 6, 70, "Input",
      CellTags->"DataType"],
    Cell[541035, 16999, 237, 7, 70, "Input",
      CellTags->"DataType"],
    Cell[541275, 17008, 536, 15, 70, "Input",
      CellTags->"DataType"],
    Cell[541836, 17027, 368, 12, 70, "Input",
      CellTags->"DataType"],
    Cell[542592, 17056, 133, 3, 70, "Input",
      CellTags->"DataType"],
    Cell[543009, 17072, 188, 5, 70, "Input",
      CellTags->"DataType"],
    Cell[543200, 17079, 270, 7, 70, "Input",
      CellTags->"DataType"],
    Cell[543473, 17088, 340, 10, 70, "Input",
      CellTags->"DataType"],
    Cell[543816, 17100, 115, 3, 70, "Text",
      CellTags->"DataType"],
    Cell[543956, 17107, 181, 4, 70, "Input",
      CellTags->"DataType"],
    Cell[544266, 17118, 84, 1, 70, "Text",
      CellTags->"DataType"],
    Cell[544375, 17123, 287, 8, 70, "Input",
      CellTags->"DataType"],
    Cell[544810, 17140, 283, 8, 70, "Input",
      CellTags->"DataType"]},
  "DeclareNonCommutative"->{
    Cell[545700, 17173, 80, 1, 70, "ObjectName",
      CellTags->"DeclareNonCommutative"],
    Cell[545805, 17178, 73, 1, 70, "Subsubsection",
      CellTags->"DeclareNonCommutative"],
    Cell[545881, 17181, 193, 4, 70, "Text",
      CellTags->"DeclareNonCommutative"],
    Cell[546077, 17187, 370, 14, 70, "Text",
      CellTags->"DeclareNonCommutative"],
    Cell[546484, 17206, 70, 1, 70, "Subsubsection",
      CellTags->"DeclareNonCommutative"],
    Cell[546557, 17209, 163, 3, 70, "Input",
      CellTags->"DeclareNonCommutative"],
    Cell[546723, 17214, 153, 4, 70, "Text",
      CellTags->"DeclareNonCommutative"],
    Cell[546901, 17222, 190, 4, 70, "Input",
      CellTags->"DeclareNonCommutative"],
    Cell[547220, 17233, 190, 4, 70, "Input",
      CellTags->"DeclareNonCommutative"],
    Cell[547435, 17241, 227, 5, 70, "Input",
      CellTags->"DeclareNonCommutative"],
    Cell[547884, 17256, 202, 4, 70, "Input",
      CellTags->"DeclareNonCommutative"],
    Cell[548111, 17264, 227, 5, 70, "Input",
      CellTags->"DeclareNonCommutative"]},
  "DeltaFunction"->{
    Cell[548609, 17283, 64, 1, 70, "ObjectName",
      CellTags->"DeltaFunction"],
    Cell[548698, 17288, 65, 1, 70, "Subsubsection",
      CellTags->"DeltaFunction"],
    Cell[548766, 17291, 210, 7, 70, "Text",
      CellTags->"DeltaFunction"],
    Cell[548979, 17300, 635, 24, 70, "Text",
      CellTags->"DeltaFunction"],
    Cell[549651, 17329, 62, 1, 70, "Subsubsection",
      CellTags->"DeltaFunction"],
    Cell[549738, 17334, 174, 4, 70, "Input",
      CellTags->"DeltaFunction"],
    Cell[550177, 17351, 387, 10, 70, "Input",
      CellTags->"DeltaFunction"],
    Cell[550744, 17371, 354, 9, 70, "Input",
      CellTags->"DeltaFunction"],
    Cell[551278, 17390, 387, 10, 70, "Input",
      CellTags->"DeltaFunction"],
    Cell[551845, 17410, 247, 6, 70, "Input",
      CellTags->"DeltaFunction"]},
  "DeltaFunctionPrime"->{
    Cell[552264, 17427, 74, 1, 70, "ObjectName",
      CellTags->"DeltaFunctionPrime"],
    Cell[552363, 17432, 70, 1, 70, "Subsubsection",
      CellTags->"DeltaFunctionPrime"],
    Cell[552436, 17435, 200, 6, 70, "Text",
      CellTags->"DeltaFunctionPrime"],
    Cell[552639, 17443, 618, 23, 70, "Text",
      CellTags->"DeltaFunctionPrime"],
    Cell[553294, 17471, 67, 1, 70, "Subsubsection",
      CellTags->"DeltaFunctionPrime"],
    Cell[553386, 17476, 184, 4, 70, "Input",
      CellTags->"DeltaFunctionPrime"],
    Cell[553872, 17494, 397, 10, 70, "Input",
      CellTags->"DeltaFunctionPrime"],
    Cell[554528, 17517, 393, 10, 70, "Input",
      CellTags->"DeltaFunctionPrime"]},
  "Dimension"->{
    Cell[555093, 17538, 56, 1, 70, "ObjectName",
      CellTags->"Dimension"],
    Cell[555174, 17543, 61, 1, 70, "Subsubsection",
      CellTags->"Dimension"],
    Cell[555238, 17546, 236, 5, 70, "Text",
      CellTags->"Dimension"],
    Cell[555499, 17555, 148, 3, 70, "Input",
      CellTags->"Dimension"],
    Cell[555958, 17572, 420, 11, 70, "Input",
      CellTags->"Dimension"],
    Cell[556979, 17606, 132, 4, 70, "Text",
      CellTags->"Dimension"],
    Cell[557136, 17614, 429, 11, 70, "Input",
      CellTags->"Dimension"],
    Cell[558080, 17642, 167, 4, 70, "Text",
      CellTags->"Dimension"],
    Cell[558250, 17648, 165, 4, 70, "Input",
      CellTags->"Dimension"],
    Cell[558440, 17656, 384, 9, 70, "Input",
      CellTags->"Dimension"],
    Cell[559757, 17699, 138, 3, 70, "Input",
      CellTags->"Dimension"],
    Cell[560423, 17719, 166, 4, 70, "Input",
      CellTags->"Dimension"]},
  "DiracGammaCombine"->{
    Cell[560638, 17729, 72, 1, 70, "ObjectName",
      CellTags->"DiracGammaCombine"],
    Cell[560735, 17734, 69, 1, 70, "Subsubsection",
      CellTags->"DiracGammaCombine"],
    Cell[560807, 17737, 136, 4, 70, "Text",
      CellTags->"DiracGammaCombine"],
    Cell[560946, 17743, 867, 34, 70, "Text",
      CellTags->"DiracGammaCombine"],
    Cell[561850, 17782, 66, 1, 70, "Subsubsection",
      CellTags->"DiracGammaCombine"],
    Cell[561941, 17787, 262, 6, 70, "Input",
      CellTags->"DiracGammaCombine"],
    Cell[562606, 17810, 150, 3, 70, "Input",
      CellTags->"DiracGammaCombine"],
    Cell[562994, 17824, 324, 8, 70, "Input",
      CellTags->"DiracGammaCombine"],
    Cell[563787, 17851, 150, 3, 70, "Input",
      CellTags->"DiracGammaCombine"],
    Cell[564237, 17867, 155, 3, 70, "Input",
      CellTags->"DiracGammaCombine"]},
  "DiracGammaExpand"->{
    Cell[565065, 17896, 70, 1, 70, "ObjectName",
      CellTags->"DiracGammaExpand"],
    Cell[565160, 17901, 68, 1, 70, "Subsubsection",
      CellTags->"DiracGammaExpand"],
    Cell[565231, 17904, 191, 4, 70, "Text",
      CellTags->"DiracGammaExpand"],
    Cell[565425, 17910, 869, 34, 70, "Text",
      CellTags->"DiracGammaExpand"],
    Cell[566331, 17949, 65, 1, 70, "Subsubsection",
      CellTags->"DiracGammaExpand"],
    Cell[566421, 17954, 375, 9, 70, "Input",
      CellTags->"DiracGammaExpand"],
    Cell[567503, 17987, 126, 3, 70, "Text",
      CellTags->"DiracGammaExpand"],
    Cell[567654, 17994, 149, 3, 70, "Input",
      CellTags->"DiracGammaExpand"],
    Cell[568132, 18009, 102, 1, 70, "Text",
      CellTags->"DiracGammaExpand"],
    Cell[568259, 18014, 153, 3, 70, "Input",
      CellTags->"DiracGammaExpand"],
    Cell[569302, 18046, 91, 1, 70, "Text",
      CellTags->"DiracGammaExpand"],
    Cell[569418, 18051, 246, 5, 70, "Input",
      CellTags->"DiracGammaExpand"],
    Cell[570015, 18070, 196, 4, 70, "Input",
      CellTags->"DiracGammaExpand"],
    Cell[570663, 18089, 107, 1, 70, "Text",
      CellTags->"DiracGammaExpand"],
    Cell[570795, 18094, 150, 3, 70, "Input",
      CellTags->"DiracGammaExpand"],
    Cell[571710, 18123, 142, 3, 70, "Input",
      CellTags->"DiracGammaExpand"]},
  "DiracGamma"->{
    Cell[571901, 18132, 58, 1, 70, "ObjectName",
      CellTags->"DiracGamma"],
    Cell[571984, 18137, 62, 1, 70, "Subsubsection",
      CellTags->"DiracGamma"],
    Cell[572049, 18140, 852, 25, 70, "Text",
      CellTags->"DiracGamma"],
    Cell[572904, 18167, 734, 29, 70, "Text",
      CellTags->"DiracGamma"],
    Cell[573675, 18201, 59, 1, 70, "Subsubsection",
      CellTags->"DiracGamma"],
    Cell[573759, 18206, 141, 3, 70, "Input",
      CellTags->"DiracGamma"],
    Cell[574083, 18219, 191, 4, 70, "Input",
      CellTags->"DiracGamma"],
    Cell[574540, 18235, 368, 13, 70, "Text",
      CellTags->"DiracGamma"],
    Cell[574933, 18252, 204, 5, 70, "Input",
      CellTags->"DiracGamma"],
    Cell[575460, 18271, 332, 8, 70, "Input",
      CellTags->"DiracGamma"],
    Cell[576521, 18305, 270, 8, 70, "Input",
      CellTags->"DiracGamma"],
    Cell[577114, 18327, 256, 7, 70, "Input",
      CellTags->"DiracGamma"],
    Cell[577931, 18355, 176, 4, 70, "Input",
      CellTags->"DiracGamma"],
    Cell[579019, 18390, 358, 9, 70, "Input",
      CellTags->"DiracGamma"],
    Cell[580040, 18422, 170, 4, 70, "Input",
      CellTags->"DiracGamma"],
    Cell[581411, 18463, 173, 4, 70, "Input",
      CellTags->"DiracGamma"],
    Cell[583275, 18518, 205, 5, 70, "Input",
      CellTags->"DiracGamma"]},
  "DiracGammaT"->{
    Cell[583529, 18529, 60, 1, 70, "ObjectName",
      CellTags->"DiracGammaT"],
    Cell[583614, 18534, 63, 1, 70, "Subsubsection",
      CellTags->"DiracGammaT"],
    Cell[583680, 18537, 209, 5, 70, "Text",
      CellTags->"DiracGammaT"],
    Cell[583892, 18544, 201, 9, 70, "Text",
      CellTags->"DiracGammaT"],
    Cell[584130, 18558, 60, 1, 70, "Subsubsection",
      CellTags->"DiracGammaT"],
    Cell[584215, 18563, 190, 4, 70, "Input",
      CellTags->"DiracGammaT"],
    Cell[584698, 18581, 141, 3, 70, "Input",
      CellTags->"DiracGammaT"],
    Cell[585124, 18598, 209, 6, 70, "Input",
      CellTags->"DiracGammaT"]},
  "DiracMatrix"->{
    Cell[585724, 18622, 60, 1, 70, "ObjectName",
      CellTags->"DiracMatrix"],
    Cell[585809, 18627, 63, 1, 70, "Subsubsection",
      CellTags->"DiracMatrix"],
    Cell[585875, 18630, 1375, 48, 70, "Text",
      CellTags->"DiracMatrix"],
    Cell[587253, 18680, 1146, 49, 70, "Text",
      CellTags->"DiracMatrix"],
    Cell[588436, 18734, 60, 1, 70, "Subsubsection",
      CellTags->"DiracMatrix"],
    Cell[588521, 18739, 147, 3, 70, "Input",
      CellTags->"DiracMatrix"],
    Cell[588931, 18754, 640, 20, 70, "Text",
      CellTags->"DiracMatrix"],
    Cell[589596, 18778, 220, 5, 70, "Input",
      CellTags->"DiracMatrix"],
    Cell[590285, 18803, 196, 5, 70, "Input",
      CellTags->"DiracMatrix"],
    Cell[590701, 18818, 177, 4, 70, "Input",
      CellTags->"DiracMatrix"],
    Cell[591065, 18832, 140, 3, 70, "Input",
      CellTags->"DiracMatrix"],
    Cell[591371, 18844, 139, 3, 70, "Input",
      CellTags->"DiracMatrix"],
    Cell[591697, 18857, 170, 4, 70, "Input",
      CellTags->"DiracMatrix"],
    Cell[592144, 18873, 184, 4, 70, "Input",
      CellTags->"DiracMatrix"],
    Cell[592637, 18890, 203, 5, 70, "Input",
      CellTags->"DiracMatrix"],
    Cell[593301, 18915, 140, 3, 70, "Input",
      CellTags->"DiracMatrix"]},
  "DiracOrder"->{
    Cell[593793, 18933, 58, 1, 70, "ObjectName",
      CellTags->"DiracOrder"],
    Cell[593876, 18938, 62, 1, 70, "Subsubsection",
      CellTags->"DiracOrder"],
    Cell[593941, 18941, 205, 5, 70, "Text",
      CellTags->"DiracOrder"],
    Cell[594149, 18948, 335, 14, 70, "Text",
      CellTags->"DiracOrder"],
    Cell[594521, 18967, 59, 1, 70, "Subsubsection",
      CellTags->"DiracOrder"],
    Cell[594605, 18972, 213, 5, 70, "Input",
      CellTags->"DiracOrder"],
    Cell[595082, 18990, 142, 3, 70, "Input",
      CellTags->"DiracOrder"],
    Cell[595841, 19015, 94, 1, 70, "Text",
      CellTags->"DiracOrder"],
    Cell[595960, 19020, 213, 5, 70, "Input",
      CellTags->"DiracOrder"],
    Cell[596481, 19038, 142, 3, 70, "Input",
      CellTags->"DiracOrder"],
    Cell[597262, 19065, 208, 5, 70, "Input",
      CellTags->"DiracOrder"],
    Cell[597752, 19081, 215, 8, 70, "Text",
      CellTags->"DiracOrder"],
    Cell[597992, 19093, 142, 3, 70, "Input",
      CellTags->"DiracOrder"],
    Cell[598650, 19117, 204, 5, 70, "Input",
      CellTags->"DiracOrder"],
    Cell[599154, 19135, 142, 3, 70, "Input",
      CellTags->"DiracOrder"],
    Cell[599655, 19154, 229, 6, 70, "Input",
      CellTags->"DiracOrder"],
    Cell[600180, 19172, 319, 10, 70, "Text",
      CellTags->"DiracOrder"],
    Cell[600524, 19186, 266, 7, 70, "Input",
      CellTags->"DiracOrder"],
    Cell[602424, 19245, 141, 3, 70, "Input",
      CellTags->"DiracOrder"],
    Cell[603177, 19271, 229, 6, 70, "Input",
      CellTags->"DiracOrder"]},
  "DiracReduce"->{
    Cell[603455, 19283, 60, 1, 70, "ObjectName",
      CellTags->"DiracReduce"],
    Cell[603540, 19288, 63, 1, 70, "Subsubsection",
      CellTags->"DiracReduce"],
    Cell[603606, 19291, 665, 11, 70, "Text",
      CellTags->"DiracReduce"],
    Cell[604296, 19306, 149, 3, 70, "Input",
      CellTags->"DiracReduce"],
    Cell[604827, 19323, 210, 9, 70, "Text",
      CellTags->"DiracReduce"],
    Cell[605074, 19337, 60, 1, 70, "Subsubsection",
      CellTags->"DiracReduce"],
    Cell[605159, 19342, 209, 5, 70, "Input",
      CellTags->"DiracReduce"],
    Cell[605625, 19359, 144, 3, 70, "Input",
      CellTags->"DiracReduce"],
    Cell[606159, 19378, 223, 5, 70, "Input",
      CellTags->"DiracReduce"],
    Cell[606681, 19396, 144, 3, 70, "Input",
      CellTags->"DiracReduce"],
    Cell[608073, 19436, 249, 6, 70, "Input",
      CellTags->"DiracReduce"],
    Cell[608672, 19457, 172, 4, 70, "Input",
      CellTags->"DiracReduce"],
    Cell[611338, 19524, 303, 7, 70, "Input",
      CellTags->"DiracReduce"],
    Cell[611813, 19541, 165, 4, 70, "Input",
      CellTags->"DiracReduce"],
    Cell[612128, 19553, 188, 4, 70, "Input",
      CellTags->"DiracReduce"]},
  "DiracSigmaExplicit"->{
    Cell[612365, 19563, 74, 1, 70, "ObjectName",
      CellTags->"DiracSigmaExplicit"],
    Cell[612464, 19568, 70, 1, 70, "Subsubsection",
      CellTags->"DiracSigmaExplicit"],
    Cell[612537, 19571, 187, 4, 70, "Text",
      CellTags->"DiracSigmaExplicit"],
    Cell[612727, 19577, 208, 9, 70, "Text",
      CellTags->"DiracSigmaExplicit"],
    Cell[612972, 19591, 67, 1, 70, "Subsubsection",
      CellTags->"DiracSigmaExplicit"],
    Cell[613064, 19596, 259, 6, 70, "Input",
      CellTags->"DiracSigmaExplicit"],
    Cell[613564, 19614, 157, 3, 70, "Input",
      CellTags->"DiracSigmaExplicit"]},
  "DiracSigma"->{
    Cell[614820, 19655, 58, 1, 70, "ObjectName",
      CellTags->"DiracSigma"],
    Cell[614903, 19660, 62, 1, 70, "Subsubsection",
      CellTags->"DiracSigma"],
    Cell[614968, 19663, 214, 5, 70, "Text",
      CellTags->"DiracSigma"],
    Cell[615185, 19670, 224, 9, 70, "Text",
      CellTags->"DiracSigma"],
    Cell[615446, 19684, 59, 1, 70, "Subsubsection",
      CellTags->"DiracSigma"],
    Cell[615530, 19689, 285, 7, 70, "Input",
      CellTags->"DiracSigma"],
    Cell[616056, 19708, 150, 3, 70, "Input",
      CellTags->"DiracSigma"],
    Cell[617281, 19747, 285, 7, 70, "Input",
      CellTags->"DiracSigma"],
    Cell[617833, 19767, 272, 7, 70, "Input",
      CellTags->"DiracSigma"],
    Cell[618326, 19785, 150, 3, 70, "Input",
      CellTags->"DiracSigma"],
    Cell[619927, 19830, 176, 4, 70, "Input",
      CellTags->"DiracSigma"]},
  "DiracSimplify"->{
    Cell[620152, 19840, 64, 1, 70, "ObjectName",
      CellTags->"DiracSimplify"],
    Cell[620241, 19845, 65, 1, 70, "Subsubsection",
      CellTags->"DiracSimplify"],
    Cell[620309, 19848, 383, 7, 70, "Text",
      CellTags->"DiracSimplify"],
    Cell[620717, 19859, 153, 3, 70, "Input",
      CellTags->"DiracSimplify"],
    Cell[621552, 19880, 455, 19, 70, "Text",
      CellTags->"DiracSimplify"],
    Cell[622044, 19904, 62, 1, 70, "Subsubsection",
      CellTags->"DiracSimplify"],
    Cell[622109, 19907, 100, 1, 70, "Text",
      CellTags->"DiracSimplify"],
    Cell[622234, 19912, 215, 5, 70, "Input",
      CellTags->"DiracSimplify"],
    Cell[622757, 19930, 148, 3, 70, "Input",
      CellTags->"DiracSimplify"],
    Cell[623229, 19947, 97, 1, 70, "Text",
      CellTags->"DiracSimplify"],
    Cell[623351, 19952, 216, 5, 70, "Input",
      CellTags->"DiracSimplify"],
    Cell[623875, 19970, 148, 3, 70, "Input",
      CellTags->"DiracSimplify"],
    Cell[624369, 19989, 211, 5, 70, "Input",
      CellTags->"DiracSimplify"],
    Cell[624862, 20005, 192, 7, 70, "Text",
      CellTags->"DiracSimplify"],
    Cell[625079, 20016, 148, 3, 70, "Input",
      CellTags->"DiracSimplify"],
    Cell[625743, 20040, 207, 5, 70, "Input",
      CellTags->"DiracSimplify"],
    Cell[626250, 20058, 148, 3, 70, "Input",
      CellTags->"DiracSimplify"],
    Cell[626757, 20077, 390, 10, 70, "Input",
      CellTags->"DiracSimplify"],
    Cell[628099, 20118, 121, 3, 70, "Text",
      CellTags->"DiracSimplify"],
    Cell[628245, 20125, 148, 3, 70, "Input",
      CellTags->"DiracSimplify"],
    Cell[631296, 20214, 145, 3, 70, "Input",
      CellTags->"DiracSimplify"],
    Cell[632378, 20247, 319, 7, 70, "Input",
      CellTags->"DiracSimplify"],
    Cell[633368, 20278, 148, 3, 70, "Input",
      CellTags->"DiracSimplify"],
    Cell[633664, 20290, 460, 12, 70, "Input",
      CellTags->"DiracSimplify"],
    Cell[634867, 20326, 147, 3, 70, "Input",
      CellTags->"DiracSimplify"],
    Cell[657658, 20983, 116, 3, 70, "Text",
      CellTags->"DiracSimplify"],
    Cell[657799, 20990, 299, 7, 70, "Input",
      CellTags->"DiracSimplify"],
    Cell[658705, 21019, 142, 4, 70, "Text",
      CellTags->"DiracSimplify"],
    Cell[658872, 21027, 344, 8, 70, "Input",
      CellTags->"DiracSimplify"],
    Cell[659999, 21061, 316, 7, 70, "Input",
      CellTags->"DiracSimplify"],
    Cell[660441, 21075, 219, 5, 70, "Input",
      CellTags->"DiracSimplify"]},
  "DiracSimplify2"->{
    Cell[660709, 21086, 66, 1, 70, "ObjectName",
      CellTags->"DiracSimplify2"],
    Cell[660800, 21091, 66, 1, 70, "Subsubsection",
      CellTags->"DiracSimplify2"],
    Cell[660869, 21094, 237, 7, 70, "Text",
      CellTags->"DiracSimplify2"],
    Cell[661109, 21103, 213, 9, 70, "Text",
      CellTags->"DiracSimplify2"],
    Cell[661359, 21117, 63, 1, 70, "Subsubsection",
      CellTags->"DiracSimplify2"],
    Cell[661447, 21122, 263, 6, 70, "Input",
      CellTags->"DiracSimplify2"],
    Cell[662228, 21146, 149, 3, 70, "Input",
      CellTags->"DiracSimplify2"]},
  "DiracSlash"->{
    Cell[663553, 21192, 58, 1, 70, "ObjectName",
      CellTags->"DiracSlash"],
    Cell[663636, 21197, 62, 1, 70, "Subsubsection",
      CellTags->"DiracSlash"],
    Cell[663701, 21200, 515, 16, 70, "Text",
      CellTags->"DiracSlash"],
    Cell[664241, 21220, 147, 3, 70, "Input",
      CellTags->"DiracSlash"],
    Cell[664677, 21235, 941, 39, 70, "Text",
      CellTags->"DiracSlash"],
    Cell[665655, 21279, 59, 1, 70, "Subsubsection",
      CellTags->"DiracSlash"],
    Cell[665717, 21282, 265, 9, 70, "Text",
      CellTags->"DiracSlash"],
    Cell[666007, 21295, 141, 3, 70, "Input",
      CellTags->"DiracSlash"],
    Cell[666471, 21312, 209, 5, 70, "Input",
      CellTags->"DiracSlash"],
    Cell[667329, 21341, 168, 4, 70, "Input",
      CellTags->"DiracSlash"],
    Cell[668146, 21369, 133, 3, 70, "Input",
      CellTags->"DiracSlash"],
    Cell[668507, 21383, 182, 5, 70, "Input",
      CellTags->"DiracSlash"],
    Cell[668898, 21398, 256, 7, 70, "Input",
      CellTags->"DiracSlash"]},
  "DiracTrace"->{
    Cell[669447, 21419, 58, 1, 70, "ObjectName",
      CellTags->"DiracTrace"],
    Cell[669530, 21424, 62, 1, 70, "Subsubsection",
      CellTags->"DiracTrace"],
    Cell[669595, 21427, 322, 6, 70, "Text",
      CellTags->"DiracTrace"],
    Cell[669942, 21437, 147, 3, 70, "Input",
      CellTags->"DiracTrace"],
    Cell[670791, 21459, 306, 12, 70, "Text",
      CellTags->"DiracTrace"],
    Cell[671100, 21473, 176, 9, 70, "Text",
      CellTags->"DiracTrace"],
    Cell[671313, 21487, 59, 1, 70, "Subsubsection",
      CellTags->"DiracTrace"],
    Cell[671397, 21492, 211, 5, 70, "Input",
      CellTags->"DiracTrace"],
    Cell[671957, 21512, 252, 6, 70, "Input",
      CellTags->"DiracTrace"],
    Cell[672672, 21535, 181, 4, 70, "Input",
      CellTags->"DiracTrace"],
    Cell[673756, 21567, 361, 9, 70, "Input",
      CellTags->"DiracTrace"],
    Cell[674931, 21605, 395, 9, 70, "Input",
      CellTags->"DiracTrace"],
    Cell[688448, 21942, 223, 5, 70, "Input",
      CellTags->"DiracTrace"],
    Cell[689526, 21976, 347, 8, 70, "Input",
      CellTags->"DiracTrace"],
    Cell[690133, 21997, 139, 3, 70, "Input",
      CellTags->"DiracTrace"]},
  "DiracTrick"->{
    Cell[690522, 22013, 58, 1, 70, "ObjectName",
      CellTags->"DiracTrick"],
    Cell[690605, 22018, 62, 1, 70, "Subsubsection",
      CellTags->"DiracTrick"],
    Cell[690670, 22021, 223, 5, 70, "Text",
      CellTags->"DiracTrick"],
    Cell[690918, 22030, 147, 3, 70, "Input",
      CellTags->"DiracTrick"],
    Cell[691272, 22043, 461, 19, 70, "Text",
      CellTags->"DiracTrick"],
    Cell[691770, 22067, 59, 1, 70, "Subsubsection",
      CellTags->"DiracTrick"],
    Cell[691832, 22070, 97, 1, 70, "Text",
      CellTags->"DiracTrick"],
    Cell[691954, 22075, 212, 5, 70, "Input",
      CellTags->"DiracTrick"],
    Cell[692474, 22093, 142, 3, 70, "Input",
      CellTags->"DiracTrick"],
    Cell[692940, 22110, 94, 1, 70, "Text",
      CellTags->"DiracTrick"],
    Cell[693059, 22115, 213, 5, 70, "Input",
      CellTags->"DiracTrick"],
    Cell[693580, 22133, 142, 3, 70, "Input",
      CellTags->"DiracTrick"],
    Cell[694104, 22153, 208, 5, 70, "Input",
      CellTags->"DiracTrick"],
    Cell[694594, 22169, 189, 7, 70, "Text",
      CellTags->"DiracTrick"],
    Cell[694808, 22180, 142, 3, 70, "Input",
      CellTags->"DiracTrick"],
    Cell[695466, 22204, 204, 5, 70, "Input",
      CellTags->"DiracTrick"],
    Cell[695970, 22222, 142, 3, 70, "Input",
      CellTags->"DiracTrick"],
    Cell[696471, 22241, 387, 10, 70, "Input",
      CellTags->"DiracTrick"],
    Cell[697832, 22284, 142, 3, 70, "Input",
      CellTags->"DiracTrick"],
    Cell[698911, 22317, 136, 3, 70, "Input",
      CellTags->"DiracTrick"],
    Cell[701950, 22406, 457, 12, 70, "Input",
      CellTags->"DiracTrick"],
    Cell[703150, 22442, 141, 3, 70, "Input",
      CellTags->"DiracTrick"]},
  "DotSimplify"->{
    Cell[728147, 23072, 60, 1, 70, "ObjectName",
      CellTags->"DotSimplify"],
    Cell[728232, 23077, 63, 1, 70, "Subsubsection",
      CellTags->"DotSimplify"],
    Cell[728298, 23080, 323, 6, 70, "Text",
      CellTags->"DotSimplify"],
    Cell[728646, 23090, 149, 3, 70, "Input",
      CellTags->"DotSimplify"],
    Cell[729173, 23107, 447, 19, 70, "Text",
      CellTags->"DotSimplify"],
    Cell[729657, 23131, 60, 1, 70, "Subsubsection",
      CellTags->"DotSimplify"],
    Cell[729742, 23136, 417, 11, 70, "Input",
      CellTags->"DotSimplify"],
    Cell[730731, 23168, 144, 3, 70, "Input",
      CellTags->"DotSimplify"],
    Cell[731595, 23195, 190, 4, 70, "Input",
      CellTags->"DotSimplify"],
    Cell[731810, 23203, 259, 7, 70, "Input",
      CellTags->"DotSimplify"],
    Cell[732354, 23224, 144, 3, 70, "Input",
      CellTags->"DotSimplify"],
    Cell[732782, 23240, 198, 5, 70, "Input",
      CellTags->"DotSimplify"],
    Cell[733128, 23254, 144, 3, 70, "Input",
      CellTags->"DotSimplify"],
    Cell[733637, 23272, 198, 5, 70, "Input",
      CellTags->"DotSimplify"],
    Cell[733860, 23281, 144, 3, 70, "Input",
      CellTags->"DotSimplify"],
    Cell[734288, 23297, 202, 5, 70, "Input",
      CellTags->"DotSimplify"],
    Cell[734638, 23311, 144, 3, 70, "Input",
      CellTags->"DotSimplify"],
    Cell[735105, 23327, 202, 5, 70, "Input",
      CellTags->"DotSimplify"],
    Cell[735332, 23336, 365, 9, 70, "Input",
      CellTags->"DotSimplify"],
    Cell[735896, 23355, 153, 3, 70, "Input",
      CellTags->"DotSimplify"],
    Cell[736074, 23362, 180, 4, 70, "Input",
      CellTags->"DotSimplify"],
    Cell[736430, 23376, 255, 6, 70, "Input",
      CellTags->"DotSimplify"],
    Cell[736848, 23390, 202, 4, 70, "Input",
      CellTags->"DotSimplify"]},
  "EpsChisholm"->{
    Cell[737099, 23400, 60, 1, 70, "ObjectName",
      CellTags->"EpsChisholm"],
    Cell[737184, 23405, 63, 1, 70, "Subsubsection",
      CellTags->"EpsChisholm"],
    Cell[737250, 23408, 167, 4, 70, "Text",
      CellTags->"EpsChisholm"],
    Cell[737420, 23414, 195, 9, 70, "Text",
      CellTags->"EpsChisholm"],
    Cell[737652, 23428, 60, 1, 70, "Subsubsection",
      CellTags->"EpsChisholm"],
    Cell[737737, 23433, 251, 6, 70, "Input",
      CellTags->"EpsChisholm"],
    Cell[740756, 23524, 143, 3, 70, "Input",
      CellTags->"EpsChisholm"]},
  "EpsEvaluate"->{
    Cell[741710, 23559, 60, 1, 70, "ObjectName",
      CellTags->"EpsEvaluate"],
    Cell[741795, 23564, 63, 1, 70, "Subsubsection",
      CellTags->"EpsEvaluate"],
    Cell[741861, 23567, 174, 4, 70, "Text",
      CellTags->"EpsEvaluate"],
    Cell[742038, 23573, 537, 24, 70, "Text",
      CellTags->"EpsEvaluate"],
    Cell[742612, 23602, 60, 1, 70, "Subsubsection",
      CellTags->"EpsEvaluate"],
    Cell[742697, 23607, 410, 11, 70, "Input",
      CellTags->"EpsEvaluate"],
    Cell[743783, 23644, 143, 3, 70, "Input",
      CellTags->"EpsEvaluate"],
    Cell[745155, 23689, 144, 3, 70, "Input",
      CellTags->"EpsEvaluate"]},
  "Epsilon"->{
    Cell[746039, 23715, 52, 1, 70, "ObjectName",
      CellTags->"Epsilon"],
    Cell[746116, 23720, 59, 1, 70, "Subsubsection",
      CellTags->"Epsilon"],
    Cell[746178, 23723, 247, 9, 70, "Text",
      CellTags->"Epsilon"],
    Cell[746428, 23734, 188, 9, 70, "Text",
      CellTags->"Epsilon"],
    Cell[746653, 23748, 56, 1, 70, "Subsubsection",
      CellTags->"Epsilon"],
    Cell[746734, 23753, 105, 2, 70, "Input",
      CellTags->"Epsilon"],
    Cell[747019, 23764, 115, 3, 70, "Text",
      CellTags->"Epsilon"],
    Cell[747159, 23771, 702, 19, 70, "Input",
      CellTags->"Epsilon"]},
  "Eps"->{
    Cell[748143, 23804, 44, 1, 70, "ObjectName",
      CellTags->"Eps"],
    Cell[748212, 23809, 55, 1, 70, "Subsubsection",
      CellTags->"Eps"],
    Cell[748270, 23812, 360, 9, 70, "Text",
      CellTags->"Eps"],
    Cell[748655, 23825, 133, 3, 70, "Input",
      CellTags->"Eps"],
    Cell[748991, 23838, 529, 24, 70, "Text",
      CellTags->"Eps"],
    Cell[749557, 23867, 52, 1, 70, "Subsubsection",
      CellTags->"Eps"],
    Cell[749634, 23872, 374, 8, 70, "Input",
      CellTags->"Eps"],
    Cell[750713, 23907, 366, 8, 70, "Input",
      CellTags->"Eps"],
    Cell[751725, 23940, 222, 6, 70, "Input",
      CellTags->"Eps"],
    Cell[752181, 23957, 174, 4, 70, "Input",
      CellTags->"Eps"],
    Cell[752503, 23970, 174, 4, 70, "Input",
      CellTags->"Eps"],
    Cell[752825, 23982, 232, 6, 70, "Input",
      CellTags->"Eps"],
    Cell[753082, 23992, 549, 13, 70, "Input",
      CellTags->"Eps"],
    Cell[754336, 24032, 156, 4, 70, "Input",
      CellTags->"Eps"],
    Cell[754641, 24044, 232, 6, 70, "Input",
      CellTags->"Eps"],
    Cell[754898, 24054, 549, 13, 70, "Input",
      CellTags->"Eps"],
    Cell[756152, 24094, 192, 5, 70, "Input",
      CellTags->"Eps"],
    Cell[756726, 24116, 541, 14, 70, "Input",
      CellTags->"Eps"],
    Cell[758838, 24181, 1225, 29, 70, "Input",
      CellTags->"Eps"],
    Cell[762354, 24277, 231, 6, 70, "Input",
      CellTags->"Eps"],
    Cell[763031, 24302, 156, 4, 70, "Input",
      CellTags->"Eps"],
    Cell[763313, 24313, 200, 5, 70, "Input",
      CellTags->"Eps"]},
  "ExpandPartialD"->{
    Cell[763562, 24324, 66, 1, 70, "ObjectName",
      CellTags->"ExpandPartialD"],
    Cell[763653, 24329, 66, 1, 70, "Subsubsection",
      CellTags->"ExpandPartialD"],
    Cell[763722, 24332, 185, 4, 70, "Text",
      CellTags->"ExpandPartialD"],
    Cell[763910, 24338, 629, 23, 70, "Text",
      CellTags->"ExpandPartialD"],
    Cell[764576, 24366, 63, 1, 70, "Subsubsection",
      CellTags->"ExpandPartialD"],
    Cell[764664, 24371, 435, 10, 70, "Input",
      CellTags->"ExpandPartialD"],
    Cell[765539, 24399, 149, 3, 70, "Input",
      CellTags->"ExpandPartialD"],
    Cell[766725, 24438, 143, 3, 70, "Input",
      CellTags->"ExpandPartialD"],
    Cell[767851, 24471, 306, 7, 70, "Input",
      CellTags->"ExpandPartialD"],
    Cell[768559, 24495, 149, 3, 70, "Input",
      CellTags->"ExpandPartialD"],
    Cell[769582, 24529, 512, 13, 70, "Input",
      CellTags->"ExpandPartialD"],
    Cell[770504, 24558, 149, 3, 70, "Input",
      CellTags->"ExpandPartialD"],
    Cell[772395, 24614, 224, 6, 70, "Input",
      CellTags->"ExpandPartialD"],
    Cell[772954, 24634, 151, 3, 70, "Input",
      CellTags->"ExpandPartialD"],
    Cell[774439, 24677, 149, 3, 70, "Input",
      CellTags->"ExpandPartialD"],
    Cell[776236, 24729, 369, 9, 70, "Input",
      CellTags->"ExpandPartialD"],
    Cell[778237, 24791, 149, 3, 70, "Input",
      CellTags->"ExpandPartialD"]},
  "ExpandScalarProduct"->{
    Cell[778558, 24805, 76, 1, 70, "ObjectName",
      CellTags->"ExpandScalarProduct"],
    Cell[778659, 24810, 71, 1, 70, "Subsubsection",
      CellTags->"ExpandScalarProduct"],
    Cell[778733, 24813, 187, 4, 70, "Text",
      CellTags->"ExpandScalarProduct"],
    Cell[778923, 24819, 191, 9, 70, "Text",
      CellTags->"ExpandScalarProduct"],
    Cell[779151, 24833, 68, 1, 70, "Subsubsection",
      CellTags->"ExpandScalarProduct"],
    Cell[779244, 24838, 198, 5, 70, "Input",
      CellTags->"ExpandScalarProduct"],
    Cell[779830, 24860, 159, 3, 70, "Input",
      CellTags->"ExpandScalarProduct"],
    Cell[780415, 24881, 202, 5, 70, "Input",
      CellTags->"ExpandScalarProduct"],
    Cell[780910, 24900, 159, 3, 70, "Input",
      CellTags->"ExpandScalarProduct"],
    Cell[781626, 24927, 263, 7, 70, "Input",
      CellTags->"ExpandScalarProduct"],
    Cell[782346, 24952, 191, 4, 70, "Input",
      CellTags->"ExpandScalarProduct"]},
  "Explicit"->{
    Cell[783347, 24986, 54, 1, 70, "ObjectName",
      CellTags->"Explicit"],
    Cell[783426, 24991, 60, 1, 70, "Subsubsection",
      CellTags->"Explicit"],
    Cell[783489, 24994, 391, 10, 70, "Text",
      CellTags->"Explicit"],
    Cell[783883, 25006, 354, 14, 70, "Text",
      CellTags->"Explicit"],
    Cell[784274, 25025, 57, 1, 70, "Subsubsection",
      CellTags->"Explicit"],
    Cell[784356, 25030, 271, 6, 70, "Input",
      CellTags->"Explicit"],
    Cell[786093, 25085, 137, 3, 70, "Input",
      CellTags->"Explicit"],
    Cell[790770, 25223, 220, 5, 70, "Input",
      CellTags->"Explicit"],
    Cell[792220, 25271, 137, 3, 70, "Input",
      CellTags->"Explicit"],
    Cell[796544, 25393, 187, 4, 70, "Input",
      CellTags->"Explicit"],
    Cell[796968, 25409, 137, 3, 70, "Input",
      CellTags->"Explicit"]},
  "ExplicitPartialD"->{
    Cell[799234, 25486, 70, 1, 70, "ObjectName",
      CellTags->"ExplicitPartialD"],
    Cell[799329, 25491, 68, 1, 70, "Subsubsection",
      CellTags->"ExplicitPartialD"],
    Cell[799400, 25494, 163, 4, 70, "Text",
      CellTags->"ExplicitPartialD"],
    Cell[799566, 25500, 508, 18, 70, "Text",
      CellTags->"ExplicitPartialD"],
    Cell[800111, 25523, 65, 1, 70, "Subsubsection",
      CellTags->"ExplicitPartialD"],
    Cell[800201, 25528, 215, 4, 70, "Input",
      CellTags->"ExplicitPartialD"],
    Cell[801107, 25557, 218, 5, 70, "Input",
      CellTags->"ExplicitPartialD"],
    Cell[801881, 25584, 225, 5, 70, "Input",
      CellTags->"ExplicitPartialD"],
    Cell[802691, 25610, 227, 6, 70, "Input",
      CellTags->"ExplicitPartialD"]},
  "ExplicitSUNIndex"->{
    Cell[803278, 25632, 70, 1, 70, "ObjectName",
      CellTags->"ExplicitSUNIndex"],
    Cell[803373, 25637, 68, 1, 70, "Subsubsection",
      CellTags->"ExplicitSUNIndex"],
    Cell[803444, 25640, 129, 3, 70, "Text",
      CellTags->"ExplicitSUNIndex"],
    Cell[803576, 25645, 526, 23, 70, "Text",
      CellTags->"ExplicitSUNIndex"],
    Cell[804139, 25673, 65, 1, 70, "Subsubsection",
      CellTags->"ExplicitSUNIndex"],
    Cell[804229, 25678, 153, 3, 70, "Input",
      CellTags->"ExplicitSUNIndex"],
    Cell[804530, 25690, 254, 7, 70, "Input",
      CellTags->"ExplicitSUNIndex"]},
  "Factor2"->{
    Cell[805093, 25711, 52, 1, 70, "ObjectName",
      CellTags->"Factor2"],
    Cell[805170, 25716, 59, 1, 70, "Subsubsection",
      CellTags->"Factor2"],
    Cell[805232, 25719, 399, 7, 70, "Text",
      CellTags->"Factor2"],
    Cell[805656, 25730, 141, 3, 70, "Input",
      CellTags->"Factor2"],
    Cell[806078, 25745, 191, 9, 70, "Text",
      CellTags->"Factor2"],
    Cell[806306, 25759, 56, 1, 70, "Subsubsection",
      CellTags->"Factor2"],
    Cell[806387, 25764, 267, 8, 70, "Input",
      CellTags->"Factor2"],
    Cell[806949, 25786, 271, 7, 70, "Input",
      CellTags->"Factor2"],
    Cell[807797, 25816, 314, 9, 70, "Input",
      CellTags->"Factor2"],
    Cell[808346, 25837, 135, 3, 70, "Input",
      CellTags->"Factor2"],
    Cell[808776, 25854, 136, 3, 70, "Input",
      CellTags->"Factor2"],
    Cell[809147, 25869, 210, 5, 70, "Input",
      CellTags->"Factor2"],
    Cell[809630, 25886, 173, 4, 70, "Input",
      CellTags->"Factor2"]},
  "FAD"->{
    Cell[809852, 25896, 44, 1, 70, "ObjectName",
      CellTags->"FAD"],
    Cell[809921, 25901, 55, 1, 70, "Subsubsection",
      CellTags->"FAD"],
    Cell[809979, 25904, 336, 6, 70, "Text",
      CellTags->"FAD"],
    Cell[810318, 25912, 865, 34, 70, "Text",
      CellTags->"FAD"],
    Cell[811220, 25951, 52, 1, 70, "Subsubsection",
      CellTags->"FAD"],
    Cell[811297, 25956, 183, 5, 70, "Input",
      CellTags->"FAD"],
    Cell[812431, 25991, 247, 7, 70, "Input",
      CellTags->"FAD"],
    Cell[813763, 26030, 307, 9, 70, "Input",
      CellTags->"FAD"],
    Cell[814289, 26050, 269, 8, 70, "Input",
      CellTags->"FAD"],
    Cell[815221, 26080, 341, 9, 70, "Input",
      CellTags->"FAD"]},
  "FCE"->{
    Cell[816249, 26113, 44, 1, 70, "ObjectName",
      CellTags->"FCE"],
    Cell[816318, 26118, 55, 1, 70, "Subsubsection",
      CellTags->"FCE"],
    Cell[816376, 26121, 127, 4, 70, "Text",
      CellTags->"FCE"],
    Cell[816506, 26127, 73, 1, 70, "Text",
      CellTags->"FCE"],
    Cell[816582, 26130, 460, 19, 70, "Text",
      CellTags->"FCE"],
    Cell[817079, 26154, 52, 1, 70, "Subsubsection",
      CellTags->"FCE"],
    Cell[817156, 26159, 325, 9, 70, "Input",
      CellTags->"FCE"],
    Cell[817821, 26183, 132, 3, 70, "Input",
      CellTags->"FCE"],
    Cell[818206, 26198, 517, 13, 70, "Input",
      CellTags->"FCE"],
    Cell[819532, 26238, 132, 3, 70, "Input",
      CellTags->"FCE"],
    Cell[820217, 26260, 123, 3, 70, "Input",
      CellTags->"FCE"],
    Cell[821592, 26305, 132, 3, 70, "Input",
      CellTags->"FCE"],
    Cell[822793, 26338, 166, 4, 70, "Input",
      CellTags->"FCE"]},
  "FCI"->{
    Cell[823536, 26363, 44, 1, 70, "ObjectName",
      CellTags->"FCI"],
    Cell[823605, 26368, 55, 1, 70, "Subsubsection",
      CellTags->"FCI"],
    Cell[823663, 26371, 160, 4, 70, "Text",
      CellTags->"FCI"],
    Cell[823826, 26377, 460, 19, 70, "Text",
      CellTags->"FCI"],
    Cell[824323, 26401, 52, 1, 70, "Subsubsection",
      CellTags->"FCI"],
    Cell[824400, 26406, 517, 13, 70, "Input",
      CellTags->"FCI"],
    Cell[825726, 26446, 132, 3, 70, "Input",
      CellTags->"FCI"],
    Cell[826411, 26468, 123, 3, 70, "Input",
      CellTags->"FCI"],
    Cell[827786, 26513, 132, 3, 70, "Input",
      CellTags->"FCI"],
    Cell[828987, 26546, 166, 4, 70, "Input",
      CellTags->"FCI"]},
  "FermionSpinSum"->{
    Cell[829730, 26571, 66, 1, 70, "ObjectName",
      CellTags->"FermionSpinSum"],
    Cell[829821, 26576, 66, 1, 70, "Subsubsection",
      CellTags->"FermionSpinSum"],
    Cell[829890, 26579, 119, 3, 70, "Text",
      CellTags->"FermionSpinSum"],
    Cell[830034, 26586, 155, 3, 70, "Input",
      CellTags->"FermionSpinSum"],
    Cell[830550, 26602, 450, 19, 70, "Text",
      CellTags->"FermionSpinSum"],
    Cell[831037, 26626, 63, 1, 70, "Subsubsection",
      CellTags->"FermionSpinSum"],
    Cell[831125, 26631, 398, 10, 70, "Input",
      CellTags->"FermionSpinSum"],
    Cell[832344, 26665, 165, 4, 70, "Text",
      CellTags->"FermionSpinSum"],
    Cell[832534, 26673, 179, 4, 70, "Input",
      CellTags->"FermionSpinSum"],
    Cell[833612, 26704, 177, 4, 70, "Input",
      CellTags->"FermionSpinSum"],
    Cell[835420, 26754, 175, 4, 70, "Input",
      CellTags->"FermionSpinSum"],
    Cell[836847, 26798, 173, 4, 70, "Input",
      CellTags->"FermionSpinSum"]},
  "FeynAmpDenominatorCombine"->{
    Cell[837069, 26808, 88, 1, 70, "ObjectName",
      CellTags->"FeynAmpDenominatorCombine"],
    Cell[837182, 26813, 77, 1, 70, "Subsubsection",
      CellTags->"FeynAmpDenominatorCombine"],
    Cell[837262, 26816, 229, 5, 70, "Text",
      CellTags->"FeynAmpDenominatorCombine"],
    Cell[837494, 26823, 254, 9, 70, "Text",
      CellTags->"FeynAmpDenominatorCombine"],
    Cell[837785, 26837, 74, 1, 70, "Subsubsection",
      CellTags->"FeynAmpDenominatorCombine"],
    Cell[837884, 26842, 282, 7, 70, "Input",
      CellTags->"FeynAmpDenominatorCombine"],
    Cell[839180, 26882, 249, 6, 70, "Input",
      CellTags->"FeynAmpDenominatorCombine"],
    Cell[839674, 26900, 247, 6, 70, "Input",
      CellTags->"FeynAmpDenominatorCombine"]},
  "FeynAmpDenominator"->{
    Cell[840224, 26921, 74, 1, 70, "ObjectName",
      CellTags->"FeynAmpDenominator"],
    Cell[840323, 26926, 70, 1, 70, "Subsubsection",
      CellTags->"FeynAmpDenominator"],
    Cell[840396, 26929, 257, 5, 70, "Text",
      CellTags->"FeynAmpDenominator"],
    Cell[840656, 26936, 361, 14, 70, "Text",
      CellTags->"FeynAmpDenominator"],
    Cell[841054, 26955, 67, 1, 70, "Subsubsection",
      CellTags->"FeynAmpDenominator"],
    Cell[841146, 26960, 238, 5, 70, "Input",
      CellTags->"FeynAmpDenominator"],
    Cell[841650, 26978, 387, 9, 70, "Input",
      CellTags->"FeynAmpDenominator"],
    Cell[842572, 27007, 297, 7, 70, "Input",
      CellTags->"FeynAmpDenominator"],
    Cell[842894, 27018, 181, 4, 70, "Input",
      CellTags->"FeynAmpDenominator"],
    Cell[843417, 27036, 181, 4, 70, "Input",
      CellTags->"FeynAmpDenominator"],
    Cell[843795, 27049, 166, 4, 70, "Input",
      CellTags->"FeynAmpDenominator"]},
  "FeynAmpDenominatorSimplify"->{
    Cell[844010, 27059, 90, 1, 70, "ObjectName",
      CellTags->"FeynAmpDenominatorSimplify"],
    Cell[844125, 27064, 78, 1, 70, "Subsubsection",
      CellTags->"FeynAmpDenominatorSimplify"],
    Cell[844206, 27067, 399, 7, 70, "Text",
      CellTags->"FeynAmpDenominatorSimplify"],
    Cell[844608, 27076, 86, 1, 70, "Text",
      CellTags->"FeynAmpDenominatorSimplify"],
    Cell[844719, 27081, 120, 2, 70, "Input",
      CellTags->"FeynAmpDenominatorSimplify"],
    Cell[844990, 27090, 231, 9, 70, "Text",
      CellTags->"FeynAmpDenominatorSimplify"],
    Cell[845258, 27104, 75, 1, 70, "Subsubsection",
      CellTags->"FeynAmpDenominatorSimplify"],
    Cell[845336, 27107, 507, 14, 70, "Text",
      CellTags->"FeynAmpDenominatorSimplify"],
    Cell[845868, 27125, 336, 8, 70, "Input",
      CellTags->"FeynAmpDenominatorSimplify"],
    Cell[846330, 27140, 575, 18, 70, "Text",
      CellTags->"FeynAmpDenominatorSimplify"],
    Cell[846930, 27162, 401, 10, 70, "Input",
      CellTags->"FeynAmpDenominatorSimplify"],
    Cell[848196, 27202, 562, 15, 70, "Input",
      CellTags->"FeynAmpDenominatorSimplify"],
    Cell[852053, 27312, 258, 6, 70, "Input",
      CellTags->"FeynAmpDenominatorSimplify"],
    Cell[854538, 27384, 189, 4, 70, "Input",
      CellTags->"FeynAmpDenominatorSimplify"],
    Cell[855826, 27425, 464, 13, 70, "Input",
      CellTags->"FeynAmpDenominatorSimplify"],
    Cell[860231, 27548, 179, 4, 70, "Input",
      CellTags->"FeynAmpDenominatorSimplify"]},
  "FeynAmpDenominatorSplit"->{
    Cell[860459, 27558, 84, 1, 70, "ObjectName",
      CellTags->"FeynAmpDenominatorSplit"],
    Cell[860568, 27563, 75, 1, 70, "Subsubsection",
      CellTags->"FeynAmpDenominatorSplit"],
    Cell[860646, 27566, 358, 7, 70, "Text",
      CellTags->"FeynAmpDenominatorSplit"],
    Cell[861007, 27575, 258, 9, 70, "Text",
      CellTags->"FeynAmpDenominatorSplit"],
    Cell[861302, 27589, 72, 1, 70, "Subsubsection",
      CellTags->"FeynAmpDenominatorSplit"],
    Cell[861399, 27594, 372, 9, 70, "Input",
      CellTags->"FeynAmpDenominatorSplit"],
    Cell[862989, 27643, 144, 3, 70, "Input",
      CellTags->"FeynAmpDenominatorSplit"],
    Cell[863298, 27655, 167, 3, 70, "Input",
      CellTags->"FeynAmpDenominatorSplit"],
    Cell[864683, 27698, 182, 4, 70, "Input",
      CellTags->"FeynAmpDenominatorSplit"],
    Cell[865366, 27721, 277, 7, 70, "Input",
      CellTags->"FeynAmpDenominatorSplit"],
    Cell[866090, 27746, 247, 6, 70, "Input",
      CellTags->"FeynAmpDenominatorSplit"],
    Cell[866680, 27765, 149, 3, 70, "Input",
      CellTags->"FeynAmpDenominatorSplit"]},
  "FeynAmp"->{
    Cell[866878, 27774, 52, 1, 70, "ObjectName",
      CellTags->"FeynAmp"],
    Cell[866955, 27779, 59, 1, 70, "Subsubsection",
      CellTags->"FeynAmp"],
    Cell[867017, 27782, 244, 5, 70, "Text",
      CellTags->"FeynAmp"],
    Cell[867264, 27789, 166, 4, 70, "Text",
      CellTags->"FeynAmp"],
    Cell[867433, 27795, 197, 9, 70, "Text",
      CellTags->"FeynAmp"],
    Cell[867667, 27809, 56, 1, 70, "Subsubsection",
      CellTags->"FeynAmp"],
    Cell[867726, 27812, 126, 4, 70, "Text",
      CellTags->"FeynAmp"],
    Cell[867877, 27820, 1007, 22, 70, "Input",
      CellTags->"FeynAmp"],
    Cell[874459, 27985, 74, 1, 70, "Text",
      CellTags->"FeynAmp"],
    Cell[874558, 27990, 240, 6, 70, "Input",
      CellTags->"FeynAmp"]},
  "FeynCalc2FORM"->{
    Cell[875350, 28018, 64, 1, 70, "ObjectName",
      CellTags->"FeynCalc2FORM"],
    Cell[875439, 28023, 65, 1, 70, "Subsubsection",
      CellTags->"FeynCalc2FORM"],
    Cell[875507, 28026, 227, 5, 70, "Text",
      CellTags->"FeynCalc2FORM"],
    Cell[875737, 28033, 212, 9, 70, "Text",
      CellTags->"FeynCalc2FORM"],
    Cell[875974, 28046, 153, 3, 70, "Input",
      CellTags->"FeynCalc2FORM"],
    Cell[877419, 28083, 62, 1, 70, "Subsubsection",
      CellTags->"FeynCalc2FORM"],
    Cell[877506, 28088, 328, 9, 70, "Input",
      CellTags->"FeynCalc2FORM"],
    Cell[878204, 28113, 169, 4, 70, "Input",
      CellTags->"FeynCalc2FORM"],
    Cell[878501, 28125, 241, 6, 70, "Input",
      CellTags->"FeynCalc2FORM"],
    Cell[879048, 28144, 169, 4, 70, "Input",
      CellTags->"FeynCalc2FORM"],
    Cell[879341, 28156, 255, 6, 70, "Input",
      CellTags->"FeynCalc2FORM"],
    Cell[880059, 28179, 169, 4, 70, "Input",
      CellTags->"FeynCalc2FORM"],
    Cell[880375, 28192, 356, 9, 70, "Input",
      CellTags->"FeynCalc2FORM"],
    Cell[881333, 28223, 169, 4, 70, "Input",
      CellTags->"FeynCalc2FORM"],
    Cell[881627, 28234, 401, 10, 70, "Input",
      CellTags->"FeynCalc2FORM"],
    Cell[882053, 28248, 406, 10, 70, "Input",
      CellTags->"FeynCalc2FORM"],
    Cell[882663, 28269, 385, 10, 70, "Input",
      CellTags->"FeynCalc2FORM"],
    Cell[891966, 28527, 252, 6, 70, "Input",
      CellTags->"FeynCalc2FORM"],
    Cell[892243, 28537, 460, 11, 70, "Input",
      CellTags->"FeynCalc2FORM"],
    Cell[894472, 28592, 380, 10, 70, "Input",
      CellTags->"FeynCalc2FORM"],
    Cell[894855, 28604, 161, 4, 70, "Input",
      CellTags->"FeynCalc2FORM"]},
  "FeynCalcExternal"->{
    Cell[895065, 28614, 70, 1, 70, "ObjectName",
      CellTags->"FeynCalcExternal"],
    Cell[895160, 28619, 68, 1, 70, "Subsubsection",
      CellTags->"FeynCalcExternal"],
    Cell[895231, 28622, 157, 4, 70, "Text",
      CellTags->"FeynCalcExternal"],
    Cell[895391, 28628, 224, 9, 70, "Text",
      CellTags->"FeynCalcExternal"],
    Cell[895652, 28642, 65, 1, 70, "Subsubsection",
      CellTags->"FeynCalcExternal"],
    Cell[895742, 28647, 194, 4, 70, "Input",
      CellTags->"FeynCalcExternal"],
    Cell[896119, 28661, 145, 3, 70, "Input",
      CellTags->"FeynCalcExternal"],
    Cell[896426, 28673, 530, 13, 70, "Input",
      CellTags->"FeynCalcExternal"],
    Cell[897765, 28713, 145, 3, 70, "Input",
      CellTags->"FeynCalcExternal"],
    Cell[898463, 28735, 149, 3, 70, "Input",
      CellTags->"FeynCalcExternal"],
    Cell[899864, 28780, 145, 3, 70, "Input",
      CellTags->"FeynCalcExternal"],
    Cell[901078, 28813, 199, 5, 70, "Input",
      CellTags->"FeynCalcExternal"]},
  "FeynCalcInternal"->{
    Cell[901854, 28839, 70, 1, 70, "ObjectName",
      CellTags->"FeynCalcInternal"],
    Cell[901949, 28844, 68, 1, 70, "Subsubsection",
      CellTags->"FeynCalcInternal"],
    Cell[902020, 28847, 158, 4, 70, "Text",
      CellTags->"FeynCalcInternal"],
    Cell[902181, 28853, 434, 19, 70, "Text",
      CellTags->"FeynCalcInternal"],
    Cell[902652, 28877, 65, 1, 70, "Subsubsection",
      CellTags->"FeynCalcInternal"],
    Cell[902742, 28882, 530, 13, 70, "Input",
      CellTags->"FeynCalcInternal"],
    Cell[904081, 28922, 145, 3, 70, "Input",
      CellTags->"FeynCalcInternal"],
    Cell[904779, 28944, 149, 3, 70, "Input",
      CellTags->"FeynCalcInternal"],
    Cell[906180, 28989, 145, 3, 70, "Input",
      CellTags->"FeynCalcInternal"],
    Cell[907394, 29022, 199, 5, 70, "Input",
      CellTags->"FeynCalcInternal"],
    Cell[908146, 29046, 621, 15, 70, "Input",
      CellTags->"FeynCalcInternal"],
    Cell[910930, 29130, 145, 3, 70, "Input",
      CellTags->"FeynCalcInternal"]},
  "FeynRule"->{
    Cell[912443, 29172, 54, 1, 70, "ObjectName",
      CellTags->"FeynRule"],
    Cell[912522, 29177, 60, 1, 70, "Subsubsection",
      CellTags->"FeynRule"],
    Cell[912585, 29180, 169, 4, 70, "Text",
      CellTags->"FeynRule"],
    Cell[912779, 29188, 143, 3, 70, "Input",
      CellTags->"FeynRule"],
    Cell[913720, 29213, 93, 1, 70, "Text",
      CellTags->"FeynRule"],
    Cell[913816, 29216, 134, 4, 70, "Text",
      CellTags->"FeynRule"],
    Cell[913953, 29222, 198, 9, 70, "Text",
      CellTags->"FeynRule"],
    Cell[914188, 29236, 57, 1, 70, "Subsubsection",
      CellTags->"FeynRule"],
    Cell[914270, 29241, 178, 4, 70, "Input",
      CellTags->"FeynRule"],
    Cell[915361, 29274, 178, 4, 70, "Input",
      CellTags->"FeynRule"],
    Cell[916944, 29320, 139, 3, 70, "Input",
      CellTags->"FeynRule"],
    Cell[922873, 29483, 173, 4, 70, "Input",
      CellTags->"FeynRule"],
    Cell[926708, 29604, 75, 1, 70, "Text",
      CellTags->"FeynRule"],
    Cell[926808, 29609, 625, 16, 70, "Input",
      CellTags->"FeynRule"],
    Cell[928414, 29661, 371, 9, 70, "Input",
      CellTags->"FeynRule"],
    Cell[934839, 29827, 73, 1, 70, "Text",
      CellTags->"FeynRule"],
    Cell[934937, 29832, 625, 16, 70, "Input",
      CellTags->"FeynRule"],
    Cell[936543, 29884, 371, 9, 70, "Input",
      CellTags->"FeynRule"],
    Cell[944257, 30063, 268, 7, 70, "Input",
      CellTags->"FeynRule"],
    Cell[945996, 30117, 111, 3, 70, "Text",
      CellTags->"FeynRule"],
    Cell[946132, 30124, 424, 10, 70, "Input",
      CellTags->"FeynRule"],
    Cell[948129, 30184, 78, 1, 70, "Text",
      CellTags->"FeynRule"],
    Cell[948232, 30189, 177, 4, 70, "Input",
      CellTags->"FeynRule"],
    Cell[949233, 30220, 91, 1, 70, "Text",
      CellTags->"FeynRule"],
    Cell[949349, 30225, 177, 4, 70, "Input",
      CellTags->"FeynRule"],
    Cell[950372, 30258, 863, 22, 70, "Input",
      CellTags->"FeynRule"],
    Cell[952573, 30325, 277, 7, 70, "Input",
      CellTags->"FeynRule"],
    Cell[960202, 30523, 501, 12, 70, "Input",
      CellTags->"FeynRule"],
    Cell[968059, 30706, 445, 12, 70, "Input",
      CellTags->"FeynRule"],
    Cell[968630, 30725, 211, 5, 70, "Text",
      CellTags->"FeynRule"],
    Cell[968844, 30732, 176, 4, 70, "Input",
      CellTags->"FeynRule"],
    Cell[969023, 30738, 52, 1, 70, "Text",
      CellTags->"FeynRule"],
    Cell[969100, 30743, 854, 21, 70, "Input",
      CellTags->"FeynRule"],
    Cell[971331, 30812, 260, 7, 70, "Input",
      CellTags->"FeynRule"],
    Cell[974458, 30903, 455, 11, 70, "Input",
      CellTags->"FeynRule"],
    Cell[977929, 31004, 240, 6, 70, "Input",
      CellTags->"FeynRule"],
    Cell[978317, 31019, 1084, 26, 70, "Input",
      CellTags->"FeynRule"],
    Cell[981176, 31105, 260, 7, 70, "Input",
      CellTags->"FeynRule"],
    Cell[986295, 31251, 542, 13, 70, "Input",
      CellTags->"FeynRule"],
    Cell[995972, 31498, 240, 6, 70, "Input",
      CellTags->"FeynRule"],
    Cell[996338, 31511, 475, 9, 70, "Input",
      CellTags->"FeynRule"]},
  "FieldStrength"->{
    Cell[996862, 31526, 64, 1, 70, "ObjectName",
      CellTags->"FieldStrength"],
    Cell[996951, 31531, 65, 1, 70, "Subsubsection",
      CellTags->"FieldStrength"],
    Cell[997019, 31534, 1453, 37, 70, "Text",
      CellTags->"FieldStrength"],
    Cell[998497, 31575, 153, 3, 70, "Input",
      CellTags->"FieldStrength"],
    Cell[999216, 31596, 209, 9, 70, "Text",
      CellTags->"FieldStrength"],
    Cell[999462, 31610, 62, 1, 70, "Subsubsection",
      CellTags->"FieldStrength"],
    Cell[999549, 31615, 182, 4, 70, "Input",
      CellTags->"FieldStrength"],
    Cell[999974, 31631, 192, 4, 70, "Input",
      CellTags->"FieldStrength"],
    Cell[1000403, 31647, 237, 5, 70, "Input",
      CellTags->"FieldStrength"],
    Cell[1001619, 31689, 247, 5, 70, "Input",
      CellTags->"FieldStrength"],
    Cell[1003973, 31766, 284, 6, 70, "Input",
      CellTags->"FieldStrength"],
    Cell[1004911, 31793, 287, 6, 70, "Input",
      CellTags->"FieldStrength"],
    Cell[1005850, 31820, 339, 7, 70, "Input",
      CellTags->"FieldStrength"]},
  "FORM2FeynCalc"->{
    Cell[1008320, 31901, 64, 1, 70, "ObjectName",
      CellTags->"FORM2FeynCalc"],
    Cell[1008409, 31906, 65, 1, 70, "Subsubsection",
      CellTags->"FORM2FeynCalc"],
    Cell[1008477, 31909, 473, 8, 70, "Text",
      CellTags->"FORM2FeynCalc"],
    Cell[1008953, 31919, 212, 9, 70, "Text",
      CellTags->"FORM2FeynCalc"],
    Cell[1009190, 31932, 153, 3, 70, "Input",
      CellTags->"FORM2FeynCalc"],
    Cell[1010149, 31960, 62, 1, 70, "Subsubsection",
      CellTags->"FORM2FeynCalc"],
    Cell[1010236, 31965, 167, 3, 70, "Input",
      CellTags->"FORM2FeynCalc"],
    Cell[1010889, 31988, 142, 3, 70, "Input",
      CellTags->"FORM2FeynCalc"],
    Cell[1011294, 32002, 160, 4, 70, "Text",
      CellTags->"FORM2FeynCalc"],
    Cell[1011479, 32010, 366, 8, 70, "Input",
      CellTags->"FORM2FeynCalc"],
    Cell[1012238, 32034, 142, 3, 70, "Input",
      CellTags->"FORM2FeynCalc"],
    Cell[1012750, 32052, 180, 4, 70, "Input",
      CellTags->"FORM2FeynCalc"],
    Cell[1013322, 32073, 145, 3, 70, "Input",
      CellTags->"FORM2FeynCalc"],
    Cell[1013748, 32090, 180, 4, 70, "Input",
      CellTags->"FORM2FeynCalc"],
    Cell[1014270, 32109, 142, 3, 70, "Input",
      CellTags->"FORM2FeynCalc"],
    Cell[1014793, 32128, 384, 9, 70, "Input",
      CellTags->"FORM2FeynCalc"],
    Cell[1015538, 32153, 231, 6, 70, "Input",
      CellTags->"FORM2FeynCalc"]},
  "FourDivergence"->{
    Cell[1016473, 32184, 66, 1, 70, "ObjectName",
      CellTags->"FourDivergence"],
    Cell[1016564, 32189, 66, 1, 70, "Subsubsection",
      CellTags->"FourDivergence"],
    Cell[1016633, 32192, 243, 5, 70, "Text",
      CellTags->"FourDivergence"],
    Cell[1016879, 32199, 210, 9, 70, "Text",
      CellTags->"FourDivergence"],
    Cell[1017126, 32213, 63, 1, 70, "Subsubsection",
      CellTags->"FourDivergence"],
    Cell[1017214, 32218, 204, 5, 70, "Input",
      CellTags->"FourDivergence"],
    Cell[1017726, 32237, 254, 6, 70, "Input",
      CellTags->"FourDivergence"],
    Cell[1018305, 32259, 235, 6, 70, "Input",
      CellTags->"FourDivergence"],
    Cell[1019135, 32287, 289, 8, 70, "Input",
      CellTags->"FourDivergence"],
    Cell[1019550, 32302, 140, 3, 70, "Input",
      CellTags->"FourDivergence"]},
  "FourLaplacian"->{
    Cell[1019739, 32311, 64, 1, 70, "ObjectName",
      CellTags->"FourLaplacian"],
    Cell[1019828, 32316, 65, 1, 70, "Subsubsection",
      CellTags->"FourLaplacian"],
    Cell[1019896, 32319, 491, 16, 70, "Text",
      CellTags->"FourLaplacian"],
    Cell[1020412, 32339, 153, 3, 70, "Input",
      CellTags->"FourLaplacian"],
    Cell[1020768, 32352, 347, 14, 70, "Text",
      CellTags->"FourLaplacian"],
    Cell[1021152, 32371, 62, 1, 70, "Subsubsection",
      CellTags->"FourLaplacian"],
    Cell[1021239, 32376, 163, 4, 70, "Input",
      CellTags->"FourLaplacian"],
    Cell[1021625, 32392, 184, 4, 70, "Input",
      CellTags->"FourLaplacian"],
    Cell[1021984, 32406, 325, 9, 70, "Input",
      CellTags->"FourLaplacian"],
    Cell[1022930, 32439, 189, 4, 70, "Input",
      CellTags->"FourLaplacian"]},
  "FourVector"->{
    Cell[1028888, 32605, 58, 1, 70, "ObjectName",
      CellTags->"FourVector"],
    Cell[1028971, 32610, 62, 1, 70, "Subsubsection",
      CellTags->"FourVector"],
    Cell[1029036, 32613, 353, 10, 70, "Text",
      CellTags->"FourVector"],
    Cell[1029392, 32625, 389, 19, 70, "Text",
      CellTags->"FourVector"],
    Cell[1029818, 32649, 59, 1, 70, "Subsubsection",
      CellTags->"FourVector"],
    Cell[1029902, 32654, 172, 4, 70, "Input",
      CellTags->"FourVector"],
    Cell[1030252, 32668, 201, 5, 70, "Input",
      CellTags->"FourVector"],
    Cell[1030826, 32690, 217, 5, 70, "Input",
      CellTags->"FourVector"],
    Cell[1031244, 32705, 272, 6, 70, "Input",
      CellTags->"FourVector"],
    Cell[1031770, 32722, 255, 6, 70, "Input",
      CellTags->"FourVector"],
    Cell[1032204, 32736, 194, 4, 70, "Text",
      CellTags->"FourVector"],
    Cell[1032423, 32744, 255, 6, 70, "Input",
      CellTags->"FourVector"]},
  "FreeQ2"->{
    Cell[1033259, 32776, 50, 1, 70, "ObjectName",
      CellTags->"FreeQ2"],
    Cell[1033334, 32781, 58, 1, 70, "Subsubsection",
      CellTags->"FreeQ2"],
    Cell[1033395, 32784, 229, 5, 70, "Text",
      CellTags->"FreeQ2"],
    Cell[1033627, 32791, 331, 14, 70, "Text",
      CellTags->"FreeQ2"],
    Cell[1033995, 32810, 55, 1, 70, "Subsubsection",
      CellTags->"FreeQ2"],
    Cell[1034075, 32815, 300, 8, 70, "Input",
      CellTags->"FreeQ2"],
    Cell[1034527, 32832, 295, 8, 70, "Input",
      CellTags->"FreeQ2"],
    Cell[1034973, 32849, 165, 4, 70, "Input",
      CellTags->"FreeQ2"],
    Cell[1035289, 32862, 199, 5, 70, "Input",
      CellTags->"FreeQ2"]},
  "FromTFi"->{
    Cell[1035664, 32878, 52, 1, 70, "ObjectName",
      CellTags->"FromTFi"],
    Cell[1035741, 32883, 59, 1, 70, "Subsubsection",
      CellTags->"FromTFi"],
    Cell[1035803, 32886, 201, 5, 70, "Text",
      CellTags->"FromTFi"],
    Cell[1036007, 32893, 280, 13, 70, "Text",
      CellTags->"FromTFi"],
    Cell[1036324, 32911, 56, 1, 70, "Subsubsection",
      CellTags->"FromTFi"],
    Cell[1036405, 32916, 453, 12, 70, "Input",
      CellTags->"FromTFi"],
    Cell[1038031, 32969, 873, 22, 70, "Input",
      CellTags->"FromTFi"],
    Cell[1040373, 33038, 951, 24, 70, "Input",
      CellTags->"FromTFi"]},
  "FRH"->{
    Cell[1043204, 33121, 44, 1, 70, "ObjectName",
      CellTags->"FRH"],
    Cell[1043273, 33126, 55, 1, 70, "Subsubsection",
      CellTags->"FRH"],
    Cell[1043331, 33129, 135, 4, 70, "Text",
      CellTags->"FRH"],
    Cell[1043469, 33135, 184, 9, 70, "Text",
      CellTags->"FRH"],
    Cell[1043690, 33149, 52, 1, 70, "Subsubsection",
      CellTags->"FRH"],
    Cell[1043767, 33154, 243, 6, 70, "Input",
      CellTags->"FRH"],
    Cell[1044341, 33175, 127, 3, 70, "Input",
      CellTags->"FRH"],
    Cell[1044616, 33187, 368, 10, 70, "Input",
      CellTags->"FRH"],
    Cell[1045681, 33223, 159, 4, 70, "Input",
      CellTags->"FRH"]},
  "FunctionalD"->{
    Cell[1046578, 33256, 60, 1, 70, "ObjectName",
      CellTags->"FunctionalD"],
    Cell[1046663, 33261, 63, 1, 70, "Subsubsection",
      CellTags->"FunctionalD"],
    Cell[1046729, 33264, 415, 7, 70, "Text",
      CellTags->"FunctionalD"],
    Cell[1047147, 33273, 96, 1, 70, "Text",
      CellTags->"FunctionalD"],
    Cell[1047246, 33276, 327, 14, 70, "Text",
      CellTags->"FunctionalD"],
    Cell[1047610, 33295, 60, 1, 70, "Subsubsection",
      CellTags->"FunctionalD"],
    Cell[1047673, 33298, 692, 20, 70, "Text",
      CellTags->"FunctionalD"],
    Cell[1048390, 33322, 270, 6, 70, "Input",
      CellTags->"FunctionalD"],
    Cell[1048808, 33337, 301, 7, 70, "Input",
      CellTags->"FunctionalD"],
    Cell[1049267, 33352, 1498, 44, 70, "Text",
      CellTags->"FunctionalD"],
    Cell[1050790, 33400, 359, 9, 70, "Input",
      CellTags->"FunctionalD"],
    Cell[1051488, 33423, 968, 24, 70, "Text",
      CellTags->"FunctionalD"],
    Cell[1052481, 33451, 843, 22, 70, "Input",
      CellTags->"FunctionalD"],
    Cell[1054302, 33505, 259, 6, 70, "Input",
      CellTags->"FunctionalD"],
    Cell[1055386, 33540, 590, 16, 70, "Text",
      CellTags->"FunctionalD"],
    Cell[1055979, 33558, 99, 2, 70, "Text",
      CellTags->"FunctionalD"],
    Cell[1056103, 33564, 371, 8, 70, "Input",
      CellTags->"FunctionalD"],
    Cell[1058305, 33635, 371, 8, 70, "Input",
      CellTags->"FunctionalD"],
    Cell[1060507, 33706, 268, 8, 70, "Input",
      CellTags->"FunctionalD"],
    Cell[1065086, 33835, 579, 13, 70, "Text",
      CellTags->"FunctionalD"],
    Cell[1065668, 33850, 1926, 50, 70, "Text",
      CellTags->"FunctionalD"],
    Cell[1067597, 33902, 534, 13, 70, "Text",
      CellTags->"FunctionalD"],
    Cell[1068156, 33919, 280, 7, 70, "Input",
      CellTags->"FunctionalD"],
    Cell[1068823, 33944, 202, 5, 70, "Input",
      CellTags->"FunctionalD"],
    Cell[1072234, 34048, 121, 3, 70, "Text",
      CellTags->"FunctionalD"],
    Cell[1072380, 34055, 213, 5, 70, "Input",
      CellTags->"FunctionalD"],
    Cell[1075802, 34159, 303, 8, 70, "Text",
      CellTags->"FunctionalD"],
    Cell[1076108, 34169, 652, 18, 70, "Input",
      CellTags->"FunctionalD"],
    Cell[1076785, 34191, 278, 7, 70, "Input",
      CellTags->"FunctionalD"],
    Cell[1077603, 34221, 289, 7, 70, "Input",
      CellTags->"FunctionalD"],
    Cell[1078482, 34252, 722, 17, 70, "Input",
      CellTags->"FunctionalD"],
    Cell[1083377, 34401, 221, 5, 70, "Input",
      CellTags->"FunctionalD"],
    Cell[1085625, 34474, 428, 11, 70, "Input",
      CellTags->"FunctionalD"],
    Cell[1087699, 34540, 294, 9, 70, "Text",
      CellTags->"FunctionalD"],
    Cell[1087996, 34551, 100, 2, 70, "Text",
      CellTags->"FunctionalD"],
    Cell[1088099, 34555, 168, 4, 70, "Text",
      CellTags->"FunctionalD"],
    Cell[1088292, 34563, 133, 3, 70, "Input",
      CellTags->"FunctionalD"],
    Cell[1092758, 34689, 237, 6, 70, "Input",
      CellTags->"FunctionalD"],
    Cell[1126720, 35703, 232, 5, 70, "Text",
      CellTags->"FunctionalD"],
    Cell[1126955, 35710, 346, 6, 70, "Text",
      CellTags->"FunctionalD"],
    Cell[1127304, 35718, 164, 4, 70, "Input",
      CellTags->"FunctionalD"],
    Cell[1127471, 35724, 3947, 76, 70, "Input",
      CellTags->"FunctionalD"],
    Cell[1131443, 35804, 206, 5, 70, "Input",
      CellTags->"FunctionalD"],
    Cell[1149033, 36340, 201, 5, 70, "Input",
      CellTags->"FunctionalD"],
    Cell[1158456, 36634, 225, 8, 70, "Text",
      CellTags->"FunctionalD"],
    Cell[1158706, 36646, 401, 11, 70, "Input",
      CellTags->"FunctionalD"],
    Cell[1162972, 36782, 828, 22, 70, "Input",
      CellTags->"FunctionalD"],
    Cell[1165670, 36870, 186, 4, 70, "Input",
      CellTags->"FunctionalD"],
    Cell[1173198, 37105, 132, 4, 70, "Text",
      CellTags->"FunctionalD"],
    Cell[1173355, 37113, 104, 2, 70, "Input",
      CellTags->"FunctionalD"],
    Cell[1175127, 37172, 957, 22, 70, "Input",
      CellTags->"FunctionalD"],
    Cell[1177616, 37242, 169, 4, 70, "Input",
      CellTags->"FunctionalD"],
    Cell[1182695, 37386, 246, 6, 70, "Input",
      CellTags->"FunctionalD"],
    Cell[1191560, 37664, 170, 4, 70, "Input",
      CellTags->"FunctionalD"],
    Cell[1203079, 38024, 200, 5, 70, "Input",
      CellTags->"FunctionalD"],
    Cell[1203405, 38036, 67, 1, 70, "Text",
      CellTags->"FunctionalD"],
    Cell[1203475, 38039, 617, 13, 70, "Input",
      CellTags->"FunctionalD"],
    Cell[1204129, 38057, 111, 2, 70, "Subsubsection",
      CellTags->"FunctionalD"],
    Cell[1204243, 38061, 80, 1, 70, "Text",
      CellTags->"FunctionalD"],
    Cell[1204348, 38066, 1536, 34, 70, "Input",
      CellTags->"FunctionalD"],
    Cell[1208041, 38170, 974, 24, 70, "Input",
      CellTags->"FunctionalD"],
    Cell[1222328, 38528, 202, 5, 70, "Input",
      CellTags->"FunctionalD"]},
  "FV"->{
    Cell[1225497, 38623, 42, 1, 70, "ObjectName",
      CellTags->"FV"],
    Cell[1225564, 38628, 54, 1, 70, "Subsubsection",
      CellTags->"FV"],
    Cell[1225621, 38631, 298, 13, 70, "Text",
      CellTags->"FV"],
    Cell[1225922, 38646, 615, 29, 70, "Text",
      CellTags->"FV"],
    Cell[1226574, 38680, 51, 1, 70, "Subsubsection",
      CellTags->"FV"],
    Cell[1226650, 38685, 156, 4, 70, "Input",
      CellTags->"FV"],
    Cell[1226986, 38699, 185, 5, 70, "Input",
      CellTags->"FV"],
    Cell[1227464, 38718, 197, 5, 70, "Input",
      CellTags->"FV"],
    Cell[1227854, 38733, 242, 7, 70, "Input",
      CellTags->"FV"],
    Cell[1228355, 38750, 131, 4, 70, "Text",
      CellTags->"FV"],
    Cell[1228511, 38758, 239, 6, 70, "Input",
      CellTags->"FV"],
    Cell[1229307, 38788, 135, 3, 70, "Input",
      CellTags->"FV"]},
  "FVD"->{
    Cell[1229938, 38810, 44, 1, 70, "ObjectName",
      CellTags->"FVD"],
    Cell[1230007, 38815, 55, 1, 70, "Subsubsection",
      CellTags->"FVD"],
    Cell[1230065, 38818, 334, 15, 70, "Text",
      CellTags->"FVD"],
    Cell[1230402, 38835, 613, 29, 70, "Text",
      CellTags->"FVD"],
    Cell[1231052, 38869, 52, 1, 70, "Subsubsection",
      CellTags->"FVD"],
    Cell[1231129, 38874, 158, 4, 70, "Input",
      CellTags->"FVD"],
    Cell[1231467, 38888, 187, 5, 70, "Input",
      CellTags->"FVD"],
    Cell[1231947, 38907, 199, 5, 70, "Input",
      CellTags->"FVD"],
    Cell[1232340, 38922, 244, 7, 70, "Input",
      CellTags->"FVD"],
    Cell[1232905, 38941, 89, 1, 70, "Text",
      CellTags->"FVD"],
    Cell[1233019, 38946, 241, 6, 70, "Input",
      CellTags->"FVD"],
    Cell[1233817, 38976, 136, 3, 70, "Input",
      CellTags->"FVD"]},
  "GA"->{
    Cell[1234581, 39002, 42, 1, 70, "ObjectName",
      CellTags->"GA"],
    Cell[1234648, 39007, 54, 1, 70, "Subsubsection",
      CellTags->"GA"],
    Cell[1234705, 39010, 708, 24, 70, "Text",
      CellTags->"GA"],
    Cell[1235416, 39036, 402, 19, 70, "Text",
      CellTags->"GA"],
    Cell[1235855, 39060, 51, 1, 70, "Subsubsection",
      CellTags->"GA"],
    Cell[1235931, 39065, 129, 3, 70, "Input",
      CellTags->"GA"],
    Cell[1236247, 39078, 259, 7, 70, "Input",
      CellTags->"GA"],
    Cell[1236913, 39102, 208, 5, 70, "Input",
      CellTags->"GA"],
    Cell[1237338, 39117, 199, 5, 70, "Input",
      CellTags->"GA"],
    Cell[1237902, 39137, 246, 6, 70, "Input",
      CellTags->"GA"],
    Cell[1238476, 39156, 301, 8, 70, "Input",
      CellTags->"GA"]},
  "GAD"->{
    Cell[1239236, 39183, 44, 1, 70, "ObjectName",
      CellTags->"GAD"],
    Cell[1239305, 39188, 55, 1, 70, "Subsubsection",
      CellTags->"GAD"],
    Cell[1239363, 39191, 725, 24, 70, "Text",
      CellTags->"GAD"],
    Cell[1240091, 39217, 400, 19, 70, "Text",
      CellTags->"GAD"],
    Cell[1240528, 39241, 52, 1, 70, "Subsubsection",
      CellTags->"GAD"],
    Cell[1240605, 39246, 131, 3, 70, "Input",
      CellTags->"GAD"],
    Cell[1240923, 39259, 262, 7, 70, "Input",
      CellTags->"GAD"],
    Cell[1241592, 39283, 210, 5, 70, "Input",
      CellTags->"GAD"],
    Cell[1242079, 39300, 201, 5, 70, "Input",
      CellTags->"GAD"],
    Cell[1242645, 39320, 248, 6, 70, "Input",
      CellTags->"GAD"],
    Cell[1243225, 39339, 305, 8, 70, "Input",
      CellTags->"GAD"]},
  "GammaEpsilon"->{
    Cell[1243989, 39366, 62, 1, 70, "ObjectName",
      CellTags->"GammaEpsilon"],
    Cell[1244076, 39371, 64, 1, 70, "Subsubsection",
      CellTags->"GammaEpsilon"],
    Cell[1244143, 39374, 168, 4, 70, "Text",
      CellTags->"GammaEpsilon"],
    Cell[1244314, 39380, 322, 14, 70, "Text",
      CellTags->"GammaEpsilon"],
    Cell[1244673, 39399, 61, 1, 70, "Subsubsection",
      CellTags->"GammaEpsilon"],
    Cell[1244737, 39402, 142, 4, 70, "Text",
      CellTags->"GammaEpsilon"],
    Cell[1244904, 39410, 207, 5, 70, "Input",
      CellTags->"GammaEpsilon"],
    Cell[1247232, 39479, 207, 5, 70, "Input",
      CellTags->"GammaEpsilon"],
    Cell[1249249, 39539, 92, 1, 70, "Text",
      CellTags->"GammaEpsilon"],
    Cell[1249366, 39544, 151, 3, 70, "Input",
      CellTags->"GammaEpsilon"],
    Cell[1251473, 39608, 145, 3, 70, "Input",
      CellTags->"GammaEpsilon"]},
  "GammaExpand"->{
    Cell[1251838, 39624, 60, 1, 70, "ObjectName",
      CellTags->"GammaExpand"],
    Cell[1251923, 39629, 63, 1, 70, "Subsubsection",
      CellTags->"GammaExpand"],
    Cell[1251989, 39632, 124, 3, 70, "Text",
      CellTags->"GammaExpand"],
    Cell[1252116, 39637, 207, 9, 70, "Text",
      CellTags->"GammaExpand"],
    Cell[1252360, 39651, 60, 1, 70, "Subsubsection",
      CellTags->"GammaExpand"],
    Cell[1252445, 39656, 224, 5, 70, "Input",
      CellTags->"GammaExpand"],
    Cell[1253122, 39680, 240, 6, 70, "Input",
      CellTags->"GammaExpand"],
    Cell[1254193, 39715, 224, 5, 70, "Input",
      CellTags->"GammaExpand"]},
  "GhostPropagator"->{
    Cell[1254726, 39735, 68, 1, 70, "ObjectName",
      CellTags->"GhostPropagator"],
    Cell[1254819, 39740, 67, 1, 70, "Subsubsection",
      CellTags->"GhostPropagator"],
    Cell[1254889, 39743, 349, 9, 70, "Text",
      CellTags->"GhostPropagator"],
    Cell[1255241, 39754, 469, 19, 70, "Text",
      CellTags->"GhostPropagator"],
    Cell[1255747, 39778, 64, 1, 70, "Subsubsection",
      CellTags->"GhostPropagator"],
    Cell[1255836, 39783, 188, 4, 70, "Input",
      CellTags->"GhostPropagator"],
    Cell[1256591, 39809, 151, 3, 70, "Input",
      CellTags->"GhostPropagator"],
    Cell[1256957, 39823, 188, 4, 70, "Input",
      CellTags->"GhostPropagator"],
    Cell[1257716, 39849, 305, 8, 70, "Input",
      CellTags->"GhostPropagator"]},
  "GHP"->{
    Cell[1258347, 39872, 44, 1, 70, "ObjectName",
      CellTags->"GHP"],
    Cell[1258416, 39877, 55, 1, 70, "Subsubsection",
      CellTags->"GHP"],
    Cell[1258474, 39880, 313, 9, 70, "Text",
      CellTags->"GHP"],
    Cell[1258790, 39891, 493, 19, 70, "Text",
      CellTags->"GHP"],
    Cell[1259320, 39915, 52, 1, 70, "Subsubsection",
      CellTags->"GHP"],
    Cell[1259397, 39920, 164, 4, 70, "Input",
      CellTags->"GHP"],
    Cell[1260128, 39946, 127, 3, 70, "Input",
      CellTags->"GHP"],
    Cell[1260470, 39960, 164, 4, 70, "Input",
      CellTags->"GHP"],
    Cell[1261205, 39986, 282, 8, 70, "Input",
      CellTags->"GHP"]},
  "GluonField"->{
    Cell[1261813, 40009, 58, 1, 70, "ObjectName",
      CellTags->"GluonField"],
    Cell[1261896, 40014, 62, 1, 70, "Subsubsection",
      CellTags->"GluonField"],
    Cell[1261961, 40017, 213, 5, 70, "Text",
      CellTags->"GluonField"],
    Cell[1262177, 40024, 341, 14, 70, "Text",
      CellTags->"GluonField"],
    Cell[1262555, 40043, 59, 1, 70, "Subsubsection",
      CellTags->"GluonField"],
    Cell[1262639, 40048, 111, 2, 70, "Input",
      CellTags->"GluonField"],
    Cell[1262898, 40059, 279, 6, 70, "Input",
      CellTags->"GluonField"]},
  "GluonGhostVertex"->{
    Cell[1263632, 40087, 70, 1, 70, "ObjectName",
      CellTags->"GluonGhostVertex"],
    Cell[1263727, 40092, 68, 1, 70, "Subsubsection",
      CellTags->"GluonGhostVertex"],
    Cell[1263798, 40095, 423, 7, 70, "Text",
      CellTags->"GluonGhostVertex"],
    Cell[1264224, 40104, 343, 13, 70, "Text",
      CellTags->"GluonGhostVertex"],
    Cell[1264592, 40121, 159, 3, 70, "Input",
      CellTags->"GluonGhostVertex"],
    Cell[1265096, 40139, 65, 1, 70, "Subsubsection",
      CellTags->"GluonGhostVertex"],
    Cell[1265186, 40144, 413, 10, 70, "Input",
      CellTags->"GluonGhostVertex"],
    Cell[1266641, 40192, 145, 3, 70, "Input",
      CellTags->"GluonGhostVertex"],
    Cell[1267385, 40215, 227, 5, 70, "Input",
      CellTags->"GluonGhostVertex"]},
  "GluonPropagator"->{
    Cell[1268682, 40260, 68, 1, 70, "ObjectName",
      CellTags->"GluonPropagator"],
    Cell[1268775, 40265, 67, 1, 70, "Subsubsection",
      CellTags->"GluonPropagator"],
    Cell[1268845, 40268, 543, 10, 70, "Text",
      CellTags->"GluonPropagator"],
    Cell[1269391, 40280, 100, 1, 70, "Text",
      CellTags->"GluonPropagator"],
    Cell[1269516, 40285, 108, 2, 70, "Input",
      CellTags->"GluonPropagator"],
    Cell[1269786, 40296, 157, 3, 70, "Input",
      CellTags->"GluonPropagator"],
    Cell[1270438, 40315, 493, 19, 70, "Text",
      CellTags->"GluonPropagator"],
    Cell[1270968, 40339, 73, 1, 70, "Subsubsection",
      CellTags->"GluonPropagator"],
    Cell[1271066, 40344, 223, 5, 70, "Input",
      CellTags->"GluonPropagator"],
    Cell[1272260, 40382, 272, 5, 70, "Input",
      CellTags->"GluonPropagator"],
    Cell[1274266, 40440, 383, 9, 70, "Input",
      CellTags->"GluonPropagator"],
    Cell[1278973, 40569, 196, 4, 70, "Input",
      CellTags->"GluonPropagator"],
    Cell[1279765, 40594, 150, 4, 70, "Text",
      CellTags->"GluonPropagator"],
    Cell[1279940, 40602, 175, 4, 70, "Input",
      CellTags->"GluonPropagator"],
    Cell[1281086, 40639, 285, 8, 70, "Input",
      CellTags->"GluonPropagator"],
    Cell[1281772, 40663, 276, 5, 70, "Input",
      CellTags->"GluonPropagator"],
    Cell[1284144, 40728, 276, 5, 70, "Input",
      CellTags->"GluonPropagator"],
    Cell[1286522, 40794, 276, 5, 70, "Input",
      CellTags->"GluonPropagator"],
    Cell[1288902, 40859, 276, 5, 70, "Input",
      CellTags->"GluonPropagator"],
    Cell[1291274, 40924, 276, 5, 70, "Input",
      CellTags->"GluonPropagator"]},
  "GluonVertex"->{
    Cell[1295599, 41041, 60, 1, 70, "ObjectName",
      CellTags->"GluonVertex"],
    Cell[1295684, 41046, 63, 1, 70, "Subsubsection",
      CellTags->"GluonVertex"],
    Cell[1295750, 41049, 89, 1, 70, "Text",
      CellTags->"GluonVertex"],
    Cell[1295842, 41052, 622, 10, 70, "Text",
      CellTags->"GluonVertex"],
    Cell[1296467, 41064, 92, 1, 70, "Text",
      CellTags->"GluonVertex"],
    Cell[1296584, 41069, 104, 2, 70, "Input",
      CellTags->"GluonVertex"],
    Cell[1296846, 41080, 149, 3, 70, "Input",
      CellTags->"GluonVertex"],
    Cell[1297436, 41098, 360, 14, 70, "Text",
      CellTags->"GluonVertex"],
    Cell[1297833, 41117, 60, 1, 70, "Subsubsection",
      CellTags->"GluonVertex"],
    Cell[1297918, 41122, 403, 10, 70, "Input",
      CellTags->"GluonVertex"],
    Cell[1299787, 41181, 459, 12, 70, "Input",
      CellTags->"GluonVertex"],
    Cell[1304786, 41328, 373, 10, 70, "Input",
      CellTags->"GluonVertex"],
    Cell[1305604, 41355, 429, 12, 70, "Input",
      CellTags->"GluonVertex"],
    Cell[1309614, 41485, 490, 12, 70, "Input",
      CellTags->"GluonVertex"],
    Cell[1319239, 41731, 450, 12, 70, "Input",
      CellTags->"GluonVertex"],
    Cell[1328830, 41977, 266, 6, 70, "Input",
      CellTags->"GluonVertex"],
    Cell[1338215, 42215, 201, 4, 70, "Text",
      CellTags->"GluonVertex"],
    Cell[1338441, 42223, 208, 5, 70, "Input",
      CellTags->"GluonVertex"],
    Cell[1340114, 42277, 237, 6, 70, "Input",
      CellTags->"GluonVertex"]},
  "GSD"->{
    Cell[1349468, 42519, 44, 1, 70, "ObjectName",
      CellTags->"GSD"],
    Cell[1349537, 42524, 55, 1, 70, "Subsubsection",
      CellTags->"GSD"],
    Cell[1349595, 42527, 736, 18, 70, "Text",
      CellTags->"GSD"],
    Cell[1350334, 42547, 526, 24, 70, "Text",
      CellTags->"GSD"],
    Cell[1350897, 42576, 52, 1, 70, "Subsubsection",
      CellTags->"GSD"],
    Cell[1350974, 42581, 127, 3, 70, "Input",
      CellTags->"GSD"],
    Cell[1351329, 42595, 205, 6, 70, "Input",
      CellTags->"GSD"],
    Cell[1351803, 42613, 174, 4, 70, "Input",
      CellTags->"GSD"],
    Cell[1352684, 42643, 222, 6, 70, "Input",
      CellTags->"GSD"],
    Cell[1353218, 42662, 292, 8, 70, "Input",
      CellTags->"GSD"]},
  "GS"->{
    Cell[1354138, 42695, 42, 1, 70, "ObjectName",
      CellTags->"GS"],
    Cell[1354205, 42700, 54, 1, 70, "Subsubsection",
      CellTags->"GS"],
    Cell[1354262, 42703, 727, 18, 70, "Text",
      CellTags->"GS"],
    Cell[1354992, 42723, 525, 24, 70, "Text",
      CellTags->"GS"],
    Cell[1355554, 42752, 51, 1, 70, "Subsubsection",
      CellTags->"GS"],
    Cell[1355630, 42757, 125, 3, 70, "Input",
      CellTags->"GS"],
    Cell[1355983, 42771, 203, 6, 70, "Input",
      CellTags->"GS"],
    Cell[1356395, 42787, 172, 4, 70, "Input",
      CellTags->"GS"],
    Cell[1357274, 42817, 220, 6, 70, "Input",
      CellTags->"GS"],
    Cell[1357802, 42836, 288, 8, 70, "Input",
      CellTags->"GS"]},
  "Gstrong"->{
    Cell[1358718, 42869, 52, 1, 70, "ObjectName",
      CellTags->"Gstrong"],
    Cell[1358795, 42874, 59, 1, 70, "Subsubsection",
      CellTags->"Gstrong"],
    Cell[1358857, 42877, 84, 1, 70, "Text",
      CellTags->"Gstrong"],
    Cell[1358944, 42880, 360, 15, 70, "Text",
      CellTags->"Gstrong"],
    Cell[1359341, 42900, 56, 1, 70, "Subsubsection",
      CellTags->"Gstrong"],
    Cell[1359400, 42903, 120, 3, 70, "Text",
      CellTags->"Gstrong"],
    Cell[1359545, 42910, 105, 2, 70, "Input",
      CellTags->"Gstrong"]},
  "Hill"->{
    Cell[1359848, 42924, 46, 1, 70, "ObjectName",
      CellTags->"Hill"],
    Cell[1359919, 42929, 56, 1, 70, "Subsubsection",
      CellTags->"Hill"],
    Cell[1359978, 42932, 130, 4, 70, "Text",
      CellTags->"Hill"],
    Cell[1360111, 42938, 209, 9, 70, "Text",
      CellTags->"Hill"],
    Cell[1360357, 42952, 53, 1, 70, "Subsubsection",
      CellTags->"Hill"],
    Cell[1360435, 42957, 156, 4, 70, "Input",
      CellTags->"Hill"],
    Cell[1363391, 43043, 293, 8, 70, "Input",
      CellTags->"Hill"],
    Cell[1363832, 43060, 325, 9, 70, "Input",
      CellTags->"Hill"],
    Cell[1365495, 43113, 316, 9, 70, "Input",
      CellTags->"Hill"]},
  "HypergeometricAC"->{
    Cell[1365983, 43133, 70, 1, 70, "ObjectName",
      CellTags->"HypergeometricAC"],
    Cell[1366078, 43138, 68, 1, 70, "Subsubsection",
      CellTags->"HypergeometricAC"],
    Cell[1366149, 43141, 554, 9, 70, "Text",
      CellTags->"HypergeometricAC"],
    Cell[1366728, 43154, 159, 3, 70, "Input",
      CellTags->"HypergeometricAC"],
    Cell[1367092, 43167, 641, 24, 70, "Text",
      CellTags->"HypergeometricAC"],
    Cell[1367770, 43196, 65, 1, 70, "Subsubsection",
      CellTags->"HypergeometricAC"],
    Cell[1367838, 43199, 102, 1, 70, "Text",
      CellTags->"HypergeometricAC"],
    Cell[1367965, 43204, 311, 7, 70, "Input",
      CellTags->"HypergeometricAC"],
    Cell[1373477, 43339, 311, 7, 70, "Input",
      CellTags->"HypergeometricAC"],
    Cell[1378913, 43472, 311, 7, 70, "Input",
      CellTags->"HypergeometricAC"],
    Cell[1384402, 43606, 311, 7, 70, "Input",
      CellTags->"HypergeometricAC"],
    Cell[1390356, 43751, 311, 7, 70, "Input",
      CellTags->"HypergeometricAC"],
    Cell[1392661, 43816, 312, 7, 70, "Input",
      CellTags->"HypergeometricAC"]},
  "HypergeometricIR"->{
    Cell[1394992, 43883, 70, 1, 70, "ObjectName",
      CellTags->"HypergeometricIR"],
    Cell[1395087, 43888, 68, 1, 70, "Subsubsection",
      CellTags->"HypergeometricIR"],
    Cell[1395158, 43891, 270, 5, 70, "Text",
      CellTags->"HypergeometricIR"],
    Cell[1395431, 43898, 512, 19, 70, "Text",
      CellTags->"HypergeometricIR"],
    Cell[1395968, 43921, 159, 3, 70, "Input",
      CellTags->"HypergeometricIR"],
    Cell[1396370, 43937, 65, 1, 70, "Subsubsection",
      CellTags->"HypergeometricIR"],
    Cell[1396460, 43942, 288, 7, 70, "Input",
      CellTags->"HypergeometricIR"],
    Cell[1397585, 43977, 492, 14, 70, "Input",
      CellTags->"HypergeometricIR"],
    Cell[1400316, 44053, 180, 4, 70, "Input",
      CellTags->"HypergeometricIR"]},
  "HypergeometricSE"->{
    Cell[1400965, 44078, 70, 1, 70, "ObjectName",
      CellTags->"HypergeometricSE"],
    Cell[1401060, 44083, 68, 1, 70, "Subsubsection",
      CellTags->"HypergeometricSE"],
    Cell[1401131, 44086, 440, 13, 70, "Text",
      CellTags->"HypergeometricSE"],
    Cell[1401596, 44103, 159, 3, 70, "Input",
      CellTags->"HypergeometricSE"],
    Cell[1401968, 44116, 224, 9, 70, "Text",
      CellTags->"HypergeometricSE"],
    Cell[1402229, 44130, 65, 1, 70, "Subsubsection",
      CellTags->"HypergeometricSE"],
    Cell[1402319, 44135, 292, 7, 70, "Input",
      CellTags->"HypergeometricSE"],
    Cell[1403418, 44167, 430, 11, 70, "Input",
      CellTags->"HypergeometricSE"]},
  "HypExplicit"->{
    Cell[1404993, 44211, 60, 1, 70, "ObjectName",
      CellTags->"HypExplicit"],
    Cell[1405078, 44216, 63, 1, 70, "Subsubsection",
      CellTags->"HypExplicit"],
    Cell[1405144, 44219, 339, 10, 70, "Text",
      CellTags->"HypExplicit"],
    Cell[1405486, 44231, 219, 9, 70, "Text",
      CellTags->"HypExplicit"],
    Cell[1405742, 44245, 60, 1, 70, "Subsubsection",
      CellTags->"HypExplicit"],
    Cell[1405827, 44250, 196, 4, 70, "Input",
      CellTags->"HypExplicit"],
    Cell[1407588, 44303, 174, 4, 70, "Input",
      CellTags->"HypExplicit"],
    Cell[1408569, 44332, 316, 8, 70, "Input",
      CellTags->"HypExplicit"],
    Cell[1410735, 44396, 174, 4, 70, "Input",
      CellTags->"HypExplicit"]},
  "Integrate2"->{
    Cell[1412054, 44433, 58, 1, 70, "ObjectName",
      CellTags->"Integrate2"],
    Cell[1412137, 44438, 62, 1, 70, "Subsubsection",
      CellTags->"Integrate2"],
    Cell[1412202, 44441, 885, 17, 70, "Text",
      CellTags->"Integrate2"],
    Cell[1413090, 44460, 551, 24, 70, "Text",
      CellTags->"Integrate2"],
    Cell[1413644, 44486, 406, 7, 70, "Text",
      CellTags->"Integrate2"],
    Cell[1414087, 44498, 59, 1, 70, "Subsubsection",
      CellTags->"Integrate2"],
    Cell[1414171, 44503, 532, 15, 70, "Input",
      CellTags->"Integrate2"],
    Cell[1415317, 44539, 196, 6, 70, "Text",
      CellTags->"Integrate2"],
    Cell[1415538, 44549, 342, 9, 70, "Input",
      CellTags->"Integrate2"],
    Cell[1416179, 44572, 337, 9, 70, "Input",
      CellTags->"Integrate2"],
    Cell[1417087, 44603, 414, 11, 70, "Input",
      CellTags->"Integrate2"],
    Cell[1418310, 44642, 384, 10, 70, "Input",
      CellTags->"Integrate2"],
    Cell[1418852, 44660, 1942, 54, 70, "Text",
      CellTags->"Integrate2"],
    Cell[1420819, 44718, 331, 9, 70, "Input",
      CellTags->"Integrate2"],
    Cell[1421276, 44734, 755, 25, 70, "Text",
      CellTags->"Integrate2"],
    Cell[1422056, 44763, 386, 10, 70, "Input",
      CellTags->"Integrate2"],
    Cell[1422590, 44782, 476, 13, 70, "Input",
      CellTags->"Integrate2"],
    Cell[1423281, 44806, 516, 14, 70, "Input",
      CellTags->"Integrate2"],
    Cell[1424166, 44837, 402, 11, 70, "Input",
      CellTags->"Integrate2"],
    Cell[1424898, 44863, 436, 12, 70, "Input",
      CellTags->"Integrate2"],
    Cell[1425849, 44895, 380, 10, 70, "Input",
      CellTags->"Integrate2"],
    Cell[1426477, 44918, 342, 9, 70, "Input",
      CellTags->"Integrate2"],
    Cell[1427321, 44947, 553, 15, 70, "Input",
      CellTags->"Integrate2"],
    Cell[1428504, 44985, 966, 25, 70, "Input",
      CellTags->"Integrate2"],
    Cell[1435257, 45175, 596, 16, 70, "Input",
      CellTags->"Integrate2"],
    Cell[1437002, 45229, 635, 17, 70, "Input",
      CellTags->"Integrate2"],
    Cell[1447267, 45533, 174, 4, 70, "Input",
      CellTags->"Integrate2"],
    Cell[1449050, 45587, 132, 3, 70, "Input",
      CellTags->"Integrate2"],
    Cell[1449350, 45599, 533, 14, 70, "Input",
      CellTags->"Integrate2"],
    Cell[1450051, 45622, 877, 23, 70, "Input",
      CellTags->"Integrate2"],
    Cell[1455909, 45796, 183, 4, 70, "Input",
      CellTags->"Integrate2"],
    Cell[1456243, 45809, 450, 12, 70, "Input",
      CellTags->"Integrate2"],
    Cell[1456819, 45828, 138, 4, 70, "Text",
      CellTags->"Integrate2"],
    Cell[1456982, 45836, 179, 4, 70, "Input",
      CellTags->"Integrate2"],
    Cell[1464481, 46024, 284, 8, 70, "Input",
      CellTags->"Integrate2"],
    Cell[1465008, 46043, 166, 4, 70, "Text",
      CellTags->"Integrate2"],
    Cell[1465199, 46051, 405, 11, 70, "Input",
      CellTags->"Integrate2"],
    Cell[1465848, 46073, 158, 4, 70, "Input",
      CellTags->"Integrate2"],
    Cell[1466031, 46081, 384, 10, 70, "Input",
      CellTags->"Integrate2"],
    Cell[1466595, 46101, 400, 11, 70, "Input",
      CellTags->"Integrate2"],
    Cell[1467337, 46128, 127, 3, 70, "Input",
      CellTags->"Integrate2"],
    Cell[1467631, 46140, 400, 11, 70, "Input",
      CellTags->"Integrate2"],
    Cell[1468198, 46160, 471, 13, 70, "Input",
      CellTags->"Integrate2"]},
  "Integrate3"->{
    Cell[1474996, 46365, 58, 1, 70, "ObjectName",
      CellTags->"Integrate3"],
    Cell[1475079, 46370, 62, 1, 70, "Subsubsection",
      CellTags->"Integrate3"],
    Cell[1475144, 46373, 332, 6, 70, "Text",
      CellTags->"Integrate3"],
    Cell[1475479, 46381, 200, 9, 70, "Text",
      CellTags->"Integrate3"],
    Cell[1475716, 46395, 59, 1, 70, "Subsubsection",
      CellTags->"Integrate3"],
    Cell[1475800, 46400, 340, 9, 70, "Input",
      CellTags->"Integrate3"],
    Cell[1476444, 46424, 489, 13, 70, "Input",
      CellTags->"Integrate3"],
    Cell[1477709, 46466, 858, 23, 70, "Input",
      CellTags->"Integrate3"],
    Cell[1481703, 46577, 320, 8, 70, "Input",
      CellTags->"Integrate3"],
    Cell[1482171, 46594, 389, 10, 70, "Input",
      CellTags->"Integrate3"],
    Cell[1482819, 46617, 331, 9, 70, "Input",
      CellTags->"Integrate3"]},
  "IntegrateByParts"->{
    Cell[1483322, 46637, 70, 1, 70, "ObjectName",
      CellTags->"IntegrateByParts"],
    Cell[1483417, 46642, 68, 1, 70, "Subsubsection",
      CellTags->"IntegrateByParts"],
    Cell[1483488, 46645, 185, 4, 70, "Text",
      CellTags->"IntegrateByParts"],
    Cell[1483698, 46653, 159, 3, 70, "Input",
      CellTags->"IntegrateByParts"],
    Cell[1484093, 46669, 65, 1, 70, "Subsubsection",
      CellTags->"IntegrateByParts"],
    Cell[1484183, 46674, 670, 19, 70, "Input",
      CellTags->"IntegrateByParts"]},
  "InverseMellin"->{
    Cell[1485704, 46724, 64, 1, 70, "ObjectName",
      CellTags->"InverseMellin"],
    Cell[1485793, 46729, 65, 1, 70, "Subsubsection",
      CellTags->"InverseMellin"],
    Cell[1485861, 46732, 578, 14, 70, "Text",
      CellTags->"InverseMellin"],
    Cell[1486442, 46748, 662, 29, 70, "Text",
      CellTags->"InverseMellin"],
    Cell[1487141, 46782, 62, 1, 70, "Subsubsection",
      CellTags->"InverseMellin"],
    Cell[1487228, 46787, 206, 5, 70, "Input",
      CellTags->"InverseMellin"],
    Cell[1487639, 46803, 270, 7, 70, "Input",
      CellTags->"InverseMellin"],
    Cell[1488114, 46821, 174, 4, 70, "Input",
      CellTags->"InverseMellin"],
    Cell[1488649, 46841, 237, 6, 70, "Input",
      CellTags->"InverseMellin"],
    Cell[1489260, 46864, 239, 7, 70, "Input",
      CellTags->"InverseMellin"],
    Cell[1489962, 46890, 251, 7, 70, "Input",
      CellTags->"InverseMellin"],
    Cell[1490654, 46914, 114, 3, 70, "Text",
      CellTags->"InverseMellin"],
    Cell[1490793, 46921, 354, 9, 70, "Input",
      CellTags->"InverseMellin"],
    Cell[1491298, 46938, 118, 3, 70, "Text",
      CellTags->"InverseMellin"],
    Cell[1491419, 46943, 4033, 103, 70, "Input",
      CellTags->"InverseMellin"],
    Cell[1495455, 47048, 290, 7, 70, "Input",
      CellTags->"InverseMellin"],
    Cell[1495770, 47059, 221, 6, 70, "Input",
      CellTags->"InverseMellin"],
    Cell[1496494, 47085, 221, 6, 70, "Input",
      CellTags->"InverseMellin"],
    Cell[1497173, 47110, 208, 5, 70, "Input",
      CellTags->"InverseMellin"],
    Cell[1498389, 47148, 105, 2, 70, "Input",
      CellTags->"InverseMellin"],
    Cell[1498519, 47154, 234, 6, 70, "Input",
      CellTags->"InverseMellin"],
    Cell[1499401, 47185, 330, 9, 70, "Input",
      CellTags->"InverseMellin"],
    Cell[1500381, 47219, 330, 9, 70, "Input",
      CellTags->"InverseMellin"],
    Cell[1501592, 47258, 329, 9, 70, "Input",
      CellTags->"InverseMellin"],
    Cell[1502874, 47299, 307, 9, 70, "Input",
      CellTags->"InverseMellin"],
    Cell[1503888, 47334, 346, 10, 70, "Input",
      CellTags->"InverseMellin"],
    Cell[1505433, 47381, 234, 6, 70, "Input",
      CellTags->"InverseMellin"],
    Cell[1506582, 47418, 277, 8, 70, "Input",
      CellTags->"InverseMellin"],
    Cell[1507815, 47458, 234, 6, 70, "Input",
      CellTags->"InverseMellin"],
    Cell[1509245, 47502, 244, 6, 70, "Input",
      CellTags->"InverseMellin"],
    Cell[1510193, 47534, 272, 7, 70, "Input",
      CellTags->"InverseMellin"],
    Cell[1511922, 47585, 272, 7, 70, "Input",
      CellTags->"InverseMellin"],
    Cell[1513576, 47634, 254, 6, 70, "Input",
      CellTags->"InverseMellin"],
    Cell[1514626, 47667, 194, 5, 70, "Input",
      CellTags->"InverseMellin"]},
  "Isolate"->{
    Cell[1514869, 47678, 52, 1, 70, "ObjectName",
      CellTags->"Isolate"],
    Cell[1514946, 47683, 59, 1, 70, "Subsubsection",
      CellTags->"Isolate"],
    Cell[1515008, 47686, 423, 7, 70, "Text",
      CellTags->"Isolate"],
    Cell[1515456, 47697, 141, 3, 70, "Input",
      CellTags->"Isolate"],
    Cell[1516050, 47717, 56, 1, 70, "Subsubsection",
      CellTags->"Isolate"],
    Cell[1516131, 47722, 192, 5, 70, "Input",
      CellTags->"Isolate"],
    Cell[1516539, 47739, 476, 13, 70, "Input",
      CellTags->"Isolate"],
    Cell[1517418, 47770, 141, 3, 70, "Input",
      CellTags->"Isolate"],
    Cell[1517927, 47790, 218, 5, 70, "Input",
      CellTags->"Isolate"],
    Cell[1518988, 47826, 698, 19, 70, "Input",
      CellTags->"Isolate"],
    Cell[1520149, 47865, 120, 3, 70, "Input",
      CellTags->"Isolate"],
    Cell[1521310, 47902, 324, 7, 70, "Input",
      CellTags->"Isolate"],
    Cell[1521849, 47921, 219, 6, 70, "Input",
      CellTags->"Isolate"],
    Cell[1522317, 47938, 172, 4, 70, "Input",
      CellTags->"Isolate"]},
  "Kummer"->{
    Cell[1522538, 47948, 50, 1, 70, "ObjectName",
      CellTags->"Kummer"],
    Cell[1522613, 47953, 58, 1, 70, "Subsubsection",
      CellTags->"Kummer"],
    Cell[1522674, 47956, 261, 5, 70, "Text",
      CellTags->"Kummer"],
    Cell[1522938, 47963, 214, 9, 70, "Text",
      CellTags->"Kummer"],
    Cell[1523189, 47977, 55, 1, 70, "Subsubsection",
      CellTags->"Kummer"],
    Cell[1523269, 47982, 402, 10, 70, "Input",
      CellTags->"Kummer"],
    Cell[1527221, 48090, 402, 10, 70, "Input",
      CellTags->"Kummer"],
    Cell[1531207, 48199, 402, 10, 70, "Input",
      CellTags->"Kummer"],
    Cell[1535193, 48308, 457, 11, 70, "Input",
      CellTags->"Kummer"],
    Cell[1539216, 48417, 561, 13, 70, "Input",
      CellTags->"Kummer"],
    Cell[1543455, 48529, 457, 11, 70, "Input",
      CellTags->"Kummer"],
    Cell[1547469, 48638, 561, 13, 70, "Input",
      CellTags->"Kummer"],
    Cell[1551729, 48751, 457, 11, 70, "Input",
      CellTags->"Kummer"],
    Cell[1555743, 48860, 561, 13, 70, "Input",
      CellTags->"Kummer"],
    Cell[1560003, 48973, 588, 15, 70, "Input",
      CellTags->"Kummer"],
    Cell[1564369, 49092, 756, 19, 70, "Input",
      CellTags->"Kummer"],
    Cell[1569072, 49218, 588, 15, 70, "Input",
      CellTags->"Kummer"],
    Cell[1573415, 49337, 756, 19, 70, "Input",
      CellTags->"Kummer"],
    Cell[1578095, 49463, 588, 15, 70, "Input",
      CellTags->"Kummer"],
    Cell[1582402, 49581, 756, 19, 70, "Input",
      CellTags->"Kummer"],
    Cell[1587150, 49708, 588, 15, 70, "Input",
      CellTags->"Kummer"],
    Cell[1591516, 49827, 756, 19, 70, "Input",
      CellTags->"Kummer"],
    Cell[1596305, 49955, 588, 15, 70, "Input",
      CellTags->"Kummer"],
    Cell[1600579, 50072, 756, 19, 70, "Input",
      CellTags->"Kummer"],
    Cell[1605276, 50198, 588, 15, 70, "Input",
      CellTags->"Kummer"],
    Cell[1609550, 50315, 756, 19, 70, "Input",
      CellTags->"Kummer"],
    Cell[1614394, 50444, 626, 15, 70, "Input",
      CellTags->"Kummer"],
    Cell[1618776, 50561, 403, 10, 70, "Input",
      CellTags->"Kummer"],
    Cell[1622729, 50669, 626, 15, 70, "Input",
      CellTags->"Kummer"],
    Cell[1627207, 50788, 403, 10, 70, "Input",
      CellTags->"Kummer"],
    Cell[1631152, 50896, 626, 15, 70, "Input",
      CellTags->"Kummer"],
    Cell[1635630, 51015, 403, 10, 70, "Input",
      CellTags->"Kummer"],
    Cell[1639575, 51123, 690, 17, 70, "Input",
      CellTags->"Kummer"],
    Cell[1644132, 51244, 458, 11, 70, "Input",
      CellTags->"Kummer"],
    Cell[1648156, 51353, 690, 17, 70, "Input",
      CellTags->"Kummer"],
    Cell[1652871, 51478, 458, 11, 70, "Input",
      CellTags->"Kummer"],
    Cell[1656959, 51589, 690, 17, 70, "Input",
      CellTags->"Kummer"],
    Cell[1661601, 51712, 458, 11, 70, "Input",
      CellTags->"Kummer"],
    Cell[1665616, 51821, 403, 10, 70, "Input",
      CellTags->"Kummer"],
    Cell[1672672, 51995, 403, 10, 70, "Input",
      CellTags->"Kummer"],
    Cell[1679820, 52172, 403, 10, 70, "Input",
      CellTags->"Kummer"]},
  "Lagrangian"->{
    Cell[1686996, 52351, 58, 1, 70, "ObjectName",
      CellTags->"Lagrangian"],
    Cell[1687079, 52356, 62, 1, 70, "Subsubsection",
      CellTags->"Lagrangian"],
    Cell[1687144, 52359, 213, 5, 70, "Text",
      CellTags->"Lagrangian"],
    Cell[1687360, 52366, 194, 9, 70, "Text",
      CellTags->"Lagrangian"],
    Cell[1687591, 52380, 59, 1, 70, "Subsubsection",
      CellTags->"Lagrangian"],
    Cell[1687675, 52385, 151, 3, 70, "Input",
      CellTags->"Lagrangian"],
    Cell[1688258, 52404, 86, 1, 70, "Text",
      CellTags->"Lagrangian"],
    Cell[1688369, 52409, 151, 3, 70, "Input",
      CellTags->"Lagrangian"],
    Cell[1689433, 52441, 151, 3, 70, "Input",
      CellTags->"Lagrangian"],
    Cell[1690989, 52486, 151, 3, 70, "Input",
      CellTags->"Lagrangian"],
    Cell[1691986, 52518, 151, 3, 70, "Input",
      CellTags->"Lagrangian"]},
  "LC"->{
    Cell[1693056, 52553, 42, 1, 70, "ObjectName",
      CellTags->"LC"],
    Cell[1693123, 52558, 54, 1, 70, "Subsubsection",
      CellTags->"LC"],
    Cell[1693180, 52561, 241, 5, 70, "Text",
      CellTags->"LC"],
    Cell[1693424, 52568, 297, 14, 70, "Text",
      CellTags->"LC"],
    Cell[1693758, 52587, 51, 1, 70, "Subsubsection",
      CellTags->"LC"],
    Cell[1693834, 52592, 199, 5, 70, "Input",
      CellTags->"LC"],
    Cell[1694334, 52610, 122, 3, 70, "Input",
      CellTags->"LC"],
    Cell[1695161, 52640, 131, 3, 70, "Input",
      CellTags->"LC"],
    Cell[1695702, 52657, 221, 6, 70, "Input",
      CellTags->"LC"],
    Cell[1696212, 52676, 161, 4, 70, "Input",
      CellTags->"LC"],
    Cell[1696825, 52696, 474, 13, 70, "Input",
      CellTags->"LC"]},
  "LCD"->{
    Cell[1697944, 52735, 44, 1, 70, "ObjectName",
      CellTags->"LCD"],
    Cell[1698013, 52740, 55, 1, 70, "Subsubsection",
      CellTags->"LCD"],
    Cell[1698071, 52743, 235, 5, 70, "Text",
      CellTags->"LCD"],
    Cell[1698309, 52750, 157, 4, 70, "Text",
      CellTags->"LCD"],
    Cell[1698469, 52756, 295, 14, 70, "Text",
      CellTags->"LCD"],
    Cell[1698801, 52775, 52, 1, 70, "Subsubsection",
      CellTags->"LCD"],
    Cell[1698856, 52778, 232, 6, 70, "Input",
      CellTags->"LCD"],
    Cell[1699113, 52788, 202, 5, 70, "Input",
      CellTags->"LCD"],
    Cell[1699617, 52806, 124, 3, 70, "Input",
      CellTags->"LCD"],
    Cell[1700447, 52836, 133, 3, 70, "Input",
      CellTags->"LCD"],
    Cell[1701115, 52857, 224, 6, 70, "Input",
      CellTags->"LCD"],
    Cell[1701629, 52876, 163, 4, 70, "Input",
      CellTags->"LCD"],
    Cell[1702307, 52898, 494, 13, 70, "Input",
      CellTags->"LCD"],
    Cell[1703347, 52932, 207, 5, 70, "Input",
      CellTags->"LCD"]},
  "LeftPartialD"->{
    Cell[1703804, 52951, 62, 1, 70, "ObjectName",
      CellTags->"LeftPartialD"],
    Cell[1703891, 52956, 64, 1, 70, "Subsubsection",
      CellTags->"LeftPartialD"],
    Cell[1703958, 52959, 358, 12, 70, "Text",
      CellTags->"LeftPartialD"],
    Cell[1704319, 52973, 616, 24, 70, "Text",
      CellTags->"LeftPartialD"],
    Cell[1704972, 53002, 70, 1, 70, "Subsubsection",
      CellTags->"LeftPartialD"],
    Cell[1705067, 53007, 300, 7, 70, "Input",
      CellTags->"LeftPartialD"],
    Cell[1705765, 53031, 148, 3, 70, "Input",
      CellTags->"LeftPartialD"],
    Cell[1706311, 53051, 146, 3, 70, "Input",
      CellTags->"LeftPartialD"],
    Cell[1706829, 53068, 193, 4, 70, "Input",
      CellTags->"LeftPartialD"],
    Cell[1707242, 53082, 434, 10, 70, "Input",
      CellTags->"LeftPartialD"],
    Cell[1708117, 53110, 148, 3, 70, "Input",
      CellTags->"LeftPartialD"],
    Cell[1708729, 53132, 146, 3, 70, "Input",
      CellTags->"LeftPartialD"]},
  "LeftRightPartialD"->{
    Cell[1709434, 53155, 72, 1, 70, "ObjectName",
      CellTags->"LeftRightPartialD"],
    Cell[1709531, 53160, 69, 1, 70, "Subsubsection",
      CellTags->"LeftRightPartialD"],
    Cell[1709603, 53163, 659, 21, 70, "Text",
      CellTags->"LeftRightPartialD"],
    Cell[1710265, 53186, 893, 33, 70, "Text",
      CellTags->"LeftRightPartialD"],
    Cell[1711195, 53224, 66, 1, 70, "Subsubsection",
      CellTags->"LeftRightPartialD"],
    Cell[1711286, 53229, 160, 3, 70, "Input",
      CellTags->"LeftRightPartialD"],
    Cell[1711778, 53247, 155, 3, 70, "Input",
      CellTags->"LeftRightPartialD"],
    Cell[1712625, 53275, 310, 7, 70, "Input",
      CellTags->"LeftRightPartialD"],
    Cell[1713338, 53299, 153, 3, 70, "Input",
      CellTags->"LeftRightPartialD"],
    Cell[1714366, 53333, 444, 10, 70, "Input",
      CellTags->"LeftRightPartialD"],
    Cell[1715256, 53361, 153, 3, 70, "Input",
      CellTags->"LeftRightPartialD"]},
  "LeftRightPartialD2"->{
    Cell[1716499, 53402, 74, 1, 70, "ObjectName",
      CellTags->"LeftRightPartialD2"],
    Cell[1716598, 53407, 70, 1, 70, "Subsubsection",
      CellTags->"LeftRightPartialD2"],
    Cell[1716671, 53410, 658, 21, 70, "Text",
      CellTags->"LeftRightPartialD2"],
    Cell[1717332, 53433, 751, 29, 70, "Text",
      CellTags->"LeftRightPartialD2"],
    Cell[1718120, 53467, 67, 1, 70, "Subsubsection",
      CellTags->"LeftRightPartialD2"],
    Cell[1718212, 53472, 162, 3, 70, "Input",
      CellTags->"LeftRightPartialD2"],
    Cell[1718706, 53490, 156, 3, 70, "Input",
      CellTags->"LeftRightPartialD2"],
    Cell[1719419, 53515, 312, 7, 70, "Input",
      CellTags->"LeftRightPartialD2"],
    Cell[1720134, 53539, 154, 3, 70, "Input",
      CellTags->"LeftRightPartialD2"],
    Cell[1721077, 53572, 446, 10, 70, "Input",
      CellTags->"LeftRightPartialD2"],
    Cell[1721969, 53600, 154, 3, 70, "Input",
      CellTags->"LeftRightPartialD2"]},
  "LeviCivita"->{
    Cell[1723090, 53638, 59, 1, 70, "ObjectName",
      CellTags->"LeviCivita"],
    Cell[1723174, 53643, 62, 1, 70, "Subsubsection",
      CellTags->"LeviCivita"],
    Cell[1723239, 53646, 1314, 41, 70, "Text",
      CellTags->"LeviCivita"],
    Cell[1724578, 53691, 148, 3, 70, "Input",
      CellTags->"LeviCivita"],
    Cell[1724930, 53704, 281, 14, 70, "Text",
      CellTags->"LeviCivita"],
    Cell[1725248, 53723, 59, 1, 70, "Subsubsection",
      CellTags->"LeviCivita"],
    Cell[1725332, 53728, 223, 5, 70, "Input",
      CellTags->"LeviCivita"],
    Cell[1726268, 53760, 245, 6, 70, "Input",
      CellTags->"LeviCivita"],
    Cell[1727111, 53789, 216, 5, 70, "Input",
      CellTags->"LeviCivita"],
    Cell[1727793, 53813, 222, 5, 70, "Input",
      CellTags->"LeviCivita"],
    Cell[1728164, 53827, 297, 8, 70, "Input",
      CellTags->"LeviCivita"],
    Cell[1728859, 53849, 488, 13, 70, "Input",
      CellTags->"LeviCivita"],
    Cell[1730719, 53908, 141, 3, 70, "Input",
      CellTags->"LeviCivita"],
    Cell[1731010, 53919, 374, 9, 70, "Input",
      CellTags->"LeviCivita"],
    Cell[1731409, 53932, 506, 13, 70, "Input",
      CellTags->"LeviCivita"],
    Cell[1732276, 53960, 374, 9, 70, "Input",
      CellTags->"LeviCivita"],
    Cell[1732675, 53973, 215, 5, 70, "Input",
      CellTags->"LeviCivita"],
    Cell[1733177, 53989, 138, 3, 70, "Input",
      CellTags->"LeviCivita"]},
  "Li2"->{
    Cell[1733364, 53998, 45, 1, 70, "ObjectName",
      CellTags->"Li2"],
    Cell[1733434, 54003, 55, 1, 70, "Subsubsection",
      CellTags->"Li2"],
    Cell[1733492, 54006, 118, 3, 70, "Text",
      CellTags->"Li2"],
    Cell[1733613, 54011, 165, 8, 70, "Text",
      CellTags->"Li2"],
    Cell[1733815, 54024, 52, 1, 70, "Subsubsection",
      CellTags->"Li2"],
    Cell[1733892, 54029, 128, 3, 70, "Input",
      CellTags->"Li2"],
    Cell[1734232, 54044, 135, 3, 70, "Input",
      CellTags->"Li2"],
    Cell[1734587, 54058, 317, 9, 70, "Input",
      CellTags->"Li2"]},
  "Li3"->{
    Cell[1735140, 54081, 45, 1, 70, "ObjectName",
      CellTags->"Li3"],
    Cell[1735210, 54086, 55, 1, 70, "Subsubsection",
      CellTags->"Li3"],
    Cell[1735268, 54089, 121, 4, 70, "Text",
      CellTags->"Li3"],
    Cell[1735392, 54095, 165, 8, 70, "Text",
      CellTags->"Li3"],
    Cell[1735594, 54108, 52, 1, 70, "Subsubsection",
      CellTags->"Li3"],
    Cell[1735671, 54113, 128, 3, 70, "Input",
      CellTags->"Li3"],
    Cell[1736011, 54128, 135, 3, 70, "Input",
      CellTags->"Li3"],
    Cell[1736366, 54142, 189, 5, 70, "Input",
      CellTags->"Li3"],
    Cell[1736801, 54160, 252, 7, 70, "Input",
      CellTags->"Li3"]},
  "LorentzIndex"->{
    Cell[1737289, 54181, 62, 1, 70, "ObjectName",
      CellTags->"LorentzIndex"],
    Cell[1737376, 54186, 64, 1, 70, "Subsubsection",
      CellTags->"LorentzIndex"],
    Cell[1737443, 54189, 244, 5, 70, "Text",
      CellTags->"LorentzIndex"],
    Cell[1737690, 54196, 337, 14, 70, "Text",
      CellTags->"LorentzIndex"],
    Cell[1738064, 54215, 61, 1, 70, "Subsubsection",
      CellTags->"LorentzIndex"],
    Cell[1738128, 54218, 90, 1, 70, "Text",
      CellTags->"LorentzIndex"],
    Cell[1738243, 54223, 153, 3, 70, "Input",
      CellTags->"LorentzIndex"],
    Cell[1738530, 54233, 126, 3, 70, "Text",
      CellTags->"LorentzIndex"],
    Cell[1738681, 54240, 180, 4, 70, "Input",
      CellTags->"LorentzIndex"],
    Cell[1739017, 54253, 131, 2, 70, "Input",
      CellTags->"LorentzIndex"],
    Cell[1739332, 54265, 197, 4, 70, "Input",
      CellTags->"LorentzIndex"],
    Cell[1739710, 54279, 246, 6, 70, "Input",
      CellTags->"LorentzIndex"],
    Cell[1740089, 54292, 142, 4, 70, "Text",
      CellTags->"LorentzIndex"],
    Cell[1740234, 54298, 169, 4, 70, "Input",
      CellTags->"LorentzIndex"],
    Cell[1740428, 54306, 412, 10, 70, "Input",
      CellTags->"LorentzIndex"],
    Cell[1741337, 54336, 180, 4, 70, "Input",
      CellTags->"LorentzIndex"]},
  "Map2"->{
    Cell[1741566, 54346, 46, 1, 70, "ObjectName",
      CellTags->"Map2"],
    Cell[1741637, 54351, 56, 1, 70, "Subsubsection",
      CellTags->"Map2"],
    Cell[1741696, 54354, 136, 4, 70, "Text",
      CellTags->"Map2"],
    Cell[1741835, 54360, 182, 9, 70, "Text",
      CellTags->"Map2"],
    Cell[1742054, 54374, 53, 1, 70, "Subsubsection",
      CellTags->"Map2"],
    Cell[1742132, 54379, 186, 5, 70, "Input",
      CellTags->"Map2"],
    Cell[1742588, 54397, 157, 4, 70, "Input",
      CellTags->"Map2"],
    Cell[1742926, 54411, 227, 6, 70, "Input",
      CellTags->"Map2"],
    Cell[1743411, 54430, 157, 4, 70, "Input",
      CellTags->"Map2"]},
  "MetricTensor"->{
    Cell[1743773, 54446, 62, 1, 70, "ObjectName",
      CellTags->"MetricTensor"],
    Cell[1743860, 54451, 64, 1, 70, "Subsubsection",
      CellTags->"MetricTensor"],
    Cell[1743927, 54454, 227, 7, 70, "Text",
      CellTags->"MetricTensor"],
    Cell[1744157, 54463, 637, 29, 70, "Text",
      CellTags->"MetricTensor"],
    Cell[1744831, 54497, 61, 1, 70, "Subsubsection",
      CellTags->"MetricTensor"],
    Cell[1744917, 54502, 186, 4, 70, "Input",
      CellTags->"MetricTensor"],
    Cell[1745338, 54518, 169, 4, 70, "Input",
      CellTags->"MetricTensor"],
    Cell[1745656, 54531, 239, 5, 70, "Input",
      CellTags->"MetricTensor"],
    Cell[1746335, 54555, 169, 4, 70, "Input",
      CellTags->"MetricTensor"],
    Cell[1746653, 54568, 218, 5, 70, "Input",
      CellTags->"MetricTensor"],
    Cell[1747153, 54585, 273, 6, 70, "Input",
      CellTags->"MetricTensor"],
    Cell[1747770, 54605, 256, 6, 70, "Input",
      CellTags->"MetricTensor"],
    Cell[1748216, 54621, 320, 8, 70, "Input",
      CellTags->"MetricTensor"]},
  "MomentumCombine"->{
    Cell[1748751, 54641, 68, 1, 70, "ObjectName",
      CellTags->"MomentumCombine"],
    Cell[1748844, 54646, 67, 1, 70, "Subsubsection",
      CellTags->"MomentumCombine"],
    Cell[1748914, 54649, 184, 4, 70, "Text",
      CellTags->"MomentumCombine"],
    Cell[1749101, 54655, 483, 18, 70, "Text",
      CellTags->"MomentumCombine"],
    Cell[1749621, 54678, 64, 1, 70, "Subsubsection",
      CellTags->"MomentumCombine"],
    Cell[1749710, 54683, 391, 10, 70, "Input",
      CellTags->"MomentumCombine"],
    Cell[1750326, 54704, 378, 10, 70, "Input",
      CellTags->"MomentumCombine"],
    Cell[1750979, 54727, 153, 3, 70, "Input",
      CellTags->"MomentumCombine"],
    Cell[1751559, 54749, 199, 5, 70, "Input",
      CellTags->"MomentumCombine"],
    Cell[1752104, 54768, 206, 5, 70, "Input",
      CellTags->"MomentumCombine"],
    Cell[1752911, 54798, 149, 3, 70, "Input",
      CellTags->"MomentumCombine"],
    Cell[1753546, 54817, 143, 3, 70, "Input",
      CellTags->"MomentumCombine"]},
  "MomentumExpand"->{
    Cell[1753738, 54826, 66, 1, 70, "ObjectName",
      CellTags->"MomentumExpand"],
    Cell[1753829, 54831, 66, 1, 70, "Subsubsection",
      CellTags->"MomentumExpand"],
    Cell[1753898, 54834, 150, 4, 70, "Text",
      CellTags->"MomentumExpand"],
    Cell[1754051, 54840, 372, 14, 70, "Text",
      CellTags->"MomentumExpand"],
    Cell[1754460, 54859, 63, 1, 70, "Subsubsection",
      CellTags->"MomentumExpand"],
    Cell[1754548, 54864, 268, 7, 70, "Input",
      CellTags->"MomentumExpand"],
    Cell[1755051, 54882, 205, 5, 70, "Input",
      CellTags->"MomentumExpand"],
    Cell[1755643, 54903, 144, 3, 70, "Input",
      CellTags->"MomentumExpand"],
    Cell[1756092, 54919, 254, 6, 70, "Input",
      CellTags->"MomentumExpand"],
    Cell[1756817, 54946, 144, 3, 70, "Input",
      CellTags->"MomentumExpand"],
    Cell[1757309, 54963, 285, 7, 70, "Input",
      CellTags->"MomentumExpand"],
    Cell[1758098, 54992, 144, 3, 70, "Input",
      CellTags->"MomentumExpand"],
    Cell[1758692, 55012, 140, 3, 70, "Input",
      CellTags->"MomentumExpand"]},
  "Momentum"->{
    Cell[1759673, 55046, 54, 1, 70, "ObjectName",
      CellTags->"Momentum"],
    Cell[1759752, 55051, 60, 1, 70, "Subsubsection",
      CellTags->"Momentum"],
    Cell[1759815, 55054, 259, 5, 70, "Text",
      CellTags->"Momentum"],
    Cell[1760077, 55061, 573, 24, 70, "Text",
      CellTags->"Momentum"],
    Cell[1760687, 55090, 57, 1, 70, "Subsubsection",
      CellTags->"Momentum"],
    Cell[1760747, 55093, 76, 1, 70, "Text",
      CellTags->"Momentum"],
    Cell[1760848, 55098, 138, 3, 70, "Input",
      CellTags->"Momentum"],
    Cell[1761113, 55108, 139, 4, 70, "Text",
      CellTags->"Momentum"],
    Cell[1761277, 55116, 165, 4, 70, "Input",
      CellTags->"Momentum"],
    Cell[1761569, 55127, 87, 1, 70, "Text",
      CellTags->"Momentum"],
    Cell[1761681, 55132, 206, 5, 70, "Input",
      CellTags->"Momentum"],
    Cell[1762083, 55147, 190, 5, 70, "Input",
      CellTags->"Momentum"],
    Cell[1762444, 55162, 139, 3, 70, "Input",
      CellTags->"Momentum"],
    Cell[1762774, 55175, 313, 8, 70, "Input",
      CellTags->"Momentum"],
    Cell[1763352, 55196, 139, 3, 70, "Input",
      CellTags->"Momentum"],
    Cell[1763784, 55212, 182, 5, 70, "Input",
      CellTags->"Momentum"],
    Cell[1764201, 55228, 188, 5, 70, "Input",
      CellTags->"Momentum"],
    Cell[1764585, 55243, 263, 7, 70, "Input",
      CellTags->"Momentum"],
    Cell[1765022, 55258, 164, 4, 70, "Input",
      CellTags->"Momentum"]},
  "MT"->{
    Cell[1765235, 55268, 42, 1, 70, "ObjectName",
      CellTags->"MT"],
    Cell[1765302, 55273, 54, 1, 70, "Subsubsection",
      CellTags->"MT"],
    Cell[1765359, 55276, 195, 7, 70, "Text",
      CellTags->"MT"],
    Cell[1765557, 55285, 657, 29, 70, "Text",
      CellTags->"MT"],
    Cell[1766251, 55319, 51, 1, 70, "Subsubsection",
      CellTags->"MT"],
    Cell[1766327, 55324, 166, 4, 70, "Input",
      CellTags->"MT"],
    Cell[1766728, 55340, 317, 8, 70, "Input",
      CellTags->"MT"],
    Cell[1767194, 55357, 194, 5, 70, "Input",
      CellTags->"MT"],
    Cell[1767578, 55372, 239, 7, 70, "Input",
      CellTags->"MT"],
    Cell[1768099, 55391, 279, 8, 70, "Input",
      CellTags->"MT"]},
  "MTD"->{
    Cell[1768592, 55411, 44, 1, 70, "ObjectName",
      CellTags->"MTD"],
    Cell[1768661, 55416, 55, 1, 70, "Subsubsection",
      CellTags->"MTD"],
    Cell[1768719, 55419, 197, 7, 70, "Text",
      CellTags->"MTD"],
    Cell[1768919, 55428, 655, 29, 70, "Text",
      CellTags->"MTD"],
    Cell[1769611, 55462, 52, 1, 70, "Subsubsection",
      CellTags->"MTD"],
    Cell[1769688, 55467, 168, 4, 70, "Input",
      CellTags->"MTD"],
    Cell[1770091, 55483, 320, 8, 70, "Input",
      CellTags->"MTD"],
    Cell[1770560, 55500, 216, 6, 70, "Input",
      CellTags->"MTD"],
    Cell[1770980, 55516, 254, 7, 70, "Input",
      CellTags->"MTD"],
    Cell[1771591, 55537, 289, 8, 70, "Input",
      CellTags->"MTD"]},
  "Nielsen"->{
    Cell[1772103, 55557, 52, 1, 70, "ObjectName",
      CellTags->"Nielsen"],
    Cell[1772180, 55562, 59, 1, 70, "Subsubsection",
      CellTags->"Nielsen"],
    Cell[1772242, 55565, 87, 1, 70, "Text",
      CellTags->"Nielsen"],
    Cell[1772354, 55570, 142, 3, 70, "Input",
      CellTags->"Nielsen"],
    Cell[1772702, 55583, 212, 9, 70, "Text",
      CellTags->"Nielsen"],
    Cell[1772951, 55597, 56, 1, 70, "Subsubsection",
      CellTags->"Nielsen"],
    Cell[1773032, 55602, 173, 4, 70, "Input",
      CellTags->"Nielsen"],
    Cell[1773549, 55621, 177, 4, 70, "Text",
      CellTags->"Nielsen"],
    Cell[1773751, 55629, 209, 5, 70, "Input",
      CellTags->"Nielsen"],
    Cell[1774106, 55641, 72, 1, 70, "Text",
      CellTags->"Nielsen"],
    Cell[1774203, 55646, 557, 14, 70, "Input",
      CellTags->"Nielsen"],
    Cell[1775565, 55689, 227, 5, 70, "Input",
      CellTags->"Nielsen"],
    Cell[1776652, 55724, 227, 5, 70, "Input",
      CellTags->"Nielsen"],
    Cell[1777961, 55765, 227, 5, 70, "Input",
      CellTags->"Nielsen"]},
  "NTerms"->{
    Cell[1778424, 55784, 50, 1, 70, "ObjectName",
      CellTags->"NTerms"],
    Cell[1778499, 55789, 58, 1, 70, "Subsubsection",
      CellTags->"NTerms"],
    Cell[1778560, 55792, 150, 4, 70, "Text",
      CellTags->"NTerms"],
    Cell[1778747, 55801, 55, 1, 70, "Subsubsection",
      CellTags->"NTerms"],
    Cell[1778827, 55806, 161, 4, 70, "Input",
      CellTags->"NTerms"],
    Cell[1779137, 55819, 171, 4, 70, "Input",
      CellTags->"NTerms"],
    Cell[1779457, 55832, 134, 3, 70, "Input",
      CellTags->"NTerms"],
    Cell[1779740, 55844, 134, 3, 70, "Input",
      CellTags->"NTerms"]},
  "OneLoop"->{
    Cell[1780047, 55858, 52, 1, 70, "ObjectName",
      CellTags->"OneLoop"],
    Cell[1780102, 55861, 673, 17, 70, "Text",
      CellTags->"OneLoop"],
    Cell[1780778, 55880, 75, 1, 70, "Text",
      CellTags->"OneLoop"],
    Cell[1780856, 55883, 1073, 27, 70, "Text",
      CellTags->"OneLoop"],
    Cell[1781954, 55914, 59, 1, 70, "Subsubsection",
      CellTags->"OneLoop"],
    Cell[1782016, 55917, 283, 6, 70, "Text",
      CellTags->"OneLoop"],
    Cell[1782302, 55925, 353, 6, 70, "Text",
      CellTags->"OneLoop"],
    Cell[1782680, 55935, 142, 3, 70, "Input",
      CellTags->"OneLoop"],
    Cell[1784232, 55971, 731, 34, 70, "Text",
      CellTags->"OneLoop"],
    Cell[1785000, 56010, 56, 1, 70, "Subsubsection",
      CellTags->"OneLoop"],
    Cell[1785081, 56015, 342, 10, 70, "Input",
      CellTags->"OneLoop"],
    Cell[1785853, 56043, 163, 4, 70, "Input",
      CellTags->"OneLoop"],
    Cell[1786417, 56062, 440, 11, 70, "Input",
      CellTags->"OneLoop"],
    Cell[1786860, 56075, 733, 20, 70, "Text",
      CellTags->"OneLoop"],
    Cell[1787618, 56099, 1146, 30, 70, "Input",
      CellTags->"OneLoop"],
    Cell[1791840, 56210, 220, 5, 70, "Text",
      CellTags->"OneLoop"],
    Cell[1792085, 56219, 163, 4, 70, "Input",
      CellTags->"OneLoop"],
    Cell[1796114, 56322, 141, 3, 70, "Input",
      CellTags->"OneLoop"],
    Cell[1799212, 56402, 416, 12, 70, "Input",
      CellTags->"OneLoop"],
    Cell[1800919, 56456, 163, 4, 70, "Input",
      CellTags->"OneLoop"],
    Cell[1803843, 56536, 134, 3, 70, "Input",
      CellTags->"OneLoop"]},
  "OneLoopSimplify"->{
    Cell[1804026, 56545, 68, 1, 70, "ObjectName",
      CellTags->"OneLoopSimplify"],
    Cell[1804119, 56550, 67, 1, 70, "Subsubsection",
      CellTags->"OneLoopSimplify"],
    Cell[1804189, 56553, 173, 4, 70, "Text",
      CellTags->"OneLoopSimplify"],
    Cell[1804387, 56561, 158, 3, 70, "Input",
      CellTags->"OneLoopSimplify"],
    Cell[1805384, 56586, 409, 19, 70, "Text",
      CellTags->"OneLoopSimplify"],
    Cell[1805830, 56610, 64, 1, 70, "Subsubsection",
      CellTags->"OneLoopSimplify"],
    Cell[1805919, 56615, 424, 12, 70, "Input",
      CellTags->"OneLoopSimplify"],
    Cell[1807634, 56669, 179, 4, 70, "Input",
      CellTags->"OneLoopSimplify"],
    Cell[1810151, 56742, 246, 6, 70, "Input",
      CellTags->"OneLoopSimplify"],
    Cell[1811414, 56782, 485, 12, 70, "Input",
      CellTags->"OneLoopSimplify"],
    Cell[1813749, 56853, 184, 4, 70, "Input",
      CellTags->"OneLoopSimplify"],
    Cell[1827441, 57215, 312, 9, 70, "Input",
      CellTags->"OneLoopSimplify"],
    Cell[1837181, 57481, 533, 15, 70, "Input",
      CellTags->"OneLoopSimplify"]},
  "OPEDelta"->{
    Cell[1841737, 57609, 54, 1, 70, "ObjectName",
      CellTags->"OPEDelta"],
    Cell[1841816, 57614, 60, 1, 70, "Subsubsection",
      CellTags->"OPEDelta"],
    Cell[1841879, 57617, 141, 4, 70, "Text",
      CellTags->"OPEDelta"],
    Cell[1842023, 57623, 225, 9, 70, "Text",
      CellTags->"OPEDelta"],
    Cell[1842285, 57637, 57, 1, 70, "Subsubsection",
      CellTags->"OPEDelta"],
    Cell[1842367, 57642, 178, 4, 70, "Input",
      CellTags->"OPEDelta"],
    Cell[1842785, 57658, 165, 4, 70, "Input",
      CellTags->"OPEDelta"],
    Cell[1843099, 57671, 173, 4, 70, "Input",
      CellTags->"OPEDelta"]},
  "OPEi"->{
    Cell[1843445, 57686, 82, 1, 70, "ObjectName",
      CellTags->"OPEi"],
    Cell[1843552, 57691, 56, 1, 70, "Subsubsection",
      CellTags->"OPEi"],
    Cell[1843611, 57694, 172, 4, 70, "Text",
      CellTags->"OPEi"],
    Cell[1843820, 57703, 53, 1, 70, "Subsubsection",
      CellTags->"OPEi"],
    Cell[1843898, 57708, 100, 2, 70, "Input",
      CellTags->"OPEi"],
    Cell[1844147, 57719, 304, 7, 70, "Input",
      CellTags->"OPEi"],
    Cell[1844747, 57739, 1365, 40, 70, "Input",
      CellTags->"OPEi"],
    Cell[1846363, 57790, 56, 1, 70, "Text",
      CellTags->"OPEi"],
    Cell[1846444, 57795, 632, 17, 70, "Input",
      CellTags->"OPEi"],
    Cell[1847335, 57824, 662, 19, 70, "Input",
      CellTags->"OPEi"],
    Cell[1848228, 57855, 632, 17, 70, "Input",
      CellTags->"OPEi"]},
  "OPESumExplicit"->{
    Cell[1849143, 57886, 66, 1, 70, "ObjectName",
      CellTags->"OPESumExplicit"],
    Cell[1849234, 57891, 66, 1, 70, "Subsubsection",
      CellTags->"OPESumExplicit"],
    Cell[1849303, 57894, 86, 1, 70, "Text",
      CellTags->"OPESumExplicit"],
    Cell[1849392, 57897, 330, 14, 70, "Text",
      CellTags->"OPESumExplicit"],
    Cell[1849759, 57916, 63, 1, 70, "Subsubsection",
      CellTags->"OPESumExplicit"],
    Cell[1849847, 57921, 482, 13, 70, "Input",
      CellTags->"OPESumExplicit"],
    Cell[1850823, 57954, 151, 3, 70, "Input",
      CellTags->"OPESumExplicit"],
    Cell[1851506, 57979, 686, 18, 70, "Input",
      CellTags->"OPESumExplicit"],
    Cell[1853108, 58029, 151, 3, 70, "Input",
      CellTags->"OPESumExplicit"],
    Cell[1856091, 58120, 194, 5, 70, "Input",
      CellTags->"OPESumExplicit"]},
  "OPESum"->{
    Cell[1856334, 58131, 50, 1, 70, "ObjectName",
      CellTags->"OPESum"],
    Cell[1856409, 58136, 58, 1, 70, "Subsubsection",
      CellTags->"OPESum"],
    Cell[1856470, 58139, 128, 4, 70, "Text",
      CellTags->"OPESum"],
    Cell[1856601, 58145, 346, 14, 70, "Text",
      CellTags->"OPESum"],
    Cell[1856984, 58164, 55, 1, 70, "Subsubsection",
      CellTags->"OPESum"],
    Cell[1857064, 58169, 571, 15, 70, "Input",
      CellTags->"OPESum"],
    Cell[1859014, 58226, 143, 3, 70, "Input",
      CellTags->"OPESum"],
    Cell[1862044, 58313, 678, 18, 70, "Input",
      CellTags->"OPESum"],
    Cell[1863638, 58363, 143, 3, 70, "Input",
      CellTags->"OPESum"],
    Cell[1866613, 58454, 186, 5, 70, "Input",
      CellTags->"OPESum"]},
  "OPESumSimplify"->{
    Cell[1866848, 58465, 66, 1, 70, "ObjectName",
      CellTags->"OPESumSimplify"],
    Cell[1866939, 58470, 66, 1, 70, "Subsubsection",
      CellTags->"OPESumSimplify"],
    Cell[1867008, 58473, 93, 1, 70, "Text",
      CellTags->"OPESumSimplify"],
    Cell[1867104, 58476, 330, 14, 70, "Text",
      CellTags->"OPESumSimplify"],
    Cell[1867471, 58495, 63, 1, 70, "Subsubsection",
      CellTags->"OPESumSimplify"],
    Cell[1867559, 58500, 168, 4, 70, "Input",
      CellTags->"OPESumSimplify"],
    Cell[1869151, 58547, 114, 2, 70, "Input",
      CellTags->"OPESumSimplify"],
    Cell[1870926, 58595, 328, 8, 70, "Input",
      CellTags->"OPESumSimplify"],
    Cell[1871624, 58620, 535, 14, 70, "Input",
      CellTags->"OPESumSimplify"],
    Cell[1872917, 58662, 144, 3, 70, "Input",
      CellTags->"OPESumSimplify"]},
  "Pair"->{
    Cell[1873585, 58686, 46, 1, 70, "ObjectName",
      CellTags->"Pair"],
    Cell[1873656, 58691, 56, 1, 70, "Subsubsection",
      CellTags->"Pair"],
    Cell[1873715, 58694, 512, 11, 70, "Text",
      CellTags->"Pair"],
    Cell[1874230, 58707, 1082, 49, 70, "Text",
      CellTags->"Pair"],
    Cell[1875349, 58761, 53, 1, 70, "Subsubsection",
      CellTags->"Pair"],
    Cell[1875405, 58764, 85, 1, 70, "Text",
      CellTags->"Pair"],
    Cell[1875515, 58769, 260, 6, 70, "Input",
      CellTags->"Pair"],
    Cell[1875988, 58785, 74, 1, 70, "Text",
      CellTags->"Pair"],
    Cell[1876087, 58790, 322, 8, 70, "Input",
      CellTags->"Pair"],
    Cell[1876849, 58817, 250, 6, 70, "Input",
      CellTags->"Pair"],
    Cell[1877428, 58839, 239, 6, 70, "Input",
      CellTags->"Pair"],
    Cell[1877976, 58859, 239, 6, 70, "Input",
      CellTags->"Pair"],
    Cell[1878439, 58877, 270, 7, 70, "Input",
      CellTags->"Pair"],
    Cell[1879098, 58901, 272, 7, 70, "Input",
      CellTags->"Pair"],
    Cell[1879594, 58920, 272, 7, 70, "Input",
      CellTags->"Pair"],
    Cell[1880090, 58939, 376, 10, 70, "Input",
      CellTags->"Pair"],
    Cell[1880615, 58958, 328, 8, 70, "Input",
      CellTags->"Pair"],
    Cell[1881370, 58984, 460, 12, 70, "Input",
      CellTags->"Pair"]},
  "PartialD"->{
    Cell[1882003, 59007, 54, 1, 70, "ObjectName",
      CellTags->"PartialD"],
    Cell[1882082, 59012, 60, 1, 70, "Subsubsection",
      CellTags->"PartialD"],
    Cell[1882145, 59015, 917, 31, 70, "Text",
      CellTags->"PartialD"],
    Cell[1883065, 59048, 492, 19, 70, "Text",
      CellTags->"PartialD"],
    Cell[1883594, 59072, 66, 1, 70, "Subsubsection",
      CellTags->"PartialD"],
    Cell[1883685, 59077, 280, 7, 70, "Input",
      CellTags->"PartialD"],
    Cell[1884363, 59101, 144, 3, 70, "Input",
      CellTags->"PartialD"],
    Cell[1884905, 59121, 142, 3, 70, "Input",
      CellTags->"PartialD"]},
  "PaVe"->{
    Cell[1885443, 59140, 46, 1, 70, "ObjectName",
      CellTags->"PaVe"],
    Cell[1885514, 59145, 56, 1, 70, "Subsubsection",
      CellTags->"PaVe"],
    Cell[1885573, 59148, 431, 8, 70, "Text",
      CellTags->"PaVe"],
    Cell[1886007, 59158, 278, 8, 70, "Text",
      CellTags->"PaVe"],
    Cell[1886288, 59168, 194, 9, 70, "Text",
      CellTags->"PaVe"],
    Cell[1886519, 59182, 53, 1, 70, "Subsubsection",
      CellTags->"PaVe"],
    Cell[1886575, 59185, 79, 1, 70, "Text",
      CellTags->"PaVe"],
    Cell[1886679, 59190, 369, 10, 70, "Input",
      CellTags->"PaVe"],
    Cell[1887764, 59219, 333, 9, 70, "Input",
      CellTags->"PaVe"]},
  "PaVeOrder"->{
    Cell[1890714, 59297, 56, 1, 70, "ObjectName",
      CellTags->"PaVeOrder"],
    Cell[1890795, 59302, 61, 1, 70, "Subsubsection",
      CellTags->"PaVeOrder"],
    Cell[1890859, 59305, 356, 7, 70, "Text",
      CellTags->"PaVeOrder"],
    Cell[1891218, 59314, 199, 9, 70, "Text",
      CellTags->"PaVeOrder"],
    Cell[1891454, 59328, 58, 1, 70, "Subsubsection",
      CellTags->"PaVeOrder"],
    Cell[1891537, 59333, 491, 12, 70, "Input",
      CellTags->"PaVeOrder"],
    Cell[1892846, 59368, 491, 12, 70, "Input",
      CellTags->"PaVeOrder"],
    Cell[1894155, 59403, 851, 20, 70, "Input",
      CellTags->"PaVeOrder"]},
  "PaVeReduce"->{
    Cell[1896505, 59460, 58, 1, 70, "ObjectName",
      CellTags->"PaVeReduce"],
    Cell[1896588, 59465, 62, 1, 70, "Subsubsection",
      CellTags->"PaVeReduce"],
    Cell[1896653, 59468, 168, 4, 70, "Text",
      CellTags->"PaVeReduce"],
    Cell[1896846, 59476, 148, 3, 70, "Input",
      CellTags->"PaVeReduce"],
    Cell[1897539, 59498, 134, 3, 70, "Input",
      CellTags->"PaVeReduce"],
    Cell[1897972, 59510, 302, 14, 70, "Text",
      CellTags->"PaVeReduce"],
    Cell[1898311, 59529, 59, 1, 70, "Subsubsection",
      CellTags->"PaVeReduce"],
    Cell[1898395, 59534, 643, 16, 70, "Input",
      CellTags->"PaVeReduce"],
    Cell[1903136, 59663, 134, 3, 70, "Input",
      CellTags->"PaVeReduce"],
    Cell[1903452, 59676, 135, 3, 70, "Input",
      CellTags->"PaVeReduce"],
    Cell[1903769, 59689, 607, 15, 70, "Input",
      CellTags->"PaVeReduce"],
    Cell[1904926, 59724, 487, 12, 70, "Input",
      CellTags->"PaVeReduce"],
    Cell[1906030, 59756, 255, 7, 70, "Input",
      CellTags->"PaVeReduce"],
    Cell[1906288, 59765, 199, 5, 70, "Input",
      CellTags->"PaVeReduce"],
    Cell[1906512, 59774, 790, 19, 70, "Input",
      CellTags->"PaVeReduce"],
    Cell[1919001, 60068, 321, 8, 70, "Input",
      CellTags->"PaVeReduce"],
    Cell[1919347, 60080, 459, 11, 70, "Input",
      CellTags->"PaVeReduce"],
    Cell[1924030, 60174, 299, 7, 70, "Input",
      CellTags->"PaVeReduce"]},
  "PlusDistribution"->{
    Cell[1924378, 60187, 70, 1, 70, "ObjectName",
      CellTags->"PlusDistribution"],
    Cell[1924473, 60192, 68, 1, 70, "Subsubsection",
      CellTags->"PlusDistribution"],
    Cell[1924544, 60195, 148, 4, 70, "Text",
      CellTags->"PlusDistribution"],
    Cell[1924695, 60201, 206, 9, 70, "Text",
      CellTags->"PlusDistribution"],
    Cell[1924938, 60215, 65, 1, 70, "Subsubsection",
      CellTags->"PlusDistribution"],
    Cell[1925028, 60220, 241, 6, 70, "Input",
      CellTags->"PlusDistribution"],
    Cell[1925537, 60240, 308, 8, 70, "Input",
      CellTags->"PlusDistribution"],
    Cell[1926188, 60264, 398, 10, 70, "Input",
      CellTags->"PlusDistribution"],
    Cell[1926735, 60283, 473, 12, 70, "Input",
      CellTags->"PlusDistribution"],
    Cell[1927357, 60304, 510, 13, 70, "Input",
      CellTags->"PlusDistribution"],
    Cell[1928016, 60326, 376, 10, 70, "Input",
      CellTags->"PlusDistribution"]},
  "Polarization"->{
    Cell[1928899, 60358, 62, 1, 70, "ObjectName",
      CellTags->"Polarization"],
    Cell[1928986, 60363, 64, 1, 70, "Subsubsection",
      CellTags->"Polarization"],
    Cell[1929053, 60366, 770, 12, 70, "Text",
      CellTags->"Polarization"],
    Cell[1929826, 60380, 226, 9, 70, "Text",
      CellTags->"Polarization"],
    Cell[1930089, 60394, 61, 1, 70, "Subsubsection",
      CellTags->"Polarization"],
    Cell[1930175, 60399, 146, 3, 70, "Input",
      CellTags->"Polarization"],
    Cell[1930804, 60421, 192, 5, 70, "Input",
      CellTags->"Polarization"],
    Cell[1931208, 60436, 196, 5, 70, "Input",
      CellTags->"Polarization"],
    Cell[1932093, 60466, 237, 6, 70, "Input",
      CellTags->"Polarization"],
    Cell[1932566, 60483, 187, 4, 70, "Input",
      CellTags->"Polarization"],
    Cell[1933445, 60510, 235, 6, 70, "Input",
      CellTags->"Polarization"],
    Cell[1933980, 60529, 364, 9, 70, "Input",
      CellTags->"Polarization"]},
  "PolarizationSum"->{
    Cell[1934517, 60549, 68, 1, 70, "ObjectName",
      CellTags->"PolarizationSum"],
    Cell[1934610, 60554, 67, 1, 70, "Subsubsection",
      CellTags->"PolarizationSum"],
    Cell[1934680, 60557, 278, 5, 70, "Text",
      CellTags->"PolarizationSum"],
    Cell[1934983, 60566, 158, 3, 70, "Input",
      CellTags->"PolarizationSum"],
    Cell[1935345, 60579, 211, 9, 70, "Text",
      CellTags->"PolarizationSum"],
    Cell[1935593, 60593, 64, 1, 70, "Subsubsection",
      CellTags->"PolarizationSum"],
    Cell[1935682, 60598, 187, 4, 70, "Input",
      CellTags->"PolarizationSum"],
    Cell[1936125, 60615, 197, 4, 70, "Input",
      CellTags->"PolarizationSum"],
    Cell[1937853, 60669, 207, 4, 70, "Input",
      CellTags->"PolarizationSum"],
    Cell[1941987, 60789, 296, 7, 70, "Input",
      CellTags->"PolarizationSum"]},
  "PolarizationVector"->{
    Cell[1952333, 61073, 74, 1, 70, "ObjectName",
      CellTags->"PolarizationVector"],
    Cell[1952432, 61078, 70, 1, 70, "Subsubsection",
      CellTags->"PolarizationVector"],
    Cell[1952505, 61081, 104, 1, 70, "Text",
      CellTags->"PolarizationVector"],
    Cell[1952612, 61084, 441, 18, 70, "Text",
      CellTags->"PolarizationVector"],
    Cell[1953090, 61107, 67, 1, 70, "Subsubsection",
      CellTags->"PolarizationVector"],
    Cell[1953182, 61112, 189, 4, 70, "Input",
      CellTags->"PolarizationVector"],
    Cell[1953842, 61135, 231, 5, 70, "Input",
      CellTags->"PolarizationVector"],
    Cell[1954532, 61157, 265, 9, 70, "Text",
      CellTags->"PolarizationVector"],
    Cell[1954822, 61170, 227, 5, 70, "Input",
      CellTags->"PolarizationVector"],
    Cell[1955405, 61188, 547, 18, 70, "Text",
      CellTags->"PolarizationVector"],
    Cell[1955977, 61210, 338, 8, 70, "Input",
      CellTags->"PolarizationVector"],
    Cell[1957125, 61247, 149, 3, 70, "Input",
      CellTags->"PolarizationVector"],
    Cell[1957423, 61259, 371, 9, 70, "Input",
      CellTags->"PolarizationVector"],
    Cell[1958649, 61298, 149, 3, 70, "Input",
      CellTags->"PolarizationVector"],
    Cell[1959746, 61331, 1987, 53, 70, "Text",
      CellTags->"PolarizationVector"],
    Cell[1961758, 61388, 371, 9, 70, "Input",
      CellTags->"PolarizationVector"],
    Cell[1962724, 61419, 149, 3, 70, "Input",
      CellTags->"PolarizationVector"],
    Cell[1963821, 61452, 185, 4, 70, "Input",
      CellTags->"PolarizationVector"]},
  "PowerSimplify"->{
    Cell[1964055, 61462, 64, 1, 70, "ObjectName",
      CellTags->"PowerSimplify"],
    Cell[1964144, 61467, 65, 1, 70, "Subsubsection",
      CellTags->"PowerSimplify"],
    Cell[1964212, 61470, 409, 7, 70, "Text",
      CellTags->"PowerSimplify"],
    Cell[1964624, 61479, 215, 11, 70, "Text",
      CellTags->"PowerSimplify"],
    Cell[1964876, 61495, 62, 1, 70, "Subsubsection",
      CellTags->"PowerSimplify"],
    Cell[1964963, 61500, 288, 8, 70, "Input",
      CellTags->"PowerSimplify"],
    Cell[1965400, 61517, 293, 8, 70, "Input",
      CellTags->"PowerSimplify"],
    Cell[1965925, 61537, 293, 8, 70, "Input",
      CellTags->"PowerSimplify"],
    Cell[1966450, 61557, 233, 6, 70, "Input",
      CellTags->"PowerSimplify"]},
  "PropagatorDenominatorExplicit"->{
    Cell[1966939, 61577, 96, 1, 70, "ObjectName",
      CellTags->"PropagatorDenominatorExplicit"],
    Cell[1967060, 61582, 81, 1, 70, "Subsubsection",
      CellTags->"PropagatorDenominatorExplicit"],
    Cell[1967144, 61585, 244, 5, 70, "Text",
      CellTags->"PropagatorDenominatorExplicit"],
    Cell[1967391, 61592, 402, 14, 70, "Text",
      CellTags->"PropagatorDenominatorExplicit"],
    Cell[1967830, 61611, 78, 1, 70, "Subsubsection",
      CellTags->"PropagatorDenominatorExplicit"],
    Cell[1967933, 61616, 383, 11, 70, "Input",
      CellTags->"PropagatorDenominatorExplicit"],
    Cell[1968762, 61646, 217, 5, 70, "Input",
      CellTags->"PropagatorDenominatorExplicit"],
    Cell[1970187, 61691, 159, 3, 70, "Input",
      CellTags->"PropagatorDenominatorExplicit"]},
  "PropagatorDenominator"->{
    Cell[1971083, 61721, 80, 1, 70, "ObjectName",
      CellTags->"PropagatorDenominator"],
    Cell[1971188, 61726, 73, 1, 70, "Subsubsection",
      CellTags->"PropagatorDenominator"],
    Cell[1971264, 61729, 569, 15, 70, "Text",
      CellTags->"PropagatorDenominator"],
    Cell[1971836, 61746, 418, 14, 70, "Text",
      CellTags->"PropagatorDenominator"],
    Cell[1972291, 61765, 70, 1, 70, "Subsubsection",
      CellTags->"PropagatorDenominator"],
    Cell[1972386, 61770, 215, 5, 70, "Input",
      CellTags->"PropagatorDenominator"],
    Cell[1972868, 61788, 164, 3, 70, "Input",
      CellTags->"PropagatorDenominator"],
    Cell[1973236, 61802, 247, 6, 70, "Input",
      CellTags->"PropagatorDenominator"],
    Cell[1973750, 61821, 190, 4, 70, "Input",
      CellTags->"PropagatorDenominator"],
    Cell[1974221, 61837, 231, 5, 70, "Input",
      CellTags->"PropagatorDenominator"],
    Cell[1974733, 61854, 173, 3, 70, "Input",
      CellTags->"PropagatorDenominator"],
    Cell[1975228, 61872, 155, 3, 70, "Input",
      CellTags->"PropagatorDenominator"],
    Cell[1975757, 61889, 149, 3, 70, "Input",
      CellTags->"PropagatorDenominator"]},
  "QuantumField"->{
    Cell[1975955, 61898, 62, 1, 70, "ObjectName",
      CellTags->"QuantumField"],
    Cell[1976042, 61903, 64, 1, 70, "Subsubsection",
      CellTags->"QuantumField"],
    Cell[1976109, 61906, 357, 7, 70, "Text",
      CellTags->"QuantumField"],
    Cell[1976469, 61915, 454, 19, 70, "Text",
      CellTags->"QuantumField"],
    Cell[1976960, 61939, 61, 1, 70, "Subsubsection",
      CellTags->"QuantumField"],
    Cell[1977024, 61942, 72, 1, 70, "Text",
      CellTags->"QuantumField"],
    Cell[1977121, 61947, 146, 3, 70, "Input",
      CellTags->"QuantumField"],
    Cell[1977416, 61959, 159, 3, 70, "Input",
      CellTags->"QuantumField"],
    Cell[1977756, 61972, 155, 3, 70, "Input",
      CellTags->"QuantumField"],
    Cell[1978043, 61982, 81, 1, 70, "Text",
      CellTags->"QuantumField"],
    Cell[1978149, 61987, 206, 5, 70, "Input",
      CellTags->"QuantumField"],
    Cell[1978512, 62000, 95, 1, 70, "Text",
      CellTags->"QuantumField"],
    Cell[1978632, 62005, 254, 6, 70, "Input",
      CellTags->"QuantumField"],
    Cell[1979318, 62031, 142, 3, 70, "Input",
      CellTags->"QuantumField"],
    Cell[1979747, 62044, 409, 14, 70, "Text",
      CellTags->"QuantumField"],
    Cell[1980181, 62062, 248, 6, 70, "Input",
      CellTags->"QuantumField"],
    Cell[1980751, 62082, 186, 4, 70, "Text",
      CellTags->"QuantumField"],
    Cell[1980962, 62090, 293, 7, 70, "Input",
      CellTags->"QuantumField"],
    Cell[1981532, 62107, 89, 1, 70, "Text",
      CellTags->"QuantumField"],
    Cell[1981646, 62112, 261, 6, 70, "Input",
      CellTags->"QuantumField"],
    Cell[1982380, 62138, 228, 6, 70, "Input",
      CellTags->"QuantumField"],
    Cell[1982939, 62159, 306, 7, 70, "Input",
      CellTags->"QuantumField"],
    Cell[1983781, 62188, 349, 9, 70, "Input",
      CellTags->"QuantumField"],
    Cell[1984674, 62219, 273, 6, 70, "Input",
      CellTags->"QuantumField"]},
  "QuarkField"->{
    Cell[1985123, 62236, 58, 1, 70, "ObjectName",
      CellTags->"QuarkField"],
    Cell[1985206, 62241, 62, 1, 70, "Subsubsection",
      CellTags->"QuarkField"],
    Cell[1985271, 62244, 190, 4, 70, "Text",
      CellTags->"QuarkField"],
    Cell[1985464, 62250, 344, 14, 70, "Text",
      CellTags->"QuarkField"],
    Cell[1985845, 62269, 59, 1, 70, "Subsubsection",
      CellTags->"QuarkField"],
    Cell[1985929, 62274, 112, 2, 70, "Input",
      CellTags->"QuarkField"]},
  "QuarkGluonVertex"->{
    Cell[1986219, 62287, 70, 1, 70, "ObjectName",
      CellTags->"QuarkGluonVertex"],
    Cell[1986314, 62292, 68, 1, 70, "Subsubsection",
      CellTags->"QuarkGluonVertex"],
    Cell[1986385, 62295, 233, 7, 70, "Text",
      CellTags->"QuarkGluonVertex"],
    Cell[1986643, 62306, 160, 3, 70, "Input",
      CellTags->"QuarkGluonVertex"],
    Cell[1987306, 62325, 209, 9, 70, "Text",
      CellTags->"QuarkGluonVertex"],
    Cell[1987552, 62339, 65, 1, 70, "Subsubsection",
      CellTags->"QuarkGluonVertex"],
    Cell[1987642, 62344, 185, 4, 70, "Input",
      CellTags->"QuarkGluonVertex"],
    Cell[1988383, 62370, 245, 5, 70, "Input",
      CellTags->"QuarkGluonVertex"],
    Cell[1989530, 62406, 245, 5, 70, "Input",
      CellTags->"QuarkGluonVertex"],
    Cell[1990540, 62438, 245, 5, 70, "Input",
      CellTags->"QuarkGluonVertex"],
    Cell[1991652, 62473, 373, 9, 70, "Input",
      CellTags->"QuarkGluonVertex"],
    Cell[1995047, 62564, 374, 9, 70, "Input",
      CellTags->"QuarkGluonVertex"]},
  "QuarkPropagator"->{
    Cell[1996001, 62597, 68, 1, 70, "ObjectName",
      CellTags->"QuarkPropagator"],
    Cell[1996094, 62602, 67, 1, 70, "Subsubsection",
      CellTags->"QuarkPropagator"],
    Cell[1996164, 62605, 175, 4, 70, "Text",
      CellTags->"QuarkPropagator"],
    Cell[1996364, 62613, 158, 3, 70, "Input",
      CellTags->"QuarkPropagator"],
    Cell[1997075, 62633, 364, 14, 70, "Text",
      CellTags->"QuarkPropagator"],
    Cell[1997476, 62652, 64, 1, 70, "Subsubsection",
      CellTags->"QuarkPropagator"],
    Cell[1997565, 62657, 152, 3, 70, "Input",
      CellTags->"QuarkPropagator"],
    Cell[1998170, 62678, 208, 5, 70, "Input",
      CellTags->"QuarkPropagator"],
    Cell[1998982, 62705, 189, 4, 70, "Input",
      CellTags->"QuarkPropagator"]},
  "RightPartialD"->{
    Cell[1999648, 62729, 64, 1, 70, "ObjectName",
      CellTags->"RightPartialD"],
    Cell[1999737, 62734, 65, 1, 70, "Subsubsection",
      CellTags->"RightPartialD"],
    Cell[1999805, 62737, 275, 10, 70, "Text",
      CellTags->"RightPartialD"],
    Cell[2000083, 62749, 467, 19, 70, "Text",
      CellTags->"RightPartialD"],
    Cell[2000587, 62773, 62, 1, 70, "Subsubsection",
      CellTags->"RightPartialD"],
    Cell[2000674, 62778, 152, 3, 70, "Input",
      CellTags->"RightPartialD"],
    Cell[2001154, 62796, 302, 7, 70, "Input",
      CellTags->"RightPartialD"],
    Cell[2001855, 62820, 149, 3, 70, "Input",
      CellTags->"RightPartialD"],
    Cell[2002477, 62843, 143, 3, 70, "Input",
      CellTags->"RightPartialD"],
    Cell[2002971, 62859, 198, 5, 70, "Input",
      CellTags->"RightPartialD"]},
  "RussianTrick"->{
    Cell[2003414, 62876, 62, 1, 70, "ObjectName",
      CellTags->"RussianTrick"],
    Cell[2003501, 62881, 64, 1, 70, "Subsubsection",
      CellTags->"RussianTrick"],
    Cell[2003568, 62884, 319, 6, 70, "Text",
      CellTags->"RussianTrick"],
    Cell[2003890, 62892, 91, 1, 70, "Text",
      CellTags->"RussianTrick"],
    Cell[2003984, 62895, 349, 14, 70, "Text",
      CellTags->"RussianTrick"],
    Cell[2004370, 62914, 61, 1, 70, "Subsubsection",
      CellTags->"RussianTrick"],
    Cell[2004456, 62919, 469, 13, 70, "Input",
      CellTags->"RussianTrick"],
    Cell[2005584, 62959, 136, 3, 70, "Input",
      CellTags->"RussianTrick"],
    Cell[2007344, 63014, 209, 5, 70, "Input",
      CellTags->"RussianTrick"],
    Cell[2016744, 63270, 140, 3, 70, "Input",
      CellTags->"RussianTrick"],
    Cell[2020524, 63390, 167, 4, 70, "Input",
      CellTags->"RussianTrick"],
    Cell[2024840, 63510, 139, 3, 70, "Input",
      CellTags->"RussianTrick"]},
  "ScalarProduct"->{
    Cell[2025028, 63519, 64, 1, 70, "ObjectName",
      CellTags->"ScalarProduct"],
    Cell[2025117, 63524, 65, 1, 70, "Subsubsection",
      CellTags->"ScalarProduct"],
    Cell[2025185, 63527, 875, 21, 70, "Text",
      CellTags->"ScalarProduct"],
    Cell[2026063, 63550, 799, 33, 70, "Text",
      CellTags->"ScalarProduct"],
    Cell[2026899, 63588, 62, 1, 70, "Subsubsection",
      CellTags->"ScalarProduct"],
    Cell[2026986, 63593, 175, 4, 70, "Input",
      CellTags->"ScalarProduct"],
    Cell[2027470, 63611, 228, 6, 70, "Input",
      CellTags->"ScalarProduct"],
    Cell[2028171, 63636, 175, 4, 70, "Input",
      CellTags->"ScalarProduct"],
    Cell[2028570, 63652, 148, 3, 70, "Input",
      CellTags->"ScalarProduct"],
    Cell[2028942, 63667, 216, 5, 70, "Input",
      CellTags->"ScalarProduct"],
    Cell[2029432, 63684, 278, 7, 70, "Input",
      CellTags->"ScalarProduct"],
    Cell[2030046, 63705, 301, 8, 70, "Input",
      CellTags->"ScalarProduct"],
    Cell[2030521, 63723, 358, 9, 70, "Input",
      CellTags->"ScalarProduct"],
    Cell[2032094, 63772, 343, 9, 70, "Input",
      CellTags->"ScalarProduct"],
    Cell[2033630, 63819, 124, 2, 70, "Input",
      CellTags->"ScalarProduct"]},
  "ScalarProductCancel"->{
    Cell[2033803, 63827, 76, 1, 70, "ObjectName",
      CellTags->"ScalarProductCancel"],
    Cell[2033904, 63832, 71, 1, 70, "Subsubsection",
      CellTags->"ScalarProductCancel"],
    Cell[2033978, 63835, 187, 4, 70, "Text",
      CellTags->"ScalarProductCancel"],
    Cell[2034190, 63843, 114, 2, 70, "Input",
      CellTags->"ScalarProductCancel"],
    Cell[2034471, 63854, 162, 3, 70, "Input",
      CellTags->"ScalarProductCancel"],
    Cell[2035095, 63873, 134, 3, 70, "Input",
      CellTags->"ScalarProductCancel"],
    Cell[2035400, 63886, 68, 1, 70, "Subsubsection",
      CellTags->"ScalarProductCancel"],
    Cell[2035471, 63889, 257, 9, 70, "Text",
      CellTags->"ScalarProductCancel"],
    Cell[2035753, 63902, 541, 15, 70, "Input",
      CellTags->"ScalarProductCancel"],
    Cell[2036910, 63941, 188, 4, 70, "Input",
      CellTags->"ScalarProductCancel"],
    Cell[2038229, 63984, 194, 4, 70, "Input",
      CellTags->"ScalarProductCancel"],
    Cell[2039344, 64021, 217, 5, 70, "Input",
      CellTags->"ScalarProductCancel"],
    Cell[2040482, 64059, 714, 19, 70, "Input",
      CellTags->"ScalarProductCancel"],
    Cell[2043281, 64144, 234, 5, 70, "Input",
      CellTags->"ScalarProductCancel"],
    Cell[2050066, 64329, 199, 5, 70, "Input",
      CellTags->"ScalarProductCancel"]},
  "SD"->{
    Cell[2050314, 64340, 42, 1, 70, "ObjectName",
      CellTags->"SD"],
    Cell[2050381, 64345, 54, 1, 70, "Subsubsection",
      CellTags->"SD"],
    Cell[2050438, 64348, 218, 5, 70, "Text",
      CellTags->"SD"],
    Cell[2050659, 64355, 186, 9, 70, "Text",
      CellTags->"SD"],
    Cell[2050882, 64369, 51, 1, 70, "Subsubsection",
      CellTags->"SD"],
    Cell[2050958, 64374, 153, 4, 70, "Input",
      CellTags->"SD"],
    Cell[2051331, 64389, 162, 4, 70, "Input",
      CellTags->"SD"],
    Cell[2051771, 64405, 162, 4, 70, "Input",
      CellTags->"SD"]},
  "SelectFree"->{
    Cell[2052147, 64421, 58, 1, 70, "ObjectName",
      CellTags->"SelectFree"],
    Cell[2052230, 64426, 62, 1, 70, "Subsubsection",
      CellTags->"SelectFree"],
    Cell[2052295, 64429, 256, 5, 70, "Text",
      CellTags->"SelectFree"],
    Cell[2052554, 64436, 78, 1, 70, "Text",
      CellTags->"SelectFree"],
    Cell[2052635, 64439, 323, 14, 70, "Text",
      CellTags->"SelectFree"],
    Cell[2052995, 64458, 59, 1, 70, "Subsubsection",
      CellTags->"SelectFree"],
    Cell[2053079, 64463, 261, 7, 70, "Input",
      CellTags->"SelectFree"],
    Cell[2053516, 64480, 203, 5, 70, "Input",
      CellTags->"SelectFree"],
    Cell[2053868, 64494, 329, 8, 70, "Input",
      CellTags->"SelectFree"],
    Cell[2054373, 64512, 169, 4, 70, "Input",
      CellTags->"SelectFree"],
    Cell[2054691, 64525, 169, 4, 70, "Input",
      CellTags->"SelectFree"],
    Cell[2055009, 64538, 169, 4, 70, "Input",
      CellTags->"SelectFree"],
    Cell[2055327, 64551, 203, 5, 70, "Input",
      CellTags->"SelectFree"]},
  "SelectNotFree"->{
    Cell[2055703, 64567, 64, 1, 70, "ObjectName",
      CellTags->"SelectNotFree"],
    Cell[2055792, 64572, 65, 1, 70, "Subsubsection",
      CellTags->"SelectNotFree"],
    Cell[2055860, 64575, 144, 4, 70, "Text",
      CellTags->"SelectNotFree"],
    Cell[2056007, 64581, 271, 5, 70, "Text",
      CellTags->"SelectNotFree"],
    Cell[2056281, 64588, 84, 1, 70, "Text",
      CellTags->"SelectNotFree"],
    Cell[2056368, 64591, 317, 14, 70, "Text",
      CellTags->"SelectNotFree"],
    Cell[2056722, 64610, 62, 1, 70, "Subsubsection",
      CellTags->"SelectNotFree"],
    Cell[2056809, 64615, 250, 6, 70, "Input",
      CellTags->"SelectNotFree"],
    Cell[2057269, 64632, 330, 8, 70, "Input",
      CellTags->"SelectNotFree"],
    Cell[2057819, 64651, 175, 4, 70, "Input",
      CellTags->"SelectNotFree"],
    Cell[2058143, 64664, 204, 5, 70, "Input",
      CellTags->"SelectNotFree"],
    Cell[2058496, 64678, 175, 4, 70, "Input",
      CellTags->"SelectNotFree"],
    Cell[2058820, 64691, 175, 4, 70, "Input",
      CellTags->"SelectNotFree"],
    Cell[2059144, 64704, 209, 5, 70, "Input",
      CellTags->"SelectNotFree"]},
  "Series2"->{
    Cell[2059558, 64721, 52, 1, 70, "ObjectName",
      CellTags->"Series2"],
    Cell[2059635, 64726, 59, 1, 70, "Subsubsection",
      CellTags->"Series2"],
    Cell[2059697, 64729, 295, 6, 70, "Text",
      CellTags->"Series2"],
    Cell[2060017, 64739, 142, 3, 70, "Input",
      CellTags->"Series2"],
    Cell[2060746, 64763, 56, 1, 70, "Subsubsection",
      CellTags->"Series2"],
    Cell[2060827, 64768, 425, 12, 70, "Input",
      CellTags->"Series2"],
    Cell[2061655, 64797, 218, 6, 70, "Input",
      CellTags->"Series2"],
    Cell[2062173, 64817, 270, 7, 70, "Input",
      CellTags->"Series2"],
    Cell[2062867, 64841, 218, 6, 70, "Input",
      CellTags->"Series2"],
    Cell[2063688, 64870, 346, 8, 70, "Input",
      CellTags->"Series2"],
    Cell[2065455, 64921, 369, 10, 70, "Input",
      CellTags->"Series2"],
    Cell[2067134, 64971, 114, 3, 70, "Text",
      CellTags->"Series2"],
    Cell[2067273, 64978, 672, 18, 70, "Input",
      CellTags->"Series2"],
    Cell[2068683, 65023, 799, 20, 70, "Input",
      CellTags->"Series2"],
    Cell[2070926, 65090, 285, 6, 70, "Input",
      CellTags->"Series2"],
    Cell[2073049, 65151, 239, 6, 70, "Input",
      CellTags->"Series2"],
    Cell[2076099, 65233, 355, 10, 70, "Text",
      CellTags->"Series2"]},
  "SimplifyDeltaFunction"->{
    Cell[2076503, 65249, 80, 1, 70, "ObjectName",
      CellTags->"SimplifyDeltaFunction"],
    Cell[2076608, 65254, 73, 1, 70, "Subsubsection",
      CellTags->"SimplifyDeltaFunction"],
    Cell[2076684, 65257, 295, 6, 70, "Text",
      CellTags->"SimplifyDeltaFunction"],
    Cell[2076982, 65265, 370, 14, 70, "Text",
      CellTags->"SimplifyDeltaFunction"],
    Cell[2077389, 65284, 70, 1, 70, "Subsubsection",
      CellTags->"SimplifyDeltaFunction"],
    Cell[2077484, 65289, 244, 6, 70, "Input",
      CellTags->"SimplifyDeltaFunction"],
    Cell[2078063, 65310, 196, 4, 70, "Input",
      CellTags->"SimplifyDeltaFunction"],
    Cell[2078753, 65334, 244, 6, 70, "Input",
      CellTags->"SimplifyDeltaFunction"],
    Cell[2079371, 65356, 196, 4, 70, "Input",
      CellTags->"SimplifyDeltaFunction"],
    Cell[2080595, 65394, 261, 6, 70, "Input",
      CellTags->"SimplifyDeltaFunction"],
    Cell[2081242, 65416, 196, 4, 70, "Input",
      CellTags->"SimplifyDeltaFunction"],
    Cell[2081704, 65433, 315, 8, 70, "Input",
      CellTags->"SimplifyDeltaFunction"],
    Cell[2082455, 65459, 196, 4, 70, "Input",
      CellTags->"SimplifyDeltaFunction"],
    Cell[2082947, 65477, 354, 9, 70, "Input",
      CellTags->"SimplifyDeltaFunction"],
    Cell[2083783, 65505, 196, 4, 70, "Input",
      CellTags->"SimplifyDeltaFunction"],
    Cell[2084128, 65518, 315, 8, 70, "Input",
      CellTags->"SimplifyDeltaFunction"],
    Cell[2084879, 65544, 196, 4, 70, "Input",
      CellTags->"SimplifyDeltaFunction"]},
  "SimplifyPolyLog"->{
    Cell[2085395, 65564, 68, 1, 70, "ObjectName",
      CellTags->"SimplifyPolyLog"],
    Cell[2085488, 65569, 67, 1, 70, "Subsubsection",
      CellTags->"SimplifyPolyLog"],
    Cell[2085558, 65572, 200, 4, 70, "Text",
      CellTags->"SimplifyPolyLog"],
    Cell[2085761, 65578, 196, 9, 70, "Text",
      CellTags->"SimplifyPolyLog"],
    Cell[2085994, 65592, 64, 1, 70, "Subsubsection",
      CellTags->"SimplifyPolyLog"],
    Cell[2086061, 65595, 265, 6, 70, "Input",
      CellTags->"SimplifyPolyLog"],
    Cell[2086351, 65605, 238, 6, 70, "Input",
      CellTags->"SimplifyPolyLog"],
    Cell[2087474, 65640, 207, 5, 70, "Input",
      CellTags->"SimplifyPolyLog"],
    Cell[2088252, 65666, 271, 7, 70, "Input",
      CellTags->"SimplifyPolyLog"],
    Cell[2089378, 65702, 238, 6, 70, "Input",
      CellTags->"SimplifyPolyLog"],
    Cell[2090443, 65736, 338, 9, 70, "Input",
      CellTags->"SimplifyPolyLog"],
    Cell[2091657, 65775, 306, 8, 70, "Input",
      CellTags->"SimplifyPolyLog"],
    Cell[2092809, 65812, 348, 9, 70, "Input",
      CellTags->"SimplifyPolyLog"],
    Cell[2094154, 65857, 266, 7, 70, "Input",
      CellTags->"SimplifyPolyLog"],
    Cell[2095075, 65888, 238, 6, 70, "Input",
      CellTags->"SimplifyPolyLog"],
    Cell[2095465, 65903, 238, 6, 70, "Input",
      CellTags->"SimplifyPolyLog"],
    Cell[2097306, 65959, 338, 9, 70, "Input",
      CellTags->"SimplifyPolyLog"],
    Cell[2099560, 66026, 271, 7, 70, "Input",
      CellTags->"SimplifyPolyLog"],
    Cell[2101666, 66090, 338, 9, 70, "Input",
      CellTags->"SimplifyPolyLog"],
    Cell[2105790, 66208, 234, 6, 70, "Input",
      CellTags->"SimplifyPolyLog"],
    Cell[2106439, 66232, 203, 5, 70, "Input",
      CellTags->"SimplifyPolyLog"],
    Cell[2106946, 66251, 178, 4, 70, "Input",
      CellTags->"SimplifyPolyLog"],
    Cell[2107636, 66276, 178, 4, 70, "Input",
      CellTags->"SimplifyPolyLog"],
    Cell[2108257, 66299, 178, 4, 70, "Input",
      CellTags->"SimplifyPolyLog"],
    Cell[2108856, 66320, 144, 3, 70, "Input",
      CellTags->"SimplifyPolyLog"]},
  "SOD"->{
    Cell[2109049, 66329, 44, 1, 70, "ObjectName",
      CellTags->"SOD"],
    Cell[2109118, 66334, 55, 1, 70, "Subsubsection",
      CellTags->"SOD"],
    Cell[2109176, 66337, 192, 5, 70, "Text",
      CellTags->"SOD"],
    Cell[2109371, 66344, 535, 24, 70, "Text",
      CellTags->"SOD"],
    Cell[2109943, 66373, 52, 1, 70, "Subsubsection",
      CellTags->"SOD"],
    Cell[2110020, 66378, 128, 3, 70, "Input",
      CellTags->"SOD"],
    Cell[2110506, 66397, 155, 4, 70, "Input",
      CellTags->"SOD"],
    Cell[2111170, 66422, 206, 6, 70, "Input",
      CellTags->"SOD"]},
  "Solve2"->{
    Cell[2111743, 66444, 50, 1, 70, "ObjectName",
      CellTags->"Solve2"],
    Cell[2111818, 66449, 58, 1, 70, "Subsubsection",
      CellTags->"Solve2"],
    Cell[2111879, 66452, 346, 7, 70, "Text",
      CellTags->"Solve2"],
    Cell[2112250, 66463, 140, 3, 70, "Input",
      CellTags->"Solve2"],
    Cell[2112740, 66481, 55, 1, 70, "Subsubsection",
      CellTags->"Solve2"],
    Cell[2112820, 66486, 491, 14, 70, "Input",
      CellTags->"Solve2"],
    Cell[2113778, 66517, 112, 3, 70, "Text",
      CellTags->"Solve2"],
    Cell[2113915, 66524, 190, 5, 70, "Input",
      CellTags->"Solve2"],
    Cell[2114342, 66541, 322, 8, 70, "Input",
      CellTags->"Solve2"],
    Cell[2114901, 66561, 549, 15, 70, "Input",
      CellTags->"Solve2"],
    Cell[2115861, 66593, 490, 14, 70, "Input",
      CellTags->"Solve2"]},
  "SO"->{
    Cell[2116918, 66630, 42, 1, 70, "ObjectName",
      CellTags->"SO"],
    Cell[2116985, 66635, 54, 1, 70, "Subsubsection",
      CellTags->"SO"],
    Cell[2117042, 66638, 174, 4, 70, "Text",
      CellTags->"SO"],
    Cell[2117219, 66644, 632, 28, 70, "Text",
      CellTags->"SO"],
    Cell[2117888, 66677, 51, 1, 70, "Subsubsection",
      CellTags->"SO"],
    Cell[2117964, 66682, 126, 3, 70, "Input",
      CellTags->"SO"],
    Cell[2118448, 66701, 153, 4, 70, "Input",
      CellTags->"SO"],
    Cell[2119110, 66726, 204, 6, 70, "Input",
      CellTags->"SO"]},
  "SP"->{
    Cell[2119619, 66746, 42, 1, 70, "ObjectName",
      CellTags->"SP"],
    Cell[2119686, 66751, 54, 1, 70, "Subsubsection",
      CellTags->"SP"],
    Cell[2119743, 66754, 353, 11, 70, "Text",
      CellTags->"SP"],
    Cell[2120099, 66767, 462, 19, 70, "Text",
      CellTags->"SP"],
    Cell[2120598, 66791, 51, 1, 70, "Subsubsection",
      CellTags->"SP"],
    Cell[2120674, 66796, 225, 6, 70, "Input",
      CellTags->"SP"],
    Cell[2121449, 66825, 237, 7, 70, "Input",
      CellTags->"SP"],
    Cell[2122177, 66851, 290, 8, 70, "Input",
      CellTags->"SP"],
    Cell[2123020, 66881, 205, 5, 70, "Input",
      CellTags->"SP"],
    Cell[2123795, 66909, 194, 5, 70, "Input",
      CellTags->"SP"],
    Cell[2124179, 66924, 235, 7, 70, "Input",
      CellTags->"SP"],
    Cell[2124688, 66943, 271, 8, 70, "Input",
      CellTags->"SP"]},
  "SPD"->{
    Cell[2125173, 66963, 44, 1, 70, "ObjectName",
      CellTags->"SPD"],
    Cell[2125242, 66968, 55, 1, 70, "Subsubsection",
      CellTags->"SPD"],
    Cell[2125300, 66971, 372, 11, 70, "Text",
      CellTags->"SPD"],
    Cell[2125675, 66984, 463, 19, 70, "Text",
      CellTags->"SPD"],
    Cell[2126175, 67008, 52, 1, 70, "Subsubsection",
      CellTags->"SPD"],
    Cell[2126252, 67013, 228, 6, 70, "Input",
      CellTags->"SPD"],
    Cell[2127030, 67042, 239, 7, 70, "Input",
      CellTags->"SPD"],
    Cell[2127760, 67068, 292, 8, 70, "Input",
      CellTags->"SPD"],
    Cell[2128605, 67098, 207, 5, 70, "Input",
      CellTags->"SPD"],
    Cell[2129382, 67126, 196, 5, 70, "Input",
      CellTags->"SPD"],
    Cell[2129769, 67141, 237, 7, 70, "Input",
      CellTags->"SPD"],
    Cell[2130342, 67162, 273, 8, 70, "Input",
      CellTags->"SPD"],
    Cell[2130806, 67180, 332, 9, 70, "Input",
      CellTags->"SPD"]},
  "Spinor"->{
    Cell[2131353, 67201, 50, 1, 70, "ObjectName",
      CellTags->"Spinor"],
    Cell[2131428, 67206, 58, 1, 70, "Subsubsection",
      CellTags->"Spinor"],
    Cell[2131489, 67209, 688, 20, 70, "Text",
      CellTags->"Spinor"],
    Cell[2132180, 67231, 691, 29, 70, "Text",
      CellTags->"Spinor"],
    Cell[2132908, 67265, 55, 1, 70, "Subsubsection",
      CellTags->"Spinor"],
    Cell[2132988, 67270, 134, 3, 70, "Input",
      CellTags->"Spinor"],
    Cell[2133404, 67286, 161, 4, 70, "Input",
      CellTags->"Spinor"],
    Cell[2133892, 67303, 309, 8, 70, "Input",
      CellTags->"Spinor"],
    Cell[2134615, 67327, 173, 4, 70, "Input",
      CellTags->"Spinor"],
    Cell[2135040, 67343, 259, 7, 70, "Input",
      CellTags->"Spinor"],
    Cell[2135551, 67362, 202, 5, 70, "Input",
      CellTags->"Spinor"],
    Cell[2136005, 67379, 257, 7, 70, "Input",
      CellTags->"Spinor"]},
  "SpinorUBar"->{
    Cell[2136538, 67400, 58, 1, 70, "ObjectName",
      CellTags->"SpinorUBar"],
    Cell[2136621, 67405, 62, 1, 70, "Subsubsection",
      CellTags->"SpinorUBar"],
    Cell[2136686, 67408, 185, 7, 70, "Text",
      CellTags->"SpinorUBar"],
    Cell[2136874, 67417, 548, 24, 70, "Text",
      CellTags->"SpinorUBar"],
    Cell[2137459, 67446, 59, 1, 70, "Subsubsection",
      CellTags->"SpinorUBar"],
    Cell[2137521, 67449, 86, 1, 70, "Text",
      CellTags->"SpinorUBar"],
    Cell[2137632, 67454, 142, 3, 70, "Input",
      CellTags->"SpinorUBar"],
    Cell[2138092, 67471, 169, 4, 70, "Input",
      CellTags->"SpinorUBar"],
    Cell[2138624, 67490, 210, 5, 70, "Input",
      CellTags->"SpinorUBar"],
    Cell[2139032, 67505, 251, 7, 70, "Input",
      CellTags->"SpinorUBar"],
    Cell[2139535, 67524, 287, 8, 70, "Input",
      CellTags->"SpinorUBar"]},
  "SpinorU"->{
    Cell[2140098, 67546, 52, 1, 70, "ObjectName",
      CellTags->"SpinorU"],
    Cell[2140175, 67551, 59, 1, 70, "Subsubsection",
      CellTags->"SpinorU"],
    Cell[2140237, 67554, 80, 1, 70, "Text",
      CellTags->"SpinorU"],
    Cell[2140320, 67557, 554, 24, 70, "Text",
      CellTags->"SpinorU"],
    Cell[2140911, 67586, 56, 1, 70, "Subsubsection",
      CellTags->"SpinorU"],
    Cell[2140992, 67591, 136, 3, 70, "Input",
      CellTags->"SpinorU"],
    Cell[2141358, 67605, 163, 4, 70, "Input",
      CellTags->"SpinorU"],
    Cell[2141798, 67621, 204, 5, 70, "Input",
      CellTags->"SpinorU"],
    Cell[2142197, 67636, 245, 7, 70, "Input",
      CellTags->"SpinorU"],
    Cell[2142694, 67655, 281, 8, 70, "Input",
      CellTags->"SpinorU"]},
  "SpinorVBar"->{
    Cell[2143251, 67677, 58, 1, 70, "ObjectName",
      CellTags->"SpinorVBar"],
    Cell[2143334, 67682, 62, 1, 70, "Subsubsection",
      CellTags->"SpinorVBar"],
    Cell[2143399, 67685, 190, 7, 70, "Text",
      CellTags->"SpinorVBar"],
    Cell[2143592, 67694, 548, 24, 70, "Text",
      CellTags->"SpinorVBar"],
    Cell[2144177, 67723, 59, 1, 70, "Subsubsection",
      CellTags->"SpinorVBar"],
    Cell[2144261, 67728, 142, 3, 70, "Input",
      CellTags->"SpinorVBar"],
    Cell[2144721, 67745, 169, 4, 70, "Input",
      CellTags->"SpinorVBar"],
    Cell[2145253, 67764, 210, 5, 70, "Input",
      CellTags->"SpinorVBar"],
    Cell[2145661, 67779, 251, 7, 70, "Input",
      CellTags->"SpinorVBar"],
    Cell[2146190, 67799, 287, 8, 70, "Input",
      CellTags->"SpinorVBar"]},
  "SpinorV"->{
    Cell[2146779, 67822, 52, 1, 70, "ObjectName",
      CellTags->"SpinorV"],
    Cell[2146856, 67827, 59, 1, 70, "Subsubsection",
      CellTags->"SpinorV"],
    Cell[2146918, 67830, 80, 1, 70, "Text",
      CellTags->"SpinorV"],
    Cell[2147001, 67833, 554, 24, 70, "Text",
      CellTags->"SpinorV"],
    Cell[2147592, 67862, 56, 1, 70, "Subsubsection",
      CellTags->"SpinorV"],
    Cell[2147673, 67867, 136, 3, 70, "Input",
      CellTags->"SpinorV"],
    Cell[2148039, 67881, 163, 4, 70, "Input",
      CellTags->"SpinorV"],
    Cell[2148479, 67897, 204, 5, 70, "Input",
      CellTags->"SpinorV"],
    Cell[2148878, 67912, 245, 7, 70, "Input",
      CellTags->"SpinorV"],
    Cell[2149401, 67932, 281, 8, 70, "Input",
      CellTags->"SpinorV"]},
  "SplittingFunction"->{
    Cell[2149984, 67955, 72, 1, 70, "ObjectName",
      CellTags->"SplittingFunction"],
    Cell[2150081, 67960, 69, 1, 70, "Subsubsection",
      CellTags->"SplittingFunction"],
    Cell[2150153, 67963, 231, 7, 70, "Text",
      CellTags->"SplittingFunction"],
    Cell[2150409, 67974, 162, 3, 70, "Input",
      CellTags->"SplittingFunction"],
    Cell[2150778, 67987, 231, 9, 70, "Text",
      CellTags->"SplittingFunction"],
    Cell[2151046, 68001, 66, 1, 70, "Subsubsection",
      CellTags->"SplittingFunction"],
    Cell[2151115, 68004, 66, 1, 70, "Text",
      CellTags->"SplittingFunction"],
    Cell[2151184, 68007, 264, 6, 70, "Input",
      CellTags->"SplittingFunction"],
    Cell[2151451, 68015, 171, 4, 70, "Text",
      CellTags->"SplittingFunction"],
    Cell[2151647, 68023, 158, 3, 70, "Input",
      CellTags->"SplittingFunction"],
    Cell[2152527, 68052, 158, 3, 70, "Input",
      CellTags->"SplittingFunction"],
    Cell[2153070, 68072, 158, 3, 70, "Input",
      CellTags->"SplittingFunction"],
    Cell[2153566, 68090, 158, 3, 70, "Input",
      CellTags->"SplittingFunction"],
    Cell[2154823, 68128, 158, 3, 70, "Input",
      CellTags->"SplittingFunction"],
    Cell[2156477, 68176, 158, 3, 70, "Input",
      CellTags->"SplittingFunction"],
    Cell[2157412, 68206, 158, 3, 70, "Input",
      CellTags->"SplittingFunction"],
    Cell[2158255, 68232, 158, 3, 70, "Input",
      CellTags->"SplittingFunction"],
    Cell[2158416, 68237, 64, 1, 70, "Text",
      CellTags->"SplittingFunction"],
    Cell[2158483, 68240, 264, 6, 70, "Input",
      CellTags->"SplittingFunction"],
    Cell[2158772, 68250, 158, 3, 70, "Input",
      CellTags->"SplittingFunction"],
    Cell[2159652, 68279, 158, 3, 70, "Input",
      CellTags->"SplittingFunction"],
    Cell[2160115, 68297, 158, 3, 70, "Input",
      CellTags->"SplittingFunction"],
    Cell[2160570, 68314, 158, 3, 70, "Input",
      CellTags->"SplittingFunction"],
    Cell[2161819, 68353, 158, 3, 70, "Input",
      CellTags->"SplittingFunction"],
    Cell[2163608, 68405, 158, 3, 70, "Input",
      CellTags->"SplittingFunction"],
    Cell[2164419, 68432, 159, 3, 70, "Input",
      CellTags->"SplittingFunction"],
    Cell[2165158, 68457, 158, 3, 70, "Input",
      CellTags->"SplittingFunction"],
    Cell[2165896, 68482, 159, 3, 70, "Input",
      CellTags->"SplittingFunction"],
    Cell[2166635, 68507, 158, 3, 70, "Input",
      CellTags->"SplittingFunction"],
    Cell[2168615, 68563, 159, 3, 70, "Input",
      CellTags->"SplittingFunction"],
    Cell[2170596, 68619, 159, 3, 70, "Input",
      CellTags->"SplittingFunction"],
    Cell[2171594, 68651, 160, 3, 70, "Input",
      CellTags->"SplittingFunction"],
    Cell[2179075, 68838, 158, 3, 70, "Input",
      CellTags->"SplittingFunction"],
    Cell[2183022, 68942, 158, 3, 70, "Input",
      CellTags->"SplittingFunction"],
    Cell[2187869, 69070, 158, 3, 70, "Input",
      CellTags->"SplittingFunction"]},
  "SumP"->{
    Cell[2193754, 69223, 46, 1, 70, "ObjectName",
      CellTags->"SumP"],
    Cell[2193825, 69228, 56, 1, 70, "Subsubsection",
      CellTags->"SumP"],
    Cell[2193884, 69231, 641, 20, 70, "Text",
      CellTags->"SumP"],
    Cell[2194528, 69253, 284, 14, 70, "Text",
      CellTags->"SumP"],
    Cell[2194849, 69272, 53, 1, 70, "Subsubsection",
      CellTags->"SumP"],
    Cell[2194927, 69277, 186, 5, 70, "Input",
      CellTags->"SumP"],
    Cell[2195454, 69297, 186, 5, 70, "Input",
      CellTags->"SumP"],
    Cell[2195981, 69317, 157, 4, 70, "Input",
      CellTags->"SumP"],
    Cell[2196448, 69335, 157, 4, 70, "Input",
      CellTags->"SumP"],
    Cell[2196781, 69349, 384, 12, 70, "Input",
      CellTags->"SumP"],
    Cell[2197341, 69371, 229, 6, 70, "Input",
      CellTags->"SumP"],
    Cell[2198573, 69412, 156, 4, 70, "Input",
      CellTags->"SumP"]},
  "SumS"->{
    Cell[2198929, 69428, 46, 1, 70, "ObjectName",
      CellTags->"SumS"],
    Cell[2199000, 69433, 56, 1, 70, "Subsubsection",
      CellTags->"SumS"],
    Cell[2199059, 69436, 1267, 39, 70, "Text",
      CellTags->"SumS"],
    Cell[2200351, 69479, 136, 3, 70, "Input",
      CellTags->"SumS"],
    Cell[2200692, 69492, 284, 14, 70, "Text",
      CellTags->"SumS"],
    Cell[2201013, 69511, 53, 1, 70, "Subsubsection",
      CellTags->"SumS"],
    Cell[2201091, 69516, 186, 5, 70, "Input",
      CellTags->"SumS"],
    Cell[2201564, 69535, 186, 5, 70, "Input",
      CellTags->"SumS"],
    Cell[2202037, 69554, 181, 5, 70, "Input",
      CellTags->"SumS"],
    Cell[2202453, 69571, 210, 5, 70, "Input",
      CellTags->"SumS"],
    Cell[2203014, 69592, 239, 6, 70, "Input",
      CellTags->"SumS"],
    Cell[2203689, 69616, 235, 6, 70, "Input",
      CellTags->"SumS"],
    Cell[2203949, 69626, 186, 5, 70, "Input",
      CellTags->"SumS"],
    Cell[2204777, 69655, 236, 6, 70, "Input",
      CellTags->"SumS"],
    Cell[2205038, 69665, 157, 4, 70, "Input",
      CellTags->"SumS"],
    Cell[2205371, 69679, 215, 6, 70, "Input",
      CellTags->"SumS"],
    Cell[2205762, 69695, 196, 5, 70, "Input",
      CellTags->"SumS"],
    Cell[2206246, 69714, 178, 4, 70, "Input",
      CellTags->"SumS"],
    Cell[2206630, 69729, 181, 5, 70, "Input",
      CellTags->"SumS"],
    Cell[2207010, 69745, 157, 4, 70, "Input",
      CellTags->"SumS"]},
  "SumT"->{
    Cell[2207390, 69762, 46, 1, 70, "ObjectName",
      CellTags->"SumT"],
    Cell[2207461, 69767, 56, 1, 70, "Subsubsection",
      CellTags->"SumT"],
    Cell[2207520, 69770, 536, 15, 70, "Text",
      CellTags->"SumT"],
    Cell[2208059, 69787, 284, 14, 70, "Text",
      CellTags->"SumT"],
    Cell[2208380, 69806, 53, 1, 70, "Subsubsection",
      CellTags->"SumT"],
    Cell[2208458, 69811, 186, 5, 70, "Input",
      CellTags->"SumT"],
    Cell[2208962, 69831, 186, 5, 70, "Input",
      CellTags->"SumT"],
    Cell[2209466, 69851, 157, 4, 70, "Input",
      CellTags->"SumT"],
    Cell[2209870, 69868, 210, 5, 70, "Input",
      CellTags->"SumT"],
    Cell[2210566, 69894, 157, 4, 70, "Input",
      CellTags->"SumT"],
    Cell[2210922, 69909, 303, 9, 70, "Input",
      CellTags->"SumT"],
    Cell[2211424, 69929, 196, 5, 70, "Input",
      CellTags->"SumT"],
    Cell[2211939, 69949, 168, 4, 70, "Input",
      CellTags->"SumT"],
    Cell[2212427, 69966, 157, 4, 70, "Input",
      CellTags->"SumT"],
    Cell[2212783, 69981, 181, 5, 70, "Input",
      CellTags->"SumT"],
    Cell[2213163, 69997, 332, 10, 70, "Input",
      CellTags->"SumT"],
    Cell[2214434, 70040, 168, 4, 70, "Input",
      CellTags->"SumT"],
    Cell[2214833, 70056, 192, 5, 70, "Input",
      CellTags->"SumT"],
    Cell[2215345, 70074, 161, 4, 70, "Input",
      CellTags->"SumT"],
    Cell[2216099, 70101, 304, 9, 70, "Input",
      CellTags->"SumT"]},
  "SUNDelta"->{
    Cell[2217020, 70135, 54, 1, 70, "ObjectName",
      CellTags->"SUNDelta"],
    Cell[2217099, 70140, 60, 1, 70, "Subsubsection",
      CellTags->"SUNDelta"],
    Cell[2217162, 70143, 123, 3, 70, "Text",
      CellTags->"SUNDelta"],
    Cell[2217288, 70148, 779, 33, 70, "Text",
      CellTags->"SUNDelta"],
    Cell[2218104, 70186, 57, 1, 70, "Subsubsection",
      CellTags->"SUNDelta"],
    Cell[2218186, 70191, 165, 4, 70, "Input",
      CellTags->"SUNDelta"],
    Cell[2218571, 70206, 316, 8, 70, "Input",
      CellTags->"SUNDelta"],
    Cell[2219319, 70233, 247, 6, 70, "Input",
      CellTags->"SUNDelta"],
    Cell[2219998, 70258, 206, 5, 70, "Input",
      CellTags->"SUNDelta"],
    Cell[2220400, 70273, 247, 7, 70, "Input",
      CellTags->"SUNDelta"],
    Cell[2220925, 70292, 283, 8, 70, "Input",
      CellTags->"SUNDelta"],
    Cell[2221398, 70310, 241, 7, 70, "Input",
      CellTags->"SUNDelta"],
    Cell[2221895, 70327, 257, 5, 70, "Text",
      CellTags->"SUNDelta"],
    Cell[2222177, 70336, 380, 10, 70, "Input",
      CellTags->"SUNDelta"],
    Cell[2223221, 70372, 138, 3, 70, "Input",
      CellTags->"SUNDelta"],
    Cell[2223840, 70392, 247, 7, 70, "Input",
      CellTags->"SUNDelta"]},
  "SUND"->{
    Cell[2224405, 70413, 46, 1, 70, "ObjectName",
      CellTags->"SUND"],
    Cell[2224476, 70418, 56, 1, 70, "Subsubsection",
      CellTags->"SUND"],
    Cell[2224535, 70421, 199, 7, 70, "Text",
      CellTags->"SUND"],
    Cell[2224737, 70430, 425, 19, 70, "Text",
      CellTags->"SUND"],
    Cell[2225199, 70454, 53, 1, 70, "Subsubsection",
      CellTags->"SUND"],
    Cell[2225277, 70459, 167, 4, 70, "Input",
      CellTags->"SUND"],
    Cell[2225683, 70475, 249, 6, 70, "Input",
      CellTags->"SUND"],
    Cell[2227575, 70532, 167, 4, 70, "Input",
      CellTags->"SUND"],
    Cell[2227981, 70548, 167, 4, 70, "Input",
      CellTags->"SUND"],
    Cell[2228297, 70561, 320, 8, 70, "Input",
      CellTags->"SUND"],
    Cell[2228957, 70584, 455, 12, 70, "Input",
      CellTags->"SUND"],
    Cell[2229822, 70614, 455, 12, 70, "Input",
      CellTags->"SUND"],
    Cell[2230957, 70652, 215, 6, 70, "Input",
      CellTags->"SUND"],
    Cell[2231374, 70668, 249, 7, 70, "Input",
      CellTags->"SUND"],
    Cell[2231948, 70688, 287, 8, 70, "Input",
      CellTags->"SUND"],
    Cell[2232415, 70704, 132, 3, 70, "Input",
      CellTags->"SUND"]},
  "SUNF"->{
    Cell[2232596, 70713, 46, 1, 70, "ObjectName",
      CellTags->"SUNF"],
    Cell[2232667, 70718, 56, 1, 70, "Subsubsection",
      CellTags->"SUNF"],
    Cell[2232726, 70721, 143, 4, 70, "Text",
      CellTags->"SUNF"],
    Cell[2232894, 70729, 136, 3, 70, "Input",
      CellTags->"SUNF"],
    Cell[2233237, 70742, 764, 34, 70, "Text",
      CellTags->"SUNF"],
    Cell[2234038, 70781, 53, 1, 70, "Subsubsection",
      CellTags->"SUNF"],
    Cell[2234116, 70786, 362, 10, 70, "Input",
      CellTags->"SUNF"],
    Cell[2234901, 70813, 131, 3, 70, "Input",
      CellTags->"SUNF"],
    Cell[2236180, 70856, 138, 3, 70, "Input",
      CellTags->"SUNF"],
    Cell[2236983, 70885, 167, 4, 70, "Input",
      CellTags->"SUNF"],
    Cell[2237389, 70901, 200, 5, 70, "Input",
      CellTags->"SUNF"],
    Cell[2237716, 70913, 375, 11, 70, "Text",
      CellTags->"SUNF"],
    Cell[2238116, 70928, 222, 5, 70, "Input",
      CellTags->"SUNF"],
    Cell[2240081, 70984, 320, 8, 70, "Input",
      CellTags->"SUNF"],
    Cell[2240908, 71013, 287, 7, 70, "Input",
      CellTags->"SUNF"],
    Cell[2242962, 71072, 215, 6, 70, "Input",
      CellTags->"SUNF"],
    Cell[2243379, 71088, 249, 7, 70, "Input",
      CellTags->"SUNF"],
    Cell[2243953, 71108, 287, 8, 70, "Input",
      CellTags->"SUNF"],
    Cell[2244442, 71126, 167, 4, 70, "Input",
      CellTags->"SUNF"],
    Cell[2244848, 71142, 199, 5, 70, "Input",
      CellTags->"SUNF"]},
  "SUNIndex"->{
    Cell[2245671, 71173, 54, 1, 70, "ObjectName",
      CellTags->"SUNIndex"],
    Cell[2245750, 71178, 60, 1, 70, "Subsubsection",
      CellTags->"SUNIndex"],
    Cell[2245813, 71181, 77, 1, 70, "Text",
      CellTags->"SUNIndex"],
    Cell[2245893, 71184, 437, 18, 70, "Text",
      CellTags->"SUNIndex"],
    Cell[2246367, 71207, 57, 1, 70, "Subsubsection",
      CellTags->"SUNIndex"],
    Cell[2246449, 71212, 138, 3, 70, "Input",
      CellTags->"SUNIndex"],
    Cell[2246736, 71224, 138, 3, 70, "Input",
      CellTags->"SUNIndex"],
    Cell[2247043, 71236, 247, 7, 70, "Input",
      CellTags->"SUNIndex"]},
  "SUNSimplify"->{
    Cell[2247592, 71257, 60, 1, 70, "ObjectName",
      CellTags->"SUNSimplify"],
    Cell[2247677, 71262, 63, 1, 70, "Subsubsection",
      CellTags->"SUNSimplify"],
    Cell[2247743, 71265, 377, 7, 70, "Text",
      CellTags->"SUNSimplify"],
    Cell[2248145, 71276, 150, 3, 70, "Input",
      CellTags->"SUNSimplify"],
    Cell[2248880, 71296, 186, 9, 70, "Text",
      CellTags->"SUNSimplify"],
    Cell[2249103, 71310, 60, 1, 70, "Subsubsection",
      CellTags->"SUNSimplify"],
    Cell[2249188, 71315, 301, 8, 70, "Input",
      CellTags->"SUNSimplify"],
    Cell[2249815, 71337, 145, 3, 70, "Input",
      CellTags->"SUNSimplify"],
    Cell[2250392, 71359, 231, 6, 70, "Input",
      CellTags->"SUNSimplify"],
    Cell[2250957, 71381, 145, 3, 70, "Input",
      CellTags->"SUNSimplify"],
    Cell[2251277, 71394, 215, 5, 70, "Input",
      CellTags->"SUNSimplify"],
    Cell[2251756, 71412, 308, 8, 70, "Input",
      CellTags->"SUNSimplify"],
    Cell[2252421, 71435, 145, 3, 70, "Input",
      CellTags->"SUNSimplify"],
    Cell[2253073, 71459, 323, 8, 70, "Input",
      CellTags->"SUNSimplify"],
    Cell[2253753, 71482, 145, 3, 70, "Input",
      CellTags->"SUNSimplify"],
    Cell[2254150, 71497, 313, 8, 70, "Input",
      CellTags->"SUNSimplify"],
    Cell[2254820, 71520, 145, 3, 70, "Input",
      CellTags->"SUNSimplify"],
    Cell[2255472, 71544, 313, 8, 70, "Input",
      CellTags->"SUNSimplify"],
    Cell[2256142, 71567, 212, 5, 70, "Input",
      CellTags->"SUNSimplify"],
    Cell[2256503, 71581, 467, 12, 70, "Input",
      CellTags->"SUNSimplify"],
    Cell[2257380, 71611, 472, 12, 70, "Input",
      CellTags->"SUNSimplify"],
    Cell[2258478, 71647, 294, 7, 70, "Input",
      CellTags->"SUNSimplify"],
    Cell[2260539, 71706, 294, 7, 70, "Input",
      CellTags->"SUNSimplify"],
    Cell[2262554, 71764, 327, 8, 70, "Input",
      CellTags->"SUNSimplify"],
    Cell[2263198, 71786, 533, 14, 70, "Input",
      CellTags->"SUNSimplify"],
    Cell[2264336, 71821, 218, 5, 70, "Input",
      CellTags->"SUNSimplify"],
    Cell[2265598, 71864, 280, 6, 70, "Input",
      CellTags->"SUNSimplify"],
    Cell[2267940, 71938, 359, 9, 70, "Input",
      CellTags->"SUNSimplify"],
    Cell[2268989, 71972, 145, 3, 70, "Input",
      CellTags->"SUNSimplify"],
    Cell[2270123, 72010, 218, 5, 70, "Input",
      CellTags->"SUNSimplify"],
    Cell[2271268, 72049, 268, 7, 70, "Input",
      CellTags->"SUNSimplify"],
    Cell[2272128, 72076, 245, 6, 70, "Input",
      CellTags->"SUNSimplify"],
    Cell[2273080, 72108, 141, 3, 70, "Input",
      CellTags->"SUNSimplify"],
    Cell[2273512, 72122, 249, 6, 70, "Input",
      CellTags->"SUNSimplify"]},
  "SUNT"->{
    Cell[2273810, 72134, 46, 1, 70, "ObjectName",
      CellTags->"SUNT"],
    Cell[2273881, 72139, 56, 1, 70, "Subsubsection",
      CellTags->"SUNT"],
    Cell[2273940, 72142, 207, 7, 70, "Text",
      CellTags->"SUNT"],
    Cell[2274150, 72151, 737, 34, 70, "Text",
      CellTags->"SUNT"],
    Cell[2274924, 72190, 53, 1, 70, "Subsubsection",
      CellTags->"SUNT"],
    Cell[2275002, 72195, 130, 3, 70, "Input",
      CellTags->"SUNT"],
    Cell[2275332, 72208, 216, 7, 70, "Text",
      CellTags->"SUNT"],
    Cell[2275573, 72219, 247, 6, 70, "Input",
      CellTags->"SUNT"],
    Cell[2276243, 72244, 177, 4, 70, "Input",
      CellTags->"SUNT"],
    Cell[2276917, 72270, 290, 7, 70, "Input",
      CellTags->"SUNT"],
    Cell[2277580, 72294, 221, 5, 70, "Input",
      CellTags->"SUNT"],
    Cell[2277986, 72309, 211, 5, 70, "Input",
      CellTags->"SUNT"],
    Cell[2278729, 72336, 290, 7, 70, "Input",
      CellTags->"SUNT"],
    Cell[2279370, 72358, 491, 15, 70, "Text",
      CellTags->"SUNT"],
    Cell[2279886, 72377, 198, 5, 70, "Input",
      CellTags->"SUNT"],
    Cell[2280539, 72400, 210, 7, 70, "Text",
      CellTags->"SUNT"],
    Cell[2280774, 72411, 240, 6, 70, "Input",
      CellTags->"SUNT"],
    Cell[2281521, 72438, 248, 7, 70, "Input",
      CellTags->"SUNT"],
    Cell[2282105, 72459, 208, 6, 70, "Input",
      CellTags->"SUNT"],
    Cell[2282517, 72475, 242, 7, 70, "Input",
      CellTags->"SUNT"]},
  "SUNTrace"->{
    Cell[2282948, 72493, 54, 1, 70, "ObjectName",
      CellTags->"SUNTrace"],
    Cell[2283027, 72498, 60, 1, 70, "Subsubsection",
      CellTags->"SUNTrace"],
    Cell[2283090, 72501, 82, 1, 70, "Text",
      CellTags->"SUNTrace"],
    Cell[2283197, 72506, 144, 3, 70, "Input",
      CellTags->"SUNTrace"],
    Cell[2283548, 72519, 303, 14, 70, "Text",
      CellTags->"SUNTrace"],
    Cell[2283888, 72538, 57, 1, 70, "Subsubsection",
      CellTags->"SUNTrace"],
    Cell[2283970, 72543, 202, 5, 70, "Input",
      CellTags->"SUNTrace"],
    Cell[2284649, 72568, 212, 5, 70, "Input",
      CellTags->"SUNTrace"],
    Cell[2285637, 72602, 288, 7, 70, "Input",
      CellTags->"SUNTrace"],
    Cell[2287153, 72651, 222, 5, 70, "Input",
      CellTags->"SUNTrace"],
    Cell[2288315, 72690, 334, 8, 70, "Input",
      CellTags->"SUNTrace"],
    Cell[2294951, 72888, 214, 5, 70, "Input",
      CellTags->"SUNTrace"],
    Cell[2296105, 72927, 355, 9, 70, "Input",
      CellTags->"SUNTrace"],
    Cell[2314004, 73383, 214, 5, 70, "Input",
      CellTags->"SUNTrace"],
    Cell[2315322, 73427, 324, 8, 70, "Input",
      CellTags->"SUNTrace"],
    Cell[2315795, 73444, 324, 8, 70, "Input",
      CellTags->"SUNTrace"],
    Cell[2316268, 73461, 324, 8, 70, "Input",
      CellTags->"SUNTrace"],
    Cell[2316741, 73478, 324, 8, 70, "Input",
      CellTags->"SUNTrace"]},
  "Symmetrize"->{
    Cell[2317869, 73517, 58, 1, 70, "ObjectName",
      CellTags->"Symmetrize"],
    Cell[2317952, 73522, 62, 1, 70, "Subsubsection",
      CellTags->"Symmetrize"],
    Cell[2318017, 73525, 146, 4, 70, "Text",
      CellTags->"Symmetrize"],
    Cell[2318166, 73531, 205, 8, 70, "Text",
      CellTags->"Symmetrize"],
    Cell[2318408, 73544, 59, 1, 70, "Subsubsection",
      CellTags->"Symmetrize"],
    Cell[2318492, 73549, 294, 8, 70, "Input",
      CellTags->"Symmetrize"],
    Cell[2319202, 73575, 314, 8, 70, "Input",
      CellTags->"Symmetrize"]},
  "Tdec"->{
    Cell[2320348, 73611, 46, 1, 70, "ObjectName",
      CellTags->"Tdec"],
    Cell[2320419, 73616, 56, 1, 70, "Subsubsection",
      CellTags->"Tdec"],
    Cell[2320478, 73619, 257, 5, 70, "Text",
      CellTags->"Tdec"],
    Cell[2320760, 73628, 136, 3, 70, "Input",
      CellTags->"Tdec"],
    Cell[2321438, 73647, 422, 19, 70, "Text",
      CellTags->"Tdec"],
    Cell[2321897, 73671, 53, 1, 70, "Subsubsection",
      CellTags->"Tdec"],
    Cell[2321953, 73674, 756, 23, 70, "Text",
      CellTags->"Tdec"],
    Cell[2322734, 73701, 250, 7, 70, "Input",
      CellTags->"Tdec"],
    Cell[2323926, 73740, 245, 7, 70, "Input",
      CellTags->"Tdec"],
    Cell[2324778, 73770, 923, 28, 70, "Text",
      CellTags->"Tdec"],
    Cell[2325704, 73800, 697, 19, 70, "Input",
      CellTags->"Tdec"],
    Cell[2326426, 73823, 245, 7, 70, "Input",
      CellTags->"Tdec"],
    Cell[2340874, 74194, 469, 13, 70, "Input",
      CellTags->"Tdec"],
    Cell[2342113, 74233, 153, 4, 70, "Input",
      CellTags->"Tdec"]},
  "Tensorfunction"->{
    Cell[2342315, 74243, 66, 1, 70, "ObjectName",
      CellTags->"Tensorfunction"],
    Cell[2342406, 74248, 66, 1, 70, "Subsubsection",
      CellTags->"Tensorfunction"],
    Cell[2342475, 74251, 361, 7, 70, "Text",
      CellTags->"Tensorfunction"],
    Cell[2342839, 74260, 204, 9, 70, "Text",
      CellTags->"Tensorfunction"],
    Cell[2343080, 74274, 63, 1, 70, "Subsubsection",
      CellTags->"Tensorfunction"],
    Cell[2343168, 74279, 217, 5, 70, "Input",
      CellTags->"Tensorfunction"],
    Cell[2343648, 74296, 144, 3, 70, "Input",
      CellTags->"Tensorfunction"],
    Cell[2344034, 74310, 241, 6, 70, "Input",
      CellTags->"Tensorfunction"],
    Cell[2344760, 74336, 144, 3, 70, "Input",
      CellTags->"Tensorfunction"],
    Cell[2345335, 74355, 277, 7, 70, "Input",
      CellTags->"Tensorfunction"],
    Cell[2345941, 74376, 277, 7, 70, "Input",
      CellTags->"Tensorfunction"],
    Cell[2346547, 74397, 144, 3, 70, "Input",
      CellTags->"Tensorfunction"],
    Cell[2346993, 74413, 146, 3, 70, "Input",
      CellTags->"Tensorfunction"],
    Cell[2347288, 74424, 186, 4, 70, "Input",
      CellTags->"Tensorfunction"]},
  "TFi"->{
    Cell[2347523, 74434, 44, 1, 70, "ObjectName",
      CellTags->"TFi"],
    Cell[2347592, 74439, 55, 1, 70, "Subsubsection",
      CellTags->"TFi"],
    Cell[2347650, 74442, 579, 10, 70, "Text",
      CellTags->"TFi"],
    Cell[2348232, 74454, 250, 8, 70, "Text",
      CellTags->"TFi"],
    Cell[2348485, 74464, 186, 4, 70, "Text",
      CellTags->"TFi"],
    Cell[2348674, 74470, 288, 13, 70, "Text",
      CellTags->"TFi"],
    Cell[2348999, 74488, 52, 1, 70, "Subsubsection",
      CellTags->"TFi"],
    Cell[2349076, 74493, 629, 17, 70, "Input",
      CellTags->"TFi"],
    Cell[2350891, 74551, 365, 10, 70, "Input",
      CellTags->"TFi"]},
  "TIDL"->{
    Cell[2352456, 74604, 46, 1, 70, "ObjectName",
      CellTags->"TIDL"],
    Cell[2352527, 74609, 56, 1, 70, "Subsubsection",
      CellTags->"TIDL"],
    Cell[2352586, 74612, 88, 1, 70, "Text",
      CellTags->"TIDL"],
    Cell[2352677, 74615, 166, 8, 70, "Text",
      CellTags->"TIDL"],
    Cell[2352858, 74626, 53, 1, 70, "Subsubsection",
      CellTags->"TIDL"],
    Cell[2352936, 74631, 171, 5, 70, "Subsubsection",
      CellTags->"TIDL"],
    Cell[2353110, 74638, 507, 14, 70, "Text",
      CellTags->"TIDL"],
    Cell[2353642, 74656, 250, 7, 70, "Input",
      CellTags->"TIDL"],
    Cell[2354586, 74691, 176, 5, 70, "Subsubsection",
      CellTags->"TIDL"],
    Cell[2354787, 74700, 390, 11, 70, "Input",
      CellTags->"TIDL"],
    Cell[2358196, 74801, 171, 5, 70, "Subsubsection",
      CellTags->"TIDL"],
    Cell[2358392, 74810, 345, 10, 70, "Input",
      CellTags->"TIDL"],
    Cell[2363096, 74946, 176, 5, 70, "Subsubsection",
      CellTags->"TIDL"],
    Cell[2363297, 74955, 485, 14, 70, "Input",
      CellTags->"TIDL"],
    Cell[2405308, 75927, 182, 5, 70, "Subsubsection",
      CellTags->"TIDL"],
    Cell[2405493, 75934, 548, 15, 70, "Input",
      CellTags->"TIDL"],
    Cell[2406078, 75954, 190, 5, 70, "Subsubsection",
      CellTags->"TIDL"],
    Cell[2406271, 75961, 637, 17, 70, "Input",
      CellTags->"TIDL"],
    Cell[2406945, 75983, 171, 5, 70, "Subsubsection",
      CellTags->"TIDL"],
    Cell[2407141, 75992, 387, 11, 70, "Input",
      CellTags->"TIDL"],
    Cell[2432846, 76610, 176, 5, 70, "Subsubsection",
      CellTags->"TIDL"],
    Cell[2433025, 76617, 473, 14, 70, "Input",
      CellTags->"TIDL"],
    Cell[2433535, 76636, 182, 5, 70, "Subsubsection",
      CellTags->"TIDL"],
    Cell[2433720, 76643, 560, 16, 70, "Input",
      CellTags->"TIDL"],
    Cell[2434317, 76664, 190, 5, 70, "Subsubsection",
      CellTags->"TIDL"],
    Cell[2434510, 76671, 664, 18, 70, "Input",
      CellTags->"TIDL"],
    Cell[2435199, 76693, 287, 7, 70, "Input",
      CellTags->"TIDL"]},
  "TID"->{
    Cell[2435735, 76714, 44, 1, 70, "ObjectName",
      CellTags->"TID"],
    Cell[2435804, 76719, 55, 1, 70, "Subsubsection",
      CellTags->"TID"],
    Cell[2435862, 76722, 81, 1, 70, "Text",
      CellTags->"TID"],
    Cell[2435968, 76727, 134, 3, 70, "Input",
      CellTags->"TID"],
    Cell[2436850, 76749, 316, 14, 70, "Text",
      CellTags->"TID"],
    Cell[2437203, 76768, 52, 1, 70, "Subsubsection",
      CellTags->"TID"],
    Cell[2437280, 76773, 458, 12, 70, "Input",
      CellTags->"TID"],
    Cell[2439337, 76837, 224, 6, 70, "Input",
      CellTags->"TID"],
    Cell[2457875, 77275, 332, 9, 70, "Input",
      CellTags->"TID"],
    Cell[2459391, 77325, 155, 4, 70, "Input",
      CellTags->"TID"],
    Cell[2462004, 77405, 236, 6, 70, "Input",
      CellTags->"TID"]},
  "ToDistribution"->{
    Cell[2463302, 77449, 66, 1, 70, "ObjectName",
      CellTags->"ToDistribution"],
    Cell[2463393, 77454, 66, 1, 70, "Subsubsection",
      CellTags->"ToDistribution"],
    Cell[2463462, 77457, 425, 7, 70, "Text",
      CellTags->"ToDistribution"],
    Cell[2463912, 77468, 156, 3, 70, "Input",
      CellTags->"ToDistribution"],
    Cell[2464286, 77481, 222, 9, 70, "Text",
      CellTags->"ToDistribution"],
    Cell[2464545, 77495, 63, 1, 70, "Subsubsection",
      CellTags->"ToDistribution"],
    Cell[2464633, 77500, 258, 6, 70, "Input",
      CellTags->"ToDistribution"],
    Cell[2465139, 77518, 347, 10, 70, "Input",
      CellTags->"ToDistribution"],
    Cell[2467190, 77582, 245, 6, 70, "Input",
      CellTags->"ToDistribution"],
    Cell[2467675, 77600, 347, 10, 70, "Input",
      CellTags->"ToDistribution"],
    Cell[2469744, 77666, 563, 14, 70, "Input",
      CellTags->"ToDistribution"],
    Cell[2470775, 77699, 146, 3, 70, "Input",
      CellTags->"ToDistribution"],
    Cell[2471334, 77718, 513, 14, 70, "Input",
      CellTags->"ToDistribution"]},
  "ToHypergeometric"->{
    Cell[2472339, 77753, 70, 1, 70, "ObjectName",
      CellTags->"ToHypergeometric"],
    Cell[2472434, 77758, 68, 1, 70, "Subsubsection",
      CellTags->"ToHypergeometric"],
    Cell[2472505, 77761, 1437, 42, 70, "Text",
      CellTags->"ToHypergeometric"],
    Cell[2473945, 77805, 512, 19, 70, "Text",
      CellTags->"ToHypergeometric"],
    Cell[2474494, 77829, 65, 1, 70, "Subsubsection",
      CellTags->"ToHypergeometric"],
    Cell[2474584, 77834, 496, 14, 70, "Input",
      CellTags->"ToHypergeometric"],
    Cell[2477320, 77910, 603, 16, 70, "Input",
      CellTags->"ToHypergeometric"],
    Cell[2479911, 77982, 496, 14, 70, "Input",
      CellTags->"ToHypergeometric"],
    Cell[2482732, 78060, 603, 16, 70, "Input",
      CellTags->"ToHypergeometric"]},
  "ToLarin"->{
    Cell[2485458, 78137, 52, 1, 70, "ObjectName",
      CellTags->"ToLarin"],
    Cell[2485535, 78142, 59, 1, 70, "Subsubsection",
      CellTags->"ToLarin"],
    Cell[2485597, 78145, 693, 20, 70, "Text",
      CellTags->"ToLarin"],
    Cell[2486293, 78167, 176, 9, 70, "Text",
      CellTags->"ToLarin"],
    Cell[2486506, 78181, 56, 1, 70, "Subsubsection",
      CellTags->"ToLarin"],
    Cell[2486587, 78186, 269, 6, 70, "Input",
      CellTags->"ToLarin"],
    Cell[2487373, 78213, 136, 3, 70, "Input",
      CellTags->"ToLarin"]},
  "ToTFi"->{
    Cell[2489048, 78269, 48, 1, 70, "ObjectName",
      CellTags->"ToTFi"],
    Cell[2489121, 78274, 57, 1, 70, "Subsubsection",
      CellTags->"ToTFi"],
    Cell[2489181, 78277, 275, 6, 70, "Text",
      CellTags->"ToTFi"],
    Cell[2489459, 78285, 284, 13, 70, "Text",
      CellTags->"ToTFi"],
    Cell[2489780, 78303, 54, 1, 70, "Subsubsection",
      CellTags->"ToTFi"],
    Cell[2489859, 78308, 404, 11, 70, "Input",
      CellTags->"ToTFi"],
    Cell[2493456, 78402, 181, 4, 70, "Input",
      CellTags->"ToTFi"],
    Cell[2494811, 78447, 135, 3, 70, "Input",
      CellTags->"ToTFi"],
    Cell[2495644, 78474, 574, 15, 70, "Input",
      CellTags->"ToTFi"],
    Cell[2498347, 78555, 132, 3, 70, "Input",
      CellTags->"ToTFi"],
    Cell[2499696, 78600, 135, 3, 70, "Input",
      CellTags->"ToTFi"]},
  "Tr"->{
    Cell[2500669, 78632, 42, 1, 70, "ObjectName",
      CellTags->"Tr"],
    Cell[2500736, 78637, 54, 1, 70, "Subsubsection",
      CellTags->"Tr"],
    Cell[2500793, 78640, 261, 5, 70, "Text",
      CellTags->"Tr"],
    Cell[2501079, 78649, 132, 3, 70, "Input",
      CellTags->"Tr"],
    Cell[2501975, 78673, 578, 23, 70, "Text",
      CellTags->"Tr"],
    Cell[2502590, 78701, 51, 1, 70, "Subsubsection",
      CellTags->"Tr"],
    Cell[2502666, 78706, 161, 4, 70, "Input",
      CellTags->"Tr"],
    Cell[2503085, 78722, 126, 3, 70, "Input",
      CellTags->"Tr"],
    Cell[2503472, 78738, 453, 12, 70, "Input",
      CellTags->"Tr"],
    Cell[2506287, 78823, 256, 7, 70, "Input",
      CellTags->"Tr"],
    Cell[2507358, 78859, 288, 7, 70, "Input",
      CellTags->"Tr"],
    Cell[2524864, 79314, 99, 2, 70, "Input",
      CellTags->"Tr"],
    Cell[2525115, 79325, 119, 3, 70, "Input",
      CellTags->"Tr"],
    Cell[2525587, 79338, 167, 4, 70, "Text",
      CellTags->"Tr"],
    Cell[2525779, 79346, 128, 3, 70, "Input",
      CellTags->"Tr"],
    Cell[2526060, 79358, 511, 13, 70, "Input",
      CellTags->"Tr"],
    Cell[2535104, 79595, 208, 5, 70, "Input",
      CellTags->"Tr"],
    Cell[2536966, 79652, 540, 14, 70, "Input",
      CellTags->"Tr"],
    Cell[2538016, 79686, 272, 7, 70, "Input",
      CellTags->"Tr"],
    Cell[2538554, 79706, 132, 3, 70, "Input",
      CellTags->"Tr"],
    Cell[2538918, 79720, 413, 10, 70, "Input",
      CellTags->"Tr"],
    Cell[2539607, 79743, 132, 3, 70, "Input",
      CellTags->"Tr"]},
  "TrickMandelstam"->{
    Cell[2540005, 79759, 68, 1, 70, "ObjectName",
      CellTags->"TrickMandelstam"],
    Cell[2540098, 79764, 67, 1, 70, "Subsubsection",
      CellTags->"TrickMandelstam"],
    Cell[2540168, 79767, 1102, 37, 70, "Text",
      CellTags->"TrickMandelstam"],
    Cell[2541307, 79809, 64, 1, 70, "Subsubsection",
      CellTags->"TrickMandelstam"],
    Cell[2541396, 79814, 664, 18, 70, "Input",
      CellTags->"TrickMandelstam"],
    Cell[2542379, 79847, 721, 18, 70, "Input",
      CellTags->"TrickMandelstam"]},
  "Trick"->{
    Cell[2543441, 79882, 48, 1, 70, "ObjectName",
      CellTags->"Trick"],
    Cell[2543514, 79887, 57, 1, 70, "Subsubsection",
      CellTags->"Trick"],
    Cell[2543574, 79890, 175, 4, 70, "Text",
      CellTags->"Trick"],
    Cell[2543752, 79896, 678, 29, 70, "Text",
      CellTags->"Trick"],
    Cell[2544467, 79930, 63, 1, 70, "Subsubsection",
      CellTags->"Trick"],
    Cell[2544533, 79933, 420, 15, 70, "Text",
      CellTags->"Trick"],
    Cell[2544978, 79952, 428, 11, 70, "Input",
      CellTags->"Trick"],
    Cell[2545775, 79980, 397, 11, 70, "Input",
      CellTags->"Trick"],
    Cell[2546831, 80016, 132, 3, 70, "Input",
      CellTags->"Trick"],
    Cell[2547780, 80048, 269, 6, 70, "Input",
      CellTags->"Trick"],
    Cell[2548580, 80075, 165, 4, 70, "Input",
      CellTags->"Trick"]},
  "Twist2GluonOperator"->{
    Cell[2549043, 80093, 76, 1, 70, "ObjectName",
      CellTags->"Twist2GluonOperator"],
    Cell[2549144, 80098, 71, 1, 70, "Subsubsection",
      CellTags->"Twist2GluonOperator"],
    Cell[2549218, 80101, 965, 15, 70, "Text",
      CellTags->"Twist2GluonOperator"],
    Cell[2550186, 80118, 236, 9, 70, "Text",
      CellTags->"Twist2GluonOperator"],
    Cell[2550459, 80132, 100, 1, 70, "Subsubsection",
      CellTags->"Twist2GluonOperator"],
    Cell[2550584, 80137, 388, 8, 70, "Input",
      CellTags->"Twist2GluonOperator"],
    Cell[2551477, 80161, 63, 1, 70, "Text",
      CellTags->"Twist2GluonOperator"],
    Cell[2551565, 80166, 325, 8, 70, "Input",
      CellTags->"Twist2GluonOperator"],
    Cell[2553106, 80216, 375, 9, 70, "Input",
      CellTags->"Twist2GluonOperator"],
    Cell[2555077, 80277, 263, 6, 70, "Input",
      CellTags->"Twist2GluonOperator"],
    Cell[2555771, 80301, 313, 7, 70, "Input",
      CellTags->"Twist2GluonOperator"],
    Cell[2557091, 80341, 63, 1, 70, "Text",
      CellTags->"Twist2GluonOperator"],
    Cell[2557179, 80346, 420, 10, 70, "Input",
      CellTags->"Twist2GluonOperator"],
    Cell[2559247, 80411, 390, 10, 70, "Input",
      CellTags->"Twist2GluonOperator"],
    Cell[2560267, 80445, 440, 11, 70, "Input",
      CellTags->"Twist2GluonOperator"],
    Cell[2577564, 80880, 63, 1, 70, "Text",
      CellTags->"Twist2GluonOperator"],
    Cell[2577652, 80885, 507, 12, 70, "Input",
      CellTags->"Twist2GluonOperator"],
    Cell[2585424, 81088, 467, 12, 70, "Input",
      CellTags->"Twist2GluonOperator"],
    Cell[2586665, 81128, 517, 13, 70, "Input",
      CellTags->"Twist2GluonOperator"],
    Cell[2624214, 82049, 101, 1, 70, "Subsubsection",
      CellTags->"Twist2GluonOperator"],
    Cell[2624340, 82054, 317, 7, 70, "Input",
      CellTags->"Twist2GluonOperator"],
    Cell[2625162, 82077, 63, 1, 70, "Text",
      CellTags->"Twist2GluonOperator"],
    Cell[2625250, 82082, 325, 8, 70, "Input",
      CellTags->"Twist2GluonOperator"],
    Cell[2626806, 82133, 375, 9, 70, "Input",
      CellTags->"Twist2GluonOperator"],
    Cell[2631369, 82261, 263, 6, 70, "Input",
      CellTags->"Twist2GluonOperator"],
    Cell[2632063, 82285, 313, 7, 70, "Input",
      CellTags->"Twist2GluonOperator"],
    Cell[2635960, 82391, 63, 1, 70, "Text",
      CellTags->"Twist2GluonOperator"],
    Cell[2636048, 82396, 420, 10, 70, "Input",
      CellTags->"Twist2GluonOperator"],
    Cell[2638201, 82463, 390, 10, 70, "Input",
      CellTags->"Twist2GluonOperator"],
    Cell[2639221, 82497, 440, 11, 70, "Input",
      CellTags->"Twist2GluonOperator"],
    Cell[2666964, 83194, 63, 1, 70, "Text",
      CellTags->"Twist2GluonOperator"],
    Cell[2667052, 83199, 507, 12, 70, "Input",
      CellTags->"Twist2GluonOperator"],
    Cell[2674839, 83403, 467, 12, 70, "Input",
      CellTags->"Twist2GluonOperator"],
    Cell[2676080, 83443, 517, 13, 70, "Input",
      CellTags->"Twist2GluonOperator"],
    Cell[2729141, 84788, 77, 1, 70, "Subsubsection",
      CellTags->"Twist2GluonOperator"],
    Cell[2729221, 84791, 98, 1, 70, "Text",
      CellTags->"Twist2GluonOperator"],
    Cell[2729322, 84794, 334, 7, 70, "Input",
      CellTags->"Twist2GluonOperator"],
    Cell[2729659, 84803, 463, 12, 70, "Input",
      CellTags->"Twist2GluonOperator"],
    Cell[2730159, 84820, 103, 1, 70, "Subsubsection",
      CellTags->"Twist2GluonOperator"],
    Cell[2730287, 84825, 316, 6, 70, "Input",
      CellTags->"Twist2GluonOperator"],
    Cell[2731107, 84847, 63, 1, 70, "Text",
      CellTags->"Twist2GluonOperator"],
    Cell[2731195, 84852, 385, 10, 70, "Input",
      CellTags->"Twist2GluonOperator"],
    Cell[2737095, 84998, 63, 1, 70, "Text",
      CellTags->"Twist2GluonOperator"],
    Cell[2737183, 85003, 420, 10, 70, "Input",
      CellTags->"Twist2GluonOperator"],
    Cell[2829555, 86884, 63, 1, 70, "Text",
      CellTags->"Twist2GluonOperator"],
    Cell[2829643, 86889, 563, 13, 70, "Input",
      CellTags->"Twist2GluonOperator"],
    Cell[2837483, 87094, 105, 1, 70, "Subsubsection",
      CellTags->"Twist2GluonOperator"],
    Cell[2837613, 87099, 316, 6, 70, "Input",
      CellTags->"Twist2GluonOperator"],
    Cell[2838433, 87121, 63, 1, 70, "Text",
      CellTags->"Twist2GluonOperator"],
    Cell[2838521, 87126, 385, 10, 70, "Input",
      CellTags->"Twist2GluonOperator"],
    Cell[2843716, 87269, 63, 1, 70, "Text",
      CellTags->"Twist2GluonOperator"],
    Cell[2843782, 87272, 463, 12, 70, "Input",
      CellTags->"Twist2GluonOperator"],
    Cell[2844270, 87288, 390, 10, 70, "Input",
      CellTags->"Twist2GluonOperator"],
    Cell[2849493, 87433, 440, 11, 70, "Input",
      CellTags->"Twist2GluonOperator"],
    Cell[2854744, 87577, 63, 1, 70, "Text",
      CellTags->"Twist2GluonOperator"],
    Cell[2854832, 87582, 563, 13, 70, "Input",
      CellTags->"Twist2GluonOperator"],
    Cell[2862653, 87785, 79, 1, 70, "Text",
      CellTags->"Twist2GluonOperator"],
    Cell[2862757, 87790, 629, 16, 70, "Input",
      CellTags->"Twist2GluonOperator"],
    Cell[2875719, 88108, 97, 1, 70, "Text",
      CellTags->"Twist2GluonOperator"],
    Cell[2875819, 88111, 334, 7, 70, "Input",
      CellTags->"Twist2GluonOperator"],
    Cell[2876178, 88122, 522, 13, 70, "Input",
      CellTags->"Twist2GluonOperator"]},
  "Twist2QuarkOperator"->{
    Cell[2885515, 88342, 76, 1, 70, "ObjectName",
      CellTags->"Twist2QuarkOperator"],
    Cell[2885616, 88347, 71, 1, 70, "Subsubsection",
      CellTags->"Twist2QuarkOperator"],
    Cell[2885690, 88350, 981, 15, 70, "Text",
      CellTags->"Twist2QuarkOperator"],
    Cell[2886674, 88367, 236, 9, 70, "Text",
      CellTags->"Twist2QuarkOperator"],
    Cell[2886925, 88379, 68, 1, 70, "Subsubsection",
      CellTags->"Twist2QuarkOperator"],
    Cell[2887018, 88384, 99, 1, 70, "Subsubsection",
      CellTags->"Twist2QuarkOperator"],
    Cell[2887142, 88389, 317, 7, 70, "Input",
      CellTags->"Twist2QuarkOperator"],
    Cell[2887963, 88412, 76, 1, 70, "Text",
      CellTags->"Twist2QuarkOperator"],
    Cell[2888064, 88417, 188, 4, 70, "Input",
      CellTags->"Twist2QuarkOperator"],
    Cell[2889092, 88448, 82, 1, 70, "Text",
      CellTags->"Twist2QuarkOperator"],
    Cell[2889199, 88453, 369, 10, 70, "Input",
      CellTags->"Twist2QuarkOperator"],
    Cell[2891748, 88525, 88, 1, 70, "Text",
      CellTags->"Twist2QuarkOperator"],
    Cell[2891861, 88530, 457, 12, 70, "Input",
      CellTags->"Twist2QuarkOperator"],
    Cell[2899812, 88717, 101, 1, 70, "Subsubsection",
      CellTags->"Twist2QuarkOperator"],
    Cell[2899938, 88722, 305, 6, 70, "Input",
      CellTags->"Twist2QuarkOperator"],
    Cell[2900747, 88744, 76, 1, 70, "Text",
      CellTags->"Twist2QuarkOperator"],
    Cell[2900848, 88749, 188, 4, 70, "Input",
      CellTags->"Twist2QuarkOperator"],
    Cell[2901700, 88775, 82, 1, 70, "Text",
      CellTags->"Twist2QuarkOperator"],
    Cell[2901807, 88780, 369, 10, 70, "Input",
      CellTags->"Twist2QuarkOperator"],
    Cell[2904281, 88850, 88, 1, 70, "Text",
      CellTags->"Twist2QuarkOperator"],
    Cell[2904394, 88855, 457, 12, 70, "Input",
      CellTags->"Twist2QuarkOperator"],
    Cell[2912603, 89044, 94, 1, 70, "Text",
      CellTags->"Twist2QuarkOperator"],
    Cell[2912722, 89049, 238, 6, 70, "Input",
      CellTags->"Twist2QuarkOperator"],
    Cell[2913280, 89069, 439, 10, 70, "Input",
      CellTags->"Twist2QuarkOperator"],
    Cell[2916679, 89164, 523, 12, 70, "Input",
      CellTags->"Twist2QuarkOperator"],
    Cell[2934519, 89546, 103, 1, 70, "Subsubsection",
      CellTags->"Twist2QuarkOperator"],
    Cell[2934647, 89551, 318, 7, 70, "Input",
      CellTags->"Twist2QuarkOperator"],
    Cell[2935470, 89574, 179, 4, 70, "Text",
      CellTags->"Twist2QuarkOperator"],
    Cell[2935652, 89580, 276, 5, 70, "Text",
      CellTags->"Twist2QuarkOperator"],
    Cell[2935953, 89589, 248, 6, 70, "Input",
      CellTags->"Twist2QuarkOperator"],
    Cell[2937346, 89630, 101, 1, 70, "Text",
      CellTags->"Twist2QuarkOperator"],
    Cell[2937472, 89635, 369, 10, 70, "Input",
      CellTags->"Twist2QuarkOperator"],
    Cell[2941976, 89745, 88, 1, 70, "Text",
      CellTags->"Twist2QuarkOperator"],
    Cell[2942089, 89750, 188, 4, 70, "Input",
      CellTags->"Twist2QuarkOperator"],
    Cell[2943651, 89795, 105, 1, 70, "Subsubsection",
      CellTags->"Twist2QuarkOperator"],
    Cell[2943781, 89800, 318, 7, 70, "Input",
      CellTags->"Twist2QuarkOperator"],
    Cell[2944604, 89823, 76, 1, 70, "Text",
      CellTags->"Twist2QuarkOperator"],
    Cell[2944705, 89828, 248, 6, 70, "Input",
      CellTags->"Twist2QuarkOperator"],
    Cell[2946098, 89869, 82, 1, 70, "Text",
      CellTags->"Twist2QuarkOperator"],
    Cell[2946205, 89874, 369, 10, 70, "Input",
      CellTags->"Twist2QuarkOperator"],
    Cell[2950709, 89984, 252, 6, 70, "Input",
      CellTags->"Twist2QuarkOperator"]},
  "Uncontract"->{
    Cell[2951010, 89996, 58, 1, 70, "ObjectName",
      CellTags->"Uncontract"],
    Cell[2951093, 90001, 62, 1, 70, "Subsubsection",
      CellTags->"Uncontract"],
    Cell[2951158, 90004, 247, 5, 70, "Text",
      CellTags->"Uncontract"],
    Cell[2951430, 90013, 148, 3, 70, "Input",
      CellTags->"Uncontract"],
    Cell[2952006, 90031, 194, 9, 70, "Text",
      CellTags->"Uncontract"],
    Cell[2952237, 90045, 59, 1, 70, "Subsubsection",
      CellTags->"Uncontract"],
    Cell[2952321, 90050, 282, 7, 70, "Input",
      CellTags->"Uncontract"],
    Cell[2953187, 90080, 175, 4, 70, "Input",
      CellTags->"Uncontract"],
    Cell[2954453, 90121, 170, 4, 70, "Input",
      CellTags->"Uncontract"],
    Cell[2954947, 90139, 175, 4, 70, "Input",
      CellTags->"Uncontract"],
    Cell[2955830, 90169, 185, 4, 70, "Input",
      CellTags->"Uncontract"],
    Cell[2957546, 90221, 90, 1, 70, "Text",
      CellTags->"Uncontract"],
    Cell[2957661, 90226, 251, 6, 70, "Input",
      CellTags->"Uncontract"],
    Cell[2958199, 90244, 153, 4, 70, "Text",
      CellTags->"Uncontract"],
    Cell[2958377, 90252, 296, 7, 70, "Input",
      CellTags->"Uncontract"],
    Cell[2959425, 90287, 329, 8, 70, "Input",
      CellTags->"Uncontract"],
    Cell[2961080, 90339, 166, 4, 70, "Input",
      CellTags->"Uncontract"]},
  "UnDeclareNonCommutative"->{
    Cell[2961295, 90349, 84, 1, 70, "ObjectName",
      CellTags->"UnDeclareNonCommutative"],
    Cell[2961404, 90354, 75, 1, 70, "Subsubsection",
      CellTags->"UnDeclareNonCommutative"],
    Cell[2961482, 90357, 199, 4, 70, "Text",
      CellTags->"UnDeclareNonCommutative"],
    Cell[2961684, 90363, 366, 14, 70, "Text",
      CellTags->"UnDeclareNonCommutative"],
    Cell[2962087, 90382, 72, 1, 70, "Subsubsection",
      CellTags->"UnDeclareNonCommutative"],
    Cell[2962162, 90385, 166, 3, 70, "Input",
      CellTags->"UnDeclareNonCommutative"],
    Cell[2962331, 90390, 154, 4, 70, "Text",
      CellTags->"UnDeclareNonCommutative"],
    Cell[2962510, 90398, 132, 2, 70, "Input",
      CellTags->"UnDeclareNonCommutative"],
    Cell[2962772, 90407, 104, 1, 70, "Text",
      CellTags->"UnDeclareNonCommutative"],
    Cell[2962879, 90410, 168, 3, 70, "Input",
      CellTags->"UnDeclareNonCommutative"],
    Cell[2963072, 90417, 193, 4, 70, "Input",
      CellTags->"UnDeclareNonCommutative"],
    Cell[2963396, 90428, 193, 4, 70, "Input",
      CellTags->"UnDeclareNonCommutative"],
    Cell[2963614, 90436, 203, 4, 70, "Input",
      CellTags->"UnDeclareNonCommutative"],
    Cell[2964006, 90449, 195, 4, 70, "Input",
      CellTags->"UnDeclareNonCommutative"],
    Cell[2964226, 90457, 203, 4, 70, "Input",
      CellTags->"UnDeclareNonCommutative"]},
  "Write2"->{
    Cell[2964666, 90474, 50, 1, 70, "ObjectName",
      CellTags->"Write2"],
    Cell[2964741, 90479, 58, 1, 70, "Subsubsection",
      CellTags->"Write2"],
    Cell[2964802, 90482, 298, 6, 70, "Text",
      CellTags->"Write2"],
    Cell[2965103, 90490, 154, 4, 70, "Text",
      CellTags->"Write2"],
    Cell[2965282, 90498, 166, 4, 70, "Input",
      CellTags->"Write2"],
    Cell[2965774, 90517, 140, 3, 70, "Input",
      CellTags->"Write2"],
    Cell[2966591, 90540, 143, 3, 70, "Input",
      CellTags->"Write2"],
    Cell[2966895, 90551, 313, 14, 70, "Text",
      CellTags->"Write2"],
    Cell[2967245, 90570, 55, 1, 70, "Subsubsection",
      CellTags->"Write2"],
    Cell[2967325, 90575, 553, 15, 70, "Input",
      CellTags->"Write2"],
    Cell[2968932, 90624, 259, 7, 70, "Input",
      CellTags->"Write2"],
    Cell[2969194, 90633, 79, 1, 70, "Text",
      CellTags->"Write2"],
    Cell[2969276, 90636, 227, 6, 70, "Input",
      CellTags->"Write2"],
    Cell[2969506, 90644, 74, 1, 70, "Text",
      CellTags->"Write2"],
    Cell[2969605, 90649, 446, 11, 70, "Input",
      CellTags->"Write2"],
    Cell[2970714, 90681, 350, 9, 70, "Input",
      CellTags->"Write2"],
    Cell[2971089, 90694, 283, 7, 70, "Input",
      CellTags->"Write2"],
    Cell[2972243, 90732, 228, 6, 70, "Input",
      CellTags->"Write2"],
    Cell[2972496, 90742, 446, 11, 70, "Input",
      CellTags->"Write2"],
    Cell[2974006, 90782, 350, 9, 70, "Input",
      CellTags->"Write2"],
    Cell[2974359, 90793, 107, 3, 70, "Text",
      CellTags->"Write2"],
    Cell[2974469, 90798, 296, 8, 70, "Input",
      CellTags->"Write2"],
    Cell[2974790, 90810, 446, 11, 70, "Input",
      CellTags->"Write2"],
    Cell[2976144, 90846, 483, 13, 70, "Input",
      CellTags->"Write2"]},
  "Zeta2"->{
    Cell[2976676, 90865, 48, 1, 70, "ObjectName",
      CellTags->"Zeta2"],
    Cell[2976749, 90870, 57, 1, 70, "Subsubsection",
      CellTags->"Zeta2"],
    Cell[2976809, 90873, 95, 1, 70, "Text",
      CellTags->"Zeta2"],
    Cell[2976907, 90876, 203, 8, 70, "Text",
      CellTags->"Zeta2"],
    Cell[2977147, 90889, 54, 1, 70, "Subsubsection",
      CellTags->"Zeta2"],
    Cell[2977226, 90894, 102, 2, 70, "Input",
      CellTags->"Zeta2"],
    Cell[2977515, 90906, 132, 3, 70, "Input",
      CellTags->"Zeta2"],
    Cell[2977814, 90918, 170, 4, 70, "Input",
      CellTags->"Zeta2"]},
  "$FCT"->{
    Cell[2978224, 90935, 46, 1, 70, "ObjectName",
      CellTags->"$FCT"],
    Cell[2978295, 90940, 56, 1, 70, "Subsubsection",
      CellTags->"$FCT"],
    Cell[2978354, 90943, 178, 4, 70, "Text",
      CellTags->"$FCT"],
    Cell[2978535, 90949, 160, 4, 70, "Input",
      CellTags->"$FCT"],
    Cell[2978720, 90957, 206, 5, 70, "Input",
      CellTags->"$FCT"],
    Cell[2979162, 90972, 161, 4, 70, "Input",
      CellTags->"$FCT"],
    Cell[2979348, 90980, 206, 5, 70, "Input",
      CellTags->"$FCT"]},
  "$LorentzIndices"->{
    Cell[2979836, 90999, 68, 1, 70, "ObjectName",
      CellTags->"$LorentzIndices"],
    Cell[2979929, 91004, 67, 1, 70, "Subsubsection",
      CellTags->"$LorentzIndices"],
    Cell[2979999, 91007, 165, 4, 70, "Text",
      CellTags->"$LorentzIndices"],
    Cell[2980167, 91013, 172, 4, 70, "Input",
      CellTags->"$LorentzIndices"],
    Cell[2980364, 91021, 391, 9, 70, "Input",
      CellTags->"$LorentzIndices"],
    Cell[2981689, 91064, 145, 3, 70, "Input",
      CellTags->"$LorentzIndices"],
    Cell[2982385, 91086, 361, 9, 70, "Input",
      CellTags->"$LorentzIndices"],
    Cell[2983975, 91139, 145, 3, 70, "Input",
      CellTags->"$LorentzIndices"],
    Cell[2984882, 91165, 173, 4, 70, "Input",
      CellTags->"$LorentzIndices"]},
  "$PairBrackets"->{
    Cell[2985104, 91175, 64, 1, 70, "ObjectName",
      CellTags->"$PairBrackets"],
    Cell[2985193, 91180, 65, 1, 70, "Subsubsection",
      CellTags->"$PairBrackets"],
    Cell[2985261, 91183, 156, 4, 70, "Text",
      CellTags->"$PairBrackets"],
    Cell[2985442, 91191, 118, 2, 70, "Input",
      CellTags->"$PairBrackets"],
    Cell[2985713, 91202, 250, 7, 70, "Input",
      CellTags->"$PairBrackets"],
    Cell[2986619, 91235, 146, 3, 70, "Input",
      CellTags->"$PairBrackets"],
    Cell[2986917, 91247, 250, 7, 70, "Input",
      CellTags->"$PairBrackets"],
    Cell[2987899, 91280, 147, 3, 70, "Input",
      CellTags->"$PairBrackets"]},
  "$VeryVerbose"->{
    Cell[2988223, 91294, 62, 1, 70, "ObjectName",
      CellTags->"$VeryVerbose"],
    Cell[2988310, 91299, 64, 1, 70, "Subsubsection",
      CellTags->"$VeryVerbose"],
    Cell[2988399, 91304, 136, 3, 70, "Input",
      CellTags->"$VeryVerbose"],
    Cell[2988810, 91317, 116, 2, 70, "Input",
      CellTags->"$VeryVerbose"],
    Cell[2989053, 91326, 173, 4, 70, "Input",
      CellTags->"$VeryVerbose"],
    Cell[2989251, 91334, 326, 9, 70, "Input",
      CellTags->"$VeryVerbose"],
    Cell[2991337, 91399, 163, 4, 70, "Input",
      CellTags->"$VeryVerbose"]},
  "$West"->{
    Cell[2991549, 91409, 48, 1, 70, "ObjectName",
      CellTags->"$West"],
    Cell[2991622, 91414, 57, 1, 70, "Subsubsection",
      CellTags->"$West"],
    Cell[2991704, 91419, 122, 3, 70, "Input",
      CellTags->"$West"],
    Cell[2992179, 91432, 170, 8, 70, "Text",
      CellTags->"$West"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Short Overview", 2995591, 91548},
  {"intro", 2995720, 91552},
  {"Load FeynCalc", 2996529, 91576},
  {"start", 2996631, 91579},
  {"About Extras", 2997580, 91606},
  {"tarcer", 2998157, 91622},
  {"phi", 2998874, 91643},
  {"fa", 2999356, 91658},
  {"Example Calculations", 2999841, 91673},
  {"ex", 2999973, 91677},
  {"Tree level", 3000249, 91685},
  {"A moment integral", 3002854, 91756},
  {"Reference Guide", 3005967, 91833},
  {"A0", 3006059, 91836},
  {"Amplitudes", 3006927, 91862},
  {"Amputate", 3007782, 91885},
  {"AnomalousDimension", 3008410, 91902},
  {"Anti5", 3010919, 91963},
  {"AntiCommutator", 3012079, 91996},
  {"AntiQuarkField", 3013697, 92037},
  {"AntiSymmetrize", 3014211, 92050},
  {"Apart1", 3014795, 92065},
  {"Apart2", 3015541, 92086},
  {"Apart3", 3016141, 92103},
  {"B00", 3016883, 92124},
  {"B0", 3017794, 92151},
  {"B11", 3018560, 92174},
  {"B1", 3019608, 92205},
  {"BackgroundGluonVertex", 3020593, 92234},
  {"C0", 3021486, 92255},
  {"Calc", 3022062, 92272},
  {"CA", 3023001, 92299},
  {"Cases2", 3023574, 92316},
  {"CF", 3024182, 92333},
  {"ChangeDimension", 3024833, 92352},
  {"ChargeConjugationMatrixInv", 3026906, 92403},
  {"ChargeConjugationMatrix", 3028058, 92428},
  {"ChiralityProjector", 3028991, 92449},
  {"Chisholm", 3029698, 92466},
  {"ClearScalarProducts", 3031292, 92509},
  {"Collect2", 3032176, 92530},
  {"Combine", 3033323, 92561},
  {"CommutatorExplicit", 3034170, 92584},
  {"Commutator", 3035214, 92609},
  {"ComplexConjugate", 3036471, 92642},
  {"ComplexIndex", 3037820, 92675},
  {"Contract", 3038789, 92700},
  {"Convolute", 3040895, 92757},
  {"CovariantD", 3043174, 92818},
  {"D0", 3045176, 92871},
  {"DataType", 3045757, 92888},
  {"DeclareNonCommutative", 3047950, 92947},
  {"DeltaFunction", 3049032, 92972},
  {"DeltaFunctionPrime", 3049868, 92993},
  {"Dimension", 3050577, 93010},
  {"DiracGammaCombine", 3051513, 93035},
  {"DiracGammaExpand", 3052385, 93056},
  {"DiracGamma", 3053728, 93089},
  {"DiracGammaT", 3055058, 93124},
  {"DiracMatrix", 3055710, 93141},
  {"DiracOrder", 3056981, 93174},
  {"DiracReduce", 3058535, 93215},
  {"DiracSigmaExplicit", 3059734, 93246},
  {"DiracSigma", 3060357, 93261},
  {"DiracSimplify", 3061231, 93284},
  {"DiracSimplify2", 3063715, 93347},
  {"DiracSlash", 3064310, 93362},
  {"DiracTrace", 3065334, 93389},
  {"DiracTrick", 3066509, 93420},
  {"DotSimplify", 3068215, 93465},
  {"EpsChisholm", 3070024, 93512},
  {"EpsEvaluate", 3070599, 93527},
  {"Epsilon", 3071249, 93544},
  {"Eps", 3071861, 93561},
  {"ExpandPartialD", 3073424, 93606},
  {"ExpandScalarProduct", 3074831, 93641},
  {"Explicit", 3075799, 93664},
  {"ExplicitPartialD", 3076656, 93687},
  {"ExplicitSUNIndex", 3077436, 93706},
  {"Factor2", 3078043, 93721},
  {"FAD", 3079020, 93748},
  {"FCE", 3079739, 93769},
  {"FCI", 3080664, 93796},
  {"FermionSpinSum", 3081395, 93817},
  {"FeynAmpDenominatorCombine", 3082406, 93842},
  {"FeynAmpDenominator", 3083177, 93859},
  {"FeynAmpDenominatorSimplify", 3084153, 93882},
  {"FeynAmpDenominatorSplit", 3085674, 93915},
  {"FeynAmp", 3086774, 93940},
  {"FeynCalc2FORM", 3087540, 93961},
  {"FeynCalcExternal", 3089245, 94004},
  {"FeynCalcInternal", 3090271, 94029},
  {"FeynRule", 3091291, 94054},
  {"FieldStrength", 3094359, 94137},
  {"FORM2FeynCalc", 3095431, 94164},
  {"FourDivergence", 3096829, 94199},
  {"FourLaplacian", 3097677, 94220},
  {"FourVector", 3098514, 94241},
  {"FreeQ2", 3099470, 94266},
  {"FromTFi", 3100160, 94285},
  {"FRH", 3100784, 94302},
  {"FunctionalD", 3101451, 94321},
  {"FV", 3106321, 94446},
  {"FVD", 3107178, 94471},
  {"GA", 3108045, 94496},
  {"GAD", 3108834, 94519},
  {"GammaEpsilon", 3109643, 94542},
  {"GammaExpand", 3110546, 94565},
  {"GhostPropagator", 3111210, 94582},
  {"GHP", 3111977, 94601},
  {"GluonField", 3112643, 94620},
  {"GluonGhostVertex", 3113224, 94635},
  {"GluonPropagator", 3114013, 94654},
  {"GluonVertex", 3115689, 94695},
  {"GSD", 3117202, 94734},
  {"GS", 3117931, 94755},
  {"Gstrong", 3118655, 94776},
  {"Hill", 3119201, 94791},
  {"HypergeometricAC", 3119881, 94810},
  {"HypergeometricIR", 3121001, 94837},
  {"HypergeometricSE", 3121791, 94856},
  {"HypExplicit", 3122493, 94873},
  {"Integrate2", 3123231, 94892},
  {"Integrate3", 3126597, 94979},
  {"IntegrateByParts", 3127488, 95002},
  {"InverseMellin", 3128026, 95015},
  {"Isolate", 3130782, 95084},
  {"Kummer", 3131852, 95113},
  {"Lagrangian", 3134916, 95196},
  {"LC", 3135788, 95219},
  {"LCD", 3136577, 95242},
  {"LeftPartialD", 3137595, 95271},
  {"LeftRightPartialD", 3138588, 95296},
  {"LeftRightPartialD2", 3139558, 95319},
  {"LeviCivita", 3140531, 95342},
  {"Li2", 3141950, 95379},
  {"Li3", 3142538, 95396},
  {"LorentzIndex", 3143205, 95415},
  {"Map2", 3144496, 95448},
  {"MetricTensor", 3145172, 95467},
  {"MomentumCombine", 3146240, 95494},
  {"MomentumExpand", 3147266, 95519},
  {"Momentum", 3148353, 95546},
  {"MT", 3149801, 95585},
  {"MTD", 3150520, 95606},
  {"Nielsen", 3151253, 95627},
  {"NTerms", 3152317, 95656},
  {"OneLoop", 3152934, 95673},
  {"OneLoopSimplify", 3154531, 95716},
  {"OPEDelta", 3155634, 95743},
  {"OPEi", 3156263, 95760},
  {"OPESumExplicit", 3157087, 95783},
  {"OPESum", 3157930, 95804},
  {"OPESumSimplify", 3158702, 95825},
  {"Pair", 3159542, 95846},
  {"PartialD", 3160854, 95883},
  {"PaVe", 3161485, 95900},
  {"PaVeOrder", 3162156, 95919},
  {"PaVeReduce", 3162802, 95936},
  {"PlusDistribution", 3164235, 95973},
  {"Polarization", 3165189, 95996},
  {"PolarizationSum", 3166178, 96021},
  {"PolarizationVector", 3167041, 96042},
  {"PowerSimplify", 3168610, 96079},
  {"PropagatorDenominatorExplicit", 3169385, 96098},
  {"PropagatorDenominator", 3170201, 96115},
  {"QuantumField", 3171384, 96142},
  {"QuarkField", 3173307, 96191},
  {"QuarkGluonVertex", 3173811, 96204},
  {"QuarkPropagator", 3174847, 96229},
  {"RightPartialD", 3175624, 96248},
  {"RussianTrick", 3176463, 96269},
  {"ScalarProduct", 3177449, 96294},
  {"ScalarProductCancel", 3178695, 96325},
  {"SD", 3180014, 96356},
  {"SelectFree", 3180601, 96373},
  {"SelectNotFree", 3181639, 96400},
  {"Series2", 3182789, 96429},
  {"SimplifyDeltaFunction", 3184097, 96464},
  {"SimplifyPolyLog", 3185634, 96499},
  {"SOD", 3187712, 96550},
  {"Solve2", 3188304, 96567},
  {"SO", 3189137, 96590},
  {"SP", 3189717, 96607},
  {"SPD", 3190575, 96632},
  {"Spinor", 3191518, 96659},
  {"SpinorUBar", 3192431, 96684},
  {"SpinorU", 3193309, 96707},
  {"SpinorVBar", 3194084, 96728},
  {"SpinorV", 3194887, 96749},
  {"SplittingFunction", 3195669, 96770},
  {"SumP", 3198633, 96841},
  {"SumS", 3199517, 96866},
  {"SumT", 3200969, 96907},
  {"SUNDelta", 3202425, 96948},
  {"SUND", 3203655, 96981},
  {"SUNF", 3204823, 97014},
  {"SUNIndex", 3206278, 97055},
  {"SUNSimplify", 3206914, 97072},
  {"SUNT", 3209598, 97141},
  {"SUNTrace", 3211050, 97182},
  {"Symmetrize", 3212435, 97219},
  {"Tdec", 3213003, 97234},
  {"Tensorfunction", 3214039, 97263},
  {"TFi", 3215201, 97292},
  {"TIDL", 3215862, 97311},
  {"TID", 3217895, 97366},
  {"ToDistribution", 3218705, 97389},
  {"ToHypergeometric", 3219803, 97416},
  {"ToLarin", 3220589, 97435},
  {"ToTFi", 3221138, 97450},
  {"Tr", 3221960, 97473},
  {"TrickMandelstam", 3223521, 97518},
  {"Trick", 3224048, 97531},
  {"Twist2GluonOperator", 3224887, 97554},
  {"Twist2QuarkOperator", 3230203, 97677},
  {"Uncontract", 3233781, 97760},
  {"UnDeclareNonCommutative", 3235135, 97795},
  {"Write2", 3236515, 97826},
  {"Zeta2", 3238297, 97875},
  {"$FCT", 3238901, 97892},
  {"$LorentzIndices", 3239432, 97907},
  {"$PairBrackets", 3240202, 97926},
  {"$VeryVerbose", 3240873, 97943},
  {"$West", 3241451, 97958}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 59, 1, 105, "Title"],
Cell[1789, 55, 123, 3, 66, "Subtitle",
  PageBreakBelow->True],
Cell[1915, 60, 83, 1, 64, "Subtitle"],
Cell[2001, 63, 59, 1, 53, "Subsubtitle"],
Cell[2063, 66, 258, 8, 53, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2346, 78, 96, 2, 70, "Section",
  PageBreakAbove->True,
  CellTags->{"Short Overview", "intro"}],
Cell[2445, 82, 1200, 30, 124, "Text",
  CellTags->"intro"],
Cell[3648, 114, 1953, 76, 73, "Text",
  CellTags->"intro"],
Cell[5604, 192, 88, 1, 39, "Text",
  CellTags->"intro"],
Cell[5695, 195, 1708, 71, 73, "Text",
  CellTags->"intro"],
Cell[7406, 268, 1149, 22, 158, "Text",
  CellTags->"intro"],
Cell[8558, 292, 272, 7, 56, "Text",
  CellTags->"intro"],
Cell[8833, 301, 391, 10, 56, "Text",
  CellTags->"intro"],
Cell[9227, 313, 569, 10, 107, "Text",
  CellTags->"intro"],
Cell[9799, 325, 570, 19, 39, "Text",
  CellTags->"intro"],
Cell[10372, 346, 94, 1, 39, "Text",
  CellTags->"intro"],
Cell[10469, 349, 216, 7, 25, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[10722, 361, 76, 1, 56, "Section",
  CellTags->{"Load FeynCalc", "start"}],
Cell[10801, 364, 357, 10, 56, "Text",
  CellTags->"start"],
Cell[11161, 376, 64, 1, 45, "MathCaption",
  CellTags->"start"],
Cell[11228, 379, 142, 3, 56, "Input",
  CellTags->"start"],
Cell[11373, 384, 241, 7, 56, "Text",
  CellTags->"start"],
Cell[11617, 393, 626, 17, 98, "Text",
  CellTags->"start"],
Cell[12246, 412, 246, 9, 45, "MathCaption",
  CellTags->"start"],
Cell[12495, 423, 416, 11, 56, "Input",
  CellTags->"start"],
Cell[12914, 436, 416, 11, 56, "Input",
  CellTags->"start"],
Cell[13333, 449, 224, 9, 45, "MathCaption",
  CellTags->"start"],

Cell[CellGroupData[{
Cell[13582, 462, 149, 4, 56, "Input",
  CellTags->"start"],
Cell[13734, 468, 318, 10, 37, "Output"]
}, Open  ]],
Cell[14067, 481, 142, 4, 45, "MathCaption",
  CellTags->"start"],

Cell[CellGroupData[{
Cell[14234, 489, 132, 3, 56, "Input",
  CellTags->"start"],
Cell[14369, 494, 143, 3, 37, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[14561, 503, 77, 2, 56, "Section",
  PageBreakAbove->True,
  CellTags->"About Extras"],
Cell[14641, 507, 484, 13, 73, "Text",
  CellTags->"About Extras"],
Cell[15128, 522, 152, 4, 45, "MathCaption",
  CellTags->"About Extras"],
Cell[15283, 528, 115, 3, 43, "Input",
  CellTags->"About Extras"],
Cell[15401, 533, 119, 3, 39, "Text",
  CellTags->"About Extras"],
Cell[15523, 538, 1149, 28, 87, "Text",
  CellTags->"About Extras"],
Cell[16675, 568, 105, 1, 31, "Caption",
  CellTags->"About Extras"],

Cell[CellGroupData[{
Cell[16805, 573, 195, 7, 74, "Subsection",
  CellTags->"tarcer"],
Cell[17003, 582, 69, 1, 70, "InspectorLevel2",
  CellTags->"tarcer"],
Cell[17075, 585, 240, 8, 70, "Text",
  CellTags->"tarcer"],
Cell[17318, 595, 141, 4, 70, "Text",
  CellTags->"tarcer"],
Cell[17462, 601, 61, 1, 70, "Subsubsection",
  CellTags->"tarcer"],
Cell[17526, 604, 626, 15, 70, "Text",
  CellTags->"tarcer"],
Cell[18155, 621, 76, 1, 70, "Text",
  CellTags->"tarcer"],
Cell[18234, 624, 109, 3, 70, "Input",
  CellTags->"tarcer"],
Cell[18346, 629, 271, 8, 70, "Text",
  CellTags->"tarcer"],
Cell[18620, 639, 300, 9, 70, "Text",
  CellTags->"tarcer"]
}, Closed]],

Cell[CellGroupData[{
Cell[18957, 653, 154, 6, 74, "Subsection",
  CellTags->"phi"],
Cell[19114, 661, 60, 1, 70, "InspectorLevel2",
  CellTags->"phi"],
Cell[19177, 664, 422, 9, 70, "Text",
  CellTags->"phi"],
Cell[19602, 675, 70, 1, 70, "Text",
  CellTags->"phi"],
Cell[19675, 678, 103, 3, 70, "Input",
  CellTags->"phi"],
Cell[19781, 683, 268, 8, 70, "Text",
  CellTags->"phi"],
Cell[20052, 693, 280, 9, 70, "Text",
  CellTags->"phi"]
}, Closed]],

Cell[CellGroupData[{
Cell[20369, 707, 48, 1, 53, "Subsection",
  CellTags->"fa"],
Cell[20420, 710, 206, 5, 70, "Text",
  CellTags->"fa"],
Cell[20629, 717, 293, 6, 70, "Text",
  CellTags->"fa"],
Cell[20925, 725, 598, 17, 70, "Text",
  CellTags->"fa"],
Cell[21526, 744, 102, 3, 70, "Input",
  CellTags->"fa"],
Cell[21631, 749, 267, 8, 70, "Text",
  CellTags->"fa"],
Cell[21901, 759, 545, 16, 70, "Text",
  CellTags->"fa"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[22495, 781, 107, 2, 56, "Section",
  PageBreakAbove->True,
  CellTags->{"Example Calculations", "ex"}],
Cell[22605, 785, 540, 15, 66, "Commentary",
  CellTags->"ex"],
Cell[23148, 802, 345, 10, 39, "Text",
  CellTags->"ex"],

Cell[CellGroupData[{
Cell[23518, 816, 342, 11, 53, "Subsection",
  CellTags->"Tree level"],
Cell[23863, 829, 324, 10, 39, "Text",
  CellTags->"Tree level"],
Cell[24190, 841, 85, 1, 39, "Text",
  CellTags->"Tree level"],
Cell[24278, 844, 168, 4, 58, "Input",
  CellTags->"Tree level"],
Cell[24449, 850, 168, 4, 58, "Input",
  CellTags->"Tree level"],
Cell[24620, 856, 168, 4, 58, "Input",
  CellTags->"Tree level"],
Cell[24791, 862, 168, 4, 58, "Input",
  CellTags->"Tree level"],
Cell[24962, 868, 99, 1, 39, "Text",
  CellTags->"Tree level"],

Cell[CellGroupData[{
Cell[25086, 873, 337, 9, 56, "Input",
  CellTags->"Tree level"],
Cell[25426, 884, 1411, 40, 38, "Output"]
}, Open  ]],
Cell[26852, 927, 2399, 77, 70, "Text",
  CellTags->"Tree level"],
Cell[29254, 1006, 371, 10, 70, "Input",
  CellTags->"Tree level"],
Cell[29628, 1018, 339, 9, 70, "Input",
  CellTags->"Tree level"],
Cell[29970, 1029, 371, 10, 70, "Input",
  CellTags->"Tree level"],
Cell[30344, 1041, 306, 8, 70, "Input",
  CellTags->"Tree level"],
Cell[30653, 1051, 306, 8, 70, "Input",
  CellTags->"Tree level"],
Cell[30962, 1061, 464, 12, 70, "Input",
  CellTags->"Tree level"],
Cell[31429, 1075, 64, 1, 70, "Text",
  CellTags->"Tree level"],

Cell[CellGroupData[{
Cell[31518, 1080, 336, 8, 70, "Input",
  CellTags->"Tree level"],
Cell[31857, 1090, 1158, 33, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33052, 1128, 336, 8, 70, "Input",
  CellTags->"Tree level"],
Cell[33391, 1138, 1158, 33, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[34586, 1176, 336, 8, 70, "Input",
  CellTags->"Tree level"],
Cell[34925, 1186, 1158, 33, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36120, 1224, 336, 8, 70, "Input",
  CellTags->"Tree level"],
Cell[36459, 1234, 1158, 33, 70, "Output"]
}, Open  ]],
Cell[37632, 1270, 74, 1, 70, "Text",
  CellTags->"Tree level"],

Cell[CellGroupData[{
Cell[37731, 1275, 134, 2, 70, "Input",
  CellTags->"Tree level"],
Cell[37868, 1279, 1749, 48, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[39654, 1332, 134, 2, 70, "Input",
  CellTags->"Tree level"],
Cell[39791, 1336, 1346, 37, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41174, 1378, 134, 2, 70, "Input",
  CellTags->"Tree level"],
Cell[41311, 1382, 1346, 37, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[42694, 1424, 134, 2, 70, "Input",
  CellTags->"Tree level"],
Cell[42831, 1428, 1749, 48, 70, "Output"]
}, Open  ]],
Cell[44595, 1479, 91, 1, 70, "Text",
  CellTags->"Tree level"],

Cell[CellGroupData[{
Cell[44711, 1484, 883, 24, 108, "Input",
  CellTags->"Tree level"],
Cell[45597, 1510, 6793, 184, 107, "Output"]
}, Open  ]],
Cell[52405, 1697, 78, 1, 39, "Text",
  CellTags->"Tree level"],

Cell[CellGroupData[{
Cell[52508, 1702, 201, 5, 56, "Input",
  CellTags->"Tree level"],
Cell[52712, 1709, 7056, 182, 61, "Output"]
}, Open  ]],
Cell[59783, 1894, 118, 3, 39, "Text",
  CellTags->"Tree level"],

Cell[CellGroupData[{
Cell[59926, 1901, 423, 11, 56, "Input",
  CellTags->"Tree level"],
Cell[60352, 1914, 107, 2, 37, "Output"]
}, Open  ]],
Cell[60474, 1919, 135, 4, 39, "Text",
  CellTags->"Tree level"],
Cell[60612, 1925, 260, 6, 56, "Input",
  CellTags->"Tree level"],
Cell[60875, 1933, 649, 27, 39, "Text",
  CellTags->"Tree level"]
}, Closed]],

Cell[CellGroupData[{
Cell[61561, 1965, 72, 1, 53, "Subsection",
  CellTags->"A moment integral"],
Cell[61636, 1968, 504, 17, 70, "Text",
  CellTags->"A moment integral"],
Cell[62143, 1987, 127, 3, 70, "Text",
  CellTags->"A moment integral"],
Cell[62273, 1992, 409, 13, 70, "Text",
  CellTags->"A moment integral"],
Cell[62685, 2007, 94, 1, 70, "Text",
  CellTags->"A moment integral"],
Cell[62782, 2010, 288, 10, 70, "Text",
  CellTags->"A moment integral"],

Cell[CellGroupData[{
Cell[63095, 2024, 149, 3, 70, "Input",
  CellTags->"A moment integral"],
Cell[63247, 2029, 161, 4, 70, "Output"]
}, Open  ]],
Cell[63423, 2036, 222, 5, 70, "Text",
  CellTags->"A moment integral"],
Cell[63648, 2043, 2187, 46, 70, "Input",
  CellTags->"A moment integral"],
Cell[65838, 2091, 167, 4, 70, "Text",
  CellTags->"A moment integral"],
Cell[66008, 2097, 17184, 630, 70, "Input",
  CellTags->"A moment integral"],

Cell[CellGroupData[{
Cell[83217, 2731, 144, 3, 70, "Input",
  CellTags->"A moment integral"],
Cell[83364, 2736, 1653, 42, 70, "Output"]
}, Open  ]],
Cell[85032, 2781, 154, 4, 70, "Commentary",
  CellTags->"A moment integral"],

Cell[CellGroupData[{
Cell[85211, 2789, 126, 2, 70, "Input",
  CellTags->"A moment integral"],
Cell[85340, 2793, 268, 8, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[85645, 2806, 144, 3, 70, "Input",
  CellTags->"A moment integral"],
Cell[85792, 2811, 218, 6, 70, "Output"]
}, Open  ]],
Cell[86025, 2820, 66, 1, 70, "Text",
  CellTags->"A moment integral"],
Cell[86094, 2823, 251, 5, 70, "Text",
  CellTags->"A moment integral"],
Cell[86348, 2830, 644, 19, 70, "Text",
  CellTags->"A moment integral"],

Cell[CellGroupData[{
Cell[87017, 2853, 438, 12, 70, "Input",
  CellTags->"A moment integral"],
Cell[87458, 2867, 223, 6, 70, "Output"]
}, Open  ]],
Cell[87696, 2876, 198, 4, 70, "Text",
  CellTags->"A moment integral"],

Cell[CellGroupData[{
Cell[87919, 2884, 547, 14, 70, "Input",
  CellTags->"A moment integral"],
Cell[88469, 2900, 223, 6, 70, "Output"]
}, Open  ]],
Cell[88707, 2909, 90, 1, 70, "Text",
  CellTags->"A moment integral"],
Cell[88800, 2912, 711, 18, 70, "Input",
  CellTags->"A moment integral"],
Cell[89514, 2932, 93, 1, 70, "Text",
  CellTags->"A moment integral"],

Cell[CellGroupData[{
Cell[89632, 2937, 1538, 38, 70, "Input",
  CellTags->"A moment integral"],
Cell[91173, 2977, 3624, 88, 70, "Output"]
}, Open  ]],
Cell[94812, 3068, 148, 4, 70, "Text",
  CellTags->"A moment integral"],
Cell[94963, 3074, 653, 17, 70, "Input",
  CellTags->"A moment integral"],

Cell[CellGroupData[{
Cell[95641, 3095, 141, 3, 70, "Input",
  CellTags->"A moment integral"],
Cell[95785, 3100, 109, 2, 70, "Output"]
}, Open  ]],
Cell[95909, 3105, 152, 4, 70, "Text",
  CellTags->"A moment integral"],
Cell[96064, 3111, 317, 9, 70, "Input",
  CellTags->"A moment integral"],
Cell[96384, 3122, 218, 5, 70, "Text",
  CellTags->"A moment integral"],

Cell[CellGroupData[{
Cell[96627, 3131, 217, 5, 70, "Input",
  CellTags->"A moment integral"],
Cell[96847, 3138, 4620, 115, 70, "Output"]
}, Open  ]],
Cell[101482, 3256, 268, 8, 70, "Text",
  CellTags->"A moment integral"],

Cell[CellGroupData[{
Cell[101775, 3268, 497, 13, 70, "Input",
  CellTags->"A moment integral"],
Cell[102275, 3283, 3550, 90, 70, "Output"]
}, Open  ]],
Cell[105840, 3376, 131, 3, 70, "Text",
  CellTags->"A moment integral"],
Cell[105974, 3381, 213, 5, 70, "Input",
  CellTags->"A moment integral"],
Cell[106190, 3388, 281, 7, 70, "Input",
  CellTags->"A moment integral"],
Cell[106474, 3397, 1240, 55, 70, "Text",
  CellTags->"A moment integral"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[107763, 3458, 65, 1, 56, "Section",
  CellTags->"Reference Guide"],

Cell[CellGroupData[{
Cell[107853, 3463, 54, 0, 70, "Commentary"],
Cell[107910, 3465, 87, 2, 70, "Text"],

Cell[CellGroupData[{
Cell[108022, 3471, 154, 3, 70, "Input"],
Cell[108179, 3476, 128, 2, 70, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[108356, 3484, 66, 2, 70, "ObjectName",
  PageBreakAbove->True,
  CellTags->"A0"],

Cell[CellGroupData[{
Cell[108447, 3490, 54, 1, 70, "Subsubsection",
  CellTags->"A0"],
Cell[108504, 3493, 381, 10, 70, "Text",
  CellTags->"A0"],

Cell[CellGroupData[{
Cell[108910, 3507, 135, 3, 70, "Input",
  CellTags->"A0"],
Cell[109048, 3512, 184, 5, 70, "Output"]
}, Closed]],
Cell[109247, 3520, 480, 24, 70, "Text",
  CellTags->"A0"]
}, Closed]],

Cell[CellGroupData[{
Cell[109764, 3549, 51, 1, 70, "Subsubsection",
  CellTags->"A0"],
Cell[109818, 3552, 272, 11, 70, "Text",
  CellTags->"A0"],

Cell[CellGroupData[{
Cell[110115, 3567, 152, 4, 70, "Input",
  CellTags->"A0"],
Cell[110270, 3573, 381, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[110688, 3588, 225, 6, 70, "Input",
  CellTags->"A0"],
Cell[110916, 3596, 381, 10, 70, "Output"]
}, Closed]],
Cell[111312, 3609, 241, 8, 70, "Text",
  CellTags->"A0"],

Cell[CellGroupData[{
Cell[111578, 3621, 124, 3, 70, "Input",
  CellTags->"A0"],
Cell[111705, 3626, 107, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[111849, 3633, 197, 5, 70, "Input",
  CellTags->"A0"],
Cell[112049, 3640, 107, 2, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[112217, 3649, 58, 1, 70, "ObjectName",
  CellTags->"Amplitudes"],

Cell[CellGroupData[{
Cell[112300, 3654, 62, 1, 70, "Subsubsection",
  CellTags->"Amplitudes"],
Cell[112365, 3657, 258, 5, 70, "Text",
  CellTags->"Amplitudes"],

Cell[CellGroupData[{
Cell[112648, 3666, 146, 3, 70, "Input",
  CellTags->"Amplitudes"],
Cell[112797, 3671, 369, 9, 70, "Output"]
}, Closed]],
Cell[113181, 3683, 191, 9, 70, "Text",
  CellTags->"Amplitudes"]
}, Closed]],

Cell[CellGroupData[{
Cell[113409, 3697, 59, 1, 70, "Subsubsection",
  CellTags->"Amplitudes"],
Cell[113471, 3700, 95, 1, 70, "Text",
  CellTags->"Amplitudes"],

Cell[CellGroupData[{
Cell[113591, 3705, 152, 3, 70, "Input",
  CellTags->"Amplitudes"],
Cell[113746, 3710, 4820, 131, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[118603, 3846, 138, 3, 70, "Input",
  CellTags->"Amplitudes"],
Cell[118744, 3851, 12289, 303, 70, "Output"]
}, Closed]],
Cell[131048, 4157, 221, 8, 70, "Text",
  CellTags->"Amplitudes"],

Cell[CellGroupData[{
Cell[131294, 4169, 375, 9, 70, "Input",
  CellTags->"Amplitudes"],
Cell[131672, 4180, 32501, 731, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[164234, 4918, 54, 1, 70, "ObjectName",
  CellTags->"Amputate"],

Cell[CellGroupData[{
Cell[164313, 4923, 60, 1, 70, "Subsubsection",
  CellTags->"Amputate"],
Cell[164376, 4926, 216, 5, 70, "Text",
  CellTags->"Amputate"],

Cell[CellGroupData[{
Cell[164617, 4935, 142, 3, 70, "Input",
  CellTags->"Amputate"],
Cell[164762, 4940, 338, 9, 70, "Output"]
}, Closed]],
Cell[165115, 4952, 708, 28, 70, "Text",
  CellTags->"Amputate"]
}, Closed]],

Cell[CellGroupData[{
Cell[165860, 4985, 57, 1, 70, "Subsubsection",
  CellTags->"Amputate"],

Cell[CellGroupData[{
Cell[165942, 4990, 206, 5, 70, "Input",
  CellTags->"Amputate"],
Cell[166151, 4997, 608, 17, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[166796, 5019, 163, 4, 70, "Input",
  CellTags->"Amputate"],
Cell[166962, 5025, 956, 27, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[167979, 5059, 74, 1, 70, "ObjectName",
  CellTags->"AnomalousDimension"],

Cell[CellGroupData[{
Cell[168078, 5064, 70, 1, 70, "Subsubsection",
  CellTags->"AnomalousDimension"],
Cell[168151, 5067, 155, 4, 70, "Text",
  CellTags->"AnomalousDimension"],

Cell[CellGroupData[{
Cell[168331, 5075, 162, 3, 70, "Input",
  CellTags->"AnomalousDimension"],
Cell[168496, 5080, 273, 7, 70, "Output"]
}, Closed]],
Cell[168784, 5090, 438, 18, 70, "Text",
  CellTags->"AnomalousDimension"]
}, Closed]],

Cell[CellGroupData[{
Cell[169259, 5113, 67, 1, 70, "Subsubsection",
  CellTags->"AnomalousDimension"],
Cell[169329, 5116, 64, 1, 70, "Text",
  CellTags->"AnomalousDimension"],

Cell[CellGroupData[{
Cell[169418, 5121, 243, 5, 70, "Input",
  CellTags->"AnomalousDimension"],
Cell[169664, 5128, 273, 7, 70, "Output"]
}, Closed]],
Cell[169952, 5138, 249, 8, 70, "Text",
  CellTags->"AnomalousDimension"],

Cell[CellGroupData[{
Cell[170226, 5150, 161, 3, 70, "Input",
  CellTags->"AnomalousDimension"],
Cell[170390, 5155, 557, 16, 70, "Output"]
}, Closed]],
Cell[170962, 5174, 248, 8, 70, "Text",
  CellTags->"AnomalousDimension"],

Cell[CellGroupData[{
Cell[171235, 5186, 160, 3, 70, "Input",
  CellTags->"AnomalousDimension"],
Cell[171398, 5191, 320, 9, 70, "Output"]
}, Closed]],
Cell[171733, 5203, 248, 8, 70, "Text",
  CellTags->"AnomalousDimension"],

Cell[CellGroupData[{
Cell[172006, 5215, 160, 3, 70, "Input",
  CellTags->"AnomalousDimension"],
Cell[172169, 5220, 319, 9, 70, "Output"]
}, Closed]],
Cell[172503, 5232, 248, 8, 70, "Text",
  CellTags->"AnomalousDimension"],

Cell[CellGroupData[{
Cell[172776, 5244, 160, 3, 70, "Input",
  CellTags->"AnomalousDimension"],
Cell[172939, 5249, 730, 21, 70, "Output"]
}, Closed]],
Cell[173684, 5273, 249, 8, 70, "Text",
  CellTags->"AnomalousDimension"],

Cell[CellGroupData[{
Cell[173958, 5285, 161, 3, 70, "Input",
  CellTags->"AnomalousDimension"],
Cell[174122, 5290, 828, 22, 70, "Output"]
}, Closed]],
Cell[174965, 5315, 249, 8, 70, "Text",
  CellTags->"AnomalousDimension"],

Cell[CellGroupData[{
Cell[175239, 5327, 161, 3, 70, "Input",
  CellTags->"AnomalousDimension"],
Cell[175403, 5332, 8523, 214, 70, "Output"]
}, Closed]],
Cell[183941, 5549, 248, 8, 70, "Text",
  CellTags->"AnomalousDimension"],

Cell[CellGroupData[{
Cell[184214, 5561, 160, 3, 70, "Input",
  CellTags->"AnomalousDimension"],
Cell[184377, 5566, 5416, 138, 70, "Output"]
}, Closed]],
Cell[189808, 5707, 248, 8, 70, "Text",
  CellTags->"AnomalousDimension"],

Cell[CellGroupData[{
Cell[190081, 5719, 160, 3, 70, "Input",
  CellTags->"AnomalousDimension"],
Cell[190244, 5724, 8323, 211, 70, "Output"]
}, Closed]],
Cell[198582, 5938, 248, 8, 70, "Text",
  CellTags->"AnomalousDimension"],

Cell[CellGroupData[{
Cell[198855, 5950, 160, 3, 70, "Input",
  CellTags->"AnomalousDimension"],
Cell[199018, 5955, 6503, 166, 70, "Output"]
}, Closed]],
Cell[205536, 6124, 275, 8, 70, "Text",
  CellTags->"AnomalousDimension"],

Cell[CellGroupData[{
Cell[205836, 6136, 160, 3, 70, "Input",
  CellTags->"AnomalousDimension"],
Cell[205999, 6141, 6133, 144, 70, "Output"]
}, Closed]],
Cell[212147, 6288, 341, 9, 70, "Text",
  CellTags->"AnomalousDimension"],

Cell[CellGroupData[{
Cell[212513, 6301, 362, 10, 70, "Input",
  CellTags->"AnomalousDimension"],
Cell[212878, 6313, 253, 6, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[213192, 6326, 48, 1, 70, "ObjectName",
  CellTags->"Anti5"],

Cell[CellGroupData[{
Cell[213265, 6331, 57, 1, 70, "Subsubsection",
  CellTags->"Anti5"],
Cell[213325, 6334, 528, 16, 70, "Text",
  CellTags->"Anti5"],
Cell[213856, 6352, 176, 7, 70, "Text",
  CellTags->"Anti5"],
Cell[214035, 6361, 456, 19, 70, "Text",
  CellTags->"Anti5"]
}, Closed]],

Cell[CellGroupData[{
Cell[214528, 6385, 54, 1, 70, "Subsubsection",
  CellTags->"Anti5"],

Cell[CellGroupData[{
Cell[214607, 6390, 191, 5, 70, "Input",
  CellTags->"Anti5"],
Cell[214801, 6397, 207, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[215045, 6407, 130, 3, 70, "Input",
  CellTags->"Anti5"],
Cell[215178, 6412, 354, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[215569, 6427, 181, 5, 70, "Input",
  CellTags->"Anti5"],
Cell[215753, 6434, 318, 9, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[216108, 6448, 236, 6, 70, "Input",
  CellTags->"Anti5"],
Cell[216347, 6456, 358, 9, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[216742, 6470, 157, 4, 70, "Input",
  CellTags->"Anti5"],
Cell[216902, 6476, 800, 24, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[217739, 6505, 165, 4, 70, "Input",
  CellTags->"Anti5"],
Cell[217907, 6511, 800, 24, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[218744, 6540, 188, 5, 70, "Input",
  CellTags->"Anti5"],
Cell[218935, 6547, 800, 24, 70, "Output"]
}, Closed]],
Cell[219750, 6574, 381, 14, 70, "Text",
  CellTags->"Anti5"],

Cell[CellGroupData[{
Cell[220156, 6592, 159, 4, 70, "Input",
  CellTags->"Anti5"],
Cell[220318, 6598, 212, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[220567, 6608, 130, 3, 70, "Input",
  CellTags->"Anti5"],
Cell[220700, 6613, 354, 10, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[221115, 6630, 66, 1, 70, "ObjectName",
  CellTags->"AntiCommutator"],

Cell[CellGroupData[{
Cell[221206, 6635, 66, 1, 70, "Subsubsection",
  CellTags->"AntiCommutator"],
Cell[221275, 6638, 146, 4, 70, "Text",
  CellTags->"AntiCommutator"],
Cell[221424, 6644, 642, 24, 70, "Text",
  CellTags->"AntiCommutator"]
}, Closed]],

Cell[CellGroupData[{
Cell[222103, 6673, 63, 1, 70, "Subsubsection",
  CellTags->"AntiCommutator"],
Cell[222169, 6676, 210, 9, 70, "Text",
  CellTags->"AntiCommutator"],
Cell[222382, 6687, 182, 4, 70, "Input",
  CellTags->"AntiCommutator"],

Cell[CellGroupData[{
Cell[222589, 6695, 176, 4, 70, "Input",
  CellTags->"AntiCommutator"],
Cell[222768, 6701, 256, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[223061, 6712, 153, 3, 70, "Input",
  CellTags->"AntiCommutator"],
Cell[223217, 6717, 193, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[223447, 6727, 347, 9, 70, "Input",
  CellTags->"AntiCommutator"],
Cell[223797, 6738, 526, 16, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[224360, 6759, 340, 9, 70, "Input",
  CellTags->"AntiCommutator"],
Cell[224703, 6770, 335, 9, 70, "Output"]
}, Closed]],
Cell[225053, 6782, 261, 6, 70, "Input",
  CellTags->"AntiCommutator"],
Cell[225317, 6790, 105, 1, 70, "Text",
  CellTags->"AntiCommutator"],

Cell[CellGroupData[{
Cell[225447, 6795, 215, 5, 70, "Input",
  CellTags->"AntiCommutator"],
Cell[225665, 6802, 108, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[225810, 6809, 220, 5, 70, "Input",
  CellTags->"AntiCommutator"],
Cell[226033, 6816, 227, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[226297, 6828, 304, 8, 70, "Input",
  CellTags->"AntiCommutator"],
Cell[226604, 6838, 135, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[226776, 6846, 300, 7, 70, "Input",
  CellTags->"AntiCommutator"],
Cell[227079, 6855, 351, 10, 70, "Output"]
}, Closed]],
Cell[227445, 6868, 283, 6, 70, "Input",
  CellTags->"AntiCommutator"],
Cell[227731, 6876, 214, 5, 70, "Input",
  CellTags->"AntiCommutator"],
Cell[227948, 6883, 276, 7, 70, "Input",
  CellTags->"AntiCommutator"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[228273, 6896, 66, 1, 70, "ObjectName",
  CellTags->"AntiQuarkField"],

Cell[CellGroupData[{
Cell[228364, 6901, 66, 1, 70, "Subsubsection",
  CellTags->"AntiQuarkField"],
Cell[228433, 6904, 198, 4, 70, "Text",
  CellTags->"AntiQuarkField"],
Cell[228634, 6910, 336, 14, 70, "Text",
  CellTags->"AntiQuarkField"]
}, Closed]],

Cell[CellGroupData[{
Cell[229007, 6929, 63, 1, 70, "Subsubsection",
  CellTags->"AntiQuarkField"],

Cell[CellGroupData[{
Cell[229095, 6934, 119, 2, 70, "Input",
  CellTags->"AntiQuarkField"],
Cell[229217, 6938, 140, 3, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[229418, 6948, 66, 1, 70, "ObjectName",
  CellTags->"AntiSymmetrize"],

Cell[CellGroupData[{
Cell[229509, 6953, 66, 1, 70, "Subsubsection",
  CellTags->"AntiSymmetrize"],
Cell[229578, 6956, 154, 4, 70, "Text",
  CellTags->"AntiSymmetrize"],
Cell[229735, 6962, 197, 8, 70, "Text",
  CellTags->"AntiSymmetrize"]
}, Closed]],

Cell[CellGroupData[{
Cell[229969, 6975, 63, 1, 70, "Subsubsection",
  CellTags->"AntiSymmetrize"],

Cell[CellGroupData[{
Cell[230057, 6980, 301, 8, 70, "Input",
  CellTags->"AntiSymmetrize"],
Cell[230361, 6990, 375, 11, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[230773, 7006, 321, 8, 70, "Input",
  CellTags->"AntiSymmetrize"],
Cell[231097, 7016, 767, 19, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[231925, 7042, 50, 1, 70, "ObjectName",
  CellTags->"Apart1"],

Cell[CellGroupData[{
Cell[232000, 7047, 58, 1, 70, "Subsubsection",
  CellTags->"Apart1"],
Cell[232061, 7050, 170, 4, 70, "Text",
  CellTags->"Apart1"],
Cell[232234, 7056, 298, 14, 70, "Text",
  CellTags->"Apart1"]
}, Closed]],

Cell[CellGroupData[{
Cell[232569, 7075, 55, 1, 70, "Subsubsection",
  CellTags->"Apart1"],
Cell[232627, 7078, 10585, 269, 70, "Input",
  CellTags->"Apart1"],

Cell[CellGroupData[{
Cell[243237, 7351, 259, 7, 70, "Input",
  CellTags->"Apart1"],
Cell[243499, 7360, 231, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[243767, 7371, 258, 7, 70, "Input",
  CellTags->"Apart1"],
Cell[244028, 7380, 230, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[244295, 7391, 158, 4, 70, "Input",
  CellTags->"Apart1"],
Cell[244456, 7397, 108, 2, 70, "Output"]
}, Closed]],
Cell[244579, 7402, 171, 4, 70, "Input",
  CellTags->"Apart1"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[244799, 7412, 50, 1, 70, "ObjectName",
  CellTags->"Apart2"],

Cell[CellGroupData[{
Cell[244874, 7417, 58, 1, 70, "Subsubsection",
  CellTags->"Apart2"],
Cell[244935, 7420, 109, 3, 70, "Text",
  CellTags->"Apart2"],
Cell[245047, 7425, 325, 14, 70, "Text",
  CellTags->"Apart2"]
}, Closed]],

Cell[CellGroupData[{
Cell[245409, 7444, 55, 1, 70, "Subsubsection",
  CellTags->"Apart2"],

Cell[CellGroupData[{
Cell[245489, 7449, 316, 9, 70, "Input",
  CellTags->"Apart2"],
Cell[245808, 7460, 1518, 36, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[247363, 7501, 133, 3, 70, "Input",
  CellTags->"Apart2"],
Cell[247499, 7506, 907, 25, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[248443, 7536, 173, 4, 70, "Input",
  CellTags->"Apart2"],
Cell[248619, 7542, 624, 18, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[249304, 7567, 50, 1, 70, "ObjectName",
  CellTags->"Apart3"],

Cell[CellGroupData[{
Cell[249379, 7572, 58, 1, 70, "Subsubsection",
  CellTags->"Apart3"],
Cell[249440, 7575, 121, 3, 70, "Text",
  CellTags->"Apart3"],
Cell[249564, 7580, 184, 9, 70, "Text",
  CellTags->"Apart3"]
}, Closed]],

Cell[CellGroupData[{
Cell[249785, 7594, 55, 1, 70, "Subsubsection",
  CellTags->"Apart3"],
Cell[249843, 7597, 10593, 269, 70, "Input",
  CellTags->"Apart3"],

Cell[CellGroupData[{
Cell[260461, 7870, 259, 7, 70, "Input",
  CellTags->"Apart3"],
Cell[260723, 7879, 231, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[260991, 7890, 258, 7, 70, "Input",
  CellTags->"Apart3"],
Cell[261252, 7899, 227, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[261516, 7910, 158, 4, 70, "Input",
  CellTags->"Apart3"],
Cell[261677, 7916, 108, 2, 70, "Output"]
}, Closed]],
Cell[261800, 7921, 171, 4, 70, "Input",
  CellTags->"Apart3"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[262020, 7931, 44, 1, 70, "ObjectName",
  CellTags->"B00"],

Cell[CellGroupData[{
Cell[262089, 7936, 55, 1, 70, "Subsubsection",
  CellTags->"B00"],
Cell[262147, 7939, 210, 5, 70, "Text",
  CellTags->"B00"],

Cell[CellGroupData[{
Cell[262382, 7948, 133, 3, 70, "Input",
  CellTags->"B00"],
Cell[262518, 7953, 186, 5, 70, "Output"]
}, Closed]],
Cell[262719, 7961, 379, 19, 70, "Text",
  CellTags->"B00"]
}, Closed]],

Cell[CellGroupData[{
Cell[263135, 7985, 52, 1, 70, "Subsubsection",
  CellTags->"B00"],
Cell[263190, 7988, 215, 7, 70, "Text",
  CellTags->"B00"],

Cell[CellGroupData[{
Cell[263430, 7999, 126, 3, 70, "Input",
  CellTags->"B00"],
Cell[263559, 8004, 183, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[263779, 8014, 259, 7, 70, "Input",
  CellTags->"B00"],
Cell[264041, 8023, 3724, 90, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[267802, 8118, 259, 7, 70, "Input",
  CellTags->"B00"],
Cell[268064, 8127, 1961, 54, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[270062, 8186, 314, 8, 70, "Input",
  CellTags->"B00"],
Cell[270379, 8196, 751, 22, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[271167, 8223, 224, 6, 70, "Input",
  CellTags->"B00"],
Cell[271394, 8231, 878, 24, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[272309, 8260, 302, 8, 70, "Input",
  CellTags->"B00"],
Cell[272614, 8270, 912, 25, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[273587, 8302, 42, 1, 70, "ObjectName",
  CellTags->"B0"],

Cell[CellGroupData[{
Cell[273654, 8307, 54, 1, 70, "Subsubsection",
  CellTags->"B0"],
Cell[273711, 8310, 312, 6, 70, "Text",
  CellTags->"B0"],

Cell[CellGroupData[{
Cell[274048, 8320, 131, 3, 70, "Input",
  CellTags->"B0"],
Cell[274182, 8325, 322, 8, 70, "Output"]
}, Closed]],
Cell[274519, 8336, 486, 24, 70, "Text",
  CellTags->"B0"]
}, Closed]],

Cell[CellGroupData[{
Cell[275042, 8365, 51, 1, 70, "Subsubsection",
  CellTags->"B0"],

Cell[CellGroupData[{
Cell[275118, 8370, 288, 8, 70, "Input",
  CellTags->"B0"],
Cell[275409, 8380, 382, 11, 70, "Output"]
}, Closed]],
Cell[275806, 8394, 287, 7, 70, "Input",
  CellTags->"B0"],

Cell[CellGroupData[{
Cell[276118, 8405, 192, 5, 70, "Input",
  CellTags->"B0"],
Cell[276313, 8412, 290, 8, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[276640, 8425, 222, 6, 70, "Input",
  CellTags->"B0"],
Cell[276865, 8433, 290, 8, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[277192, 8446, 220, 6, 70, "Input",
  CellTags->"B0"],
Cell[277415, 8454, 248, 6, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[277724, 8467, 44, 1, 70, "ObjectName",
  CellTags->"B11"],

Cell[CellGroupData[{
Cell[277793, 8472, 55, 1, 70, "Subsubsection",
  CellTags->"B11"],
Cell[277851, 8475, 544, 17, 70, "Text",
  CellTags->"B11"],

Cell[CellGroupData[{
Cell[278420, 8496, 133, 3, 70, "Input",
  CellTags->"B11"],
Cell[278556, 8501, 186, 5, 70, "Output"]
}, Closed]],
Cell[278757, 8509, 484, 24, 70, "Text",
  CellTags->"B11"]
}, Closed]],

Cell[CellGroupData[{
Cell[279278, 8538, 52, 1, 70, "Subsubsection",
  CellTags->"B11"],
Cell[279333, 8541, 233, 7, 70, "Text",
  CellTags->"B11"],

Cell[CellGroupData[{
Cell[279591, 8552, 126, 3, 70, "Input",
  CellTags->"B11"],
Cell[279720, 8557, 183, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[279940, 8567, 259, 7, 70, "Input",
  CellTags->"B11"],
Cell[280202, 8576, 3915, 96, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[284154, 8677, 259, 7, 70, "Input",
  CellTags->"B11"],
Cell[284416, 8686, 1636, 46, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[286089, 8737, 208, 5, 70, "Input",
  CellTags->"B11"],
Cell[286300, 8744, 187, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[286524, 8754, 259, 7, 70, "Input",
  CellTags->"B11"],
Cell[286786, 8763, 751, 22, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[287574, 8790, 207, 5, 70, "Input",
  CellTags->"B11"],
Cell[287784, 8797, 186, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[288007, 8807, 224, 6, 70, "Input",
  CellTags->"B11"],
Cell[288234, 8815, 310, 8, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[288581, 8828, 302, 8, 70, "Input",
  CellTags->"B11"],
Cell[288886, 8838, 342, 9, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[289289, 8854, 42, 1, 70, "ObjectName",
  CellTags->"B1"],

Cell[CellGroupData[{
Cell[289356, 8859, 54, 1, 70, "Subsubsection",
  CellTags->"B1"],
Cell[289413, 8862, 245, 7, 70, "Text",
  CellTags->"B1"],

Cell[CellGroupData[{
Cell[289683, 8873, 131, 3, 70, "Input",
  CellTags->"B1"],
Cell[289817, 8878, 186, 5, 70, "Output"]
}, Closed]],
Cell[290018, 8886, 612, 29, 70, "Text",
  CellTags->"B1"]
}, Closed]],

Cell[CellGroupData[{
Cell[290667, 8920, 51, 1, 70, "Subsubsection",
  CellTags->"B1"],

Cell[CellGroupData[{
Cell[290743, 8925, 257, 7, 70, "Input",
  CellTags->"B1"],
Cell[291003, 8934, 1502, 41, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[292542, 8980, 312, 8, 70, "Input",
  CellTags->"B1"],
Cell[292857, 8990, 382, 11, 70, "Output"]
}, Closed]],
Cell[293254, 9004, 231, 6, 70, "Input",
  CellTags->"B1"],

Cell[CellGroupData[{
Cell[293510, 9014, 257, 7, 70, "Input",
  CellTags->"B1"],
Cell[293770, 9023, 480, 14, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[294287, 9042, 222, 6, 70, "Input",
  CellTags->"B1"],
Cell[294512, 9050, 503, 14, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[295052, 9069, 192, 5, 70, "Input",
  CellTags->"B1"],
Cell[295247, 9076, 503, 14, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[295787, 9095, 287, 7, 70, "Input",
  CellTags->"B1"],
Cell[296077, 9104, 966, 24, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[297080, 9133, 336, 9, 70, "Input",
  CellTags->"B1"],
Cell[297419, 9144, 523, 14, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[298003, 9165, 80, 1, 70, "ObjectName",
  CellTags->"BackgroundGluonVertex"],

Cell[CellGroupData[{
Cell[298108, 9170, 73, 1, 70, "Subsubsection",
  CellTags->"BackgroundGluonVertex"],
Cell[298184, 9173, 1050, 19, 70, "Text",
  CellTags->"BackgroundGluonVertex"],

Cell[CellGroupData[{
Cell[299259, 9196, 169, 3, 70, "Input",
  CellTags->"BackgroundGluonVertex"],
Cell[299431, 9201, 351, 9, 70, "Output"]
}, Closed]],
Cell[299797, 9213, 214, 9, 70, "Text",
  CellTags->"BackgroundGluonVertex"]
}, Closed]],

Cell[CellGroupData[{
Cell[300048, 9227, 70, 1, 70, "Subsubsection",
  CellTags->"BackgroundGluonVertex"],

Cell[CellGroupData[{
Cell[300143, 9232, 428, 11, 70, "Input",
  CellTags->"BackgroundGluonVertex"],
Cell[300574, 9245, 3900, 102, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[304511, 9352, 513, 12, 70, "Input",
  CellTags->"BackgroundGluonVertex"],
Cell[305027, 9366, 10929, 269, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[315993, 9640, 482, 11, 70, "Input",
  CellTags->"BackgroundGluonVertex"],
Cell[316478, 9653, 4148, 107, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[320663, 9765, 569, 13, 70, "Input",
  CellTags->"BackgroundGluonVertex"],
Cell[321235, 9780, 11101, 271, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[332397, 10058, 42, 1, 70, "ObjectName",
  CellTags->"C0"],

Cell[CellGroupData[{
Cell[332464, 10063, 54, 1, 70, "Subsubsection",
  CellTags->"C0"],
Cell[332521, 10066, 463, 10, 70, "Text",
  CellTags->"C0"],
Cell[332987, 10078, 501, 24, 70, "Text",
  CellTags->"C0"]
}, Closed]],

Cell[CellGroupData[{
Cell[333525, 10107, 51, 1, 70, "Subsubsection",
  CellTags->"C0"],

Cell[CellGroupData[{
Cell[333601, 10112, 217, 6, 70, "Input",
  CellTags->"C0"],
Cell[333821, 10120, 507, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[334365, 10135, 245, 6, 70, "Input",
  CellTags->"C0"],
Cell[334613, 10143, 507, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[335157, 10158, 399, 11, 70, "Input",
  CellTags->"C0"],
Cell[335559, 10171, 507, 10, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[336127, 10188, 46, 1, 70, "ObjectName",
  CellTags->"Calc"],

Cell[CellGroupData[{
Cell[336198, 10193, 56, 1, 70, "Subsubsection",
  CellTags->"Calc"],
Cell[336257, 10196, 228, 5, 70, "Text",
  CellTags->"Calc"],
Cell[336488, 10203, 440, 19, 70, "Text",
  CellTags->"Calc"]
}, Closed]],

Cell[CellGroupData[{
Cell[336965, 10227, 62, 1, 70, "Subsubsection",
  CellTags->"Calc"],
Cell[337030, 10230, 382, 13, 70, "Text",
  CellTags->"Calc"],

Cell[CellGroupData[{
Cell[337437, 10247, 347, 9, 70, "Input",
  CellTags->"Calc"],
Cell[337787, 10258, 164, 4, 70, "Output"]
}, Closed]],
Cell[337966, 10265, 244, 9, 70, "Text",
  CellTags->"Calc"],

Cell[CellGroupData[{
Cell[338235, 10278, 312, 8, 70, "Input",
  CellTags->"Calc"],
Cell[338550, 10288, 466, 14, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[339053, 10307, 395, 11, 70, "Input",
  CellTags->"Calc"],
Cell[339451, 10320, 618, 18, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[340106, 10343, 129, 3, 70, "Input",
  CellTags->"Calc"],
Cell[340238, 10348, 776, 22, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[341051, 10375, 258, 6, 70, "Input",
  CellTags->"Calc"],
Cell[341312, 10383, 1492, 44, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[342841, 10432, 476, 14, 70, "Input",
  CellTags->"Calc"],
Cell[343320, 10448, 108, 2, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[343489, 10457, 42, 1, 70, "ObjectName",
  CellTags->"CA"],

Cell[CellGroupData[{
Cell[343556, 10462, 54, 1, 70, "Subsubsection",
  CellTags->"CA"],
Cell[343613, 10465, 87, 1, 70, "Text",
  CellTags->"CA"],
Cell[343703, 10468, 297, 14, 70, "Text",
  CellTags->"CA"]
}, Closed]],

Cell[CellGroupData[{
Cell[344037, 10487, 51, 1, 70, "Subsubsection",
  CellTags->"CA"],

Cell[CellGroupData[{
Cell[344113, 10492, 95, 2, 70, "Input",
  CellTags->"CA"],
Cell[344211, 10496, 134, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[344382, 10504, 210, 5, 70, "Input",
  CellTags->"CA"],
Cell[344595, 10511, 108, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[344740, 10518, 97, 2, 70, "Input",
  CellTags->"CA"],
Cell[344840, 10522, 108, 2, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[345009, 10531, 50, 1, 70, "ObjectName",
  CellTags->"Cases2"],

Cell[CellGroupData[{
Cell[345084, 10536, 58, 1, 70, "Subsubsection",
  CellTags->"Cases2"],
Cell[345145, 10539, 294, 6, 70, "Text",
  CellTags->"Cases2"]
}, Closed]],

Cell[CellGroupData[{
Cell[345476, 10550, 64, 1, 70, "Subsubsection",
  CellTags->"Cases2"],

Cell[CellGroupData[{
Cell[345565, 10555, 374, 10, 70, "Input",
  CellTags->"Cases2"],
Cell[345942, 10567, 322, 9, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[346301, 10581, 390, 11, 70, "Input",
  CellTags->"Cases2"],
Cell[346694, 10594, 326, 9, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[347057, 10608, 522, 14, 70, "Input",
  CellTags->"Cases2"],
Cell[347582, 10624, 415, 11, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[348034, 10640, 397, 10, 70, "Input",
  CellTags->"Cases2"],
Cell[348434, 10652, 673, 19, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[349168, 10678, 42, 1, 70, "ObjectName",
  CellTags->"CF"],

Cell[CellGroupData[{
Cell[349235, 10683, 54, 1, 70, "Subsubsection",
  CellTags->"CF"],
Cell[349292, 10686, 107, 3, 70, "Text",
  CellTags->"CF"],
Cell[349402, 10691, 297, 14, 70, "Text",
  CellTags->"CF"]
}, Closed]],

Cell[CellGroupData[{
Cell[349736, 10710, 51, 1, 70, "Subsubsection",
  CellTags->"CF"],

Cell[CellGroupData[{
Cell[349812, 10715, 95, 2, 70, "Input",
  CellTags->"CF"],
Cell[349910, 10719, 134, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[350081, 10727, 220, 5, 70, "Input",
  CellTags->"CF"],
Cell[350304, 10734, 223, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[350564, 10745, 97, 2, 70, "Input",
  CellTags->"CF"],
Cell[350664, 10749, 108, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[350809, 10756, 214, 5, 70, "Input",
  CellTags->"CF"],
Cell[351026, 10763, 134, 3, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[351221, 10773, 68, 1, 70, "ObjectName",
  CellTags->"ChangeDimension"],

Cell[CellGroupData[{
Cell[351314, 10778, 67, 1, 70, "Subsubsection",
  CellTags->"ChangeDimension"],
Cell[351384, 10781, 211, 5, 70, "Text",
  CellTags->"ChangeDimension"],
Cell[351598, 10788, 562, 24, 70, "Text",
  CellTags->"ChangeDimension"]
}, Closed]],

Cell[CellGroupData[{
Cell[352197, 10817, 64, 1, 70, "Subsubsection",
  CellTags->"ChangeDimension"],
Cell[352264, 10820, 220, 5, 70, "Text",
  CellTags->"ChangeDimension"],

Cell[CellGroupData[{
Cell[352509, 10829, 254, 6, 70, "Input",
  CellTags->"ChangeDimension"],
Cell[352766, 10837, 221, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[353024, 10849, 183, 4, 70, "Input",
  CellTags->"ChangeDimension"],
Cell[353210, 10855, 221, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[353468, 10867, 144, 3, 70, "Input",
  CellTags->"ChangeDimension"],
Cell[353615, 10872, 295, 7, 70, "Output"]
}, Closed]],
Cell[353925, 10882, 120, 3, 70, "Text",
  CellTags->"ChangeDimension"],

Cell[CellGroupData[{
Cell[354070, 10889, 242, 6, 70, "Input",
  CellTags->"ChangeDimension"],
Cell[354315, 10897, 233, 5, 70, "Output"]
}, Closed]],
Cell[354563, 10905, 106, 1, 70, "Text",
  CellTags->"ChangeDimension"],

Cell[CellGroupData[{
Cell[354694, 10910, 582, 15, 70, "Input",
  CellTags->"ChangeDimension"],
Cell[355279, 10927, 707, 18, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[356023, 10950, 185, 4, 70, "Input",
  CellTags->"ChangeDimension"],
Cell[356211, 10956, 240, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[356488, 10968, 265, 6, 70, "Input",
  CellTags->"ChangeDimension"],
Cell[356756, 10976, 240, 7, 70, "Output"]
}, Closed]],
Cell[357011, 10986, 135, 4, 70, "Text",
  CellTags->"ChangeDimension"],
Cell[357149, 10992, 251, 6, 70, "Input",
  CellTags->"ChangeDimension"],
Cell[357403, 11000, 215, 5, 70, "Text",
  CellTags->"ChangeDimension"],
Cell[357621, 11007, 244, 6, 70, "Input",
  CellTags->"ChangeDimension"],

Cell[CellGroupData[{
Cell[357890, 11017, 262, 6, 70, "Input",
  CellTags->"ChangeDimension"],
Cell[358155, 11025, 665, 20, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[358857, 11050, 219, 5, 70, "Input",
  CellTags->"ChangeDimension"],
Cell[359079, 11057, 665, 20, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[359781, 11082, 213, 5, 70, "Input",
  CellTags->"ChangeDimension"],
Cell[359997, 11089, 342, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[360376, 11104, 173, 4, 70, "Input",
  CellTags->"ChangeDimension"],
Cell[360552, 11110, 131, 3, 70, "Output"]
}, Closed]],
Cell[360698, 11116, 244, 6, 70, "Input",
  CellTags->"ChangeDimension"],
Cell[360945, 11124, 194, 5, 70, "Input",
  CellTags->"ChangeDimension"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[361188, 11135, 90, 1, 70, "ObjectName",
  CellTags->"ChargeConjugationMatrixInv"],

Cell[CellGroupData[{
Cell[361303, 11140, 78, 1, 70, "Subsubsection",
  CellTags->"ChargeConjugationMatrixInv"],
Cell[361384, 11143, 196, 4, 70, "Text",
  CellTags->"ChargeConjugationMatrixInv"],
Cell[361583, 11149, 255, 9, 70, "Text",
  CellTags->"ChargeConjugationMatrixInv"]
}, Closed]],

Cell[CellGroupData[{
Cell[361875, 11163, 75, 1, 70, "Subsubsection",
  CellTags->"ChargeConjugationMatrixInv"],

Cell[CellGroupData[{
Cell[361975, 11168, 253, 5, 70, "Input",
  CellTags->"ChargeConjugationMatrixInv"],
Cell[362231, 11175, 347, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[362615, 11190, 151, 3, 70, "Input",
  CellTags->"ChargeConjugationMatrixInv"],
Cell[362769, 11195, 285, 8, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[363091, 11208, 248, 5, 70, "Input",
  CellTags->"ChargeConjugationMatrixInv"],
Cell[363342, 11215, 237, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[363616, 11226, 151, 3, 70, "Input",
  CellTags->"ChargeConjugationMatrixInv"],
Cell[363770, 11231, 198, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[364005, 11241, 195, 4, 70, "Input",
  CellTags->"ChargeConjugationMatrixInv"],
Cell[364203, 11247, 190, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[364430, 11257, 147, 3, 70, "Input",
  CellTags->"ChargeConjugationMatrixInv"],
Cell[364580, 11262, 108, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[364725, 11269, 168, 3, 70, "Input",
  CellTags->"ChargeConjugationMatrixInv"],
Cell[364896, 11274, 130, 3, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[365087, 11284, 84, 1, 70, "ObjectName",
  CellTags->"ChargeConjugationMatrix"],

Cell[CellGroupData[{
Cell[365196, 11289, 75, 1, 70, "Subsubsection",
  CellTags->"ChargeConjugationMatrix"],
Cell[365274, 11292, 182, 6, 70, "Text",
  CellTags->"ChargeConjugationMatrix"],
Cell[365459, 11300, 261, 9, 70, "Text",
  CellTags->"ChargeConjugationMatrix"]
}, Closed]],

Cell[CellGroupData[{
Cell[365757, 11314, 72, 1, 70, "Subsubsection",
  CellTags->"ChargeConjugationMatrix"],

Cell[CellGroupData[{
Cell[365854, 11319, 250, 5, 70, "Input",
  CellTags->"ChargeConjugationMatrix"],
Cell[366107, 11326, 347, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[366491, 11341, 148, 3, 70, "Input",
  CellTags->"ChargeConjugationMatrix"],
Cell[366642, 11346, 285, 8, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[366964, 11359, 245, 5, 70, "Input",
  CellTags->"ChargeConjugationMatrix"],
Cell[367212, 11366, 237, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[367486, 11377, 148, 3, 70, "Input",
  CellTags->"ChargeConjugationMatrix"],
Cell[367637, 11382, 198, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[367872, 11392, 162, 3, 70, "Input",
  CellTags->"ChargeConjugationMatrix"],
Cell[368037, 11397, 130, 3, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[368228, 11407, 74, 1, 70, "ObjectName",
  CellTags->"ChiralityProjector"],

Cell[CellGroupData[{
Cell[368327, 11412, 70, 1, 70, "Subsubsection",
  CellTags->"ChiralityProjector"],
Cell[368400, 11415, 577, 19, 70, "Text",
  CellTags->"ChiralityProjector"],
Cell[368980, 11436, 442, 19, 70, "Text",
  CellTags->"ChiralityProjector"]
}, Closed]],

Cell[CellGroupData[{
Cell[369459, 11460, 67, 1, 70, "Subsubsection",
  CellTags->"ChiralityProjector"],

Cell[CellGroupData[{
Cell[369551, 11465, 316, 8, 70, "Input",
  CellTags->"ChiralityProjector"],
Cell[369870, 11475, 249, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[370156, 11487, 142, 3, 70, "Input",
  CellTags->"ChiralityProjector"],
Cell[370301, 11492, 249, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[370587, 11504, 233, 5, 70, "Input",
  CellTags->"ChiralityProjector"],
Cell[370823, 11511, 443, 13, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[371327, 11531, 54, 1, 70, "ObjectName",
  CellTags->"Chisholm"],

Cell[CellGroupData[{
Cell[371406, 11536, 60, 1, 70, "Subsubsection",
  CellTags->"Chisholm"],
Cell[371469, 11539, 143, 4, 70, "Text",
  CellTags->"Chisholm"],
Cell[371615, 11545, 201, 9, 70, "Text",
  CellTags->"Chisholm"]
}, Closed]],

Cell[CellGroupData[{
Cell[371853, 11559, 57, 1, 70, "Subsubsection",
  CellTags->"Chisholm"],

Cell[CellGroupData[{
Cell[371935, 11564, 249, 6, 70, "Input",
  CellTags->"Chisholm"],
Cell[372187, 11572, 2730, 78, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[374954, 11655, 220, 5, 70, "Input",
  CellTags->"Chisholm"],
Cell[375177, 11662, 259, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[375473, 11673, 171, 4, 70, "Input",
  CellTags->"Chisholm"],
Cell[375647, 11679, 1887, 54, 70, "Output"]
}, Closed]],
Cell[377549, 11736, 78, 1, 70, "Text",
  CellTags->"Chisholm"],

Cell[CellGroupData[{
Cell[377652, 11741, 162, 4, 70, "Input",
  CellTags->"Chisholm"],
Cell[377817, 11747, 109, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[377963, 11754, 171, 4, 70, "Input",
  CellTags->"Chisholm"],
Cell[378137, 11760, 1887, 54, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[380061, 11819, 162, 4, 70, "Input",
  CellTags->"Chisholm"],
Cell[380226, 11825, 109, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[380372, 11832, 206, 5, 70, "Input",
  CellTags->"Chisholm"],
Cell[380581, 11839, 856, 24, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[381474, 11868, 138, 3, 70, "Input",
  CellTags->"Chisholm"],
Cell[381615, 11873, 2187, 63, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[383839, 11941, 280, 7, 70, "Input",
  CellTags->"Chisholm"],
Cell[384122, 11950, 431, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[384590, 11965, 171, 4, 70, "Input",
  CellTags->"Chisholm"],
Cell[384764, 11971, 15974, 439, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[400775, 12415, 171, 4, 70, "Input",
  CellTags->"Chisholm"],
Cell[400949, 12421, 15974, 439, 70, "Output"]
}, Closed]],
Cell[416938, 12863, 86, 1, 70, "Text",
  CellTags->"Chisholm"],

Cell[CellGroupData[{
Cell[417049, 12868, 162, 4, 70, "Input",
  CellTags->"Chisholm"],
Cell[417214, 12874, 133, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[417384, 12882, 162, 4, 70, "Input",
  CellTags->"Chisholm"],
Cell[417549, 12888, 133, 3, 70, "Output"]
}, Closed]],
Cell[417697, 12894, 234, 6, 70, "Input",
  CellTags->"Chisholm"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[417980, 12906, 76, 1, 70, "ObjectName",
  CellTags->"ClearScalarProducts"],

Cell[CellGroupData[{
Cell[418081, 12911, 71, 1, 70, "Subsubsection",
  CellTags->"ClearScalarProducts"],
Cell[418155, 12914, 146, 4, 70, "Text",
  CellTags->"ClearScalarProducts"],
Cell[418304, 12920, 526, 23, 70, "Text",
  CellTags->"ClearScalarProducts"]
}, Closed]],

Cell[CellGroupData[{
Cell[418867, 12948, 68, 1, 70, "Subsubsection",
  CellTags->"ClearScalarProducts"],

Cell[CellGroupData[{
Cell[418960, 12953, 236, 6, 70, "Input",
  CellTags->"ClearScalarProducts"],
Cell[419199, 12961, 136, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[419372, 12969, 253, 6, 70, "Input",
  CellTags->"ClearScalarProducts"],
Cell[419628, 12977, 136, 3, 70, "Output"]
}, Closed]],
Cell[419779, 12983, 129, 2, 70, "Input",
  CellTags->"ClearScalarProducts"],

Cell[CellGroupData[{
Cell[419933, 12989, 253, 6, 70, "Input",
  CellTags->"ClearScalarProducts"],
Cell[420189, 12997, 183, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[420409, 13007, 180, 4, 70, "Input",
  CellTags->"ClearScalarProducts"],
Cell[420592, 13013, 183, 5, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[420836, 13025, 54, 1, 70, "ObjectName",
  CellTags->"Collect2"],

Cell[CellGroupData[{
Cell[420915, 13030, 60, 1, 70, "Subsubsection",
  CellTags->"Collect2"],
Cell[420978, 13033, 614, 10, 70, "Text",
  CellTags->"Collect2"],

Cell[CellGroupData[{
Cell[421617, 13047, 143, 3, 70, "Input",
  CellTags->"Collect2"],
Cell[421763, 13052, 446, 10, 70, "Output"]
}, Closed]],
Cell[422224, 13065, 189, 9, 70, "Text",
  CellTags->"Collect2"]
}, Closed]],

Cell[CellGroupData[{
Cell[422450, 13079, 57, 1, 70, "Subsubsection",
  CellTags->"Collect2"],

Cell[CellGroupData[{
Cell[422532, 13084, 542, 14, 70, "Input",
  CellTags->"Collect2"],
Cell[423077, 13100, 950, 27, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[424064, 13132, 217, 5, 70, "Input",
  CellTags->"Collect2"],
Cell[424284, 13139, 921, 25, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[425242, 13169, 218, 5, 70, "Input",
  CellTags->"Collect2"],
Cell[425463, 13176, 950, 27, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[426450, 13208, 652, 18, 70, "Input",
  CellTags->"Collect2"],
Cell[427105, 13228, 599, 16, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[427741, 13249, 388, 10, 70, "Input",
  CellTags->"Collect2"],
Cell[428132, 13261, 998, 30, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[429167, 13296, 140, 3, 70, "Input",
  CellTags->"Collect2"],
Cell[429310, 13301, 983, 27, 70, "Output"]
}, Closed]],
Cell[430308, 13331, 162, 4, 70, "Input",
  CellTags->"Collect2"],

Cell[CellGroupData[{
Cell[430495, 13339, 377, 10, 70, "Input",
  CellTags->"Collect2"],
Cell[430875, 13351, 1132, 30, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[432044, 13386, 176, 4, 70, "Input",
  CellTags->"Collect2"],
Cell[432223, 13392, 784, 21, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[433068, 13420, 52, 1, 70, "ObjectName",
  CellTags->"Combine"],

Cell[CellGroupData[{
Cell[433145, 13425, 59, 1, 70, "Subsubsection",
  CellTags->"Combine"],
Cell[433207, 13428, 316, 6, 70, "Text",
  CellTags->"Combine"],

Cell[CellGroupData[{
Cell[433548, 13438, 141, 3, 70, "Input",
  CellTags->"Combine"],
Cell[433692, 13443, 189, 5, 70, "Output"]
}, Closed]],
Cell[433896, 13451, 188, 9, 70, "Text",
  CellTags->"Combine"]
}, Closed]],

Cell[CellGroupData[{
Cell[434121, 13465, 56, 1, 70, "Subsubsection",
  CellTags->"Combine"],

Cell[CellGroupData[{
Cell[434202, 13470, 363, 11, 70, "Input",
  CellTags->"Combine"],
Cell[434568, 13483, 360, 10, 70, "Output"]
}, Closed]],
Cell[434943, 13496, 125, 4, 70, "Text",
  CellTags->"Combine"],

Cell[CellGroupData[{
Cell[435093, 13504, 364, 11, 70, "Input",
  CellTags->"Combine"],
Cell[435460, 13517, 347, 9, 70, "Output"]
}, Closed]],
Cell[435822, 13529, 176, 4, 70, "Text",
  CellTags->"Combine"],

Cell[CellGroupData[{
Cell[436023, 13537, 443, 12, 70, "Input",
  CellTags->"Combine"],
Cell[436469, 13551, 347, 9, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[436877, 13567, 74, 1, 70, "ObjectName",
  CellTags->"CommutatorExplicit"],

Cell[CellGroupData[{
Cell[436976, 13572, 70, 1, 70, "Subsubsection",
  CellTags->"CommutatorExplicit"],
Cell[437049, 13575, 158, 4, 70, "Text",
  CellTags->"CommutatorExplicit"],
Cell[437210, 13581, 319, 14, 70, "Text",
  CellTags->"CommutatorExplicit"]
}, Closed]],

Cell[CellGroupData[{
Cell[437566, 13600, 67, 1, 70, "Subsubsection",
  CellTags->"CommutatorExplicit"],
Cell[437636, 13603, 207, 4, 70, "Input",
  CellTags->"CommutatorExplicit"],

Cell[CellGroupData[{
Cell[437868, 13611, 176, 4, 70, "Input",
  CellTags->"CommutatorExplicit"],
Cell[438047, 13617, 201, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[438285, 13627, 157, 3, 70, "Input",
  CellTags->"CommutatorExplicit"],
Cell[438445, 13632, 193, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[438675, 13642, 238, 6, 70, "Input",
  CellTags->"CommutatorExplicit"],
Cell[438916, 13650, 400, 11, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[439353, 13666, 157, 3, 70, "Input",
  CellTags->"CommutatorExplicit"],
Cell[439513, 13671, 449, 13, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[439999, 13689, 203, 5, 70, "Input",
  CellTags->"CommutatorExplicit"],
Cell[440205, 13696, 427, 11, 70, "Output"]
}, Closed]],
Cell[440647, 13710, 209, 4, 70, "Input",
  CellTags->"CommutatorExplicit"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[440905, 13720, 58, 1, 70, "ObjectName",
  CellTags->"Commutator"],

Cell[CellGroupData[{
Cell[440988, 13725, 62, 1, 70, "Subsubsection",
  CellTags->"Commutator"],
Cell[441053, 13728, 139, 4, 70, "Text",
  CellTags->"Commutator"],
Cell[441195, 13734, 650, 24, 70, "Text",
  CellTags->"Commutator"]
}, Closed]],

Cell[CellGroupData[{
Cell[441882, 13763, 59, 1, 70, "Subsubsection",
  CellTags->"Commutator"],
Cell[441944, 13766, 199, 4, 70, "Input",
  CellTags->"Commutator"],

Cell[CellGroupData[{
Cell[442168, 13774, 168, 4, 70, "Input",
  CellTags->"Commutator"],
Cell[442339, 13780, 201, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[442577, 13790, 149, 3, 70, "Input",
  CellTags->"Commutator"],
Cell[442729, 13795, 193, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[442959, 13805, 304, 8, 70, "Input",
  CellTags->"Commutator"],
Cell[443266, 13815, 427, 11, 70, "Output"]
}, Closed]],
Cell[443708, 13829, 201, 4, 70, "Input",
  CellTags->"Commutator"],
Cell[443912, 13835, 69, 1, 70, "Text",
  CellTags->"Commutator"],
Cell[443984, 13838, 269, 6, 70, "Input",
  CellTags->"Commutator"],

Cell[CellGroupData[{
Cell[444278, 13848, 557, 15, 70, "Input",
  CellTags->"Commutator"],
Cell[444838, 13865, 887, 22, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[445762, 13892, 142, 3, 70, "Input",
  CellTags->"Commutator"],
Cell[445907, 13897, 108, 2, 70, "Output"]
}, Closed]],
Cell[446030, 13902, 141, 3, 70, "Input",
  CellTags->"Commutator"],
Cell[446174, 13907, 191, 4, 70, "Input",
  CellTags->"Commutator"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[446414, 13917, 70, 1, 70, "ObjectName",
  CellTags->"ComplexConjugate"],

Cell[CellGroupData[{
Cell[446509, 13922, 68, 1, 70, "Subsubsection",
  CellTags->"ComplexConjugate"],
Cell[446580, 13925, 415, 7, 70, "Text",
  CellTags->"ComplexConjugate"],
Cell[446998, 13934, 482, 19, 70, "Text",
  CellTags->"ComplexConjugate"]
}, Closed]],

Cell[CellGroupData[{
Cell[447517, 13958, 65, 1, 70, "Subsubsection",
  CellTags->"ComplexConjugate"],

Cell[CellGroupData[{
Cell[447607, 13963, 233, 5, 70, "Input",
  CellTags->"ComplexConjugate"],
Cell[447843, 13970, 352, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[448232, 13985, 149, 3, 70, "Input",
  CellTags->"ComplexConjugate"],
Cell[448384, 13990, 350, 8, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[448771, 14003, 184, 4, 70, "Input",
  CellTags->"ComplexConjugate"],
Cell[448958, 14009, 264, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[449259, 14020, 153, 3, 70, "Input",
  CellTags->"ComplexConjugate"],
Cell[449415, 14025, 598, 17, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[450050, 14047, 219, 5, 70, "Input",
  CellTags->"ComplexConjugate"],
Cell[450272, 14054, 735, 22, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[451044, 14081, 153, 3, 70, "Input",
  CellTags->"ComplexConjugate"],
Cell[451200, 14086, 735, 22, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[451972, 14113, 227, 5, 70, "Input",
  CellTags->"ComplexConjugate"],
Cell[452202, 14120, 509, 16, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[452748, 14141, 327, 8, 70, "Input",
  CellTags->"ComplexConjugate"],
Cell[453078, 14151, 247, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[453362, 14161, 323, 8, 70, "Input",
  CellTags->"ComplexConjugate"],
Cell[453688, 14171, 550, 13, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[454275, 14189, 153, 3, 70, "Input",
  CellTags->"ComplexConjugate"],
Cell[454431, 14194, 706, 17, 70, "Output"]
}, Closed]],
Cell[455152, 14214, 167, 4, 70, "Text",
  CellTags->"ComplexConjugate"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[455368, 14224, 62, 1, 70, "ObjectName",
  CellTags->"ComplexIndex"],

Cell[CellGroupData[{
Cell[455455, 14229, 64, 1, 70, "Subsubsection",
  CellTags->"ComplexIndex"],
Cell[455522, 14232, 155, 4, 70, "Text",
  CellTags->"ComplexIndex"],
Cell[455680, 14238, 208, 9, 70, "Text",
  CellTags->"ComplexIndex"]
}, Closed]],

Cell[CellGroupData[{
Cell[455925, 14252, 61, 1, 70, "Subsubsection",
  CellTags->"ComplexIndex"],

Cell[CellGroupData[{
Cell[456011, 14257, 149, 3, 70, "Input",
  CellTags->"ComplexIndex"],
Cell[456163, 14262, 112, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[456312, 14269, 149, 3, 70, "Input",
  CellTags->"ComplexIndex"],
Cell[456464, 14274, 140, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[456641, 14282, 141, 3, 70, "Input",
  CellTags->"ComplexIndex"],
Cell[456785, 14287, 179, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[457001, 14295, 174, 4, 70, "Input",
  CellTags->"ComplexIndex"],
Cell[457178, 14301, 138, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[457353, 14309, 149, 3, 70, "Input",
  CellTags->"ComplexIndex"],
Cell[457505, 14314, 319, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[457861, 14329, 141, 3, 70, "Input",
  CellTags->"ComplexIndex"],
Cell[458005, 14334, 288, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[458330, 14345, 149, 3, 70, "Input",
  CellTags->"ComplexIndex"],
Cell[458482, 14350, 285, 9, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[458828, 14366, 54, 1, 70, "ObjectName",
  CellTags->"Contract"],

Cell[CellGroupData[{
Cell[458907, 14371, 60, 1, 70, "Subsubsection",
  CellTags->"Contract"],
Cell[458970, 14374, 412, 7, 70, "Text",
  CellTags->"Contract"],

Cell[CellGroupData[{
Cell[459407, 14385, 143, 3, 70, "Input",
  CellTags->"Contract"],
Cell[459553, 14390, 628, 13, 70, "Output"]
}, Closed]],
Cell[460196, 14406, 456, 19, 70, "Text",
  CellTags->"Contract"]
}, Closed]],

Cell[CellGroupData[{
Cell[460689, 14430, 57, 1, 70, "Subsubsection",
  CellTags->"Contract"],

Cell[CellGroupData[{
Cell[460771, 14435, 279, 7, 70, "Input",
  CellTags->"Contract"],
Cell[461053, 14444, 252, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[461342, 14456, 137, 3, 70, "Input",
  CellTags->"Contract"],
Cell[461482, 14461, 285, 9, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[461804, 14475, 240, 6, 70, "Input",
  CellTags->"Contract"],
Cell[462047, 14483, 314, 9, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[462398, 14497, 137, 3, 70, "Input",
  CellTags->"Contract"],
Cell[462538, 14502, 283, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[462858, 14514, 176, 4, 70, "Input",
  CellTags->"Contract"],
Cell[463037, 14520, 184, 5, 70, "Output"]
}, Closed]],
Cell[463236, 14528, 84, 1, 70, "Text",
  CellTags->"Contract"],

Cell[CellGroupData[{
Cell[463345, 14533, 137, 3, 70, "Input",
  CellTags->"Contract"],
Cell[463485, 14538, 108, 2, 70, "Output"]
}, Closed]],
Cell[463608, 14543, 209, 5, 70, "Text",
  CellTags->"Contract"],

Cell[CellGroupData[{
Cell[463842, 14552, 277, 7, 70, "Input",
  CellTags->"Contract"],
Cell[464122, 14561, 298, 8, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[464457, 14574, 137, 3, 70, "Input",
  CellTags->"Contract"],
Cell[464597, 14579, 108, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[464742, 14586, 277, 7, 70, "Input",
  CellTags->"Contract"],
Cell[465022, 14595, 298, 8, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[465357, 14608, 273, 7, 70, "Input",
  CellTags->"Contract"],
Cell[465633, 14617, 199, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[465869, 14627, 142, 3, 70, "Input",
  CellTags->"Contract"],
Cell[466014, 14632, 268, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[466319, 14644, 335, 9, 70, "Input",
  CellTags->"Contract"],
Cell[466657, 14655, 606, 18, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[467300, 14678, 137, 3, 70, "Input",
  CellTags->"Contract"],
Cell[467440, 14683, 835, 23, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[468312, 14711, 323, 8, 70, "Input",
  CellTags->"Contract"],
Cell[468638, 14721, 765, 22, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[469440, 14748, 137, 3, 70, "Input",
  CellTags->"Contract"],
Cell[469580, 14753, 605, 18, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[470222, 14776, 400, 10, 70, "Input",
  CellTags->"Contract"],
Cell[470625, 14788, 1324, 39, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[471986, 14832, 137, 3, 70, "Input",
  CellTags->"Contract"],
Cell[472126, 14837, 249, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[472412, 14849, 508, 13, 70, "Input",
  CellTags->"Contract"],
Cell[472923, 14864, 460, 11, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[473420, 14880, 171, 4, 70, "Input",
  CellTags->"Contract"],
Cell[473594, 14886, 646, 19, 70, "Output"]
}, Closed]],
Cell[474255, 14908, 237, 6, 70, "Input",
  CellTags->"Contract"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[474541, 14920, 56, 1, 70, "ObjectName",
  CellTags->"Convolute"],
Cell[474600, 14923, 52, 1, 70, "Text",
  CellTags->"Convolute"],
Cell[474655, 14926, 1136, 28, 70, "Text",
  CellTags->"Convolute"],

Cell[CellGroupData[{
Cell[475816, 14958, 145, 3, 70, "Input",
  CellTags->"Convolute"],
Cell[475964, 14963, 469, 12, 70, "Output"]
}, Closed]],
Cell[476448, 14978, 217, 9, 70, "Text",
  CellTags->"Convolute"],

Cell[CellGroupData[{
Cell[476690, 14991, 58, 1, 70, "Subsubsection",
  CellTags->"Convolute"],

Cell[CellGroupData[{
Cell[476773, 14996, 166, 4, 70, "Input",
  CellTags->"Convolute"],
Cell[476942, 15002, 166, 4, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[477145, 15011, 166, 4, 70, "Input",
  CellTags->"Convolute"],
Cell[477314, 15017, 195, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[477546, 15027, 166, 4, 70, "Input",
  CellTags->"Convolute"],
Cell[477715, 15033, 135, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[477887, 15041, 224, 6, 70, "Input",
  CellTags->"Convolute"],
Cell[478114, 15049, 238, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[478389, 15060, 277, 7, 70, "Input",
  CellTags->"Convolute"],
Cell[478669, 15069, 238, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[478944, 15080, 224, 6, 70, "Input",
  CellTags->"Convolute"],
Cell[479171, 15088, 329, 9, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[479537, 15102, 282, 8, 70, "Input",
  CellTags->"Convolute"],
Cell[479822, 15112, 637, 18, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[480496, 15135, 233, 6, 70, "Input",
  CellTags->"Convolute"],
Cell[480732, 15143, 399, 11, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[481168, 15159, 266, 7, 70, "Input",
  CellTags->"Convolute"],
Cell[481437, 15168, 316, 9, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[481790, 15182, 291, 8, 70, "Input",
  CellTags->"Convolute"],
Cell[482084, 15192, 422, 11, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[482543, 15208, 324, 9, 70, "Input",
  CellTags->"Convolute"],
Cell[482870, 15219, 699, 19, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[483606, 15243, 295, 8, 70, "Input",
  CellTags->"Convolute"],
Cell[483904, 15253, 848, 23, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[484789, 15281, 233, 6, 70, "Input",
  CellTags->"Convolute"],
Cell[485025, 15289, 249, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[485311, 15301, 233, 6, 70, "Input",
  CellTags->"Convolute"],
Cell[485547, 15309, 366, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[485950, 15324, 320, 9, 70, "Input",
  CellTags->"Convolute"],
Cell[486273, 15335, 539, 16, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[486849, 15356, 202, 5, 70, "Input",
  CellTags->"Convolute"],
Cell[487054, 15363, 263, 8, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[487354, 15376, 238, 6, 70, "Input",
  CellTags->"Convolute"],
Cell[487595, 15384, 273, 8, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[487905, 15397, 260, 7, 70, "Input",
  CellTags->"Convolute"],
Cell[488168, 15406, 537, 15, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[488742, 15426, 262, 7, 70, "Input",
  CellTags->"Convolute"],
Cell[489007, 15435, 389, 11, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[489433, 15451, 291, 8, 70, "Input",
  CellTags->"Convolute"],
Cell[489727, 15461, 696, 19, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[490460, 15485, 262, 7, 70, "Input",
  CellTags->"Convolute"],
Cell[490725, 15494, 507, 14, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[491269, 15513, 233, 6, 70, "Input",
  CellTags->"Convolute"],
Cell[491505, 15521, 249, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[491791, 15533, 202, 5, 70, "Input",
  CellTags->"Convolute"],
Cell[491996, 15540, 212, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[492245, 15551, 353, 10, 70, "Input",
  CellTags->"Convolute"],
Cell[492601, 15563, 1054, 30, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[493716, 15600, 58, 1, 70, "ObjectName",
  CellTags->"CovariantD"],

Cell[CellGroupData[{
Cell[493799, 15605, 62, 1, 70, "Subsubsection",
  CellTags->"CovariantD"],
Cell[493864, 15608, 735, 12, 70, "Text",
  CellTags->"CovariantD"],

Cell[CellGroupData[{
Cell[494624, 15624, 147, 3, 70, "Input",
  CellTags->"CovariantD"],
Cell[494774, 15629, 491, 11, 70, "Output"]
}, Closed]],
Cell[495280, 15643, 186, 4, 70, "Text",
  CellTags->"CovariantD"],
Cell[495469, 15649, 488, 19, 70, "Text",
  CellTags->"CovariantD"]
}, Closed]],

Cell[CellGroupData[{
Cell[495994, 15673, 59, 1, 70, "Subsubsection",
  CellTags->"CovariantD"],

Cell[CellGroupData[{
Cell[496078, 15678, 145, 3, 70, "Input",
  CellTags->"CovariantD"],
Cell[496226, 15683, 138, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[496401, 15691, 182, 4, 70, "Input",
  CellTags->"CovariantD"],
Cell[496586, 15697, 186, 4, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[496809, 15706, 217, 5, 70, "Input",
  CellTags->"CovariantD"],
Cell[497029, 15713, 1299, 38, 70, "Output"]
}, Closed]],
Cell[498343, 15754, 165, 4, 70, "Text",
  CellTags->"CovariantD"],

Cell[CellGroupData[{
Cell[498533, 15762, 148, 3, 70, "Input",
  CellTags->"CovariantD"],
Cell[498684, 15767, 195, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[498916, 15777, 185, 4, 70, "Input",
  CellTags->"CovariantD"],
Cell[499104, 15783, 243, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[499384, 15794, 235, 5, 70, "Input",
  CellTags->"CovariantD"],
Cell[499622, 15801, 1232, 35, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[500891, 15841, 215, 5, 70, "Input",
  CellTags->"CovariantD"],
Cell[501109, 15848, 1201, 34, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[502347, 15887, 224, 5, 70, "Input",
  CellTags->"CovariantD"],
Cell[502574, 15894, 1845, 49, 70, "Output"]
}, Closed]],
Cell[504434, 15946, 675, 22, 70, "Text",
  CellTags->"CovariantD"],

Cell[CellGroupData[{
Cell[505134, 15972, 258, 6, 70, "Input",
  CellTags->"CovariantD"],
Cell[505395, 15980, 661, 19, 70, "Output"]
}, Closed]],
Cell[506071, 16002, 372, 11, 70, "Text",
  CellTags->"CovariantD"],

Cell[CellGroupData[{
Cell[506468, 16017, 258, 6, 70, "Input",
  CellTags->"CovariantD"],
Cell[506729, 16025, 3181, 79, 70, "Output"]
}, Closed]],
Cell[509925, 16107, 207, 7, 70, "Text",
  CellTags->"CovariantD"],

Cell[CellGroupData[{
Cell[510157, 16118, 258, 6, 70, "Input",
  CellTags->"CovariantD"],
Cell[510418, 16126, 8818, 199, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[519273, 16330, 218, 5, 70, "Input",
  CellTags->"CovariantD"],
Cell[519494, 16337, 323, 9, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[519854, 16351, 238, 6, 70, "Input",
  CellTags->"CovariantD"],
Cell[520095, 16359, 6343, 145, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[526475, 16509, 265, 7, 70, "Input",
  CellTags->"CovariantD"],
Cell[526743, 16518, 928, 23, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[527708, 16546, 282, 7, 70, "Input",
  CellTags->"CovariantD"],
Cell[527993, 16555, 934, 24, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[528988, 16586, 42, 1, 70, "ObjectName",
  CellTags->"D0"],

Cell[CellGroupData[{
Cell[529055, 16591, 54, 1, 70, "Subsubsection",
  CellTags->"D0"],
Cell[529112, 16594, 537, 12, 70, "Text",
  CellTags->"D0"],
Cell[529652, 16608, 501, 24, 70, "Text",
  CellTags->"D0"]
}, Closed]],

Cell[CellGroupData[{
Cell[530190, 16637, 51, 1, 70, "Subsubsection",
  CellTags->"D0"],

Cell[CellGroupData[{
Cell[530266, 16642, 380, 10, 70, "Input",
  CellTags->"D0"],
Cell[530649, 16654, 1262, 32, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[531948, 16691, 587, 15, 70, "Input",
  CellTags->"D0"],
Cell[532538, 16708, 1271, 33, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[533846, 16746, 132, 3, 70, "Input",
  CellTags->"D0"],
Cell[533981, 16751, 1262, 32, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[535304, 16790, 54, 1, 70, "ObjectName",
  CellTags->"DataType"],

Cell[CellGroupData[{
Cell[535383, 16795, 60, 1, 70, "Subsubsection",
  CellTags->"DataType"],
Cell[535446, 16798, 345, 6, 70, "Text",
  CellTags->"DataType"],
Cell[535794, 16806, 231, 9, 70, "Text",
  CellTags->"DataType"]
}, Closed]],

Cell[CellGroupData[{
Cell[536062, 16820, 57, 1, 70, "Subsubsection",
  CellTags->"DataType"],
Cell[536122, 16823, 75, 1, 70, "Text",
  CellTags->"DataType"],
Cell[536200, 16826, 269, 7, 70, "Input",
  CellTags->"DataType"],

Cell[CellGroupData[{
Cell[536494, 16837, 279, 8, 70, "Input",
  CellTags->"DataType"],
Cell[536776, 16847, 274, 8, 70, "Output"]
}, Closed]],
Cell[537065, 16858, 180, 4, 70, "Text",
  CellTags->"DataType"],

Cell[CellGroupData[{
Cell[537270, 16866, 140, 3, 70, "Input",
  CellTags->"DataType"],
Cell[537413, 16871, 234, 6, 70, "Output"]
}, Closed]],
Cell[537662, 16880, 339, 10, 70, "Input",
  CellTags->"DataType"],
Cell[538004, 16892, 518, 14, 70, "Input",
  CellTags->"DataType"],
Cell[538525, 16908, 504, 14, 70, "Input",
  CellTags->"DataType"],

Cell[CellGroupData[{
Cell[539054, 16926, 426, 13, 70, "Input",
  CellTags->"DataType"],
Cell[539483, 16941, 412, 12, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[539932, 16958, 135, 3, 70, "Input",
  CellTags->"DataType"],
Cell[540070, 16963, 347, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[540454, 16978, 135, 3, 70, "Input",
  CellTags->"DataType"],
Cell[540592, 16983, 191, 5, 70, "Output"]
}, Closed]],
Cell[540798, 16991, 234, 6, 70, "Input",
  CellTags->"DataType"],
Cell[541035, 16999, 237, 7, 70, "Input",
  CellTags->"DataType"],
Cell[541275, 17008, 536, 15, 70, "Input",
  CellTags->"DataType"],

Cell[CellGroupData[{
Cell[541836, 17027, 368, 12, 70, "Input",
  CellTags->"DataType"],
Cell[542207, 17041, 348, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[542592, 17056, 133, 3, 70, "Input",
  CellTags->"DataType"],
Cell[542728, 17061, 266, 8, 70, "Output"]
}, Closed]],
Cell[543009, 17072, 188, 5, 70, "Input",
  CellTags->"DataType"],
Cell[543200, 17079, 270, 7, 70, "Input",
  CellTags->"DataType"],
Cell[543473, 17088, 340, 10, 70, "Input",
  CellTags->"DataType"],
Cell[543816, 17100, 115, 3, 70, "Text",
  CellTags->"DataType"],

Cell[CellGroupData[{
Cell[543956, 17107, 181, 4, 70, "Input",
  CellTags->"DataType"],
Cell[544140, 17113, 111, 2, 70, "Output"]
}, Closed]],
Cell[544266, 17118, 84, 1, 70, "Text",
  CellTags->"DataType"],

Cell[CellGroupData[{
Cell[544375, 17123, 287, 8, 70, "Input",
  CellTags->"DataType"],
Cell[544665, 17133, 108, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[544810, 17140, 283, 8, 70, "Input",
  CellTags->"DataType"],
Cell[545096, 17150, 543, 16, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[545700, 17173, 80, 1, 70, "ObjectName",
  CellTags->"DeclareNonCommutative"],

Cell[CellGroupData[{
Cell[545805, 17178, 73, 1, 70, "Subsubsection",
  CellTags->"DeclareNonCommutative"],
Cell[545881, 17181, 193, 4, 70, "Text",
  CellTags->"DeclareNonCommutative"],
Cell[546077, 17187, 370, 14, 70, "Text",
  CellTags->"DeclareNonCommutative"]
}, Closed]],

Cell[CellGroupData[{
Cell[546484, 17206, 70, 1, 70, "Subsubsection",
  CellTags->"DeclareNonCommutative"],
Cell[546557, 17209, 163, 3, 70, "Input",
  CellTags->"DeclareNonCommutative"],
Cell[546723, 17214, 153, 4, 70, "Text",
  CellTags->"DeclareNonCommutative"],

Cell[CellGroupData[{
Cell[546901, 17222, 190, 4, 70, "Input",
  CellTags->"DeclareNonCommutative"],
Cell[547094, 17228, 111, 2, 70, "Output"]
}, Closed]],
Cell[547220, 17233, 190, 4, 70, "Input",
  CellTags->"DeclareNonCommutative"],

Cell[CellGroupData[{
Cell[547435, 17241, 227, 5, 70, "Input",
  CellTags->"DeclareNonCommutative"],
Cell[547665, 17248, 204, 5, 70, "Output"]
}, Closed]],
Cell[547884, 17256, 202, 4, 70, "Input",
  CellTags->"DeclareNonCommutative"],

Cell[CellGroupData[{
Cell[548111, 17264, 227, 5, 70, "Input",
  CellTags->"DeclareNonCommutative"],
Cell[548341, 17271, 207, 5, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[548609, 17283, 64, 1, 70, "ObjectName",
  CellTags->"DeltaFunction"],

Cell[CellGroupData[{
Cell[548698, 17288, 65, 1, 70, "Subsubsection",
  CellTags->"DeltaFunction"],
Cell[548766, 17291, 210, 7, 70, "Text",
  CellTags->"DeltaFunction"],
Cell[548979, 17300, 635, 24, 70, "Text",
  CellTags->"DeltaFunction"]
}, Closed]],

Cell[CellGroupData[{
Cell[549651, 17329, 62, 1, 70, "Subsubsection",
  CellTags->"DeltaFunction"],

Cell[CellGroupData[{
Cell[549738, 17334, 174, 4, 70, "Input",
  CellTags->"DeltaFunction"],
Cell[549915, 17340, 225, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[550177, 17351, 387, 10, 70, "Input",
  CellTags->"DeltaFunction"],
Cell[550567, 17363, 140, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[550744, 17371, 354, 9, 70, "Input",
  CellTags->"DeltaFunction"],
Cell[551101, 17382, 140, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[551278, 17390, 387, 10, 70, "Input",
  CellTags->"DeltaFunction"],
Cell[551668, 17402, 140, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[551845, 17410, 247, 6, 70, "Input",
  CellTags->"DeltaFunction"],
Cell[552095, 17418, 108, 2, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[552264, 17427, 74, 1, 70, "ObjectName",
  CellTags->"DeltaFunctionPrime"],

Cell[CellGroupData[{
Cell[552363, 17432, 70, 1, 70, "Subsubsection",
  CellTags->"DeltaFunctionPrime"],
Cell[552436, 17435, 200, 6, 70, "Text",
  CellTags->"DeltaFunctionPrime"],
Cell[552639, 17443, 618, 23, 70, "Text",
  CellTags->"DeltaFunctionPrime"]
}, Closed]],

Cell[CellGroupData[{
Cell[553294, 17471, 67, 1, 70, "Subsubsection",
  CellTags->"DeltaFunctionPrime"],

Cell[CellGroupData[{
Cell[553386, 17476, 184, 4, 70, "Input",
  CellTags->"DeltaFunctionPrime"],
Cell[553573, 17482, 262, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[553872, 17494, 397, 10, 70, "Input",
  CellTags->"DeltaFunctionPrime"],
Cell[554272, 17506, 219, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[554528, 17517, 393, 10, 70, "Input",
  CellTags->"DeltaFunctionPrime"],
Cell[554924, 17529, 108, 2, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[555093, 17538, 56, 1, 70, "ObjectName",
  CellTags->"Dimension"],

Cell[CellGroupData[{
Cell[555174, 17543, 61, 1, 70, "Subsubsection",
  CellTags->"Dimension"],
Cell[555238, 17546, 236, 5, 70, "Text",
  CellTags->"Dimension"],

Cell[CellGroupData[{
Cell[555499, 17555, 148, 3, 70, "Input",
  CellTags->"Dimension"],
Cell[555650, 17560, 271, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[555958, 17572, 420, 11, 70, "Input",
  CellTags->"Dimension"],
Cell[556381, 17585, 583, 18, 70, "Output"]
}, Closed]],
Cell[556979, 17606, 132, 4, 70, "Text",
  CellTags->"Dimension"],

Cell[CellGroupData[{
Cell[557136, 17614, 429, 11, 70, "Input",
  CellTags->"Dimension"],
Cell[557568, 17627, 497, 12, 70, "Output"]
}, Closed]],
Cell[558080, 17642, 167, 4, 70, "Text",
  CellTags->"Dimension"],
Cell[558250, 17648, 165, 4, 70, "Input",
  CellTags->"Dimension"],

Cell[CellGroupData[{
Cell[558440, 17656, 384, 9, 70, "Input",
  CellTags->"Dimension"],
Cell[558827, 17667, 893, 27, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[559757, 17699, 138, 3, 70, "Input",
  CellTags->"Dimension"],
Cell[559898, 17704, 510, 12, 70, "Output"]
}, Closed]],
Cell[560423, 17719, 166, 4, 70, "Input",
  CellTags->"Dimension"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[560638, 17729, 72, 1, 70, "ObjectName",
  CellTags->"DiracGammaCombine"],

Cell[CellGroupData[{
Cell[560735, 17734, 69, 1, 70, "Subsubsection",
  CellTags->"DiracGammaCombine"],
Cell[560807, 17737, 136, 4, 70, "Text",
  CellTags->"DiracGammaCombine"],
Cell[560946, 17743, 867, 34, 70, "Text",
  CellTags->"DiracGammaCombine"]
}, Closed]],

Cell[CellGroupData[{
Cell[561850, 17782, 66, 1, 70, "Subsubsection",
  CellTags->"DiracGammaCombine"],

Cell[CellGroupData[{
Cell[561941, 17787, 262, 6, 70, "Input",
  CellTags->"DiracGammaCombine"],
Cell[562206, 17795, 363, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[562606, 17810, 150, 3, 70, "Input",
  CellTags->"DiracGammaCombine"],
Cell[562759, 17815, 198, 4, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[562994, 17824, 324, 8, 70, "Input",
  CellTags->"DiracGammaCombine"],
Cell[563321, 17834, 429, 12, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[563787, 17851, 150, 3, 70, "Input",
  CellTags->"DiracGammaCombine"],
Cell[563940, 17856, 260, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[564237, 17867, 155, 3, 70, "Input",
  CellTags->"DiracGammaCombine"],
Cell[564395, 17872, 609, 17, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[565065, 17896, 70, 1, 70, "ObjectName",
  CellTags->"DiracGammaExpand"],

Cell[CellGroupData[{
Cell[565160, 17901, 68, 1, 70, "Subsubsection",
  CellTags->"DiracGammaExpand"],
Cell[565231, 17904, 191, 4, 70, "Text",
  CellTags->"DiracGammaExpand"],
Cell[565425, 17910, 869, 34, 70, "Text",
  CellTags->"DiracGammaExpand"]
}, Closed]],

Cell[CellGroupData[{
Cell[566331, 17949, 65, 1, 70, "Subsubsection",
  CellTags->"DiracGammaExpand"],

Cell[CellGroupData[{
Cell[566421, 17954, 375, 9, 70, "Input",
  CellTags->"DiracGammaExpand"],
Cell[566799, 17965, 689, 19, 70, "Output"]
}, Closed]],
Cell[567503, 17987, 126, 3, 70, "Text",
  CellTags->"DiracGammaExpand"],

Cell[CellGroupData[{
Cell[567654, 17994, 149, 3, 70, "Input",
  CellTags->"DiracGammaExpand"],
Cell[567806, 17999, 311, 7, 70, "Output"]
}, Closed]],
Cell[568132, 18009, 102, 1, 70, "Text",
  CellTags->"DiracGammaExpand"],

Cell[CellGroupData[{
Cell[568259, 18014, 153, 3, 70, "Input",
  CellTags->"DiracGammaExpand"],
Cell[568415, 18019, 872, 24, 70, "Output"]
}, Closed]],
Cell[569302, 18046, 91, 1, 70, "Text",
  CellTags->"DiracGammaExpand"],

Cell[CellGroupData[{
Cell[569418, 18051, 246, 5, 70, "Input",
  CellTags->"DiracGammaExpand"],
Cell[569667, 18058, 311, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[570015, 18070, 196, 4, 70, "Input",
  CellTags->"DiracGammaExpand"],
Cell[570214, 18076, 434, 10, 70, "Output"]
}, Closed]],
Cell[570663, 18089, 107, 1, 70, "Text",
  CellTags->"DiracGammaExpand"],

Cell[CellGroupData[{
Cell[570795, 18094, 150, 3, 70, "Input",
  CellTags->"DiracGammaExpand"],
Cell[570948, 18099, 747, 21, 70, "Output"]
}, Closed]],
Cell[571710, 18123, 142, 3, 70, "Input",
  CellTags->"DiracGammaExpand"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[571901, 18132, 58, 1, 70, "ObjectName",
  CellTags->"DiracGamma"],

Cell[CellGroupData[{
Cell[571984, 18137, 62, 1, 70, "Subsubsection",
  CellTags->"DiracGamma"],
Cell[572049, 18140, 852, 25, 70, "Text",
  CellTags->"DiracGamma"],
Cell[572904, 18167, 734, 29, 70, "Text",
  CellTags->"DiracGamma"]
}, Closed]],

Cell[CellGroupData[{
Cell[573675, 18201, 59, 1, 70, "Subsubsection",
  CellTags->"DiracGamma"],

Cell[CellGroupData[{
Cell[573759, 18206, 141, 3, 70, "Input",
  CellTags->"DiracGamma"],
Cell[573903, 18211, 143, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[574083, 18219, 191, 4, 70, "Input",
  CellTags->"DiracGamma"],
Cell[574277, 18225, 248, 7, 70, "Output"]
}, Closed]],
Cell[574540, 18235, 368, 13, 70, "Text",
  CellTags->"DiracGamma"],

Cell[CellGroupData[{
Cell[574933, 18252, 204, 5, 70, "Input",
  CellTags->"DiracGamma"],
Cell[575140, 18259, 283, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[575460, 18271, 332, 8, 70, "Input",
  CellTags->"DiracGamma"],
Cell[575795, 18281, 689, 19, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[576521, 18305, 270, 8, 70, "Input",
  CellTags->"DiracGamma"],
Cell[576794, 18315, 283, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[577114, 18327, 256, 7, 70, "Input",
  CellTags->"DiracGamma"],
Cell[577373, 18336, 521, 14, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[577931, 18355, 176, 4, 70, "Input",
  CellTags->"DiracGamma"],
Cell[578110, 18361, 872, 24, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[579019, 18390, 358, 9, 70, "Input",
  CellTags->"DiracGamma"],
Cell[579380, 18401, 623, 16, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[580040, 18422, 170, 4, 70, "Input",
  CellTags->"DiracGamma"],
Cell[580213, 18428, 1161, 30, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[581411, 18463, 173, 4, 70, "Input",
  CellTags->"DiracGamma"],
Cell[581587, 18469, 1673, 46, 70, "Output"]
}, Closed]],
Cell[583275, 18518, 205, 5, 70, "Input",
  CellTags->"DiracGamma"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[583529, 18529, 60, 1, 70, "ObjectName",
  CellTags->"DiracGammaT"],

Cell[CellGroupData[{
Cell[583614, 18534, 63, 1, 70, "Subsubsection",
  CellTags->"DiracGammaT"],
Cell[583680, 18537, 209, 5, 70, "Text",
  CellTags->"DiracGammaT"],
Cell[583892, 18544, 201, 9, 70, "Text",
  CellTags->"DiracGammaT"]
}, Closed]],

Cell[CellGroupData[{
Cell[584130, 18558, 60, 1, 70, "Subsubsection",
  CellTags->"DiracGammaT"],

Cell[CellGroupData[{
Cell[584215, 18563, 190, 4, 70, "Input",
  CellTags->"DiracGammaT"],
Cell[584408, 18569, 253, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[584698, 18581, 141, 3, 70, "Input",
  CellTags->"DiracGammaT"],
Cell[584842, 18586, 245, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[585124, 18598, 209, 6, 70, "Input",
  CellTags->"DiracGammaT"],
Cell[585336, 18606, 327, 9, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[585724, 18622, 60, 1, 70, "ObjectName",
  CellTags->"DiracMatrix"],

Cell[CellGroupData[{
Cell[585809, 18627, 63, 1, 70, "Subsubsection",
  CellTags->"DiracMatrix"],
Cell[585875, 18630, 1375, 48, 70, "Text",
  CellTags->"DiracMatrix"],
Cell[587253, 18680, 1146, 49, 70, "Text",
  CellTags->"DiracMatrix"]
}, Closed]],

Cell[CellGroupData[{
Cell[588436, 18734, 60, 1, 70, "Subsubsection",
  CellTags->"DiracMatrix"],

Cell[CellGroupData[{
Cell[588521, 18739, 147, 3, 70, "Input",
  CellTags->"DiracMatrix"],
Cell[588671, 18744, 245, 7, 70, "Output"]
}, Closed]],
Cell[588931, 18754, 640, 20, 70, "Text",
  CellTags->"DiracMatrix"],

Cell[CellGroupData[{
Cell[589596, 18778, 220, 5, 70, "Input",
  CellTags->"DiracMatrix"],
Cell[589819, 18785, 429, 13, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[590285, 18803, 196, 5, 70, "Input",
  CellTags->"DiracMatrix"],
Cell[590484, 18810, 180, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[590701, 18818, 177, 4, 70, "Input",
  CellTags->"DiracMatrix"],
Cell[590881, 18824, 147, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[591065, 18832, 140, 3, 70, "Input",
  CellTags->"DiracMatrix"],
Cell[591208, 18837, 126, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[591371, 18844, 139, 3, 70, "Input",
  CellTags->"DiracMatrix"],
Cell[591513, 18849, 147, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[591697, 18857, 170, 4, 70, "Input",
  CellTags->"DiracMatrix"],
Cell[591870, 18863, 237, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[592144, 18873, 184, 4, 70, "Input",
  CellTags->"DiracMatrix"],
Cell[592331, 18879, 269, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[592637, 18890, 203, 5, 70, "Input",
  CellTags->"DiracMatrix"],
Cell[592843, 18897, 421, 13, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[593301, 18915, 140, 3, 70, "Input",
  CellTags->"DiracMatrix"],
Cell[593444, 18920, 288, 6, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[593793, 18933, 58, 1, 70, "ObjectName",
  CellTags->"DiracOrder"],

Cell[CellGroupData[{
Cell[593876, 18938, 62, 1, 70, "Subsubsection",
  CellTags->"DiracOrder"],
Cell[593941, 18941, 205, 5, 70, "Text",
  CellTags->"DiracOrder"],
Cell[594149, 18948, 335, 14, 70, "Text",
  CellTags->"DiracOrder"]
}, Closed]],

Cell[CellGroupData[{
Cell[594521, 18967, 59, 1, 70, "Subsubsection",
  CellTags->"DiracOrder"],

Cell[CellGroupData[{
Cell[594605, 18972, 213, 5, 70, "Input",
  CellTags->"DiracOrder"],
Cell[594821, 18979, 224, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[595082, 18990, 142, 3, 70, "Input",
  CellTags->"DiracOrder"],
Cell[595227, 18995, 599, 17, 70, "Output"]
}, Closed]],
Cell[595841, 19015, 94, 1, 70, "Text",
  CellTags->"DiracOrder"],

Cell[CellGroupData[{
Cell[595960, 19020, 213, 5, 70, "Input",
  CellTags->"DiracOrder"],
Cell[596176, 19027, 268, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[596481, 19038, 142, 3, 70, "Input",
  CellTags->"DiracOrder"],
Cell[596626, 19043, 599, 17, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[597262, 19065, 208, 5, 70, "Input",
  CellTags->"DiracOrder"],
Cell[597473, 19072, 264, 6, 70, "Output"]
}, Closed]],
Cell[597752, 19081, 215, 8, 70, "Text",
  CellTags->"DiracOrder"],

Cell[CellGroupData[{
Cell[597992, 19093, 142, 3, 70, "Input",
  CellTags->"DiracOrder"],
Cell[598137, 19098, 476, 14, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[598650, 19117, 204, 5, 70, "Input",
  CellTags->"DiracOrder"],
Cell[598857, 19124, 260, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[599154, 19135, 142, 3, 70, "Input",
  CellTags->"DiracOrder"],
Cell[599299, 19140, 319, 9, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[599655, 19154, 229, 6, 70, "Input",
  CellTags->"DiracOrder"],
Cell[599887, 19162, 278, 7, 70, "Output"]
}, Closed]],
Cell[600180, 19172, 319, 10, 70, "Text",
  CellTags->"DiracOrder"],

Cell[CellGroupData[{
Cell[600524, 19186, 266, 7, 70, "Input",
  CellTags->"DiracOrder"],
Cell[600793, 19195, 1594, 45, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[602424, 19245, 141, 3, 70, "Input",
  CellTags->"DiracOrder"],
Cell[602568, 19250, 594, 18, 70, "Output"]
}, Closed]],
Cell[603177, 19271, 229, 6, 70, "Input",
  CellTags->"DiracOrder"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[603455, 19283, 60, 1, 70, "ObjectName",
  CellTags->"DiracReduce"],

Cell[CellGroupData[{
Cell[603540, 19288, 63, 1, 70, "Subsubsection",
  CellTags->"DiracReduce"],
Cell[603606, 19291, 665, 11, 70, "Text",
  CellTags->"DiracReduce"],

Cell[CellGroupData[{
Cell[604296, 19306, 149, 3, 70, "Input",
  CellTags->"DiracReduce"],
Cell[604448, 19311, 364, 9, 70, "Output"]
}, Closed]],
Cell[604827, 19323, 210, 9, 70, "Text",
  CellTags->"DiracReduce"]
}, Closed]],

Cell[CellGroupData[{
Cell[605074, 19337, 60, 1, 70, "Subsubsection",
  CellTags->"DiracReduce"],

Cell[CellGroupData[{
Cell[605159, 19342, 209, 5, 70, "Input",
  CellTags->"DiracReduce"],
Cell[605371, 19349, 217, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[605625, 19359, 144, 3, 70, "Input",
  CellTags->"DiracReduce"],
Cell[605772, 19364, 350, 9, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[606159, 19378, 223, 5, 70, "Input",
  CellTags->"DiracReduce"],
Cell[606385, 19385, 259, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[606681, 19396, 144, 3, 70, "Input",
  CellTags->"DiracReduce"],
Cell[606828, 19401, 1208, 30, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[608073, 19436, 249, 6, 70, "Input",
  CellTags->"DiracReduce"],
Cell[608325, 19444, 310, 8, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[608672, 19457, 172, 4, 70, "Input",
  CellTags->"DiracReduce"],
Cell[608847, 19463, 2454, 56, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[611338, 19524, 303, 7, 70, "Input",
  CellTags->"DiracReduce"],
Cell[611644, 19533, 132, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[611813, 19541, 165, 4, 70, "Input",
  CellTags->"DiracReduce"],
Cell[611981, 19547, 132, 3, 70, "Output"]
}, Closed]],
Cell[612128, 19553, 188, 4, 70, "Input",
  CellTags->"DiracReduce"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[612365, 19563, 74, 1, 70, "ObjectName",
  CellTags->"DiracSigmaExplicit"],

Cell[CellGroupData[{
Cell[612464, 19568, 70, 1, 70, "Subsubsection",
  CellTags->"DiracSigmaExplicit"],
Cell[612537, 19571, 187, 4, 70, "Text",
  CellTags->"DiracSigmaExplicit"],
Cell[612727, 19577, 208, 9, 70, "Text",
  CellTags->"DiracSigmaExplicit"]
}, Closed]],

Cell[CellGroupData[{
Cell[612972, 19591, 67, 1, 70, "Subsubsection",
  CellTags->"DiracSigmaExplicit"],

Cell[CellGroupData[{
Cell[613064, 19596, 259, 6, 70, "Input",
  CellTags->"DiracSigmaExplicit"],
Cell[613326, 19604, 201, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[613564, 19614, 157, 3, 70, "Input",
  CellTags->"DiracSigmaExplicit"],
Cell[613724, 19619, 1035, 29, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[614820, 19655, 58, 1, 70, "ObjectName",
  CellTags->"DiracSigma"],

Cell[CellGroupData[{
Cell[614903, 19660, 62, 1, 70, "Subsubsection",
  CellTags->"DiracSigma"],
Cell[614968, 19663, 214, 5, 70, "Text",
  CellTags->"DiracSigma"],
Cell[615185, 19670, 224, 9, 70, "Text",
  CellTags->"DiracSigma"]
}, Closed]],

Cell[CellGroupData[{
Cell[615446, 19684, 59, 1, 70, "Subsubsection",
  CellTags->"DiracSigma"],

Cell[CellGroupData[{
Cell[615530, 19689, 285, 7, 70, "Input",
  CellTags->"DiracSigma"],
Cell[615818, 19698, 201, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[616056, 19708, 150, 3, 70, "Input",
  CellTags->"DiracSigma"],
Cell[616209, 19713, 1035, 29, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[617281, 19747, 285, 7, 70, "Input",
  CellTags->"DiracSigma"],
Cell[617569, 19756, 227, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[617833, 19767, 272, 7, 70, "Input",
  CellTags->"DiracSigma"],
Cell[618108, 19776, 181, 4, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[618326, 19785, 150, 3, 70, "Input",
  CellTags->"DiracSigma"],
Cell[618479, 19790, 1433, 37, 70, "Output"]
}, Closed]],
Cell[619927, 19830, 176, 4, 70, "Input",
  CellTags->"DiracSigma"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[620152, 19840, 64, 1, 70, "ObjectName",
  CellTags->"DiracSimplify"],

Cell[CellGroupData[{
Cell[620241, 19845, 65, 1, 70, "Subsubsection",
  CellTags->"DiracSimplify"],
Cell[620309, 19848, 383, 7, 70, "Text",
  CellTags->"DiracSimplify"],

Cell[CellGroupData[{
Cell[620717, 19859, 153, 3, 70, "Input",
  CellTags->"DiracSimplify"],
Cell[620873, 19864, 664, 13, 70, "Output"]
}, Closed]],
Cell[621552, 19880, 455, 19, 70, "Text",
  CellTags->"DiracSimplify"]
}, Closed]],

Cell[CellGroupData[{
Cell[622044, 19904, 62, 1, 70, "Subsubsection",
  CellTags->"DiracSimplify"],
Cell[622109, 19907, 100, 1, 70, "Text",
  CellTags->"DiracSimplify"],

Cell[CellGroupData[{
Cell[622234, 19912, 215, 5, 70, "Input",
  CellTags->"DiracSimplify"],
Cell[622452, 19919, 268, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[622757, 19930, 148, 3, 70, "Input",
  CellTags->"DiracSimplify"],
Cell[622908, 19935, 306, 9, 70, "Output"]
}, Closed]],
Cell[623229, 19947, 97, 1, 70, "Text",
  CellTags->"DiracSimplify"],

Cell[CellGroupData[{
Cell[623351, 19952, 216, 5, 70, "Input",
  CellTags->"DiracSimplify"],
Cell[623570, 19959, 268, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[623875, 19970, 148, 3, 70, "Input",
  CellTags->"DiracSimplify"],
Cell[624026, 19975, 306, 9, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[624369, 19989, 211, 5, 70, "Input",
  CellTags->"DiracSimplify"],
Cell[624583, 19996, 264, 6, 70, "Output"]
}, Closed]],
Cell[624862, 20005, 192, 7, 70, "Text",
  CellTags->"DiracSimplify"],

Cell[CellGroupData[{
Cell[625079, 20016, 148, 3, 70, "Input",
  CellTags->"DiracSimplify"],
Cell[625230, 20021, 476, 14, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[625743, 20040, 207, 5, 70, "Input",
  CellTags->"DiracSimplify"],
Cell[625953, 20047, 260, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[626250, 20058, 148, 3, 70, "Input",
  CellTags->"DiracSimplify"],
Cell[626401, 20063, 319, 9, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[626757, 20077, 390, 10, 70, "Input",
  CellTags->"DiracSimplify"],
Cell[627150, 20089, 934, 26, 70, "Output"]
}, Closed]],
Cell[628099, 20118, 121, 3, 70, "Text",
  CellTags->"DiracSimplify"],

Cell[CellGroupData[{
Cell[628245, 20125, 148, 3, 70, "Input",
  CellTags->"DiracSimplify"],
Cell[628396, 20130, 2863, 79, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[631296, 20214, 145, 3, 70, "Input",
  CellTags->"DiracSimplify"],
Cell[631444, 20219, 897, 23, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[632378, 20247, 319, 7, 70, "Input",
  CellTags->"DiracSimplify"],
Cell[632700, 20256, 631, 17, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[633368, 20278, 148, 3, 70, "Input",
  CellTags->"DiracSimplify"],
Cell[633519, 20283, 108, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[633664, 20290, 460, 12, 70, "Input",
  CellTags->"DiracSimplify"],
Cell[634127, 20304, 703, 17, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[634867, 20326, 147, 3, 70, "Input",
  CellTags->"DiracSimplify"],
Cell[635017, 20331, 22626, 649, 70, "Output"]
}, Closed]],
Cell[657658, 20983, 116, 3, 70, "Text",
  CellTags->"DiracSimplify"],

Cell[CellGroupData[{
Cell[657799, 20990, 299, 7, 70, "Input",
  CellTags->"DiracSimplify"],
Cell[658101, 20999, 589, 17, 70, "Output"]
}, Closed]],
Cell[658705, 21019, 142, 4, 70, "Text",
  CellTags->"DiracSimplify"],

Cell[CellGroupData[{
Cell[658872, 21027, 344, 8, 70, "Input",
  CellTags->"DiracSimplify"],
Cell[659219, 21037, 743, 19, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[659999, 21061, 316, 7, 70, "Input",
  CellTags->"DiracSimplify"],
Cell[660318, 21070, 108, 2, 70, "Output"]
}, Closed]],
Cell[660441, 21075, 219, 5, 70, "Input",
  CellTags->"DiracSimplify"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[660709, 21086, 66, 1, 70, "ObjectName",
  CellTags->"DiracSimplify2"],

Cell[CellGroupData[{
Cell[660800, 21091, 66, 1, 70, "Subsubsection",
  CellTags->"DiracSimplify2"],
Cell[660869, 21094, 237, 7, 70, "Text",
  CellTags->"DiracSimplify2"],
Cell[661109, 21103, 213, 9, 70, "Text",
  CellTags->"DiracSimplify2"]
}, Closed]],

Cell[CellGroupData[{
Cell[661359, 21117, 63, 1, 70, "Subsubsection",
  CellTags->"DiracSimplify2"],

Cell[CellGroupData[{
Cell[661447, 21122, 263, 6, 70, "Input",
  CellTags->"DiracSimplify2"],
Cell[661713, 21130, 478, 11, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[662228, 21146, 149, 3, 70, "Input",
  CellTags->"DiracSimplify2"],
Cell[662380, 21151, 1112, 34, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[663553, 21192, 58, 1, 70, "ObjectName",
  CellTags->"DiracSlash"],

Cell[CellGroupData[{
Cell[663636, 21197, 62, 1, 70, "Subsubsection",
  CellTags->"DiracSlash"],
Cell[663701, 21200, 515, 16, 70, "Text",
  CellTags->"DiracSlash"],

Cell[CellGroupData[{
Cell[664241, 21220, 147, 3, 70, "Input",
  CellTags->"DiracSlash"],
Cell[664391, 21225, 271, 7, 70, "Output"]
}, Closed]],
Cell[664677, 21235, 941, 39, 70, "Text",
  CellTags->"DiracSlash"]
}, Closed]],

Cell[CellGroupData[{
Cell[665655, 21279, 59, 1, 70, "Subsubsection",
  CellTags->"DiracSlash"],
Cell[665717, 21282, 265, 9, 70, "Text",
  CellTags->"DiracSlash"],

Cell[CellGroupData[{
Cell[666007, 21295, 141, 3, 70, "Input",
  CellTags->"DiracSlash"],
Cell[666151, 21300, 283, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[666471, 21312, 209, 5, 70, "Input",
  CellTags->"DiracSlash"],
Cell[666683, 21319, 609, 17, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[667329, 21341, 168, 4, 70, "Input",
  CellTags->"DiracSlash"],
Cell[667500, 21347, 609, 17, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[668146, 21369, 133, 3, 70, "Input",
  CellTags->"DiracSlash"],
Cell[668282, 21374, 188, 4, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[668507, 21383, 182, 5, 70, "Input",
  CellTags->"DiracSlash"],
Cell[668692, 21390, 169, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[668898, 21398, 256, 7, 70, "Input",
  CellTags->"DiracSlash"],
Cell[669157, 21407, 229, 5, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[669447, 21419, 58, 1, 70, "ObjectName",
  CellTags->"DiracTrace"],

Cell[CellGroupData[{
Cell[669530, 21424, 62, 1, 70, "Subsubsection",
  CellTags->"DiracTrace"],
Cell[669595, 21427, 322, 6, 70, "Text",
  CellTags->"DiracTrace"],

Cell[CellGroupData[{
Cell[669942, 21437, 147, 3, 70, "Input",
  CellTags->"DiracTrace"],
Cell[670092, 21442, 684, 14, 70, "Output"]
}, Closed]],
Cell[670791, 21459, 306, 12, 70, "Text",
  CellTags->"DiracTrace"],
Cell[671100, 21473, 176, 9, 70, "Text",
  CellTags->"DiracTrace"]
}, Closed]],

Cell[CellGroupData[{
Cell[671313, 21487, 59, 1, 70, "Subsubsection",
  CellTags->"DiracTrace"],

Cell[CellGroupData[{
Cell[671397, 21492, 211, 5, 70, "Input",
  CellTags->"DiracTrace"],
Cell[671611, 21499, 309, 8, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[671957, 21512, 252, 6, 70, "Input",
  CellTags->"DiracTrace"],
Cell[672212, 21520, 423, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[672672, 21535, 181, 4, 70, "Input",
  CellTags->"DiracTrace"],
Cell[672856, 21541, 863, 21, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[673756, 21567, 361, 9, 70, "Input",
  CellTags->"DiracTrace"],
Cell[674120, 21578, 774, 22, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[674931, 21605, 395, 9, 70, "Input",
  CellTags->"DiracTrace"],
Cell[675329, 21616, 13082, 321, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[688448, 21942, 223, 5, 70, "Input",
  CellTags->"DiracTrace"],
Cell[688674, 21949, 815, 22, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[689526, 21976, 347, 8, 70, "Input",
  CellTags->"DiracTrace"],
Cell[689876, 21986, 220, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[690133, 21997, 139, 3, 70, "Input",
  CellTags->"DiracTrace"],
Cell[690275, 22002, 186, 4, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[690522, 22013, 58, 1, 70, "ObjectName",
  CellTags->"DiracTrick"],

Cell[CellGroupData[{
Cell[690605, 22018, 62, 1, 70, "Subsubsection",
  CellTags->"DiracTrick"],
Cell[690670, 22021, 223, 5, 70, "Text",
  CellTags->"DiracTrick"],

Cell[CellGroupData[{
Cell[690918, 22030, 147, 3, 70, "Input",
  CellTags->"DiracTrick"],
Cell[691068, 22035, 189, 5, 70, "Output"]
}, Closed]],
Cell[691272, 22043, 461, 19, 70, "Text",
  CellTags->"DiracTrick"]
}, Closed]],

Cell[CellGroupData[{
Cell[691770, 22067, 59, 1, 70, "Subsubsection",
  CellTags->"DiracTrick"],
Cell[691832, 22070, 97, 1, 70, "Text",
  CellTags->"DiracTrick"],

Cell[CellGroupData[{
Cell[691954, 22075, 212, 5, 70, "Input",
  CellTags->"DiracTrick"],
Cell[692169, 22082, 268, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[692474, 22093, 142, 3, 70, "Input",
  CellTags->"DiracTrick"],
Cell[692619, 22098, 306, 9, 70, "Output"]
}, Closed]],
Cell[692940, 22110, 94, 1, 70, "Text",
  CellTags->"DiracTrick"],

Cell[CellGroupData[{
Cell[693059, 22115, 213, 5, 70, "Input",
  CellTags->"DiracTrick"],
Cell[693275, 22122, 268, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[693580, 22133, 142, 3, 70, "Input",
  CellTags->"DiracTrick"],
Cell[693725, 22138, 342, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[694104, 22153, 208, 5, 70, "Input",
  CellTags->"DiracTrick"],
Cell[694315, 22160, 264, 6, 70, "Output"]
}, Closed]],
Cell[694594, 22169, 189, 7, 70, "Text",
  CellTags->"DiracTrick"],

Cell[CellGroupData[{
Cell[694808, 22180, 142, 3, 70, "Input",
  CellTags->"DiracTrick"],
Cell[694953, 22185, 476, 14, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[695466, 22204, 204, 5, 70, "Input",
  CellTags->"DiracTrick"],
Cell[695673, 22211, 260, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[695970, 22222, 142, 3, 70, "Input",
  CellTags->"DiracTrick"],
Cell[696115, 22227, 319, 9, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[696471, 22241, 387, 10, 70, "Input",
  CellTags->"DiracTrick"],
Cell[696861, 22253, 934, 26, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[697832, 22284, 142, 3, 70, "Input",
  CellTags->"DiracTrick"],
Cell[697977, 22289, 897, 23, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[698911, 22317, 136, 3, 70, "Input",
  CellTags->"DiracTrick"],
Cell[699050, 22322, 2863, 79, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[701950, 22406, 457, 12, 70, "Input",
  CellTags->"DiracTrick"],
Cell[702410, 22420, 703, 17, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[703150, 22442, 141, 3, 70, "Input",
  CellTags->"DiracTrick"],
Cell[703294, 22447, 24792, 618, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[728147, 23072, 60, 1, 70, "ObjectName",
  CellTags->"DotSimplify"],

Cell[CellGroupData[{
Cell[728232, 23077, 63, 1, 70, "Subsubsection",
  CellTags->"DotSimplify"],
Cell[728298, 23080, 323, 6, 70, "Text",
  CellTags->"DotSimplify"],

Cell[CellGroupData[{
Cell[728646, 23090, 149, 3, 70, "Input",
  CellTags->"DotSimplify"],
Cell[728798, 23095, 360, 9, 70, "Output"]
}, Closed]],
Cell[729173, 23107, 447, 19, 70, "Text",
  CellTags->"DotSimplify"]
}, Closed]],

Cell[CellGroupData[{
Cell[729657, 23131, 60, 1, 70, "Subsubsection",
  CellTags->"DotSimplify"],

Cell[CellGroupData[{
Cell[729742, 23136, 417, 11, 70, "Input",
  CellTags->"DotSimplify"],
Cell[730162, 23149, 532, 14, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[730731, 23168, 144, 3, 70, "Input",
  CellTags->"DotSimplify"],
Cell[730878, 23173, 702, 19, 70, "Output"]
}, Closed]],
Cell[731595, 23195, 190, 4, 70, "Input",
  CellTags->"DotSimplify"],

Cell[CellGroupData[{
Cell[731810, 23203, 259, 7, 70, "Input",
  CellTags->"DotSimplify"],
Cell[732072, 23212, 245, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[732354, 23224, 144, 3, 70, "Input",
  CellTags->"DotSimplify"],
Cell[732501, 23229, 244, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[732782, 23240, 198, 5, 70, "Input",
  CellTags->"DotSimplify"],
Cell[732983, 23247, 108, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[733128, 23254, 144, 3, 70, "Input",
  CellTags->"DotSimplify"],
Cell[733275, 23259, 347, 10, 70, "Output"]
}, Closed]],
Cell[733637, 23272, 198, 5, 70, "Input",
  CellTags->"DotSimplify"],

Cell[CellGroupData[{
Cell[733860, 23281, 144, 3, 70, "Input",
  CellTags->"DotSimplify"],
Cell[734007, 23286, 244, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[734288, 23297, 202, 5, 70, "Input",
  CellTags->"DotSimplify"],
Cell[734493, 23304, 108, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[734638, 23311, 144, 3, 70, "Input",
  CellTags->"DotSimplify"],
Cell[734785, 23316, 305, 8, 70, "Output"]
}, Closed]],
Cell[735105, 23327, 202, 5, 70, "Input",
  CellTags->"DotSimplify"],

Cell[CellGroupData[{
Cell[735332, 23336, 365, 9, 70, "Input",
  CellTags->"DotSimplify"],
Cell[735700, 23347, 181, 5, 70, "Output"]
}, Closed]],
Cell[735896, 23355, 153, 3, 70, "Input",
  CellTags->"DotSimplify"],

Cell[CellGroupData[{
Cell[736074, 23362, 180, 4, 70, "Input",
  CellTags->"DotSimplify"],
Cell[736257, 23368, 136, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[736430, 23376, 255, 6, 70, "Input",
  CellTags->"DotSimplify"],
Cell[736688, 23384, 145, 3, 70, "Output"]
}, Closed]],
Cell[736848, 23390, 202, 4, 70, "Input",
  CellTags->"DotSimplify"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[737099, 23400, 60, 1, 70, "ObjectName",
  CellTags->"EpsChisholm"],

Cell[CellGroupData[{
Cell[737184, 23405, 63, 1, 70, "Subsubsection",
  CellTags->"EpsChisholm"],
Cell[737250, 23408, 167, 4, 70, "Text",
  CellTags->"EpsChisholm"],
Cell[737420, 23414, 195, 9, 70, "Text",
  CellTags->"EpsChisholm"]
}, Closed]],

Cell[CellGroupData[{
Cell[737652, 23428, 60, 1, 70, "Subsubsection",
  CellTags->"EpsChisholm"],

Cell[CellGroupData[{
Cell[737737, 23433, 251, 6, 70, "Input",
  CellTags->"EpsChisholm"],
Cell[737991, 23441, 2728, 78, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[740756, 23524, 143, 3, 70, "Input",
  CellTags->"EpsChisholm"],
Cell[740902, 23529, 747, 23, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[741710, 23559, 60, 1, 70, "ObjectName",
  CellTags->"EpsEvaluate"],

Cell[CellGroupData[{
Cell[741795, 23564, 63, 1, 70, "Subsubsection",
  CellTags->"EpsEvaluate"],
Cell[741861, 23567, 174, 4, 70, "Text",
  CellTags->"EpsEvaluate"],
Cell[742038, 23573, 537, 24, 70, "Text",
  CellTags->"EpsEvaluate"]
}, Closed]],

Cell[CellGroupData[{
Cell[742612, 23602, 60, 1, 70, "Subsubsection",
  CellTags->"EpsEvaluate"],

Cell[CellGroupData[{
Cell[742697, 23607, 410, 11, 70, "Input",
  CellTags->"EpsEvaluate"],
Cell[743110, 23620, 636, 19, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[743783, 23644, 143, 3, 70, "Input",
  CellTags->"EpsEvaluate"],
Cell[743929, 23649, 1189, 35, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[745155, 23689, 144, 3, 70, "Input",
  CellTags->"EpsEvaluate"],
Cell[745302, 23694, 676, 14, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[746039, 23715, 52, 1, 70, "ObjectName",
  CellTags->"Epsilon"],

Cell[CellGroupData[{
Cell[746116, 23720, 59, 1, 70, "Subsubsection",
  CellTags->"Epsilon"],
Cell[746178, 23723, 247, 9, 70, "Text",
  CellTags->"Epsilon"],
Cell[746428, 23734, 188, 9, 70, "Text",
  CellTags->"Epsilon"]
}, Closed]],

Cell[CellGroupData[{
Cell[746653, 23748, 56, 1, 70, "Subsubsection",
  CellTags->"Epsilon"],

Cell[CellGroupData[{
Cell[746734, 23753, 105, 2, 70, "Input",
  CellTags->"Epsilon"],
Cell[746842, 23757, 162, 4, 70, "Output"]
}, Closed]],
Cell[747019, 23764, 115, 3, 70, "Text",
  CellTags->"Epsilon"],

Cell[CellGroupData[{
Cell[747159, 23771, 702, 19, 70, "Input",
  CellTags->"Epsilon"],
Cell[747864, 23792, 218, 5, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[748143, 23804, 44, 1, 70, "ObjectName",
  CellTags->"Eps"],

Cell[CellGroupData[{
Cell[748212, 23809, 55, 1, 70, "Subsubsection",
  CellTags->"Eps"],
Cell[748270, 23812, 360, 9, 70, "Text",
  CellTags->"Eps"],

Cell[CellGroupData[{
Cell[748655, 23825, 133, 3, 70, "Input",
  CellTags->"Eps"],
Cell[748791, 23830, 185, 5, 70, "Output"]
}, Closed]],
Cell[748991, 23838, 529, 24, 70, "Text",
  CellTags->"Eps"]
}, Closed]],

Cell[CellGroupData[{
Cell[749557, 23867, 52, 1, 70, "Subsubsection",
  CellTags->"Eps"],

Cell[CellGroupData[{
Cell[749634, 23872, 374, 8, 70, "Input",
  CellTags->"Eps"],
Cell[750011, 23882, 665, 20, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[750713, 23907, 366, 8, 70, "Input",
  CellTags->"Eps"],
Cell[751082, 23917, 606, 18, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[751725, 23940, 222, 6, 70, "Input",
  CellTags->"Eps"],
Cell[751950, 23948, 194, 4, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[752181, 23957, 174, 4, 70, "Input",
  CellTags->"Eps"],
Cell[752358, 23963, 108, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[752503, 23970, 174, 4, 70, "Input",
  CellTags->"Eps"],
Cell[752680, 23976, 130, 3, 70, "Output"]
}, Closed]],
Cell[752825, 23982, 232, 6, 70, "Input",
  CellTags->"Eps"],

Cell[CellGroupData[{
Cell[753082, 23992, 549, 13, 70, "Input",
  CellTags->"Eps"],
Cell[753634, 24007, 665, 20, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[754336, 24032, 156, 4, 70, "Input",
  CellTags->"Eps"],
Cell[754495, 24038, 131, 3, 70, "Output"]
}, Closed]],
Cell[754641, 24044, 232, 6, 70, "Input",
  CellTags->"Eps"],

Cell[CellGroupData[{
Cell[754898, 24054, 549, 13, 70, "Input",
  CellTags->"Eps"],
Cell[755450, 24069, 665, 20, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[756152, 24094, 192, 5, 70, "Input",
  CellTags->"Eps"],
Cell[756347, 24101, 342, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[756726, 24116, 541, 14, 70, "Input",
  CellTags->"Eps"],
Cell[757270, 24132, 1531, 44, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[758838, 24181, 1225, 29, 70, "Input",
  CellTags->"Eps"],
Cell[760066, 24212, 2251, 60, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[762354, 24277, 231, 6, 70, "Input",
  CellTags->"Eps"],
Cell[762588, 24285, 406, 12, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[763031, 24302, 156, 4, 70, "Input",
  CellTags->"Eps"],
Cell[763190, 24308, 108, 2, 70, "Output"]
}, Closed]],
Cell[763313, 24313, 200, 5, 70, "Input",
  CellTags->"Eps"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[763562, 24324, 66, 1, 70, "ObjectName",
  CellTags->"ExpandPartialD"],

Cell[CellGroupData[{
Cell[763653, 24329, 66, 1, 70, "Subsubsection",
  CellTags->"ExpandPartialD"],
Cell[763722, 24332, 185, 4, 70, "Text",
  CellTags->"ExpandPartialD"],
Cell[763910, 24338, 629, 23, 70, "Text",
  CellTags->"ExpandPartialD"]
}, Closed]],

Cell[CellGroupData[{
Cell[764576, 24366, 63, 1, 70, "Subsubsection",
  CellTags->"ExpandPartialD"],

Cell[CellGroupData[{
Cell[764664, 24371, 435, 10, 70, "Input",
  CellTags->"ExpandPartialD"],
Cell[765102, 24383, 400, 11, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[765539, 24399, 149, 3, 70, "Input",
  CellTags->"ExpandPartialD"],
Cell[765691, 24404, 997, 29, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[766725, 24438, 143, 3, 70, "Input",
  CellTags->"ExpandPartialD"],
Cell[766871, 24443, 943, 23, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[767851, 24471, 306, 7, 70, "Input",
  CellTags->"ExpandPartialD"],
Cell[768160, 24480, 362, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[768559, 24495, 149, 3, 70, "Input",
  CellTags->"ExpandPartialD"],
Cell[768711, 24500, 834, 24, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[769582, 24529, 512, 13, 70, "Input",
  CellTags->"ExpandPartialD"],
Cell[770097, 24544, 370, 9, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[770504, 24558, 149, 3, 70, "Input",
  CellTags->"ExpandPartialD"],
Cell[770656, 24563, 1702, 46, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[772395, 24614, 224, 6, 70, "Input",
  CellTags->"ExpandPartialD"],
Cell[772622, 24622, 295, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[772954, 24634, 151, 3, 70, "Input",
  CellTags->"ExpandPartialD"],
Cell[773108, 24639, 1294, 33, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[774439, 24677, 149, 3, 70, "Input",
  CellTags->"ExpandPartialD"],
Cell[774591, 24682, 1608, 42, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[776236, 24729, 369, 9, 70, "Input",
  CellTags->"ExpandPartialD"],
Cell[776608, 24740, 1592, 46, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[778237, 24791, 149, 3, 70, "Input",
  CellTags->"ExpandPartialD"],
Cell[778389, 24796, 108, 2, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[778558, 24805, 76, 1, 70, "ObjectName",
  CellTags->"ExpandScalarProduct"],

Cell[CellGroupData[{
Cell[778659, 24810, 71, 1, 70, "Subsubsection",
  CellTags->"ExpandScalarProduct"],
Cell[778733, 24813, 187, 4, 70, "Text",
  CellTags->"ExpandScalarProduct"],
Cell[778923, 24819, 191, 9, 70, "Text",
  CellTags->"ExpandScalarProduct"]
}, Closed]],

Cell[CellGroupData[{
Cell[779151, 24833, 68, 1, 70, "Subsubsection",
  CellTags->"ExpandScalarProduct"],

Cell[CellGroupData[{
Cell[779244, 24838, 198, 5, 70, "Input",
  CellTags->"ExpandScalarProduct"],
Cell[779445, 24845, 348, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[779830, 24860, 159, 3, 70, "Input",
  CellTags->"ExpandScalarProduct"],
Cell[779992, 24865, 386, 11, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[780415, 24881, 202, 5, 70, "Input",
  CellTags->"ExpandScalarProduct"],
Cell[780620, 24888, 253, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[780910, 24900, 159, 3, 70, "Input",
  CellTags->"ExpandScalarProduct"],
Cell[781072, 24905, 517, 17, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[781626, 24927, 263, 7, 70, "Input",
  CellTags->"ExpandScalarProduct"],
Cell[781892, 24936, 417, 11, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[782346, 24952, 191, 4, 70, "Input",
  CellTags->"ExpandScalarProduct"],
Cell[782540, 24958, 746, 21, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[783347, 24986, 54, 1, 70, "ObjectName",
  CellTags->"Explicit"],

Cell[CellGroupData[{
Cell[783426, 24991, 60, 1, 70, "Subsubsection",
  CellTags->"Explicit"],
Cell[783489, 24994, 391, 10, 70, "Text",
  CellTags->"Explicit"],
Cell[783883, 25006, 354, 14, 70, "Text",
  CellTags->"Explicit"]
}, Closed]],

Cell[CellGroupData[{
Cell[784274, 25025, 57, 1, 70, "Subsubsection",
  CellTags->"Explicit"],

Cell[CellGroupData[{
Cell[784356, 25030, 271, 6, 70, "Input",
  CellTags->"Explicit"],
Cell[784630, 25038, 1426, 42, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[786093, 25085, 137, 3, 70, "Input",
  CellTags->"Explicit"],
Cell[786233, 25090, 4500, 128, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[790770, 25223, 220, 5, 70, "Input",
  CellTags->"Explicit"],
Cell[790993, 25230, 1190, 36, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[792220, 25271, 137, 3, 70, "Input",
  CellTags->"Explicit"],
Cell[792360, 25276, 4147, 112, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[796544, 25393, 187, 4, 70, "Input",
  CellTags->"Explicit"],
Cell[796734, 25399, 197, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[796968, 25409, 137, 3, 70, "Input",
  CellTags->"Explicit"],
Cell[797108, 25414, 2065, 65, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[799234, 25486, 70, 1, 70, "ObjectName",
  CellTags->"ExplicitPartialD"],

Cell[CellGroupData[{
Cell[799329, 25491, 68, 1, 70, "Subsubsection",
  CellTags->"ExplicitPartialD"],
Cell[799400, 25494, 163, 4, 70, "Text",
  CellTags->"ExplicitPartialD"],
Cell[799566, 25500, 508, 18, 70, "Text",
  CellTags->"ExplicitPartialD"]
}, Closed]],

Cell[CellGroupData[{
Cell[800111, 25523, 65, 1, 70, "Subsubsection",
  CellTags->"ExplicitPartialD"],

Cell[CellGroupData[{
Cell[800201, 25528, 215, 4, 70, "Input",
  CellTags->"ExplicitPartialD"],
Cell[800419, 25534, 651, 18, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[801107, 25557, 218, 5, 70, "Input",
  CellTags->"ExplicitPartialD"],
Cell[801328, 25564, 516, 15, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[801881, 25584, 225, 5, 70, "Input",
  CellTags->"ExplicitPartialD"],
Cell[802109, 25591, 545, 14, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[802691, 25610, 227, 6, 70, "Input",
  CellTags->"ExplicitPartialD"],
Cell[802921, 25618, 296, 7, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[803278, 25632, 70, 1, 70, "ObjectName",
  CellTags->"ExplicitSUNIndex"],

Cell[CellGroupData[{
Cell[803373, 25637, 68, 1, 70, "Subsubsection",
  CellTags->"ExplicitSUNIndex"],
Cell[803444, 25640, 129, 3, 70, "Text",
  CellTags->"ExplicitSUNIndex"],
Cell[803576, 25645, 526, 23, 70, "Text",
  CellTags->"ExplicitSUNIndex"]
}, Closed]],

Cell[CellGroupData[{
Cell[804139, 25673, 65, 1, 70, "Subsubsection",
  CellTags->"ExplicitSUNIndex"],

Cell[CellGroupData[{
Cell[804229, 25678, 153, 3, 70, "Input",
  CellTags->"ExplicitSUNIndex"],
Cell[804385, 25683, 108, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[804530, 25690, 254, 7, 70, "Input",
  CellTags->"ExplicitSUNIndex"],
Cell[804787, 25699, 245, 5, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[805093, 25711, 52, 1, 70, "ObjectName",
  CellTags->"Factor2"],

Cell[CellGroupData[{
Cell[805170, 25716, 59, 1, 70, "Subsubsection",
  CellTags->"Factor2"],
Cell[805232, 25719, 399, 7, 70, "Text",
  CellTags->"Factor2"],

Cell[CellGroupData[{
Cell[805656, 25730, 141, 3, 70, "Input",
  CellTags->"Factor2"],
Cell[805800, 25735, 263, 7, 70, "Output"]
}, Closed]],
Cell[806078, 25745, 191, 9, 70, "Text",
  CellTags->"Factor2"]
}, Closed]],

Cell[CellGroupData[{
Cell[806306, 25759, 56, 1, 70, "Subsubsection",
  CellTags->"Factor2"],

Cell[CellGroupData[{
Cell[806387, 25764, 267, 8, 70, "Input",
  CellTags->"Factor2"],
Cell[806657, 25774, 255, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[806949, 25786, 271, 7, 70, "Input",
  CellTags->"Factor2"],
Cell[807223, 25795, 537, 16, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[807797, 25816, 314, 9, 70, "Input",
  CellTags->"Factor2"],
Cell[808114, 25827, 195, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[808346, 25837, 135, 3, 70, "Input",
  CellTags->"Factor2"],
Cell[808484, 25842, 255, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[808776, 25854, 136, 3, 70, "Input",
  CellTags->"Factor2"],
Cell[808915, 25859, 195, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[809147, 25869, 210, 5, 70, "Input",
  CellTags->"Factor2"],
Cell[809360, 25876, 255, 7, 70, "Output"]
}, Closed]],
Cell[809630, 25886, 173, 4, 70, "Input",
  CellTags->"Factor2"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[809852, 25896, 44, 1, 70, "ObjectName",
  CellTags->"FAD"],

Cell[CellGroupData[{
Cell[809921, 25901, 55, 1, 70, "Subsubsection",
  CellTags->"FAD"],
Cell[809979, 25904, 336, 6, 70, "Text",
  CellTags->"FAD"],
Cell[810318, 25912, 865, 34, 70, "Text",
  CellTags->"FAD"]
}, Closed]],

Cell[CellGroupData[{
Cell[811220, 25951, 52, 1, 70, "Subsubsection",
  CellTags->"FAD"],

Cell[CellGroupData[{
Cell[811297, 25956, 183, 5, 70, "Input",
  CellTags->"FAD"],
Cell[811483, 25963, 911, 23, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[812431, 25991, 247, 7, 70, "Input",
  CellTags->"FAD"],
Cell[812681, 26000, 1045, 25, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[813763, 26030, 307, 9, 70, "Input",
  CellTags->"FAD"],
Cell[814073, 26041, 179, 4, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[814289, 26050, 269, 8, 70, "Input",
  CellTags->"FAD"],
Cell[814561, 26060, 623, 15, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[815221, 26080, 341, 9, 70, "Input",
  CellTags->"FAD"],
Cell[815565, 26091, 623, 15, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[816249, 26113, 44, 1, 70, "ObjectName",
  CellTags->"FCE"],

Cell[CellGroupData[{
Cell[816318, 26118, 55, 1, 70, "Subsubsection",
  CellTags->"FCE"],
Cell[816376, 26121, 127, 4, 70, "Text",
  CellTags->"FCE"],
Cell[816506, 26127, 73, 1, 70, "Text",
  CellTags->"FCE"],
Cell[816582, 26130, 460, 19, 70, "Text",
  CellTags->"FCE"]
}, Closed]],

Cell[CellGroupData[{
Cell[817079, 26154, 52, 1, 70, "Subsubsection",
  CellTags->"FCE"],

Cell[CellGroupData[{
Cell[817156, 26159, 325, 9, 70, "Input",
  CellTags->"FCE"],
Cell[817484, 26170, 300, 8, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[817821, 26183, 132, 3, 70, "Input",
  CellTags->"FCE"],
Cell[817956, 26188, 213, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[818206, 26198, 517, 13, 70, "Input",
  CellTags->"FCE"],
Cell[818726, 26213, 769, 20, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[819532, 26238, 132, 3, 70, "Input",
  CellTags->"FCE"],
Cell[819667, 26243, 513, 12, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[820217, 26260, 123, 3, 70, "Input",
  CellTags->"FCE"],
Cell[820343, 26265, 1212, 35, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[821592, 26305, 132, 3, 70, "Input",
  CellTags->"FCE"],
Cell[821727, 26310, 1029, 23, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[822793, 26338, 166, 4, 70, "Input",
  CellTags->"FCE"],
Cell[822962, 26344, 513, 12, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[823536, 26363, 44, 1, 70, "ObjectName",
  CellTags->"FCI"],

Cell[CellGroupData[{
Cell[823605, 26368, 55, 1, 70, "Subsubsection",
  CellTags->"FCI"],
Cell[823663, 26371, 160, 4, 70, "Text",
  CellTags->"FCI"],
Cell[823826, 26377, 460, 19, 70, "Text",
  CellTags->"FCI"]
}, Closed]],

Cell[CellGroupData[{
Cell[824323, 26401, 52, 1, 70, "Subsubsection",
  CellTags->"FCI"],

Cell[CellGroupData[{
Cell[824400, 26406, 517, 13, 70, "Input",
  CellTags->"FCI"],
Cell[824920, 26421, 769, 20, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[825726, 26446, 132, 3, 70, "Input",
  CellTags->"FCI"],
Cell[825861, 26451, 513, 12, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[826411, 26468, 123, 3, 70, "Input",
  CellTags->"FCI"],
Cell[826537, 26473, 1212, 35, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[827786, 26513, 132, 3, 70, "Input",
  CellTags->"FCI"],
Cell[827921, 26518, 1029, 23, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[828987, 26546, 166, 4, 70, "Input",
  CellTags->"FCI"],
Cell[829156, 26552, 513, 12, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[829730, 26571, 66, 1, 70, "ObjectName",
  CellTags->"FermionSpinSum"],

Cell[CellGroupData[{
Cell[829821, 26576, 66, 1, 70, "Subsubsection",
  CellTags->"FermionSpinSum"],
Cell[829890, 26579, 119, 3, 70, "Text",
  CellTags->"FermionSpinSum"],

Cell[CellGroupData[{
Cell[830034, 26586, 155, 3, 70, "Input",
  CellTags->"FermionSpinSum"],
Cell[830192, 26591, 343, 8, 70, "Output"]
}, Closed]],
Cell[830550, 26602, 450, 19, 70, "Text",
  CellTags->"FermionSpinSum"]
}, Closed]],

Cell[CellGroupData[{
Cell[831037, 26626, 63, 1, 70, "Subsubsection",
  CellTags->"FermionSpinSum"],

Cell[CellGroupData[{
Cell[831125, 26631, 398, 10, 70, "Input",
  CellTags->"FermionSpinSum"],
Cell[831526, 26643, 803, 19, 70, "Output"]
}, Closed]],
Cell[832344, 26665, 165, 4, 70, "Text",
  CellTags->"FermionSpinSum"],

Cell[CellGroupData[{
Cell[832534, 26673, 179, 4, 70, "Input",
  CellTags->"FermionSpinSum"],
Cell[832716, 26679, 859, 20, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[833612, 26704, 177, 4, 70, "Input",
  CellTags->"FermionSpinSum"],
Cell[833792, 26710, 1591, 39, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[835420, 26754, 175, 4, 70, "Input",
  CellTags->"FermionSpinSum"],
Cell[835598, 26760, 1234, 35, 70, "Output"]
}, Closed]],
Cell[836847, 26798, 173, 4, 70, "Input",
  CellTags->"FermionSpinSum"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[837069, 26808, 88, 1, 70, "ObjectName",
  CellTags->"FeynAmpDenominatorCombine"],

Cell[CellGroupData[{
Cell[837182, 26813, 77, 1, 70, "Subsubsection",
  CellTags->"FeynAmpDenominatorCombine"],
Cell[837262, 26816, 229, 5, 70, "Text",
  CellTags->"FeynAmpDenominatorCombine"],
Cell[837494, 26823, 254, 9, 70, "Text",
  CellTags->"FeynAmpDenominatorCombine"]
}, Closed]],

Cell[CellGroupData[{
Cell[837785, 26837, 74, 1, 70, "Subsubsection",
  CellTags->"FeynAmpDenominatorCombine"],

Cell[CellGroupData[{
Cell[837884, 26842, 282, 7, 70, "Input",
  CellTags->"FeynAmpDenominatorCombine"],
Cell[838169, 26851, 974, 26, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[839180, 26882, 249, 6, 70, "Input",
  CellTags->"FeynAmpDenominatorCombine"],
Cell[839432, 26890, 205, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[839674, 26900, 247, 6, 70, "Input",
  CellTags->"FeynAmpDenominatorCombine"],
Cell[839924, 26908, 239, 6, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[840224, 26921, 74, 1, 70, "ObjectName",
  CellTags->"FeynAmpDenominator"],

Cell[CellGroupData[{
Cell[840323, 26926, 70, 1, 70, "Subsubsection",
  CellTags->"FeynAmpDenominator"],
Cell[840396, 26929, 257, 5, 70, "Text",
  CellTags->"FeynAmpDenominator"],
Cell[840656, 26936, 361, 14, 70, "Text",
  CellTags->"FeynAmpDenominator"]
}, Closed]],

Cell[CellGroupData[{
Cell[841054, 26955, 67, 1, 70, "Subsubsection",
  CellTags->"FeynAmpDenominator"],

Cell[CellGroupData[{
Cell[841146, 26960, 238, 5, 70, "Input",
  CellTags->"FeynAmpDenominator"],
Cell[841387, 26967, 226, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[841650, 26978, 387, 9, 70, "Input",
  CellTags->"FeynAmpDenominator"],
Cell[842040, 26989, 517, 15, 70, "Output"]
}, Closed]],
Cell[842572, 27007, 297, 7, 70, "Input",
  CellTags->"FeynAmpDenominator"],

Cell[CellGroupData[{
Cell[842894, 27018, 181, 4, 70, "Input",
  CellTags->"FeynAmpDenominator"],
Cell[843078, 27024, 302, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[843417, 27036, 181, 4, 70, "Input",
  CellTags->"FeynAmpDenominator"],
Cell[843601, 27042, 179, 4, 70, "Output"]
}, Closed]],
Cell[843795, 27049, 166, 4, 70, "Input",
  CellTags->"FeynAmpDenominator"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[844010, 27059, 90, 1, 70, "ObjectName",
  CellTags->"FeynAmpDenominatorSimplify"],

Cell[CellGroupData[{
Cell[844125, 27064, 78, 1, 70, "Subsubsection",
  CellTags->"FeynAmpDenominatorSimplify"],
Cell[844206, 27067, 399, 7, 70, "Text",
  CellTags->"FeynAmpDenominatorSimplify"],
Cell[844608, 27076, 86, 1, 70, "Text",
  CellTags->"FeynAmpDenominatorSimplify"],

Cell[CellGroupData[{
Cell[844719, 27081, 120, 2, 70, "Input",
  CellTags->"FeynAmpDenominatorSimplify"],
Cell[844842, 27085, 133, 2, 70, "Output"]
}, Closed]],
Cell[844990, 27090, 231, 9, 70, "Text",
  CellTags->"FeynAmpDenominatorSimplify"]
}, Closed]],

Cell[CellGroupData[{
Cell[845258, 27104, 75, 1, 70, "Subsubsection",
  CellTags->"FeynAmpDenominatorSimplify"],
Cell[845336, 27107, 507, 14, 70, "Text",
  CellTags->"FeynAmpDenominatorSimplify"],

Cell[CellGroupData[{
Cell[845868, 27125, 336, 8, 70, "Input",
  CellTags->"FeynAmpDenominatorSimplify"],
Cell[846207, 27135, 108, 2, 70, "Output"]
}, Closed]],
Cell[846330, 27140, 575, 18, 70, "Text",
  CellTags->"FeynAmpDenominatorSimplify"],

Cell[CellGroupData[{
Cell[846930, 27162, 401, 10, 70, "Input",
  CellTags->"FeynAmpDenominatorSimplify"],
Cell[847334, 27174, 825, 23, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[848196, 27202, 562, 15, 70, "Input",
  CellTags->"FeynAmpDenominatorSimplify"],
Cell[848761, 27219, 3255, 88, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[852053, 27312, 258, 6, 70, "Input",
  CellTags->"FeynAmpDenominatorSimplify"],
Cell[852314, 27320, 2187, 59, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[854538, 27384, 189, 4, 70, "Input",
  CellTags->"FeynAmpDenominatorSimplify"],
Cell[854730, 27390, 1059, 30, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[855826, 27425, 464, 13, 70, "Input",
  CellTags->"FeynAmpDenominatorSimplify"],
Cell[856293, 27440, 3923, 105, 70, "Output"]
}, Closed]],
Cell[860231, 27548, 179, 4, 70, "Input",
  CellTags->"FeynAmpDenominatorSimplify"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[860459, 27558, 84, 1, 70, "ObjectName",
  CellTags->"FeynAmpDenominatorSplit"],

Cell[CellGroupData[{
Cell[860568, 27563, 75, 1, 70, "Subsubsection",
  CellTags->"FeynAmpDenominatorSplit"],
Cell[860646, 27566, 358, 7, 70, "Text",
  CellTags->"FeynAmpDenominatorSplit"],
Cell[861007, 27575, 258, 9, 70, "Text",
  CellTags->"FeynAmpDenominatorSplit"]
}, Closed]],

Cell[CellGroupData[{
Cell[861302, 27589, 72, 1, 70, "Subsubsection",
  CellTags->"FeynAmpDenominatorSplit"],

Cell[CellGroupData[{
Cell[861399, 27594, 372, 9, 70, "Input",
  CellTags->"FeynAmpDenominatorSplit"],
Cell[861774, 27605, 1178, 33, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[862989, 27643, 144, 3, 70, "Input",
  CellTags->"FeynAmpDenominatorSplit"],
Cell[863136, 27648, 125, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[863298, 27655, 167, 3, 70, "Input",
  CellTags->"FeynAmpDenominatorSplit"],
Cell[863468, 27660, 1178, 33, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[864683, 27698, 182, 4, 70, "Input",
  CellTags->"FeynAmpDenominatorSplit"],
Cell[864868, 27704, 461, 12, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[865366, 27721, 277, 7, 70, "Input",
  CellTags->"FeynAmpDenominatorSplit"],
Cell[865646, 27730, 407, 11, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[866090, 27746, 247, 6, 70, "Input",
  CellTags->"FeynAmpDenominatorSplit"],
Cell[866340, 27754, 325, 8, 70, "Output"]
}, Closed]],
Cell[866680, 27765, 149, 3, 70, "Input",
  CellTags->"FeynAmpDenominatorSplit"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[866878, 27774, 52, 1, 70, "ObjectName",
  CellTags->"FeynAmp"],

Cell[CellGroupData[{
Cell[866955, 27779, 59, 1, 70, "Subsubsection",
  CellTags->"FeynAmp"],
Cell[867017, 27782, 244, 5, 70, "Text",
  CellTags->"FeynAmp"],
Cell[867264, 27789, 166, 4, 70, "Text",
  CellTags->"FeynAmp"],
Cell[867433, 27795, 197, 9, 70, "Text",
  CellTags->"FeynAmp"]
}, Closed]],

Cell[CellGroupData[{
Cell[867667, 27809, 56, 1, 70, "Subsubsection",
  CellTags->"FeynAmp"],
Cell[867726, 27812, 126, 4, 70, "Text",
  CellTags->"FeynAmp"],

Cell[CellGroupData[{
Cell[867877, 27820, 1007, 22, 70, "Input",
  CellTags->"FeynAmp"],
Cell[868887, 27844, 5557, 138, 70, "Output"]
}, Closed]],
Cell[874459, 27985, 74, 1, 70, "Text",
  CellTags->"FeynAmp"],

Cell[CellGroupData[{
Cell[874558, 27990, 240, 6, 70, "Input",
  CellTags->"FeynAmp"],
Cell[874801, 27998, 488, 13, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[875350, 28018, 64, 1, 70, "ObjectName",
  CellTags->"FeynCalc2FORM"],

Cell[CellGroupData[{
Cell[875439, 28023, 65, 1, 70, "Subsubsection",
  CellTags->"FeynCalc2FORM"],
Cell[875507, 28026, 227, 5, 70, "Text",
  CellTags->"FeynCalc2FORM"],
Cell[875737, 28033, 212, 9, 70, "Text",
  CellTags->"FeynCalc2FORM"],

Cell[CellGroupData[{
Cell[875974, 28046, 153, 3, 70, "Input",
  CellTags->"FeynCalc2FORM"],
Cell[876130, 28051, 1240, 26, 70, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[877419, 28083, 62, 1, 70, "Subsubsection",
  CellTags->"FeynCalc2FORM"],

Cell[CellGroupData[{
Cell[877506, 28088, 328, 9, 70, "Input",
  CellTags->"FeynCalc2FORM"],
Cell[877837, 28099, 330, 9, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[878204, 28113, 169, 4, 70, "Input",
  CellTags->"FeynCalc2FORM"],
Cell[878376, 28119, 88, 1, 70, "Print"]
}, Closed]],

Cell[CellGroupData[{
Cell[878501, 28125, 241, 6, 70, "Input",
  CellTags->"FeynCalc2FORM"],
Cell[878745, 28133, 266, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[879048, 28144, 169, 4, 70, "Input",
  CellTags->"FeynCalc2FORM"],
Cell[879220, 28150, 84, 1, 70, "Print"]
}, Closed]],

Cell[CellGroupData[{
Cell[879341, 28156, 255, 6, 70, "Input",
  CellTags->"FeynCalc2FORM"],
Cell[879599, 28164, 423, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[880059, 28179, 169, 4, 70, "Input",
  CellTags->"FeynCalc2FORM"],
Cell[880231, 28185, 107, 2, 70, "Print"]
}, Closed]],

Cell[CellGroupData[{
Cell[880375, 28192, 356, 9, 70, "Input",
  CellTags->"FeynCalc2FORM"],
Cell[880734, 28203, 562, 15, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[881333, 28223, 169, 4, 70, "Input",
  CellTags->"FeynCalc2FORM"],
Cell[881505, 28229, 107, 2, 70, "Print"]
}, Closed]],
Cell[881627, 28234, 401, 10, 70, "Input",
  CellTags->"FeynCalc2FORM"],

Cell[CellGroupData[{
Cell[882053, 28248, 406, 10, 70, "Input",
  CellTags->"FeynCalc2FORM"],
Cell[882462, 28260, 164, 4, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[882663, 28269, 385, 10, 70, "Input",
  CellTags->"FeynCalc2FORM"],
Cell[883051, 28281, 8900, 243, 70, "Output"]
}, Closed]],
Cell[891966, 28527, 252, 6, 70, "Input",
  CellTags->"FeynCalc2FORM"],

Cell[CellGroupData[{
Cell[892243, 28537, 460, 11, 70, "Input",
  CellTags->"FeynCalc2FORM"],
Cell[892706, 28550, 1751, 39, 70, "Output"]
}, Closed]],
Cell[894472, 28592, 380, 10, 70, "Input",
  CellTags->"FeynCalc2FORM"],
Cell[894855, 28604, 161, 4, 70, "Input",
  CellTags->"FeynCalc2FORM"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[895065, 28614, 70, 1, 70, "ObjectName",
  CellTags->"FeynCalcExternal"],

Cell[CellGroupData[{
Cell[895160, 28619, 68, 1, 70, "Subsubsection",
  CellTags->"FeynCalcExternal"],
Cell[895231, 28622, 157, 4, 70, "Text",
  CellTags->"FeynCalcExternal"],
Cell[895391, 28628, 224, 9, 70, "Text",
  CellTags->"FeynCalcExternal"]
}, Closed]],

Cell[CellGroupData[{
Cell[895652, 28642, 65, 1, 70, "Subsubsection",
  CellTags->"FeynCalcExternal"],

Cell[CellGroupData[{
Cell[895742, 28647, 194, 4, 70, "Input",
  CellTags->"FeynCalcExternal"],
Cell[895939, 28653, 143, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[896119, 28661, 145, 3, 70, "Input",
  CellTags->"FeynCalcExternal"],
Cell[896267, 28666, 122, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[896426, 28673, 530, 13, 70, "Input",
  CellTags->"FeynCalcExternal"],
Cell[896959, 28688, 769, 20, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[897765, 28713, 145, 3, 70, "Input",
  CellTags->"FeynCalcExternal"],
Cell[897913, 28718, 513, 12, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[898463, 28735, 149, 3, 70, "Input",
  CellTags->"FeynCalcExternal"],
Cell[898615, 28740, 1212, 35, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[899864, 28780, 145, 3, 70, "Input",
  CellTags->"FeynCalcExternal"],
Cell[900012, 28785, 1029, 23, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[901078, 28813, 199, 5, 70, "Input",
  CellTags->"FeynCalcExternal"],
Cell[901280, 28820, 513, 12, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[901854, 28839, 70, 1, 70, "ObjectName",
  CellTags->"FeynCalcInternal"],

Cell[CellGroupData[{
Cell[901949, 28844, 68, 1, 70, "Subsubsection",
  CellTags->"FeynCalcInternal"],
Cell[902020, 28847, 158, 4, 70, "Text",
  CellTags->"FeynCalcInternal"],
Cell[902181, 28853, 434, 19, 70, "Text",
  CellTags->"FeynCalcInternal"]
}, Closed]],

Cell[CellGroupData[{
Cell[902652, 28877, 65, 1, 70, "Subsubsection",
  CellTags->"FeynCalcInternal"],

Cell[CellGroupData[{
Cell[902742, 28882, 530, 13, 70, "Input",
  CellTags->"FeynCalcInternal"],
Cell[903275, 28897, 769, 20, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[904081, 28922, 145, 3, 70, "Input",
  CellTags->"FeynCalcInternal"],
Cell[904229, 28927, 513, 12, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[904779, 28944, 149, 3, 70, "Input",
  CellTags->"FeynCalcInternal"],
Cell[904931, 28949, 1212, 35, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[906180, 28989, 145, 3, 70, "Input",
  CellTags->"FeynCalcInternal"],
Cell[906328, 28994, 1029, 23, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[907394, 29022, 199, 5, 70, "Input",
  CellTags->"FeynCalcInternal"],
Cell[907596, 29029, 513, 12, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[908146, 29046, 621, 15, 70, "Input",
  CellTags->"FeynCalcInternal"],
Cell[908770, 29063, 2123, 62, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[910930, 29130, 145, 3, 70, "Input",
  CellTags->"FeynCalcInternal"],
Cell[911078, 29135, 1304, 30, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[912443, 29172, 54, 1, 70, "ObjectName",
  CellTags->"FeynRule"],

Cell[CellGroupData[{
Cell[912522, 29177, 60, 1, 70, "Subsubsection",
  CellTags->"FeynRule"],
Cell[912585, 29180, 169, 4, 70, "Text",
  CellTags->"FeynRule"],

Cell[CellGroupData[{
Cell[912779, 29188, 143, 3, 70, "Input",
  CellTags->"FeynRule"],
Cell[912925, 29193, 780, 17, 70, "Output"]
}, Closed]],
Cell[913720, 29213, 93, 1, 70, "Text",
  CellTags->"FeynRule"],
Cell[913816, 29216, 134, 4, 70, "Text",
  CellTags->"FeynRule"],
Cell[913953, 29222, 198, 9, 70, "Text",
  CellTags->"FeynRule"]
}, Closed]],

Cell[CellGroupData[{
Cell[914188, 29236, 57, 1, 70, "Subsubsection",
  CellTags->"FeynRule"],

Cell[CellGroupData[{
Cell[914270, 29241, 178, 4, 70, "Input",
  CellTags->"FeynRule"],
Cell[914451, 29247, 873, 22, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[915361, 29274, 178, 4, 70, "Input",
  CellTags->"FeynRule"],
Cell[915542, 29280, 1365, 35, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[916944, 29320, 139, 3, 70, "Input",
  CellTags->"FeynRule"],
Cell[917086, 29325, 5750, 153, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[922873, 29483, 173, 4, 70, "Input",
  CellTags->"FeynRule"],
Cell[923049, 29489, 3644, 112, 70, "Output"]
}, Closed]],
Cell[926708, 29604, 75, 1, 70, "Text",
  CellTags->"FeynRule"],

Cell[CellGroupData[{
Cell[926808, 29609, 625, 16, 70, "Input",
  CellTags->"FeynRule"],
Cell[927436, 29627, 941, 29, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[928414, 29661, 371, 9, 70, "Input",
  CellTags->"FeynRule"],
Cell[928788, 29672, 6036, 152, 70, "Output"]
}, Closed]],
Cell[934839, 29827, 73, 1, 70, "Text",
  CellTags->"FeynRule"],

Cell[CellGroupData[{
Cell[934937, 29832, 625, 16, 70, "Input",
  CellTags->"FeynRule"],
Cell[935565, 29850, 941, 29, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[936543, 29884, 371, 9, 70, "Input",
  CellTags->"FeynRule"],
Cell[936917, 29895, 7303, 163, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[944257, 30063, 268, 7, 70, "Input",
  CellTags->"FeynRule"],
Cell[944528, 30072, 1453, 42, 70, "Output"]
}, Closed]],
Cell[945996, 30117, 111, 3, 70, "Text",
  CellTags->"FeynRule"],

Cell[CellGroupData[{
Cell[946132, 30124, 424, 10, 70, "Input",
  CellTags->"FeynRule"],
Cell[946559, 30136, 1555, 45, 70, "Output"]
}, Closed]],
Cell[948129, 30184, 78, 1, 70, "Text",
  CellTags->"FeynRule"],

Cell[CellGroupData[{
Cell[948232, 30189, 177, 4, 70, "Input",
  CellTags->"FeynRule"],
Cell[948412, 30195, 806, 22, 70, "Output"]
}, Closed]],
Cell[949233, 30220, 91, 1, 70, "Text",
  CellTags->"FeynRule"],

Cell[CellGroupData[{
Cell[949349, 30225, 177, 4, 70, "Input",
  CellTags->"FeynRule"],
Cell[949529, 30231, 806, 22, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[950372, 30258, 863, 22, 70, "Input",
  CellTags->"FeynRule"],
Cell[951238, 30282, 1298, 38, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[952573, 30325, 277, 7, 70, "Input",
  CellTags->"FeynRule"],
Cell[952853, 30334, 7312, 184, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[960202, 30523, 501, 12, 70, "Input",
  CellTags->"FeynRule"],
Cell[960706, 30537, 7316, 164, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[968059, 30706, 445, 12, 70, "Input",
  CellTags->"FeynRule"],
Cell[968507, 30720, 108, 2, 70, "Output"]
}, Closed]],
Cell[968630, 30725, 211, 5, 70, "Text",
  CellTags->"FeynRule"],
Cell[968844, 30732, 176, 4, 70, "Input",
  CellTags->"FeynRule"],
Cell[969023, 30738, 52, 1, 70, "Text",
  CellTags->"FeynRule"],

Cell[CellGroupData[{
Cell[969100, 30743, 854, 21, 70, "Input",
  CellTags->"FeynRule"],
Cell[969957, 30766, 1337, 41, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[971331, 30812, 260, 7, 70, "Input",
  CellTags->"FeynRule"],
Cell[971594, 30821, 2827, 77, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[974458, 30903, 455, 11, 70, "Input",
  CellTags->"FeynRule"],
Cell[974916, 30916, 2976, 83, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[977929, 31004, 240, 6, 70, "Input",
  CellTags->"FeynRule"],
Cell[978172, 31012, 108, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[978317, 31019, 1084, 26, 70, "Input",
  CellTags->"FeynRule"],
Cell[979404, 31047, 1735, 53, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[981176, 31105, 260, 7, 70, "Input",
  CellTags->"FeynRule"],
Cell[981439, 31114, 4819, 132, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[986295, 31251, 542, 13, 70, "Input",
  CellTags->"FeynRule"],
Cell[986840, 31266, 9095, 227, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[995972, 31498, 240, 6, 70, "Input",
  CellTags->"FeynRule"],
Cell[996215, 31506, 108, 2, 70, "Output"]
}, Closed]],
Cell[996338, 31511, 475, 9, 70, "Input",
  CellTags->"FeynRule"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[996862, 31526, 64, 1, 70, "ObjectName",
  CellTags->"FieldStrength"],

Cell[CellGroupData[{
Cell[996951, 31531, 65, 1, 70, "Subsubsection",
  CellTags->"FieldStrength"],
Cell[997019, 31534, 1453, 37, 70, "Text",
  CellTags->"FieldStrength"],

Cell[CellGroupData[{
Cell[998497, 31575, 153, 3, 70, "Input",
  CellTags->"FieldStrength"],
Cell[998653, 31580, 548, 13, 70, "Output"]
}, Closed]],
Cell[999216, 31596, 209, 9, 70, "Text",
  CellTags->"FieldStrength"]
}, Closed]],

Cell[CellGroupData[{
Cell[999462, 31610, 62, 1, 70, "Subsubsection",
  CellTags->"FieldStrength"],

Cell[CellGroupData[{
Cell[999549, 31615, 182, 4, 70, "Input",
  CellTags->"FieldStrength"],
Cell[999734, 31621, 203, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[999974, 31631, 192, 4, 70, "Input",
  CellTags->"FieldStrength"],
Cell[1000169, 31637, 197, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1000403, 31647, 237, 5, 70, "Input",
  CellTags->"FieldStrength"],
Cell[1000643, 31654, 939, 30, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1001619, 31689, 247, 5, 70, "Input",
  CellTags->"FieldStrength"],
Cell[1001869, 31696, 2067, 65, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1003973, 31766, 284, 6, 70, "Input",
  CellTags->"FieldStrength"],
Cell[1004260, 31774, 614, 14, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1004911, 31793, 287, 6, 70, "Input",
  CellTags->"FieldStrength"],
Cell[1005201, 31801, 612, 14, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1005850, 31820, 339, 7, 70, "Input",
  CellTags->"FieldStrength"],
Cell[1006192, 31829, 2067, 65, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1008320, 31901, 64, 1, 70, "ObjectName",
  CellTags->"FORM2FeynCalc"],

Cell[CellGroupData[{
Cell[1008409, 31906, 65, 1, 70, "Subsubsection",
  CellTags->"FORM2FeynCalc"],
Cell[1008477, 31909, 473, 8, 70, "Text",
  CellTags->"FORM2FeynCalc"],
Cell[1008953, 31919, 212, 9, 70, "Text",
  CellTags->"FORM2FeynCalc"],

Cell[CellGroupData[{
Cell[1009190, 31932, 153, 3, 70, "Input",
  CellTags->"FORM2FeynCalc"],
Cell[1009346, 31937, 754, 17, 70, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1010149, 31960, 62, 1, 70, "Subsubsection",
  CellTags->"FORM2FeynCalc"],

Cell[CellGroupData[{
Cell[1010236, 31965, 167, 3, 70, "Input",
  CellTags->"FORM2FeynCalc"],
Cell[1010406, 31970, 446, 13, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1010889, 31988, 142, 3, 70, "Input",
  CellTags->"FORM2FeynCalc"],
Cell[1011034, 31993, 245, 6, 70, "Output"]
}, Closed]],
Cell[1011294, 32002, 160, 4, 70, "Text",
  CellTags->"FORM2FeynCalc"],

Cell[CellGroupData[{
Cell[1011479, 32010, 366, 8, 70, "Input",
  CellTags->"FORM2FeynCalc"],
Cell[1011848, 32020, 353, 9, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1012238, 32034, 142, 3, 70, "Input",
  CellTags->"FORM2FeynCalc"],
Cell[1012383, 32039, 330, 8, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1012750, 32052, 180, 4, 70, "Input",
  CellTags->"FORM2FeynCalc"],
Cell[1012933, 32058, 352, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1013322, 32073, 145, 3, 70, "Input",
  CellTags->"FORM2FeynCalc"],
Cell[1013470, 32078, 241, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1013748, 32090, 180, 4, 70, "Input",
  CellTags->"FORM2FeynCalc"],
Cell[1013931, 32096, 302, 8, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1014270, 32109, 142, 3, 70, "Input",
  CellTags->"FORM2FeynCalc"],
Cell[1014415, 32114, 341, 9, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1014793, 32128, 384, 9, 70, "Input",
  CellTags->"FORM2FeynCalc"],
Cell[1015180, 32139, 321, 9, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1015538, 32153, 231, 6, 70, "Input",
  CellTags->"FORM2FeynCalc"],
Cell[1015772, 32161, 640, 16, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1016473, 32184, 66, 1, 70, "ObjectName",
  CellTags->"FourDivergence"],

Cell[CellGroupData[{
Cell[1016564, 32189, 66, 1, 70, "Subsubsection",
  CellTags->"FourDivergence"],
Cell[1016633, 32192, 243, 5, 70, "Text",
  CellTags->"FourDivergence"],
Cell[1016879, 32199, 210, 9, 70, "Text",
  CellTags->"FourDivergence"]
}, Closed]],

Cell[CellGroupData[{
Cell[1017126, 32213, 63, 1, 70, "Subsubsection",
  CellTags->"FourDivergence"],

Cell[CellGroupData[{
Cell[1017214, 32218, 204, 5, 70, "Input",
  CellTags->"FourDivergence"],
Cell[1017421, 32225, 268, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1017726, 32237, 254, 6, 70, "Input",
  CellTags->"FourDivergence"],
Cell[1017983, 32245, 285, 9, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1018305, 32259, 235, 6, 70, "Input",
  CellTags->"FourDivergence"],
Cell[1018543, 32267, 555, 15, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1019135, 32287, 289, 8, 70, "Input",
  CellTags->"FourDivergence"],
Cell[1019427, 32297, 108, 2, 70, "Output"]
}, Closed]],
Cell[1019550, 32302, 140, 3, 70, "Input",
  CellTags->"FourDivergence"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1019739, 32311, 64, 1, 70, "ObjectName",
  CellTags->"FourLaplacian"],

Cell[CellGroupData[{
Cell[1019828, 32316, 65, 1, 70, "Subsubsection",
  CellTags->"FourLaplacian"],
Cell[1019896, 32319, 491, 16, 70, "Text",
  CellTags->"FourLaplacian"],

Cell[CellGroupData[{
Cell[1020412, 32339, 153, 3, 70, "Input",
  CellTags->"FourLaplacian"],
Cell[1020568, 32344, 185, 5, 70, "Output"]
}, Closed]],
Cell[1020768, 32352, 347, 14, 70, "Text",
  CellTags->"FourLaplacian"]
}, Closed]],

Cell[CellGroupData[{
Cell[1021152, 32371, 62, 1, 70, "Subsubsection",
  CellTags->"FourLaplacian"],

Cell[CellGroupData[{
Cell[1021239, 32376, 163, 4, 70, "Input",
  CellTags->"FourLaplacian"],
Cell[1021405, 32382, 183, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1021625, 32392, 184, 4, 70, "Input",
  CellTags->"FourLaplacian"],
Cell[1021812, 32398, 135, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1021984, 32406, 325, 9, 70, "Input",
  CellTags->"FourLaplacian"],
Cell[1022312, 32417, 581, 17, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1022930, 32439, 189, 4, 70, "Input",
  CellTags->"FourLaplacian"],
Cell[1023122, 32445, 5705, 153, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1028888, 32605, 58, 1, 70, "ObjectName",
  CellTags->"FourVector"],

Cell[CellGroupData[{
Cell[1028971, 32610, 62, 1, 70, "Subsubsection",
  CellTags->"FourVector"],
Cell[1029036, 32613, 353, 10, 70, "Text",
  CellTags->"FourVector"],
Cell[1029392, 32625, 389, 19, 70, "Text",
  CellTags->"FourVector"]
}, Closed]],

Cell[CellGroupData[{
Cell[1029818, 32649, 59, 1, 70, "Subsubsection",
  CellTags->"FourVector"],

Cell[CellGroupData[{
Cell[1029902, 32654, 172, 4, 70, "Input",
  CellTags->"FourVector"],
Cell[1030077, 32660, 138, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1030252, 32668, 201, 5, 70, "Input",
  CellTags->"FourVector"],
Cell[1030456, 32675, 333, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1030826, 32690, 217, 5, 70, "Input",
  CellTags->"FourVector"],
Cell[1031046, 32697, 161, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1031244, 32705, 272, 6, 70, "Input",
  CellTags->"FourVector"],
Cell[1031519, 32713, 214, 4, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1031770, 32722, 255, 6, 70, "Input",
  CellTags->"FourVector"],
Cell[1032028, 32730, 161, 3, 70, "Output"]
}, Closed]],
Cell[1032204, 32736, 194, 4, 70, "Text",
  CellTags->"FourVector"],

Cell[CellGroupData[{
Cell[1032423, 32744, 255, 6, 70, "Input",
  CellTags->"FourVector"],
Cell[1032681, 32752, 517, 17, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1033259, 32776, 50, 1, 70, "ObjectName",
  CellTags->"FreeQ2"],

Cell[CellGroupData[{
Cell[1033334, 32781, 58, 1, 70, "Subsubsection",
  CellTags->"FreeQ2"],
Cell[1033395, 32784, 229, 5, 70, "Text",
  CellTags->"FreeQ2"],
Cell[1033627, 32791, 331, 14, 70, "Text",
  CellTags->"FreeQ2"]
}, Closed]],

Cell[CellGroupData[{
Cell[1033995, 32810, 55, 1, 70, "Subsubsection",
  CellTags->"FreeQ2"],

Cell[CellGroupData[{
Cell[1034075, 32815, 300, 8, 70, "Input",
  CellTags->"FreeQ2"],
Cell[1034378, 32825, 112, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1034527, 32832, 295, 8, 70, "Input",
  CellTags->"FreeQ2"],
Cell[1034825, 32842, 111, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1034973, 32849, 165, 4, 70, "Input",
  CellTags->"FreeQ2"],
Cell[1035141, 32855, 111, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1035289, 32862, 199, 5, 70, "Input",
  CellTags->"FreeQ2"],
Cell[1035491, 32869, 112, 2, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1035664, 32878, 52, 1, 70, "ObjectName",
  CellTags->"FromTFi"],

Cell[CellGroupData[{
Cell[1035741, 32883, 59, 1, 70, "Subsubsection",
  CellTags->"FromTFi"],
Cell[1035803, 32886, 201, 5, 70, "Text",
  CellTags->"FromTFi"],
Cell[1036007, 32893, 280, 13, 70, "Text",
  CellTags->"FromTFi"]
}, Closed]],

Cell[CellGroupData[{
Cell[1036324, 32911, 56, 1, 70, "Subsubsection",
  CellTags->"FromTFi"],

Cell[CellGroupData[{
Cell[1036405, 32916, 453, 12, 70, "Input",
  CellTags->"FromTFi"],
Cell[1036861, 32930, 1133, 34, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1038031, 32969, 873, 22, 70, "Input",
  CellTags->"FromTFi"],
Cell[1038907, 32993, 1429, 40, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1040373, 33038, 951, 24, 70, "Input",
  CellTags->"FromTFi"],
Cell[1041327, 33064, 1816, 50, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1043204, 33121, 44, 1, 70, "ObjectName",
  CellTags->"FRH"],

Cell[CellGroupData[{
Cell[1043273, 33126, 55, 1, 70, "Subsubsection",
  CellTags->"FRH"],
Cell[1043331, 33129, 135, 4, 70, "Text",
  CellTags->"FRH"],
Cell[1043469, 33135, 184, 9, 70, "Text",
  CellTags->"FRH"]
}, Closed]],

Cell[CellGroupData[{
Cell[1043690, 33149, 52, 1, 70, "Subsubsection",
  CellTags->"FRH"],

Cell[CellGroupData[{
Cell[1043767, 33154, 243, 6, 70, "Input",
  CellTags->"FRH"],
Cell[1044013, 33162, 291, 8, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1044341, 33175, 127, 3, 70, "Input",
  CellTags->"FRH"],
Cell[1044471, 33180, 108, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1044616, 33187, 368, 10, 70, "Input",
  CellTags->"FRH"],
Cell[1044987, 33199, 657, 19, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1045681, 33223, 159, 4, 70, "Input",
  CellTags->"FRH"],
Cell[1045843, 33229, 674, 20, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1046578, 33256, 60, 1, 70, "ObjectName",
  CellTags->"FunctionalD"],

Cell[CellGroupData[{
Cell[1046663, 33261, 63, 1, 70, "Subsubsection",
  CellTags->"FunctionalD"],
Cell[1046729, 33264, 415, 7, 70, "Text",
  CellTags->"FunctionalD"],
Cell[1047147, 33273, 96, 1, 70, "Text",
  CellTags->"FunctionalD"],
Cell[1047246, 33276, 327, 14, 70, "Text",
  CellTags->"FunctionalD"]
}, Closed]],

Cell[CellGroupData[{
Cell[1047610, 33295, 60, 1, 70, "Subsubsection",
  CellTags->"FunctionalD"],
Cell[1047673, 33298, 692, 20, 70, "Text",
  CellTags->"FunctionalD"],

Cell[CellGroupData[{
Cell[1048390, 33322, 270, 6, 70, "Input",
  CellTags->"FunctionalD"],
Cell[1048663, 33330, 108, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1048808, 33337, 301, 7, 70, "Input",
  CellTags->"FunctionalD"],
Cell[1049112, 33346, 140, 3, 70, "Output"]
}, Closed]],
Cell[1049267, 33352, 1498, 44, 70, "Text",
  CellTags->"FunctionalD"],

Cell[CellGroupData[{
Cell[1050790, 33400, 359, 9, 70, "Input",
  CellTags->"FunctionalD"],
Cell[1051152, 33411, 321, 9, 70, "Output"]
}, Closed]],
Cell[1051488, 33423, 968, 24, 70, "Text",
  CellTags->"FunctionalD"],

Cell[CellGroupData[{
Cell[1052481, 33451, 843, 22, 70, "Input",
  CellTags->"FunctionalD"],
Cell[1053327, 33475, 938, 25, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1054302, 33505, 259, 6, 70, "Input",
  CellTags->"FunctionalD"],
Cell[1054564, 33513, 807, 24, 70, "Output"]
}, Closed]],
Cell[1055386, 33540, 590, 16, 70, "Text",
  CellTags->"FunctionalD"],
Cell[1055979, 33558, 99, 2, 70, "Text",
  CellTags->"FunctionalD"],

Cell[CellGroupData[{
Cell[1056103, 33564, 371, 8, 70, "Input",
  CellTags->"FunctionalD"],
Cell[1056477, 33574, 1791, 56, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1058305, 33635, 371, 8, 70, "Input",
  CellTags->"FunctionalD"],
Cell[1058679, 33645, 1791, 56, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1060507, 33706, 268, 8, 70, "Input",
  CellTags->"FunctionalD"],
Cell[1060778, 33716, 4293, 116, 70, "Output"]
}, Closed]],
Cell[1065086, 33835, 579, 13, 70, "Text",
  CellTags->"FunctionalD"],
Cell[1065668, 33850, 1926, 50, 70, "Text",
  CellTags->"FunctionalD"],
Cell[1067597, 33902, 534, 13, 70, "Text",
  CellTags->"FunctionalD"],

Cell[CellGroupData[{
Cell[1068156, 33919, 280, 7, 70, "Input",
  CellTags->"FunctionalD"],
Cell[1068439, 33928, 347, 11, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1068823, 33944, 202, 5, 70, "Input",
  CellTags->"FunctionalD"],
Cell[1069028, 33951, 3191, 94, 70, "Output"]
}, Closed]],
Cell[1072234, 34048, 121, 3, 70, "Text",
  CellTags->"FunctionalD"],

Cell[CellGroupData[{
Cell[1072380, 34055, 213, 5, 70, "Input",
  CellTags->"FunctionalD"],
Cell[1072596, 34062, 3191, 94, 70, "Output"]
}, Closed]],
Cell[1075802, 34159, 303, 8, 70, "Text",
  CellTags->"FunctionalD"],
Cell[1076108, 34169, 652, 18, 70, "Input",
  CellTags->"FunctionalD"],

Cell[CellGroupData[{
Cell[1076785, 34191, 278, 7, 70, "Input",
  CellTags->"FunctionalD"],
Cell[1077066, 34200, 500, 16, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1077603, 34221, 289, 7, 70, "Input",
  CellTags->"FunctionalD"],
Cell[1077895, 34230, 550, 17, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1078482, 34252, 722, 17, 70, "Input",
  CellTags->"FunctionalD"],
Cell[1079207, 34271, 4133, 125, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1083377, 34401, 221, 5, 70, "Input",
  CellTags->"FunctionalD"],
Cell[1083601, 34408, 1987, 61, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1085625, 34474, 428, 11, 70, "Input",
  CellTags->"FunctionalD"],
Cell[1086056, 34487, 1628, 50, 70, "Output"]
}, Closed]],
Cell[1087699, 34540, 294, 9, 70, "Text",
  CellTags->"FunctionalD"],
Cell[1087996, 34551, 100, 2, 70, "Text",
  CellTags->"FunctionalD"],
Cell[1088099, 34555, 168, 4, 70, "Text",
  CellTags->"FunctionalD"],

Cell[CellGroupData[{
Cell[1088292, 34563, 133, 3, 70, "Input",
  CellTags->"FunctionalD"],
Cell[1088428, 34568, 4293, 116, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1092758, 34689, 237, 6, 70, "Input",
  CellTags->"FunctionalD"],
Cell[1092998, 34697, 33707, 1003, 70, "Output"]
}, Closed]],
Cell[1126720, 35703, 232, 5, 70, "Text",
  CellTags->"FunctionalD"],
Cell[1126955, 35710, 346, 6, 70, "Text",
  CellTags->"FunctionalD"],
Cell[1127304, 35718, 164, 4, 70, "Input",
  CellTags->"FunctionalD"],
Cell[1127471, 35724, 3947, 76, 70, "Input",
  CellTags->"FunctionalD"],

Cell[CellGroupData[{
Cell[1131443, 35804, 206, 5, 70, "Input",
  CellTags->"FunctionalD"],
Cell[1131652, 35811, 17344, 524, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1149033, 36340, 201, 5, 70, "Input",
  CellTags->"FunctionalD"],
Cell[1149237, 36347, 9204, 284, 70, "Output"]
}, Closed]],
Cell[1158456, 36634, 225, 8, 70, "Text",
  CellTags->"FunctionalD"],

Cell[CellGroupData[{
Cell[1158706, 36646, 401, 11, 70, "Input",
  CellTags->"FunctionalD"],
Cell[1159110, 36659, 3825, 118, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1162972, 36782, 828, 22, 70, "Input",
  CellTags->"FunctionalD"],
Cell[1163803, 36806, 1830, 59, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1165670, 36870, 186, 4, 70, "Input",
  CellTags->"FunctionalD"],
Cell[1165859, 36876, 7324, 226, 70, "Output"]
}, Closed]],
Cell[1173198, 37105, 132, 4, 70, "Text",
  CellTags->"FunctionalD"],

Cell[CellGroupData[{
Cell[1173355, 37113, 104, 2, 70, "Input",
  CellTags->"FunctionalD"],
Cell[1173462, 37117, 1628, 50, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1175127, 37172, 957, 22, 70, "Input",
  CellTags->"FunctionalD"],
Cell[1176087, 37196, 1492, 41, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1177616, 37242, 169, 4, 70, "Input",
  CellTags->"FunctionalD"],
Cell[1177788, 37248, 4870, 133, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1182695, 37386, 246, 6, 70, "Input",
  CellTags->"FunctionalD"],
Cell[1182944, 37394, 8579, 265, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1191560, 37664, 170, 4, 70, "Input",
  CellTags->"FunctionalD"],
Cell[1191733, 37670, 11309, 349, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1203079, 38024, 200, 5, 70, "Input",
  CellTags->"FunctionalD"],
Cell[1203282, 38031, 108, 2, 70, "Output"]
}, Closed]],
Cell[1203405, 38036, 67, 1, 70, "Text",
  CellTags->"FunctionalD"],
Cell[1203475, 38039, 617, 13, 70, "Input",
  CellTags->"FunctionalD"]
}, Closed]],

Cell[CellGroupData[{
Cell[1204129, 38057, 111, 2, 70, "Subsubsection",
  CellTags->"FunctionalD"],
Cell[1204243, 38061, 80, 1, 70, "Text",
  CellTags->"FunctionalD"],

Cell[CellGroupData[{
Cell[1204348, 38066, 1536, 34, 70, "Input",
  CellTags->"FunctionalD"],
Cell[1205887, 38102, 2117, 63, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1208041, 38170, 974, 24, 70, "Input",
  CellTags->"FunctionalD"],
Cell[1209018, 38196, 13273, 327, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1222328, 38528, 202, 5, 70, "Input",
  CellTags->"FunctionalD"],
Cell[1222533, 38535, 2903, 81, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1225497, 38623, 42, 1, 70, "ObjectName",
  CellTags->"FV"],

Cell[CellGroupData[{
Cell[1225564, 38628, 54, 1, 70, "Subsubsection",
  CellTags->"FV"],
Cell[1225621, 38631, 298, 13, 70, "Text",
  CellTags->"FV"],
Cell[1225922, 38646, 615, 29, 70, "Text",
  CellTags->"FV"]
}, Closed]],

Cell[CellGroupData[{
Cell[1226574, 38680, 51, 1, 70, "Subsubsection",
  CellTags->"FV"],

Cell[CellGroupData[{
Cell[1226650, 38685, 156, 4, 70, "Input",
  CellTags->"FV"],
Cell[1226809, 38691, 140, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1226986, 38699, 185, 5, 70, "Input",
  CellTags->"FV"],
Cell[1227174, 38706, 253, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1227464, 38718, 197, 5, 70, "Input",
  CellTags->"FV"],
Cell[1227664, 38725, 153, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1227854, 38733, 242, 7, 70, "Input",
  CellTags->"FV"],
Cell[1228099, 38742, 241, 5, 70, "Output"]
}, Closed]],
Cell[1228355, 38750, 131, 4, 70, "Text",
  CellTags->"FV"],

Cell[CellGroupData[{
Cell[1228511, 38758, 239, 6, 70, "Input",
  CellTags->"FV"],
Cell[1228753, 38766, 517, 17, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1229307, 38788, 135, 3, 70, "Input",
  CellTags->"FV"],
Cell[1229445, 38793, 432, 10, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1229938, 38810, 44, 1, 70, "ObjectName",
  CellTags->"FVD"],

Cell[CellGroupData[{
Cell[1230007, 38815, 55, 1, 70, "Subsubsection",
  CellTags->"FVD"],
Cell[1230065, 38818, 334, 15, 70, "Text",
  CellTags->"FVD"],
Cell[1230402, 38835, 613, 29, 70, "Text",
  CellTags->"FVD"]
}, Closed]],

Cell[CellGroupData[{
Cell[1231052, 38869, 52, 1, 70, "Subsubsection",
  CellTags->"FVD"],

Cell[CellGroupData[{
Cell[1231129, 38874, 158, 4, 70, "Input",
  CellTags->"FVD"],
Cell[1231290, 38880, 140, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1231467, 38888, 187, 5, 70, "Input",
  CellTags->"FVD"],
Cell[1231657, 38895, 253, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1231947, 38907, 199, 5, 70, "Input",
  CellTags->"FVD"],
Cell[1232149, 38914, 154, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1232340, 38922, 244, 7, 70, "Input",
  CellTags->"FVD"],
Cell[1232587, 38931, 303, 7, 70, "Output"]
}, Closed]],
Cell[1232905, 38941, 89, 1, 70, "Text",
  CellTags->"FVD"],

Cell[CellGroupData[{
Cell[1233019, 38946, 241, 6, 70, "Input",
  CellTags->"FVD"],
Cell[1233263, 38954, 517, 17, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1233817, 38976, 136, 3, 70, "Input",
  CellTags->"FVD"],
Cell[1233956, 38981, 564, 14, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1234581, 39002, 42, 1, 70, "ObjectName",
  CellTags->"GA"],

Cell[CellGroupData[{
Cell[1234648, 39007, 54, 1, 70, "Subsubsection",
  CellTags->"GA"],
Cell[1234705, 39010, 708, 24, 70, "Text",
  CellTags->"GA"],
Cell[1235416, 39036, 402, 19, 70, "Text",
  CellTags->"GA"]
}, Closed]],

Cell[CellGroupData[{
Cell[1235855, 39060, 51, 1, 70, "Subsubsection",
  CellTags->"GA"],

Cell[CellGroupData[{
Cell[1235931, 39065, 129, 3, 70, "Input",
  CellTags->"GA"],
Cell[1236063, 39070, 147, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1236247, 39078, 259, 7, 70, "Input",
  CellTags->"GA"],
Cell[1236509, 39087, 367, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1236913, 39102, 208, 5, 70, "Input",
  CellTags->"GA"],
Cell[1237124, 39109, 177, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1237338, 39117, 199, 5, 70, "Input",
  CellTags->"GA"],
Cell[1237540, 39124, 325, 8, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1237902, 39137, 246, 6, 70, "Input",
  CellTags->"GA"],
Cell[1238151, 39145, 288, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1238476, 39156, 301, 8, 70, "Input",
  CellTags->"GA"],
Cell[1238780, 39166, 395, 10, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1239236, 39183, 44, 1, 70, "ObjectName",
  CellTags->"GAD"],

Cell[CellGroupData[{
Cell[1239305, 39188, 55, 1, 70, "Subsubsection",
  CellTags->"GAD"],
Cell[1239363, 39191, 725, 24, 70, "Text",
  CellTags->"GAD"],
Cell[1240091, 39217, 400, 19, 70, "Text",
  CellTags->"GAD"]
}, Closed]],

Cell[CellGroupData[{
Cell[1240528, 39241, 52, 1, 70, "Subsubsection",
  CellTags->"GAD"],

Cell[CellGroupData[{
Cell[1240605, 39246, 131, 3, 70, "Input",
  CellTags->"GAD"],
Cell[1240739, 39251, 147, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1240923, 39259, 262, 7, 70, "Input",
  CellTags->"GAD"],
Cell[1241188, 39268, 367, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1241592, 39283, 210, 5, 70, "Input",
  CellTags->"GAD"],
Cell[1241805, 39290, 237, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1242079, 39300, 201, 5, 70, "Input",
  CellTags->"GAD"],
Cell[1242283, 39307, 325, 8, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1242645, 39320, 248, 6, 70, "Input",
  CellTags->"GAD"],
Cell[1242896, 39328, 292, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1243225, 39339, 305, 8, 70, "Input",
  CellTags->"GAD"],
Cell[1243533, 39349, 395, 10, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1243989, 39366, 62, 1, 70, "ObjectName",
  CellTags->"GammaEpsilon"],

Cell[CellGroupData[{
Cell[1244076, 39371, 64, 1, 70, "Subsubsection",
  CellTags->"GammaEpsilon"],
Cell[1244143, 39374, 168, 4, 70, "Text",
  CellTags->"GammaEpsilon"],
Cell[1244314, 39380, 322, 14, 70, "Text",
  CellTags->"GammaEpsilon"]
}, Closed]],

Cell[CellGroupData[{
Cell[1244673, 39399, 61, 1, 70, "Subsubsection",
  CellTags->"GammaEpsilon"],
Cell[1244737, 39402, 142, 4, 70, "Text",
  CellTags->"GammaEpsilon"],

Cell[CellGroupData[{
Cell[1244904, 39410, 207, 5, 70, "Input",
  CellTags->"GammaEpsilon"],
Cell[1245114, 39417, 2081, 57, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1247232, 39479, 207, 5, 70, "Input",
  CellTags->"GammaEpsilon"],
Cell[1247442, 39486, 1792, 50, 70, "Output"]
}, Closed]],
Cell[1249249, 39539, 92, 1, 70, "Text",
  CellTags->"GammaEpsilon"],

Cell[CellGroupData[{
Cell[1249366, 39544, 151, 3, 70, "Input",
  CellTags->"GammaEpsilon"],
Cell[1249520, 39549, 1916, 54, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1251473, 39608, 145, 3, 70, "Input",
  CellTags->"GammaEpsilon"],
Cell[1251621, 39613, 156, 4, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1251838, 39624, 60, 1, 70, "ObjectName",
  CellTags->"GammaExpand"],

Cell[CellGroupData[{
Cell[1251923, 39629, 63, 1, 70, "Subsubsection",
  CellTags->"GammaExpand"],
Cell[1251989, 39632, 124, 3, 70, "Text",
  CellTags->"GammaExpand"],
Cell[1252116, 39637, 207, 9, 70, "Text",
  CellTags->"GammaExpand"]
}, Closed]],

Cell[CellGroupData[{
Cell[1252360, 39651, 60, 1, 70, "Subsubsection",
  CellTags->"GammaExpand"],

Cell[CellGroupData[{
Cell[1252445, 39656, 224, 5, 70, "Input",
  CellTags->"GammaExpand"],
Cell[1252672, 39663, 413, 12, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1253122, 39680, 240, 6, 70, "Input",
  CellTags->"GammaExpand"],
Cell[1253365, 39688, 791, 22, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1254193, 39715, 224, 5, 70, "Input",
  CellTags->"GammaExpand"],
Cell[1254420, 39722, 245, 6, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1254726, 39735, 68, 1, 70, "ObjectName",
  CellTags->"GhostPropagator"],

Cell[CellGroupData[{
Cell[1254819, 39740, 67, 1, 70, "Subsubsection",
  CellTags->"GhostPropagator"],
Cell[1254889, 39743, 349, 9, 70, "Text",
  CellTags->"GhostPropagator"],
Cell[1255241, 39754, 469, 19, 70, "Text",
  CellTags->"GhostPropagator"]
}, Closed]],

Cell[CellGroupData[{
Cell[1255747, 39778, 64, 1, 70, "Subsubsection",
  CellTags->"GhostPropagator"],

Cell[CellGroupData[{
Cell[1255836, 39783, 188, 4, 70, "Input",
  CellTags->"GhostPropagator"],
Cell[1256027, 39789, 527, 15, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1256591, 39809, 151, 3, 70, "Input",
  CellTags->"GhostPropagator"],
Cell[1256745, 39814, 175, 4, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1256957, 39823, 188, 4, 70, "Input",
  CellTags->"GhostPropagator"],
Cell[1257148, 39829, 531, 15, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1257716, 39849, 305, 8, 70, "Input",
  CellTags->"GhostPropagator"],
Cell[1258024, 39859, 262, 6, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1258347, 39872, 44, 1, 70, "ObjectName",
  CellTags->"GHP"],

Cell[CellGroupData[{
Cell[1258416, 39877, 55, 1, 70, "Subsubsection",
  CellTags->"GHP"],
Cell[1258474, 39880, 313, 9, 70, "Text",
  CellTags->"GHP"],
Cell[1258790, 39891, 493, 19, 70, "Text",
  CellTags->"GHP"]
}, Closed]],

Cell[CellGroupData[{
Cell[1259320, 39915, 52, 1, 70, "Subsubsection",
  CellTags->"GHP"],

Cell[CellGroupData[{
Cell[1259397, 39920, 164, 4, 70, "Input",
  CellTags->"GHP"],
Cell[1259564, 39926, 527, 15, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1260128, 39946, 127, 3, 70, "Input",
  CellTags->"GHP"],
Cell[1260258, 39951, 175, 4, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1260470, 39960, 164, 4, 70, "Input",
  CellTags->"GHP"],
Cell[1260637, 39966, 531, 15, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1261205, 39986, 282, 8, 70, "Input",
  CellTags->"GHP"],
Cell[1261490, 39996, 262, 6, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1261813, 40009, 58, 1, 70, "ObjectName",
  CellTags->"GluonField"],

Cell[CellGroupData[{
Cell[1261896, 40014, 62, 1, 70, "Subsubsection",
  CellTags->"GluonField"],
Cell[1261961, 40017, 213, 5, 70, "Text",
  CellTags->"GluonField"],
Cell[1262177, 40024, 341, 14, 70, "Text",
  CellTags->"GluonField"]
}, Closed]],

Cell[CellGroupData[{
Cell[1262555, 40043, 59, 1, 70, "Subsubsection",
  CellTags->"GluonField"],

Cell[CellGroupData[{
Cell[1262639, 40048, 111, 2, 70, "Input",
  CellTags->"GluonField"],
Cell[1262753, 40052, 108, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1262898, 40059, 279, 6, 70, "Input",
  CellTags->"GluonField"],
Cell[1263180, 40067, 391, 13, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1263632, 40087, 70, 1, 70, "ObjectName",
  CellTags->"GluonGhostVertex"],

Cell[CellGroupData[{
Cell[1263727, 40092, 68, 1, 70, "Subsubsection",
  CellTags->"GluonGhostVertex"],
Cell[1263798, 40095, 423, 7, 70, "Text",
  CellTags->"GluonGhostVertex"],
Cell[1264224, 40104, 343, 13, 70, "Text",
  CellTags->"GluonGhostVertex"],

Cell[CellGroupData[{
Cell[1264592, 40121, 159, 3, 70, "Input",
  CellTags->"GluonGhostVertex"],
Cell[1264754, 40126, 293, 7, 70, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1265096, 40139, 65, 1, 70, "Subsubsection",
  CellTags->"GluonGhostVertex"],

Cell[CellGroupData[{
Cell[1265186, 40144, 413, 10, 70, "Input",
  CellTags->"GluonGhostVertex"],
Cell[1265602, 40156, 1002, 31, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1266641, 40192, 145, 3, 70, "Input",
  CellTags->"GluonGhostVertex"],
Cell[1266789, 40197, 559, 13, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1267385, 40215, 227, 5, 70, "Input",
  CellTags->"GluonGhostVertex"],
Cell[1267615, 40222, 1006, 31, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1268682, 40260, 68, 1, 70, "ObjectName",
  CellTags->"GluonPropagator"],

Cell[CellGroupData[{
Cell[1268775, 40265, 67, 1, 70, "Subsubsection",
  CellTags->"GluonPropagator"],
Cell[1268845, 40268, 543, 10, 70, "Text",
  CellTags->"GluonPropagator"],
Cell[1269391, 40280, 100, 1, 70, "Text",
  CellTags->"GluonPropagator"],

Cell[CellGroupData[{
Cell[1269516, 40285, 108, 2, 70, "Input",
  CellTags->"GluonPropagator"],
Cell[1269627, 40289, 122, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1269786, 40296, 157, 3, 70, "Input",
  CellTags->"GluonPropagator"],
Cell[1269946, 40301, 477, 11, 70, "Output"]
}, Closed]],
Cell[1270438, 40315, 493, 19, 70, "Text",
  CellTags->"GluonPropagator"]
}, Closed]],

Cell[CellGroupData[{
Cell[1270968, 40339, 73, 1, 70, "Subsubsection",
  CellTags->"GluonPropagator"],

Cell[CellGroupData[{
Cell[1271066, 40344, 223, 5, 70, "Input",
  CellTags->"GluonPropagator"],
Cell[1271292, 40351, 931, 26, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1272260, 40382, 272, 5, 70, "Input",
  CellTags->"GluonPropagator"],
Cell[1272535, 40389, 1694, 46, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1274266, 40440, 383, 9, 70, "Input",
  CellTags->"GluonPropagator"],
Cell[1274652, 40451, 4284, 113, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1278973, 40569, 196, 4, 70, "Input",
  CellTags->"GluonPropagator"],
Cell[1279172, 40575, 578, 16, 70, "Output"]
}, Closed]],
Cell[1279765, 40594, 150, 4, 70, "Text",
  CellTags->"GluonPropagator"],

Cell[CellGroupData[{
Cell[1279940, 40602, 175, 4, 70, "Input",
  CellTags->"GluonPropagator"],
Cell[1280118, 40608, 931, 26, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1281086, 40639, 285, 8, 70, "Input",
  CellTags->"GluonPropagator"],
Cell[1281374, 40649, 361, 9, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1281772, 40663, 276, 5, 70, "Input",
  CellTags->"GluonPropagator"],
Cell[1282051, 40670, 2056, 53, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1284144, 40728, 276, 5, 70, "Input",
  CellTags->"GluonPropagator"],
Cell[1284423, 40735, 2062, 54, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1286522, 40794, 276, 5, 70, "Input",
  CellTags->"GluonPropagator"],
Cell[1286801, 40801, 2064, 53, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1288902, 40859, 276, 5, 70, "Input",
  CellTags->"GluonPropagator"],
Cell[1289181, 40866, 2056, 53, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1291274, 40924, 276, 5, 70, "Input",
  CellTags->"GluonPropagator"],
Cell[1291553, 40931, 3985, 103, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1295599, 41041, 60, 1, 70, "ObjectName",
  CellTags->"GluonVertex"],

Cell[CellGroupData[{
Cell[1295684, 41046, 63, 1, 70, "Subsubsection",
  CellTags->"GluonVertex"],
Cell[1295750, 41049, 89, 1, 70, "Text",
  CellTags->"GluonVertex"],
Cell[1295842, 41052, 622, 10, 70, "Text",
  CellTags->"GluonVertex"],
Cell[1296467, 41064, 92, 1, 70, "Text",
  CellTags->"GluonVertex"],

Cell[CellGroupData[{
Cell[1296584, 41069, 104, 2, 70, "Input",
  CellTags->"GluonVertex"],
Cell[1296691, 41073, 118, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1296846, 41080, 149, 3, 70, "Input",
  CellTags->"GluonVertex"],
Cell[1296998, 41085, 423, 10, 70, "Output"]
}, Closed]],
Cell[1297436, 41098, 360, 14, 70, "Text",
  CellTags->"GluonVertex"]
}, Closed]],

Cell[CellGroupData[{
Cell[1297833, 41117, 60, 1, 70, "Subsubsection",
  CellTags->"GluonVertex"],

Cell[CellGroupData[{
Cell[1297918, 41122, 403, 10, 70, "Input",
  CellTags->"GluonVertex"],
Cell[1298324, 41134, 1426, 42, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1299787, 41181, 459, 12, 70, "Input",
  CellTags->"GluonVertex"],
Cell[1300249, 41195, 4500, 128, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1304786, 41328, 373, 10, 70, "Input",
  CellTags->"GluonVertex"],
Cell[1305162, 41340, 405, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1305604, 41355, 429, 12, 70, "Input",
  CellTags->"GluonVertex"],
Cell[1306036, 41369, 3541, 111, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1309614, 41485, 490, 12, 70, "Input",
  CellTags->"GluonVertex"],
Cell[1310107, 41499, 9095, 227, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1319239, 41731, 450, 12, 70, "Input",
  CellTags->"GluonVertex"],
Cell[1319692, 41745, 9101, 227, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1328830, 41977, 266, 6, 70, "Input",
  CellTags->"GluonVertex"],
Cell[1329099, 41985, 9101, 227, 70, "Output"]
}, Closed]],
Cell[1338215, 42215, 201, 4, 70, "Text",
  CellTags->"GluonVertex"],

Cell[CellGroupData[{
Cell[1338441, 42223, 208, 5, 70, "Input",
  CellTags->"GluonVertex"],
Cell[1338652, 42230, 1425, 42, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1340114, 42277, 237, 6, 70, "Input",
  CellTags->"GluonVertex"],
Cell[1340354, 42285, 9053, 227, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1349468, 42519, 44, 1, 70, "ObjectName",
  CellTags->"GSD"],

Cell[CellGroupData[{
Cell[1349537, 42524, 55, 1, 70, "Subsubsection",
  CellTags->"GSD"],
Cell[1349595, 42527, 736, 18, 70, "Text",
  CellTags->"GSD"],
Cell[1350334, 42547, 526, 24, 70, "Text",
  CellTags->"GSD"]
}, Closed]],

Cell[CellGroupData[{
Cell[1350897, 42576, 52, 1, 70, "Subsubsection",
  CellTags->"GSD"],

Cell[CellGroupData[{
Cell[1350974, 42581, 127, 3, 70, "Input",
  CellTags->"GSD"],
Cell[1351104, 42586, 188, 4, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1351329, 42595, 205, 6, 70, "Input",
  CellTags->"GSD"],
Cell[1351537, 42603, 229, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1351803, 42613, 174, 4, 70, "Input",
  CellTags->"GSD"],
Cell[1351980, 42619, 667, 19, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1352684, 42643, 222, 6, 70, "Input",
  CellTags->"GSD"],
Cell[1352909, 42651, 272, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1353218, 42662, 292, 8, 70, "Input",
  CellTags->"GSD"],
Cell[1353513, 42672, 564, 16, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1354138, 42695, 42, 1, 70, "ObjectName",
  CellTags->"GS"],

Cell[CellGroupData[{
Cell[1354205, 42700, 54, 1, 70, "Subsubsection",
  CellTags->"GS"],
Cell[1354262, 42703, 727, 18, 70, "Text",
  CellTags->"GS"],
Cell[1354992, 42723, 525, 24, 70, "Text",
  CellTags->"GS"]
}, Closed]],

Cell[CellGroupData[{
Cell[1355554, 42752, 51, 1, 70, "Subsubsection",
  CellTags->"GS"],

Cell[CellGroupData[{
Cell[1355630, 42757, 125, 3, 70, "Input",
  CellTags->"GS"],
Cell[1355758, 42762, 188, 4, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1355983, 42771, 203, 6, 70, "Input",
  CellTags->"GS"],
Cell[1356189, 42779, 169, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1356395, 42787, 172, 4, 70, "Input",
  CellTags->"GS"],
Cell[1356570, 42793, 667, 19, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1357274, 42817, 220, 6, 70, "Input",
  CellTags->"GS"],
Cell[1357497, 42825, 268, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1357802, 42836, 288, 8, 70, "Input",
  CellTags->"GS"],
Cell[1358093, 42846, 564, 16, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1358718, 42869, 52, 1, 70, "ObjectName",
  CellTags->"Gstrong"],

Cell[CellGroupData[{
Cell[1358795, 42874, 59, 1, 70, "Subsubsection",
  CellTags->"Gstrong"],
Cell[1358857, 42877, 84, 1, 70, "Text",
  CellTags->"Gstrong"],
Cell[1358944, 42880, 360, 15, 70, "Text",
  CellTags->"Gstrong"]
}, Closed]],

Cell[CellGroupData[{
Cell[1359341, 42900, 56, 1, 70, "Subsubsection",
  CellTags->"Gstrong"],
Cell[1359400, 42903, 120, 3, 70, "Text",
  CellTags->"Gstrong"],

Cell[CellGroupData[{
Cell[1359545, 42910, 105, 2, 70, "Input",
  CellTags->"Gstrong"],
Cell[1359653, 42914, 134, 3, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1359848, 42924, 46, 1, 70, "ObjectName",
  CellTags->"Hill"],

Cell[CellGroupData[{
Cell[1359919, 42929, 56, 1, 70, "Subsubsection",
  CellTags->"Hill"],
Cell[1359978, 42932, 130, 4, 70, "Text",
  CellTags->"Hill"],
Cell[1360111, 42938, 209, 9, 70, "Text",
  CellTags->"Hill"]
}, Closed]],

Cell[CellGroupData[{
Cell[1360357, 42952, 53, 1, 70, "Subsubsection",
  CellTags->"Hill"],

Cell[CellGroupData[{
Cell[1360435, 42957, 156, 4, 70, "Input",
  CellTags->"Hill"],
Cell[1360594, 42963, 2760, 75, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1363391, 43043, 293, 8, 70, "Input",
  CellTags->"Hill"],
Cell[1363687, 43053, 108, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1363832, 43060, 325, 9, 70, "Input",
  CellTags->"Hill"],
Cell[1364160, 43071, 1298, 37, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1365495, 43113, 316, 9, 70, "Input",
  CellTags->"Hill"],
Cell[1365814, 43124, 108, 2, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1365983, 43133, 70, 1, 70, "ObjectName",
  CellTags->"HypergeometricAC"],

Cell[CellGroupData[{
Cell[1366078, 43138, 68, 1, 70, "Subsubsection",
  CellTags->"HypergeometricAC"],
Cell[1366149, 43141, 554, 9, 70, "Text",
  CellTags->"HypergeometricAC"],

Cell[CellGroupData[{
Cell[1366728, 43154, 159, 3, 70, "Input",
  CellTags->"HypergeometricAC"],
Cell[1366890, 43159, 187, 5, 70, "Output"]
}, Closed]],
Cell[1367092, 43167, 641, 24, 70, "Text",
  CellTags->"HypergeometricAC"]
}, Closed]],

Cell[CellGroupData[{
Cell[1367770, 43196, 65, 1, 70, "Subsubsection",
  CellTags->"HypergeometricAC"],
Cell[1367838, 43199, 102, 1, 70, "Text",
  CellTags->"HypergeometricAC"],

Cell[CellGroupData[{
Cell[1367965, 43204, 311, 7, 70, "Input",
  CellTags->"HypergeometricAC"],
Cell[1368279, 43213, 5161, 121, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1373477, 43339, 311, 7, 70, "Input",
  CellTags->"HypergeometricAC"],
Cell[1373791, 43348, 5085, 119, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1378913, 43472, 311, 7, 70, "Input",
  CellTags->"HypergeometricAC"],
Cell[1379227, 43481, 5138, 120, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1384402, 43606, 311, 7, 70, "Input",
  CellTags->"HypergeometricAC"],
Cell[1384716, 43615, 5603, 131, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1390356, 43751, 311, 7, 70, "Input",
  CellTags->"HypergeometricAC"],
Cell[1390670, 43760, 1954, 51, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1392661, 43816, 312, 7, 70, "Input",
  CellTags->"HypergeometricAC"],
Cell[1392976, 43825, 1955, 51, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1394992, 43883, 70, 1, 70, "ObjectName",
  CellTags->"HypergeometricIR"],

Cell[CellGroupData[{
Cell[1395087, 43888, 68, 1, 70, "Subsubsection",
  CellTags->"HypergeometricIR"],
Cell[1395158, 43891, 270, 5, 70, "Text",
  CellTags->"HypergeometricIR"],
Cell[1395431, 43898, 512, 19, 70, "Text",
  CellTags->"HypergeometricIR"],

Cell[CellGroupData[{
Cell[1395968, 43921, 159, 3, 70, "Input",
  CellTags->"HypergeometricIR"],
Cell[1396130, 43926, 191, 5, 70, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1396370, 43937, 65, 1, 70, "Subsubsection",
  CellTags->"HypergeometricIR"],

Cell[CellGroupData[{
Cell[1396460, 43942, 288, 7, 70, "Input",
  CellTags->"HypergeometricIR"],
Cell[1396751, 43951, 797, 21, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1397585, 43977, 492, 14, 70, "Input",
  CellTags->"HypergeometricIR"],
Cell[1398080, 43993, 2199, 55, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1400316, 44053, 180, 4, 70, "Input",
  CellTags->"HypergeometricIR"],
Cell[1400499, 44059, 405, 12, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1400965, 44078, 70, 1, 70, "ObjectName",
  CellTags->"HypergeometricSE"],

Cell[CellGroupData[{
Cell[1401060, 44083, 68, 1, 70, "Subsubsection",
  CellTags->"HypergeometricSE"],
Cell[1401131, 44086, 440, 13, 70, "Text",
  CellTags->"HypergeometricSE"],

Cell[CellGroupData[{
Cell[1401596, 44103, 159, 3, 70, "Input",
  CellTags->"HypergeometricSE"],
Cell[1401758, 44108, 195, 5, 70, "Output"]
}, Closed]],
Cell[1401968, 44116, 224, 9, 70, "Text",
  CellTags->"HypergeometricSE"]
}, Closed]],

Cell[CellGroupData[{
Cell[1402229, 44130, 65, 1, 70, "Subsubsection",
  CellTags->"HypergeometricSE"],

Cell[CellGroupData[{
Cell[1402319, 44135, 292, 7, 70, "Input",
  CellTags->"HypergeometricSE"],
Cell[1402614, 44144, 767, 18, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1403418, 44167, 430, 11, 70, "Input",
  CellTags->"HypergeometricSE"],
Cell[1403851, 44180, 1081, 24, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1404993, 44211, 60, 1, 70, "ObjectName",
  CellTags->"HypExplicit"],

Cell[CellGroupData[{
Cell[1405078, 44216, 63, 1, 70, "Subsubsection",
  CellTags->"HypExplicit"],
Cell[1405144, 44219, 339, 10, 70, "Text",
  CellTags->"HypExplicit"],
Cell[1405486, 44231, 219, 9, 70, "Text",
  CellTags->"HypExplicit"]
}, Closed]],

Cell[CellGroupData[{
Cell[1405742, 44245, 60, 1, 70, "Subsubsection",
  CellTags->"HypExplicit"],

Cell[CellGroupData[{
Cell[1405827, 44250, 196, 4, 70, "Input",
  CellTags->"HypExplicit"],
Cell[1406026, 44256, 1525, 42, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1407588, 44303, 174, 4, 70, "Input",
  CellTags->"HypExplicit"],
Cell[1407765, 44309, 767, 18, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1408569, 44332, 316, 8, 70, "Input",
  CellTags->"HypExplicit"],
Cell[1408888, 44342, 1810, 49, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1410735, 44396, 174, 4, 70, "Input",
  CellTags->"HypExplicit"],
Cell[1410912, 44402, 1081, 24, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1412054, 44433, 58, 1, 70, "ObjectName",
  CellTags->"Integrate2"],

Cell[CellGroupData[{
Cell[1412137, 44438, 62, 1, 70, "Subsubsection",
  CellTags->"Integrate2"],
Cell[1412202, 44441, 885, 17, 70, "Text",
  CellTags->"Integrate2"],
Cell[1413090, 44460, 551, 24, 70, "Text",
  CellTags->"Integrate2"],
Cell[1413644, 44486, 406, 7, 70, "Text",
  CellTags->"Integrate2"]
}, Closed]],

Cell[CellGroupData[{
Cell[1414087, 44498, 59, 1, 70, "Subsubsection",
  CellTags->"Integrate2"],

Cell[CellGroupData[{
Cell[1414171, 44503, 532, 15, 70, "Input",
  CellTags->"Integrate2"],
Cell[1414706, 44520, 596, 16, 70, "Output"]
}, Closed]],
Cell[1415317, 44539, 196, 6, 70, "Text",
  CellTags->"Integrate2"],

Cell[CellGroupData[{
Cell[1415538, 44549, 342, 9, 70, "Input",
  CellTags->"Integrate2"],
Cell[1415883, 44560, 259, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1416179, 44572, 337, 9, 70, "Input",
  CellTags->"Integrate2"],
Cell[1416519, 44583, 531, 15, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1417087, 44603, 414, 11, 70, "Input",
  CellTags->"Integrate2"],
Cell[1417504, 44616, 769, 21, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1418310, 44642, 384, 10, 70, "Input",
  CellTags->"Integrate2"],
Cell[1418697, 44654, 140, 3, 70, "Output"]
}, Closed]],
Cell[1418852, 44660, 1942, 54, 70, "Text",
  CellTags->"Integrate2"],

Cell[CellGroupData[{
Cell[1420819, 44718, 331, 9, 70, "Input",
  CellTags->"Integrate2"],
Cell[1421153, 44729, 108, 2, 70, "Output"]
}, Closed]],
Cell[1421276, 44734, 755, 25, 70, "Text",
  CellTags->"Integrate2"],

Cell[CellGroupData[{
Cell[1422056, 44763, 386, 10, 70, "Input",
  CellTags->"Integrate2"],
Cell[1422445, 44775, 108, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1422590, 44782, 476, 13, 70, "Input",
  CellTags->"Integrate2"],
Cell[1423069, 44797, 175, 4, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1423281, 44806, 516, 14, 70, "Input",
  CellTags->"Integrate2"],
Cell[1423800, 44822, 329, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1424166, 44837, 402, 11, 70, "Input",
  CellTags->"Integrate2"],
Cell[1424571, 44850, 290, 8, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1424898, 44863, 436, 12, 70, "Input",
  CellTags->"Integrate2"],
Cell[1425337, 44877, 475, 13, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1425849, 44895, 380, 10, 70, "Input",
  CellTags->"Integrate2"],
Cell[1426232, 44907, 208, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1426477, 44918, 342, 9, 70, "Input",
  CellTags->"Integrate2"],
Cell[1426822, 44929, 462, 13, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1427321, 44947, 553, 15, 70, "Input",
  CellTags->"Integrate2"],
Cell[1427877, 44964, 590, 16, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1428504, 44985, 966, 25, 70, "Input",
  CellTags->"Integrate2"],
Cell[1429473, 45012, 5747, 158, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1435257, 45175, 596, 16, 70, "Input",
  CellTags->"Integrate2"],
Cell[1435856, 45193, 1109, 31, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1437002, 45229, 635, 17, 70, "Input",
  CellTags->"Integrate2"],
Cell[1437640, 45248, 9590, 280, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1447267, 45533, 174, 4, 70, "Input",
  CellTags->"Integrate2"],
Cell[1447444, 45539, 1569, 43, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1449050, 45587, 132, 3, 70, "Input",
  CellTags->"Integrate2"],
Cell[1449185, 45592, 128, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1449350, 45599, 533, 14, 70, "Input",
  CellTags->"Integrate2"],
Cell[1449886, 45615, 128, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1450051, 45622, 877, 23, 70, "Input",
  CellTags->"Integrate2"],
Cell[1450931, 45647, 4941, 144, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1455909, 45796, 183, 4, 70, "Input",
  CellTags->"Integrate2"],
Cell[1456095, 45802, 111, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1456243, 45809, 450, 12, 70, "Input",
  CellTags->"Integrate2"],
Cell[1456696, 45823, 108, 2, 70, "Output"]
}, Closed]],
Cell[1456819, 45828, 138, 4, 70, "Text",
  CellTags->"Integrate2"],

Cell[CellGroupData[{
Cell[1456982, 45836, 179, 4, 70, "Input",
  CellTags->"Integrate2"],
Cell[1457164, 45842, 7280, 177, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1464481, 46024, 284, 8, 70, "Input",
  CellTags->"Integrate2"],
Cell[1464768, 46034, 225, 6, 70, "Output"]
}, Closed]],
Cell[1465008, 46043, 166, 4, 70, "Text",
  CellTags->"Integrate2"],

Cell[CellGroupData[{
Cell[1465199, 46051, 405, 11, 70, "Input",
  CellTags->"Integrate2"],
Cell[1465607, 46064, 226, 6, 70, "Output"]
}, Closed]],
Cell[1465848, 46073, 158, 4, 70, "Input",
  CellTags->"Integrate2"],

Cell[CellGroupData[{
Cell[1466031, 46081, 384, 10, 70, "Input",
  CellTags->"Integrate2"],
Cell[1466418, 46093, 140, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1466595, 46101, 400, 11, 70, "Input",
  CellTags->"Integrate2"],
Cell[1466998, 46114, 302, 9, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1467337, 46128, 127, 3, 70, "Input",
  CellTags->"Integrate2"],
Cell[1467467, 46133, 127, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1467631, 46140, 400, 11, 70, "Input",
  CellTags->"Integrate2"],
Cell[1468034, 46153, 127, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1468198, 46160, 471, 13, 70, "Input",
  CellTags->"Integrate2"],
Cell[1468672, 46175, 6263, 183, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1474996, 46365, 58, 1, 70, "ObjectName",
  CellTags->"Integrate3"],

Cell[CellGroupData[{
Cell[1475079, 46370, 62, 1, 70, "Subsubsection",
  CellTags->"Integrate3"],
Cell[1475144, 46373, 332, 6, 70, "Text",
  CellTags->"Integrate3"],
Cell[1475479, 46381, 200, 9, 70, "Text",
  CellTags->"Integrate3"]
}, Closed]],

Cell[CellGroupData[{
Cell[1475716, 46395, 59, 1, 70, "Subsubsection",
  CellTags->"Integrate3"],

Cell[CellGroupData[{
Cell[1475800, 46400, 340, 9, 70, "Input",
  CellTags->"Integrate3"],
Cell[1476143, 46411, 264, 8, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1476444, 46424, 489, 13, 70, "Input",
  CellTags->"Integrate3"],
Cell[1476936, 46439, 736, 22, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1477709, 46466, 858, 23, 70, "Input",
  CellTags->"Integrate3"],
Cell[1478570, 46491, 3096, 81, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1481703, 46577, 320, 8, 70, "Input",
  CellTags->"Integrate3"],
Cell[1482026, 46587, 108, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1482171, 46594, 389, 10, 70, "Input",
  CellTags->"Integrate3"],
Cell[1482563, 46606, 219, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1482819, 46617, 331, 9, 70, "Input",
  CellTags->"Integrate3"],
Cell[1483153, 46628, 108, 2, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1483322, 46637, 70, 1, 70, "ObjectName",
  CellTags->"IntegrateByParts"],

Cell[CellGroupData[{
Cell[1483417, 46642, 68, 1, 70, "Subsubsection",
  CellTags->"IntegrateByParts"],
Cell[1483488, 46645, 185, 4, 70, "Text",
  CellTags->"IntegrateByParts"],

Cell[CellGroupData[{
Cell[1483698, 46653, 159, 3, 70, "Input",
  CellTags->"IntegrateByParts"],
Cell[1483860, 46658, 184, 5, 70, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1484093, 46669, 65, 1, 70, "Subsubsection",
  CellTags->"IntegrateByParts"],

Cell[CellGroupData[{
Cell[1484183, 46674, 670, 19, 70, "Input",
  CellTags->"IntegrateByParts"],
Cell[1484856, 46695, 787, 22, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1485704, 46724, 64, 1, 70, "ObjectName",
  CellTags->"InverseMellin"],

Cell[CellGroupData[{
Cell[1485793, 46729, 65, 1, 70, "Subsubsection",
  CellTags->"InverseMellin"],
Cell[1485861, 46732, 578, 14, 70, "Text",
  CellTags->"InverseMellin"],
Cell[1486442, 46748, 662, 29, 70, "Text",
  CellTags->"InverseMellin"]
}, Closed]],

Cell[CellGroupData[{
Cell[1487141, 46782, 62, 1, 70, "Subsubsection",
  CellTags->"InverseMellin"],

Cell[CellGroupData[{
Cell[1487228, 46787, 206, 5, 70, "Input",
  CellTags->"InverseMellin"],
Cell[1487437, 46794, 165, 4, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1487639, 46803, 270, 7, 70, "Input",
  CellTags->"InverseMellin"],
Cell[1487912, 46812, 165, 4, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1488114, 46821, 174, 4, 70, "Input",
  CellTags->"InverseMellin"],
Cell[1488291, 46827, 321, 9, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1488649, 46841, 237, 6, 70, "Input",
  CellTags->"InverseMellin"],
Cell[1488889, 46849, 334, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1489260, 46864, 239, 7, 70, "Input",
  CellTags->"InverseMellin"],
Cell[1489502, 46873, 423, 12, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1489962, 46890, 251, 7, 70, "Input",
  CellTags->"InverseMellin"],
Cell[1490216, 46899, 423, 12, 70, "Output"]
}, Closed]],
Cell[1490654, 46914, 114, 3, 70, "Text",
  CellTags->"InverseMellin"],

Cell[CellGroupData[{
Cell[1490793, 46921, 354, 9, 70, "Input",
  CellTags->"InverseMellin"],
Cell[1491150, 46932, 133, 3, 70, "Output"]
}, Closed]],
Cell[1491298, 46938, 118, 3, 70, "Text",
  CellTags->"InverseMellin"],
Cell[1491419, 46943, 4033, 103, 70, "Input",
  CellTags->"InverseMellin"],
Cell[1495455, 47048, 290, 7, 70, "Input",
  CellTags->"InverseMellin"],

Cell[CellGroupData[{
Cell[1495770, 47059, 221, 6, 70, "Input",
  CellTags->"InverseMellin"],
Cell[1495994, 47067, 463, 13, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1496494, 47085, 221, 6, 70, "Input",
  CellTags->"InverseMellin"],
Cell[1496718, 47093, 418, 12, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1497173, 47110, 208, 5, 70, "Input",
  CellTags->"InverseMellin"],
Cell[1497384, 47117, 990, 28, 70, "Output"]
}, Closed]],
Cell[1498389, 47148, 105, 2, 70, "Input",
  CellTags->"InverseMellin"],

Cell[CellGroupData[{
Cell[1498519, 47154, 234, 6, 70, "Input",
  CellTags->"InverseMellin"],
Cell[1498756, 47162, 608, 18, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1499401, 47185, 330, 9, 70, "Input",
  CellTags->"InverseMellin"],
Cell[1499734, 47196, 610, 18, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1500381, 47219, 330, 9, 70, "Input",
  CellTags->"InverseMellin"],
Cell[1500714, 47230, 841, 23, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1501592, 47258, 329, 9, 70, "Input",
  CellTags->"InverseMellin"],
Cell[1501924, 47269, 913, 25, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1502874, 47299, 307, 9, 70, "Input",
  CellTags->"InverseMellin"],
Cell[1503184, 47310, 667, 19, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1503888, 47334, 346, 10, 70, "Input",
  CellTags->"InverseMellin"],
Cell[1504237, 47346, 1159, 30, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1505433, 47381, 234, 6, 70, "Input",
  CellTags->"InverseMellin"],
Cell[1505670, 47389, 875, 24, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1506582, 47418, 277, 8, 70, "Input",
  CellTags->"InverseMellin"],
Cell[1506862, 47428, 916, 25, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1507815, 47458, 234, 6, 70, "Input",
  CellTags->"InverseMellin"],
Cell[1508052, 47466, 1156, 31, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1509245, 47502, 244, 6, 70, "Input",
  CellTags->"InverseMellin"],
Cell[1509492, 47510, 664, 19, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1510193, 47534, 272, 7, 70, "Input",
  CellTags->"InverseMellin"],
Cell[1510468, 47543, 1417, 37, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1511922, 47585, 272, 7, 70, "Input",
  CellTags->"InverseMellin"],
Cell[1512197, 47594, 1342, 35, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1513576, 47634, 254, 6, 70, "Input",
  CellTags->"InverseMellin"],
Cell[1513833, 47642, 778, 22, 70, "Output"]
}, Closed]],
Cell[1514626, 47667, 194, 5, 70, "Input",
  CellTags->"InverseMellin"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1514869, 47678, 52, 1, 70, "ObjectName",
  CellTags->"Isolate"],

Cell[CellGroupData[{
Cell[1514946, 47683, 59, 1, 70, "Subsubsection",
  CellTags->"Isolate"],
Cell[1515008, 47686, 423, 7, 70, "Text",
  CellTags->"Isolate"],

Cell[CellGroupData[{
Cell[1515456, 47697, 141, 3, 70, "Input",
  CellTags->"Isolate"],
Cell[1515600, 47702, 401, 9, 70, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1516050, 47717, 56, 1, 70, "Subsubsection",
  CellTags->"Isolate"],

Cell[CellGroupData[{
Cell[1516131, 47722, 192, 5, 70, "Input",
  CellTags->"Isolate"],
Cell[1516326, 47729, 176, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1516539, 47739, 476, 13, 70, "Input",
  CellTags->"Isolate"],
Cell[1517018, 47754, 363, 11, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1517418, 47770, 141, 3, 70, "Input",
  CellTags->"Isolate"],
Cell[1517562, 47775, 328, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1517927, 47790, 218, 5, 70, "Input",
  CellTags->"Isolate"],
Cell[1518148, 47797, 803, 24, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1518988, 47826, 698, 19, 70, "Input",
  CellTags->"Isolate"],
Cell[1519689, 47847, 423, 13, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1520149, 47865, 120, 3, 70, "Input",
  CellTags->"Isolate"],
Cell[1520272, 47870, 86, 1, 70, "Print"],
Cell[1520361, 47873, 912, 24, 70, "Print"]
}, Closed]],

Cell[CellGroupData[{
Cell[1521310, 47902, 324, 7, 70, "Input",
  CellTags->"Isolate"],
Cell[1521637, 47911, 175, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1521849, 47921, 219, 6, 70, "Input",
  CellTags->"Isolate"],
Cell[1522071, 47929, 231, 6, 70, "Output"]
}, Closed]],
Cell[1522317, 47938, 172, 4, 70, "Input",
  CellTags->"Isolate"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1522538, 47948, 50, 1, 70, "ObjectName",
  CellTags->"Kummer"],

Cell[CellGroupData[{
Cell[1522613, 47953, 58, 1, 70, "Subsubsection",
  CellTags->"Kummer"],
Cell[1522674, 47956, 261, 5, 70, "Text",
  CellTags->"Kummer"],
Cell[1522938, 47963, 214, 9, 70, "Text",
  CellTags->"Kummer"]
}, Closed]],

Cell[CellGroupData[{
Cell[1523189, 47977, 55, 1, 70, "Subsubsection",
  CellTags->"Kummer"],

Cell[CellGroupData[{
Cell[1523269, 47982, 402, 10, 70, "Input",
  CellTags->"Kummer"],
Cell[1523674, 47994, 3510, 91, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1527221, 48090, 402, 10, 70, "Input",
  CellTags->"Kummer"],
Cell[1527626, 48102, 3544, 92, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1531207, 48199, 402, 10, 70, "Input",
  CellTags->"Kummer"],
Cell[1531612, 48211, 3544, 92, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1535193, 48308, 457, 11, 70, "Input",
  CellTags->"Kummer"],
Cell[1535653, 48321, 3526, 91, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1539216, 48417, 561, 13, 70, "Input",
  CellTags->"Kummer"],
Cell[1539780, 48432, 3638, 92, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1543455, 48529, 457, 11, 70, "Input",
  CellTags->"Kummer"],
Cell[1543915, 48542, 3517, 91, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1547469, 48638, 561, 13, 70, "Input",
  CellTags->"Kummer"],
Cell[1548033, 48653, 3659, 93, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1551729, 48751, 457, 11, 70, "Input",
  CellTags->"Kummer"],
Cell[1552189, 48764, 3517, 91, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1555743, 48860, 561, 13, 70, "Input",
  CellTags->"Kummer"],
Cell[1556307, 48875, 3659, 93, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1560003, 48973, 588, 15, 70, "Input",
  CellTags->"Kummer"],
Cell[1560594, 48990, 3738, 97, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1564369, 49092, 756, 19, 70, "Input",
  CellTags->"Kummer"],
Cell[1565128, 49113, 3907, 100, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1569072, 49218, 588, 15, 70, "Input",
  CellTags->"Kummer"],
Cell[1569663, 49235, 3715, 97, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1573415, 49337, 756, 19, 70, "Input",
  CellTags->"Kummer"],
Cell[1574174, 49358, 3884, 100, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1578095, 49463, 588, 15, 70, "Input",
  CellTags->"Kummer"],
Cell[1578686, 49480, 3679, 96, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1582402, 49581, 756, 19, 70, "Input",
  CellTags->"Kummer"],
Cell[1583161, 49602, 3952, 101, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1587150, 49708, 588, 15, 70, "Input",
  CellTags->"Kummer"],
Cell[1587741, 49725, 3738, 97, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1591516, 49827, 756, 19, 70, "Input",
  CellTags->"Kummer"],
Cell[1592275, 49848, 3993, 102, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1596305, 49955, 588, 15, 70, "Input",
  CellTags->"Kummer"],
Cell[1596896, 49972, 3646, 95, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1600579, 50072, 756, 19, 70, "Input",
  CellTags->"Kummer"],
Cell[1601338, 50093, 3901, 100, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1605276, 50198, 588, 15, 70, "Input",
  CellTags->"Kummer"],
Cell[1605867, 50215, 3646, 95, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1609550, 50315, 756, 19, 70, "Input",
  CellTags->"Kummer"],
Cell[1610309, 50336, 4048, 103, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1614394, 50444, 626, 15, 70, "Input",
  CellTags->"Kummer"],
Cell[1615023, 50461, 3716, 95, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1618776, 50561, 403, 10, 70, "Input",
  CellTags->"Kummer"],
Cell[1619182, 50573, 3510, 91, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1622729, 50669, 626, 15, 70, "Input",
  CellTags->"Kummer"],
Cell[1623358, 50686, 3812, 97, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1627207, 50788, 403, 10, 70, "Input",
  CellTags->"Kummer"],
Cell[1627613, 50800, 3502, 91, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1631152, 50896, 626, 15, 70, "Input",
  CellTags->"Kummer"],
Cell[1631781, 50913, 3812, 97, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1635630, 51015, 403, 10, 70, "Input",
  CellTags->"Kummer"],
Cell[1636036, 51027, 3502, 91, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1639575, 51123, 690, 17, 70, "Input",
  CellTags->"Kummer"],
Cell[1640268, 51142, 3827, 97, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1644132, 51244, 458, 11, 70, "Input",
  CellTags->"Kummer"],
Cell[1644593, 51257, 3526, 91, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1648156, 51353, 690, 17, 70, "Input",
  CellTags->"Kummer"],
Cell[1648849, 51372, 3985, 101, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1652871, 51478, 458, 11, 70, "Input",
  CellTags->"Kummer"],
Cell[1653332, 51491, 3590, 93, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1656959, 51589, 690, 17, 70, "Input",
  CellTags->"Kummer"],
Cell[1657652, 51608, 3912, 99, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1661601, 51712, 458, 11, 70, "Input",
  CellTags->"Kummer"],
Cell[1662062, 51725, 3517, 91, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1665616, 51821, 403, 10, 70, "Input",
  CellTags->"Kummer"],
Cell[1666022, 51833, 6613, 157, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1672672, 51995, 403, 10, 70, "Input",
  CellTags->"Kummer"],
Cell[1673078, 52007, 6705, 160, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1679820, 52172, 403, 10, 70, "Input",
  CellTags->"Kummer"],
Cell[1680226, 52184, 6709, 160, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1686996, 52351, 58, 1, 70, "ObjectName",
  CellTags->"Lagrangian"],

Cell[CellGroupData[{
Cell[1687079, 52356, 62, 1, 70, "Subsubsection",
  CellTags->"Lagrangian"],
Cell[1687144, 52359, 213, 5, 70, "Text",
  CellTags->"Lagrangian"],
Cell[1687360, 52366, 194, 9, 70, "Text",
  CellTags->"Lagrangian"]
}, Closed]],

Cell[CellGroupData[{
Cell[1687591, 52380, 59, 1, 70, "Subsubsection",
  CellTags->"Lagrangian"],

Cell[CellGroupData[{
Cell[1687675, 52385, 151, 3, 70, "Input",
  CellTags->"Lagrangian"],
Cell[1687829, 52390, 414, 11, 70, "Output"]
}, Closed]],
Cell[1688258, 52404, 86, 1, 70, "Text",
  CellTags->"Lagrangian"],

Cell[CellGroupData[{
Cell[1688369, 52409, 151, 3, 70, "Input",
  CellTags->"Lagrangian"],
Cell[1688523, 52414, 873, 22, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1689433, 52441, 151, 3, 70, "Input",
  CellTags->"Lagrangian"],
Cell[1689587, 52446, 1365, 35, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1690989, 52486, 151, 3, 70, "Input",
  CellTags->"Lagrangian"],
Cell[1691143, 52491, 806, 22, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1691986, 52518, 151, 3, 70, "Input",
  CellTags->"Lagrangian"],
Cell[1692140, 52523, 855, 23, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1693056, 52553, 42, 1, 70, "ObjectName",
  CellTags->"LC"],

Cell[CellGroupData[{
Cell[1693123, 52558, 54, 1, 70, "Subsubsection",
  CellTags->"LC"],
Cell[1693180, 52561, 241, 5, 70, "Text",
  CellTags->"LC"],
Cell[1693424, 52568, 297, 14, 70, "Text",
  CellTags->"LC"]
}, Closed]],

Cell[CellGroupData[{
Cell[1693758, 52587, 51, 1, 70, "Subsubsection",
  CellTags->"LC"],

Cell[CellGroupData[{
Cell[1693834, 52592, 199, 5, 70, "Input",
  CellTags->"LC"],
Cell[1694036, 52599, 261, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1694334, 52610, 122, 3, 70, "Input",
  CellTags->"LC"],
Cell[1694459, 52615, 665, 20, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1695161, 52640, 131, 3, 70, "Input",
  CellTags->"LC"],
Cell[1695295, 52645, 370, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1695702, 52657, 221, 6, 70, "Input",
  CellTags->"LC"],
Cell[1695926, 52665, 249, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1696212, 52676, 161, 4, 70, "Input",
  CellTags->"LC"],
Cell[1696376, 52682, 412, 9, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1696825, 52696, 474, 13, 70, "Input",
  CellTags->"LC"],
Cell[1697302, 52711, 581, 17, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1697944, 52735, 44, 1, 70, "ObjectName",
  CellTags->"LCD"],

Cell[CellGroupData[{
Cell[1698013, 52740, 55, 1, 70, "Subsubsection",
  CellTags->"LCD"],
Cell[1698071, 52743, 235, 5, 70, "Text",
  CellTags->"LCD"],
Cell[1698309, 52750, 157, 4, 70, "Text",
  CellTags->"LCD"],
Cell[1698469, 52756, 295, 14, 70, "Text",
  CellTags->"LCD"]
}, Closed]],

Cell[CellGroupData[{
Cell[1698801, 52775, 52, 1, 70, "Subsubsection",
  CellTags->"LCD"],
Cell[1698856, 52778, 232, 6, 70, "Input",
  CellTags->"LCD"],

Cell[CellGroupData[{
Cell[1699113, 52788, 202, 5, 70, "Input",
  CellTags->"LCD"],
Cell[1699318, 52795, 262, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1699617, 52806, 124, 3, 70, "Input",
  CellTags->"LCD"],
Cell[1699744, 52811, 666, 20, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1700447, 52836, 133, 3, 70, "Input",
  CellTags->"LCD"],
Cell[1700583, 52841, 495, 11, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1701115, 52857, 224, 6, 70, "Input",
  CellTags->"LCD"],
Cell[1701342, 52865, 250, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1701629, 52876, 163, 4, 70, "Input",
  CellTags->"LCD"],
Cell[1701795, 52882, 475, 11, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1702307, 52898, 494, 13, 70, "Input",
  CellTags->"LCD"],
Cell[1702804, 52913, 506, 14, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1703347, 52932, 207, 5, 70, "Input",
  CellTags->"LCD"],
Cell[1703557, 52939, 186, 5, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1703804, 52951, 62, 1, 70, "ObjectName",
  CellTags->"LeftPartialD"],

Cell[CellGroupData[{
Cell[1703891, 52956, 64, 1, 70, "Subsubsection",
  CellTags->"LeftPartialD"],
Cell[1703958, 52959, 358, 12, 70, "Text",
  CellTags->"LeftPartialD"],
Cell[1704319, 52973, 616, 24, 70, "Text",
  CellTags->"LeftPartialD"]
}, Closed]],

Cell[CellGroupData[{
Cell[1704972, 53002, 70, 1, 70, "Subsubsection",
  CellTags->"LeftPartialD"],

Cell[CellGroupData[{
Cell[1705067, 53007, 300, 7, 70, "Input",
  CellTags->"LeftPartialD"],
Cell[1705370, 53016, 358, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1705765, 53031, 148, 3, 70, "Input",
  CellTags->"LeftPartialD"],
Cell[1705916, 53036, 358, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1706311, 53051, 146, 3, 70, "Input",
  CellTags->"LeftPartialD"],
Cell[1706460, 53056, 332, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1706829, 53068, 193, 4, 70, "Input",
  CellTags->"LeftPartialD"],
Cell[1707025, 53074, 180, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1707242, 53082, 434, 10, 70, "Input",
  CellTags->"LeftPartialD"],
Cell[1707679, 53094, 401, 11, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1708117, 53110, 148, 3, 70, "Input",
  CellTags->"LeftPartialD"],
Cell[1708268, 53115, 424, 12, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1708729, 53132, 146, 3, 70, "Input",
  CellTags->"LeftPartialD"],
Cell[1708878, 53137, 495, 11, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1709434, 53155, 72, 1, 70, "ObjectName",
  CellTags->"LeftRightPartialD"],

Cell[CellGroupData[{
Cell[1709531, 53160, 69, 1, 70, "Subsubsection",
  CellTags->"LeftRightPartialD"],
Cell[1709603, 53163, 659, 21, 70, "Text",
  CellTags->"LeftRightPartialD"],
Cell[1710265, 53186, 893, 33, 70, "Text",
  CellTags->"LeftRightPartialD"]
}, Closed]],

Cell[CellGroupData[{
Cell[1711195, 53224, 66, 1, 70, "Subsubsection",
  CellTags->"LeftRightPartialD"],

Cell[CellGroupData[{
Cell[1711286, 53229, 160, 3, 70, "Input",
  CellTags->"LeftRightPartialD"],
Cell[1711449, 53234, 292, 8, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1711778, 53247, 155, 3, 70, "Input",
  CellTags->"LeftRightPartialD"],
Cell[1711936, 53252, 652, 18, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1712625, 53275, 310, 7, 70, "Input",
  CellTags->"LeftRightPartialD"],
Cell[1712938, 53284, 363, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1713338, 53299, 153, 3, 70, "Input",
  CellTags->"LeftRightPartialD"],
Cell[1713494, 53304, 835, 24, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1714366, 53333, 444, 10, 70, "Input",
  CellTags->"LeftRightPartialD"],
Cell[1714813, 53345, 406, 11, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1715256, 53361, 153, 3, 70, "Input",
  CellTags->"LeftRightPartialD"],
Cell[1715412, 53366, 1026, 29, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1716499, 53402, 74, 1, 70, "ObjectName",
  CellTags->"LeftRightPartialD2"],

Cell[CellGroupData[{
Cell[1716598, 53407, 70, 1, 70, "Subsubsection",
  CellTags->"LeftRightPartialD2"],
Cell[1716671, 53410, 658, 21, 70, "Text",
  CellTags->"LeftRightPartialD2"],
Cell[1717332, 53433, 751, 29, 70, "Text",
  CellTags->"LeftRightPartialD2"]
}, Closed]],

Cell[CellGroupData[{
Cell[1718120, 53467, 67, 1, 70, "Subsubsection",
  CellTags->"LeftRightPartialD2"],

Cell[CellGroupData[{
Cell[1718212, 53472, 162, 3, 70, "Input",
  CellTags->"LeftRightPartialD2"],
Cell[1718377, 53477, 292, 8, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1718706, 53490, 156, 3, 70, "Input",
  CellTags->"LeftRightPartialD2"],
Cell[1718865, 53495, 517, 15, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1719419, 53515, 312, 7, 70, "Input",
  CellTags->"LeftRightPartialD2"],
Cell[1719734, 53524, 363, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1720134, 53539, 154, 3, 70, "Input",
  CellTags->"LeftRightPartialD2"],
Cell[1720291, 53544, 749, 23, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1721077, 53572, 446, 10, 70, "Input",
  CellTags->"LeftRightPartialD2"],
Cell[1721526, 53584, 406, 11, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1721969, 53600, 154, 3, 70, "Input",
  CellTags->"LeftRightPartialD2"],
Cell[1722126, 53605, 903, 26, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1723090, 53638, 59, 1, 70, "ObjectName",
  CellTags->"LeviCivita"],

Cell[CellGroupData[{
Cell[1723174, 53643, 62, 1, 70, "Subsubsection",
  CellTags->"LeviCivita"],
Cell[1723239, 53646, 1314, 41, 70, "Text",
  CellTags->"LeviCivita"],

Cell[CellGroupData[{
Cell[1724578, 53691, 148, 3, 70, "Input",
  CellTags->"LeviCivita"],
Cell[1724729, 53696, 186, 5, 70, "Output"]
}, Closed]],
Cell[1724930, 53704, 281, 14, 70, "Text",
  CellTags->"LeviCivita"]
}, Closed]],

Cell[CellGroupData[{
Cell[1725248, 53723, 59, 1, 70, "Subsubsection",
  CellTags->"LeviCivita"],

Cell[CellGroupData[{
Cell[1725332, 53728, 223, 5, 70, "Input",
  CellTags->"LeviCivita"],
Cell[1725558, 53735, 673, 20, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1726268, 53760, 245, 6, 70, "Input",
  CellTags->"LeviCivita"],
Cell[1726516, 53768, 558, 16, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1727111, 53789, 216, 5, 70, "Input",
  CellTags->"LeviCivita"],
Cell[1727330, 53796, 426, 12, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1727793, 53813, 222, 5, 70, "Input",
  CellTags->"LeviCivita"],
Cell[1728018, 53820, 109, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1728164, 53827, 297, 8, 70, "Input",
  CellTags->"LeviCivita"],
Cell[1728464, 53837, 358, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1728859, 53849, 488, 13, 70, "Input",
  CellTags->"LeviCivita"],
Cell[1729350, 53864, 1332, 39, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1730719, 53908, 141, 3, 70, "Input",
  CellTags->"LeviCivita"],
Cell[1730863, 53913, 132, 3, 70, "Output"]
}, Closed]],
Cell[1731010, 53919, 374, 9, 70, "Input",
  CellTags->"LeviCivita"],

Cell[CellGroupData[{
Cell[1731409, 53932, 506, 13, 70, "Input",
  CellTags->"LeviCivita"],
Cell[1731918, 53947, 343, 10, 70, "Output"]
}, Closed]],
Cell[1732276, 53960, 374, 9, 70, "Input",
  CellTags->"LeviCivita"],

Cell[CellGroupData[{
Cell[1732675, 53973, 215, 5, 70, "Input",
  CellTags->"LeviCivita"],
Cell[1732893, 53980, 269, 6, 70, "Output"]
}, Closed]],
Cell[1733177, 53989, 138, 3, 70, "Input",
  CellTags->"LeviCivita"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1733364, 53998, 45, 1, 70, "ObjectName",
  CellTags->"Li2"],

Cell[CellGroupData[{
Cell[1733434, 54003, 55, 1, 70, "Subsubsection",
  CellTags->"Li2"],
Cell[1733492, 54006, 118, 3, 70, "Text",
  CellTags->"Li2"],
Cell[1733613, 54011, 165, 8, 70, "Text",
  CellTags->"Li2"]
}, Closed]],

Cell[CellGroupData[{
Cell[1733815, 54024, 52, 1, 70, "Subsubsection",
  CellTags->"Li2"],

Cell[CellGroupData[{
Cell[1733892, 54029, 128, 3, 70, "Input",
  CellTags->"Li2"],
Cell[1734023, 54034, 172, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1734232, 54044, 135, 3, 70, "Input",
  CellTags->"Li2"],
Cell[1734370, 54049, 180, 4, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1734587, 54058, 317, 9, 70, "Input",
  CellTags->"Li2"],
Cell[1734907, 54069, 172, 5, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1735140, 54081, 45, 1, 70, "ObjectName",
  CellTags->"Li3"],

Cell[CellGroupData[{
Cell[1735210, 54086, 55, 1, 70, "Subsubsection",
  CellTags->"Li3"],
Cell[1735268, 54089, 121, 4, 70, "Text",
  CellTags->"Li3"],
Cell[1735392, 54095, 165, 8, 70, "Text",
  CellTags->"Li3"]
}, Closed]],

Cell[CellGroupData[{
Cell[1735594, 54108, 52, 1, 70, "Subsubsection",
  CellTags->"Li3"],

Cell[CellGroupData[{
Cell[1735671, 54113, 128, 3, 70, "Input",
  CellTags->"Li3"],
Cell[1735802, 54118, 172, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1736011, 54128, 135, 3, 70, "Input",
  CellTags->"Li3"],
Cell[1736149, 54133, 180, 4, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1736366, 54142, 189, 5, 70, "Input",
  CellTags->"Li3"],
Cell[1736558, 54149, 206, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1736801, 54160, 252, 7, 70, "Input",
  CellTags->"Li3"],
Cell[1737056, 54169, 172, 5, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1737289, 54181, 62, 1, 70, "ObjectName",
  CellTags->"LorentzIndex"],

Cell[CellGroupData[{
Cell[1737376, 54186, 64, 1, 70, "Subsubsection",
  CellTags->"LorentzIndex"],
Cell[1737443, 54189, 244, 5, 70, "Text",
  CellTags->"LorentzIndex"],
Cell[1737690, 54196, 337, 14, 70, "Text",
  CellTags->"LorentzIndex"]
}, Closed]],

Cell[CellGroupData[{
Cell[1738064, 54215, 61, 1, 70, "Subsubsection",
  CellTags->"LorentzIndex"],
Cell[1738128, 54218, 90, 1, 70, "Text",
  CellTags->"LorentzIndex"],

Cell[CellGroupData[{
Cell[1738243, 54223, 153, 3, 70, "Input",
  CellTags->"LorentzIndex"],
Cell[1738399, 54228, 116, 2, 70, "Output"]
}, Closed]],
Cell[1738530, 54233, 126, 3, 70, "Text",
  CellTags->"LorentzIndex"],

Cell[CellGroupData[{
Cell[1738681, 54240, 180, 4, 70, "Input",
  CellTags->"LorentzIndex"],
Cell[1738864, 54246, 116, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1739017, 54253, 131, 2, 70, "Input",
  CellTags->"LorentzIndex"],
Cell[1739151, 54257, 144, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1739332, 54265, 197, 4, 70, "Input",
  CellTags->"LorentzIndex"],
Cell[1739532, 54271, 141, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1739710, 54279, 246, 6, 70, "Input",
  CellTags->"LorentzIndex"],
Cell[1739959, 54287, 115, 2, 70, "Output"]
}, Closed]],
Cell[1740089, 54292, 142, 4, 70, "Text",
  CellTags->"LorentzIndex"],
Cell[1740234, 54298, 169, 4, 70, "Input",
  CellTags->"LorentzIndex"],

Cell[CellGroupData[{
Cell[1740428, 54306, 412, 10, 70, "Input",
  CellTags->"LorentzIndex"],
Cell[1740843, 54318, 479, 15, 70, "Output"]
}, Closed]],
Cell[1741337, 54336, 180, 4, 70, "Input",
  CellTags->"LorentzIndex"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1741566, 54346, 46, 1, 70, "ObjectName",
  CellTags->"Map2"],

Cell[CellGroupData[{
Cell[1741637, 54351, 56, 1, 70, "Subsubsection",
  CellTags->"Map2"],
Cell[1741696, 54354, 136, 4, 70, "Text",
  CellTags->"Map2"],
Cell[1741835, 54360, 182, 9, 70, "Text",
  CellTags->"Map2"]
}, Closed]],

Cell[CellGroupData[{
Cell[1742054, 54374, 53, 1, 70, "Subsubsection",
  CellTags->"Map2"],

Cell[CellGroupData[{
Cell[1742132, 54379, 186, 5, 70, "Input",
  CellTags->"Map2"],
Cell[1742321, 54386, 230, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1742588, 54397, 157, 4, 70, "Input",
  CellTags->"Map2"],
Cell[1742748, 54403, 141, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1742926, 54411, 227, 6, 70, "Input",
  CellTags->"Map2"],
Cell[1743156, 54419, 218, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1743411, 54430, 157, 4, 70, "Input",
  CellTags->"Map2"],
Cell[1743571, 54436, 141, 3, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1743773, 54446, 62, 1, 70, "ObjectName",
  CellTags->"MetricTensor"],

Cell[CellGroupData[{
Cell[1743860, 54451, 64, 1, 70, "Subsubsection",
  CellTags->"MetricTensor"],
Cell[1743927, 54454, 227, 7, 70, "Text",
  CellTags->"MetricTensor"],
Cell[1744157, 54463, 637, 29, 70, "Text",
  CellTags->"MetricTensor"]
}, Closed]],

Cell[CellGroupData[{
Cell[1744831, 54497, 61, 1, 70, "Subsubsection",
  CellTags->"MetricTensor"],

Cell[CellGroupData[{
Cell[1744917, 54502, 186, 4, 70, "Input",
  CellTags->"MetricTensor"],
Cell[1745106, 54508, 195, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1745338, 54518, 169, 4, 70, "Input",
  CellTags->"MetricTensor"],
Cell[1745510, 54524, 109, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1745656, 54531, 239, 5, 70, "Input",
  CellTags->"MetricTensor"],
Cell[1745898, 54538, 400, 12, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1746335, 54555, 169, 4, 70, "Input",
  CellTags->"MetricTensor"],
Cell[1746507, 54561, 109, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1746653, 54568, 218, 5, 70, "Input",
  CellTags->"MetricTensor"],
Cell[1746874, 54575, 242, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1747153, 54585, 273, 6, 70, "Input",
  CellTags->"MetricTensor"],
Cell[1747429, 54593, 304, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1747770, 54605, 256, 6, 70, "Input",
  CellTags->"MetricTensor"],
Cell[1748029, 54613, 150, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1748216, 54621, 320, 8, 70, "Input",
  CellTags->"MetricTensor"],
Cell[1748539, 54631, 151, 3, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1748751, 54641, 68, 1, 70, "ObjectName",
  CellTags->"MomentumCombine"],

Cell[CellGroupData[{
Cell[1748844, 54646, 67, 1, 70, "Subsubsection",
  CellTags->"MomentumCombine"],
Cell[1748914, 54649, 184, 4, 70, "Text",
  CellTags->"MomentumCombine"],
Cell[1749101, 54655, 483, 18, 70, "Text",
  CellTags->"MomentumCombine"]
}, Closed]],

Cell[CellGroupData[{
Cell[1749621, 54678, 64, 1, 70, "Subsubsection",
  CellTags->"MomentumCombine"],

Cell[CellGroupData[{
Cell[1749710, 54683, 391, 10, 70, "Input",
  CellTags->"MomentumCombine"],
Cell[1750104, 54695, 185, 4, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1750326, 54704, 378, 10, 70, "Input",
  CellTags->"MomentumCombine"],
Cell[1750707, 54716, 235, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1750979, 54727, 153, 3, 70, "Input",
  CellTags->"MomentumCombine"],
Cell[1751135, 54732, 387, 12, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1751559, 54749, 199, 5, 70, "Input",
  CellTags->"MomentumCombine"],
Cell[1751761, 54756, 306, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1752104, 54768, 206, 5, 70, "Input",
  CellTags->"MomentumCombine"],
Cell[1752313, 54775, 561, 18, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1752911, 54798, 149, 3, 70, "Input",
  CellTags->"MomentumCombine"],
Cell[1753063, 54803, 468, 11, 70, "Output"]
}, Closed]],
Cell[1753546, 54817, 143, 3, 70, "Input",
  CellTags->"MomentumCombine"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1753738, 54826, 66, 1, 70, "ObjectName",
  CellTags->"MomentumExpand"],

Cell[CellGroupData[{
Cell[1753829, 54831, 66, 1, 70, "Subsubsection",
  CellTags->"MomentumExpand"],
Cell[1753898, 54834, 150, 4, 70, "Text",
  CellTags->"MomentumExpand"],
Cell[1754051, 54840, 372, 14, 70, "Text",
  CellTags->"MomentumExpand"]
}, Closed]],

Cell[CellGroupData[{
Cell[1754460, 54859, 63, 1, 70, "Subsubsection",
  CellTags->"MomentumExpand"],

Cell[CellGroupData[{
Cell[1754548, 54864, 268, 7, 70, "Input",
  CellTags->"MomentumExpand"],
Cell[1754819, 54873, 195, 4, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1755051, 54882, 205, 5, 70, "Input",
  CellTags->"MomentumExpand"],
Cell[1755259, 54889, 347, 9, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1755643, 54903, 144, 3, 70, "Input",
  CellTags->"MomentumExpand"],
Cell[1755790, 54908, 265, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1756092, 54919, 254, 6, 70, "Input",
  CellTags->"MomentumExpand"],
Cell[1756349, 54927, 431, 14, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1756817, 54946, 144, 3, 70, "Input",
  CellTags->"MomentumExpand"],
Cell[1756964, 54951, 308, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1757309, 54963, 285, 7, 70, "Input",
  CellTags->"MomentumExpand"],
Cell[1757597, 54972, 464, 15, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1758098, 54992, 144, 3, 70, "Input",
  CellTags->"MomentumExpand"],
Cell[1758245, 54997, 410, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1758692, 55012, 140, 3, 70, "Input",
  CellTags->"MomentumExpand"],
Cell[1758835, 55017, 777, 22, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1759673, 55046, 54, 1, 70, "ObjectName",
  CellTags->"Momentum"],

Cell[CellGroupData[{
Cell[1759752, 55051, 60, 1, 70, "Subsubsection",
  CellTags->"Momentum"],
Cell[1759815, 55054, 259, 5, 70, "Text",
  CellTags->"Momentum"],
Cell[1760077, 55061, 573, 24, 70, "Text",
  CellTags->"Momentum"]
}, Closed]],

Cell[CellGroupData[{
Cell[1760687, 55090, 57, 1, 70, "Subsubsection",
  CellTags->"Momentum"],
Cell[1760747, 55093, 76, 1, 70, "Text",
  CellTags->"Momentum"],

Cell[CellGroupData[{
Cell[1760848, 55098, 138, 3, 70, "Input",
  CellTags->"Momentum"],
Cell[1760989, 55103, 109, 2, 70, "Output"]
}, Closed]],
Cell[1761113, 55108, 139, 4, 70, "Text",
  CellTags->"Momentum"],

Cell[CellGroupData[{
Cell[1761277, 55116, 165, 4, 70, "Input",
  CellTags->"Momentum"],
Cell[1761445, 55122, 109, 2, 70, "Output"]
}, Closed]],
Cell[1761569, 55127, 87, 1, 70, "Text",
  CellTags->"Momentum"],

Cell[CellGroupData[{
Cell[1761681, 55132, 206, 5, 70, "Input",
  CellTags->"Momentum"],
Cell[1761890, 55139, 156, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1762083, 55147, 190, 5, 70, "Input",
  CellTags->"Momentum"],
Cell[1762276, 55154, 131, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1762444, 55162, 139, 3, 70, "Input",
  CellTags->"Momentum"],
Cell[1762586, 55167, 151, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1762774, 55175, 313, 8, 70, "Input",
  CellTags->"Momentum"],
Cell[1763090, 55185, 225, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1763352, 55196, 139, 3, 70, "Input",
  CellTags->"Momentum"],
Cell[1763494, 55201, 253, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1763784, 55212, 182, 5, 70, "Input",
  CellTags->"Momentum"],
Cell[1763969, 55219, 195, 4, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1764201, 55228, 188, 5, 70, "Input",
  CellTags->"Momentum"],
Cell[1764392, 55235, 156, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1764585, 55243, 263, 7, 70, "Input",
  CellTags->"Momentum"],
Cell[1764851, 55252, 156, 3, 70, "Output"]
}, Closed]],
Cell[1765022, 55258, 164, 4, 70, "Input",
  CellTags->"Momentum"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1765235, 55268, 42, 1, 70, "ObjectName",
  CellTags->"MT"],

Cell[CellGroupData[{
Cell[1765302, 55273, 54, 1, 70, "Subsubsection",
  CellTags->"MT"],
Cell[1765359, 55276, 195, 7, 70, "Text",
  CellTags->"MT"],
Cell[1765557, 55285, 657, 29, 70, "Text",
  CellTags->"MT"]
}, Closed]],

Cell[CellGroupData[{
Cell[1766251, 55319, 51, 1, 70, "Subsubsection",
  CellTags->"MT"],

Cell[CellGroupData[{
Cell[1766327, 55324, 166, 4, 70, "Input",
  CellTags->"MT"],
Cell[1766496, 55330, 195, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1766728, 55340, 317, 8, 70, "Input",
  CellTags->"MT"],
Cell[1767048, 55350, 109, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1767194, 55357, 194, 5, 70, "Input",
  CellTags->"MT"],
Cell[1767391, 55364, 150, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1767578, 55372, 239, 7, 70, "Input",
  CellTags->"MT"],
Cell[1767820, 55381, 242, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1768099, 55391, 279, 8, 70, "Input",
  CellTags->"MT"],
Cell[1768381, 55401, 150, 3, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1768592, 55411, 44, 1, 70, "ObjectName",
  CellTags->"MTD"],

Cell[CellGroupData[{
Cell[1768661, 55416, 55, 1, 70, "Subsubsection",
  CellTags->"MTD"],
Cell[1768719, 55419, 197, 7, 70, "Text",
  CellTags->"MTD"],
Cell[1768919, 55428, 655, 29, 70, "Text",
  CellTags->"MTD"]
}, Closed]],

Cell[CellGroupData[{
Cell[1769611, 55462, 52, 1, 70, "Subsubsection",
  CellTags->"MTD"],

Cell[CellGroupData[{
Cell[1769688, 55467, 168, 4, 70, "Input",
  CellTags->"MTD"],
Cell[1769859, 55473, 195, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1770091, 55483, 320, 8, 70, "Input",
  CellTags->"MTD"],
Cell[1770414, 55493, 109, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1770560, 55500, 216, 6, 70, "Input",
  CellTags->"MTD"],
Cell[1770779, 55508, 164, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1770980, 55516, 254, 7, 70, "Input",
  CellTags->"MTD"],
Cell[1771237, 55525, 317, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1771591, 55537, 289, 8, 70, "Input",
  CellTags->"MTD"],
Cell[1771883, 55547, 159, 3, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1772103, 55557, 52, 1, 70, "ObjectName",
  CellTags->"Nielsen"],

Cell[CellGroupData[{
Cell[1772180, 55562, 59, 1, 70, "Subsubsection",
  CellTags->"Nielsen"],
Cell[1772242, 55565, 87, 1, 70, "Text",
  CellTags->"Nielsen"],

Cell[CellGroupData[{
Cell[1772354, 55570, 142, 3, 70, "Input",
  CellTags->"Nielsen"],
Cell[1772499, 55575, 188, 5, 70, "Output"]
}, Closed]],
Cell[1772702, 55583, 212, 9, 70, "Text",
  CellTags->"Nielsen"]
}, Closed]],

Cell[CellGroupData[{
Cell[1772951, 55597, 56, 1, 70, "Subsubsection",
  CellTags->"Nielsen"],

Cell[CellGroupData[{
Cell[1773032, 55602, 173, 4, 70, "Input",
  CellTags->"Nielsen"],
Cell[1773208, 55608, 326, 10, 70, "Output"]
}, Closed]],
Cell[1773549, 55621, 177, 4, 70, "Text",
  CellTags->"Nielsen"],

Cell[CellGroupData[{
Cell[1773751, 55629, 209, 5, 70, "Input",
  CellTags->"Nielsen"],
Cell[1773963, 55636, 128, 2, 70, "Output"]
}, Closed]],
Cell[1774106, 55641, 72, 1, 70, "Text",
  CellTags->"Nielsen"],

Cell[CellGroupData[{
Cell[1774203, 55646, 557, 14, 70, "Input",
  CellTags->"Nielsen"],
Cell[1774763, 55662, 765, 22, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1775565, 55689, 227, 5, 70, "Input",
  CellTags->"Nielsen"],
Cell[1775795, 55696, 820, 23, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1776652, 55724, 227, 5, 70, "Input",
  CellTags->"Nielsen"],
Cell[1776882, 55731, 1042, 29, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1777961, 55765, 227, 5, 70, "Input",
  CellTags->"Nielsen"],
Cell[1778191, 55772, 172, 5, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1778424, 55784, 50, 1, 70, "ObjectName",
  CellTags->"NTerms"],

Cell[CellGroupData[{
Cell[1778499, 55789, 58, 1, 70, "Subsubsection",
  CellTags->"NTerms"],
Cell[1778560, 55792, 150, 4, 70, "Text",
  CellTags->"NTerms"]
}, Closed]],

Cell[CellGroupData[{
Cell[1778747, 55801, 55, 1, 70, "Subsubsection",
  CellTags->"NTerms"],

Cell[CellGroupData[{
Cell[1778827, 55806, 161, 4, 70, "Input",
  CellTags->"NTerms"],
Cell[1778991, 55812, 109, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1779137, 55819, 171, 4, 70, "Input",
  CellTags->"NTerms"],
Cell[1779311, 55825, 109, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1779457, 55832, 134, 3, 70, "Input",
  CellTags->"NTerms"],
Cell[1779594, 55837, 109, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1779740, 55844, 134, 3, 70, "Input",
  CellTags->"NTerms"],
Cell[1779877, 55849, 109, 2, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1780047, 55858, 52, 1, 70, "ObjectName",
  CellTags->"OneLoop"],
Cell[1780102, 55861, 673, 17, 70, "Text",
  CellTags->"OneLoop"],
Cell[1780778, 55880, 75, 1, 70, "Text",
  CellTags->"OneLoop"],
Cell[1780856, 55883, 1073, 27, 70, "Text",
  CellTags->"OneLoop"],

Cell[CellGroupData[{
Cell[1781954, 55914, 59, 1, 70, "Subsubsection",
  CellTags->"OneLoop"],
Cell[1782016, 55917, 283, 6, 70, "Text",
  CellTags->"OneLoop"],
Cell[1782302, 55925, 353, 6, 70, "Text",
  CellTags->"OneLoop"],

Cell[CellGroupData[{
Cell[1782680, 55935, 142, 3, 70, "Input",
  CellTags->"OneLoop"],
Cell[1782825, 55940, 1392, 28, 70, "Output"]
}, Closed]],
Cell[1784232, 55971, 731, 34, 70, "Text",
  CellTags->"OneLoop"]
}, Closed]],

Cell[CellGroupData[{
Cell[1785000, 56010, 56, 1, 70, "Subsubsection",
  CellTags->"OneLoop"],

Cell[CellGroupData[{
Cell[1785081, 56015, 342, 10, 70, "Input",
  CellTags->"OneLoop"],
Cell[1785426, 56027, 390, 11, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1785853, 56043, 163, 4, 70, "Input",
  CellTags->"OneLoop"],
Cell[1786019, 56049, 383, 10, 70, "Output"]
}, Closed]],
Cell[1786417, 56062, 440, 11, 70, "Input",
  CellTags->"OneLoop"],
Cell[1786860, 56075, 733, 20, 70, "Text",
  CellTags->"OneLoop"],

Cell[CellGroupData[{
Cell[1787618, 56099, 1146, 30, 70, "Input",
  CellTags->"OneLoop"],
Cell[1788767, 56131, 3058, 76, 70, "Output"]
}, Closed]],
Cell[1791840, 56210, 220, 5, 70, "Text",
  CellTags->"OneLoop"],

Cell[CellGroupData[{
Cell[1792085, 56219, 163, 4, 70, "Input",
  CellTags->"OneLoop"],
Cell[1792251, 56225, 3826, 92, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1796114, 56322, 141, 3, 70, "Input",
  CellTags->"OneLoop"],
Cell[1796258, 56327, 2917, 70, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1799212, 56402, 416, 12, 70, "Input",
  CellTags->"OneLoop"],
Cell[1799631, 56416, 1251, 35, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1800919, 56456, 163, 4, 70, "Input",
  CellTags->"OneLoop"],
Cell[1801085, 56462, 2743, 71, 70, "Output"]
}, Closed]],
Cell[1803843, 56536, 134, 3, 70, "Input",
  CellTags->"OneLoop"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1804026, 56545, 68, 1, 70, "ObjectName",
  CellTags->"OneLoopSimplify"],

Cell[CellGroupData[{
Cell[1804119, 56550, 67, 1, 70, "Subsubsection",
  CellTags->"OneLoopSimplify"],
Cell[1804189, 56553, 173, 4, 70, "Text",
  CellTags->"OneLoopSimplify"],

Cell[CellGroupData[{
Cell[1804387, 56561, 158, 3, 70, "Input",
  CellTags->"OneLoopSimplify"],
Cell[1804548, 56566, 821, 17, 70, "Output"]
}, Closed]],
Cell[1805384, 56586, 409, 19, 70, "Text",
  CellTags->"OneLoopSimplify"]
}, Closed]],

Cell[CellGroupData[{
Cell[1805830, 56610, 64, 1, 70, "Subsubsection",
  CellTags->"OneLoopSimplify"],

Cell[CellGroupData[{
Cell[1805919, 56615, 424, 12, 70, "Input",
  CellTags->"OneLoopSimplify"],
Cell[1806346, 56629, 1251, 35, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1807634, 56669, 179, 4, 70, "Input",
  CellTags->"OneLoopSimplify"],
Cell[1807816, 56675, 2298, 62, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1810151, 56742, 246, 6, 70, "Input",
  CellTags->"OneLoopSimplify"],
Cell[1810400, 56750, 977, 27, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1811414, 56782, 485, 12, 70, "Input",
  CellTags->"OneLoopSimplify"],
Cell[1811902, 56796, 1810, 52, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1813749, 56853, 184, 4, 70, "Input",
  CellTags->"OneLoopSimplify"],
Cell[1813936, 56859, 13468, 351, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1827441, 57215, 312, 9, 70, "Input",
  CellTags->"OneLoopSimplify"],
Cell[1827756, 57226, 9388, 250, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1837181, 57481, 533, 15, 70, "Input",
  CellTags->"OneLoopSimplify"],
Cell[1837717, 57498, 3959, 104, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1841737, 57609, 54, 1, 70, "ObjectName",
  CellTags->"OPEDelta"],

Cell[CellGroupData[{
Cell[1841816, 57614, 60, 1, 70, "Subsubsection",
  CellTags->"OPEDelta"],
Cell[1841879, 57617, 141, 4, 70, "Text",
  CellTags->"OPEDelta"],
Cell[1842023, 57623, 225, 9, 70, "Text",
  CellTags->"OPEDelta"]
}, Closed]],

Cell[CellGroupData[{
Cell[1842285, 57637, 57, 1, 70, "Subsubsection",
  CellTags->"OPEDelta"],

Cell[CellGroupData[{
Cell[1842367, 57642, 178, 4, 70, "Input",
  CellTags->"OPEDelta"],
Cell[1842548, 57648, 200, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1842785, 57658, 165, 4, 70, "Input",
  CellTags->"OPEDelta"],
Cell[1842953, 57664, 109, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1843099, 57671, 173, 4, 70, "Input",
  CellTags->"OPEDelta"],
Cell[1843275, 57677, 109, 2, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1843445, 57686, 82, 1, 70, "ObjectName",
  CellTags->"OPEi"],

Cell[CellGroupData[{
Cell[1843552, 57691, 56, 1, 70, "Subsubsection",
  CellTags->"OPEi"],
Cell[1843611, 57694, 172, 4, 70, "Text",
  CellTags->"OPEi"]
}, Closed]],

Cell[CellGroupData[{
Cell[1843820, 57703, 53, 1, 70, "Subsubsection",
  CellTags->"OPEi"],

Cell[CellGroupData[{
Cell[1843898, 57708, 100, 2, 70, "Input",
  CellTags->"OPEi"],
Cell[1844001, 57712, 109, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1844147, 57719, 304, 7, 70, "Input",
  CellTags->"OPEi"],
Cell[1844454, 57728, 256, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1844747, 57739, 1365, 40, 70, "Input",
  CellTags->"OPEi"],
Cell[1846115, 57781, 233, 6, 70, "Output"]
}, Closed]],
Cell[1846363, 57790, 56, 1, 70, "Text",
  CellTags->"OPEi"],

Cell[CellGroupData[{
Cell[1846444, 57795, 632, 17, 70, "Input",
  CellTags->"OPEi"],
Cell[1847079, 57814, 219, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1847335, 57824, 662, 19, 70, "Input",
  CellTags->"OPEi"],
Cell[1848000, 57845, 191, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1848228, 57855, 632, 17, 70, "Input",
  CellTags->"OPEi"],
Cell[1848863, 57874, 219, 5, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1849143, 57886, 66, 1, 70, "ObjectName",
  CellTags->"OPESumExplicit"],

Cell[CellGroupData[{
Cell[1849234, 57891, 66, 1, 70, "Subsubsection",
  CellTags->"OPESumExplicit"],
Cell[1849303, 57894, 86, 1, 70, "Text",
  CellTags->"OPESumExplicit"],
Cell[1849392, 57897, 330, 14, 70, "Text",
  CellTags->"OPESumExplicit"]
}, Closed]],

Cell[CellGroupData[{
Cell[1849759, 57916, 63, 1, 70, "Subsubsection",
  CellTags->"OPESumExplicit"],

Cell[CellGroupData[{
Cell[1849847, 57921, 482, 13, 70, "Input",
  CellTags->"OPESumExplicit"],
Cell[1850332, 57936, 454, 13, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1850823, 57954, 151, 3, 70, "Input",
  CellTags->"OPESumExplicit"],
Cell[1850977, 57959, 492, 15, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1851506, 57979, 686, 18, 70, "Input",
  CellTags->"OPESumExplicit"],
Cell[1852195, 57999, 876, 25, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1853108, 58029, 151, 3, 70, "Input",
  CellTags->"OPESumExplicit"],
Cell[1853262, 58034, 2814, 83, 70, "Output"]
}, Closed]],
Cell[1856091, 58120, 194, 5, 70, "Input",
  CellTags->"OPESumExplicit"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1856334, 58131, 50, 1, 70, "ObjectName",
  CellTags->"OPESum"],

Cell[CellGroupData[{
Cell[1856409, 58136, 58, 1, 70, "Subsubsection",
  CellTags->"OPESum"],
Cell[1856470, 58139, 128, 4, 70, "Text",
  CellTags->"OPESum"],
Cell[1856601, 58145, 346, 14, 70, "Text",
  CellTags->"OPESum"]
}, Closed]],

Cell[CellGroupData[{
Cell[1856984, 58164, 55, 1, 70, "Subsubsection",
  CellTags->"OPESum"],

Cell[CellGroupData[{
Cell[1857064, 58169, 571, 15, 70, "Input",
  CellTags->"OPESum"],
Cell[1857638, 58186, 1339, 35, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1859014, 58226, 143, 3, 70, "Input",
  CellTags->"OPESum"],
Cell[1859160, 58231, 2847, 77, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1862044, 58313, 678, 18, 70, "Input",
  CellTags->"OPESum"],
Cell[1862725, 58333, 876, 25, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1863638, 58363, 143, 3, 70, "Input",
  CellTags->"OPESum"],
Cell[1863784, 58368, 2814, 83, 70, "Output"]
}, Closed]],
Cell[1866613, 58454, 186, 5, 70, "Input",
  CellTags->"OPESum"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1866848, 58465, 66, 1, 70, "ObjectName",
  CellTags->"OPESumSimplify"],

Cell[CellGroupData[{
Cell[1866939, 58470, 66, 1, 70, "Subsubsection",
  CellTags->"OPESumSimplify"],
Cell[1867008, 58473, 93, 1, 70, "Text",
  CellTags->"OPESumSimplify"],
Cell[1867104, 58476, 330, 14, 70, "Text",
  CellTags->"OPESumSimplify"]
}, Closed]],

Cell[CellGroupData[{
Cell[1867471, 58495, 63, 1, 70, "Subsubsection",
  CellTags->"OPESumSimplify"],

Cell[CellGroupData[{
Cell[1867559, 58500, 168, 4, 70, "Input",
  CellTags->"OPESumSimplify"],
Cell[1867730, 58506, 1384, 36, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1869151, 58547, 114, 2, 70, "Input",
  CellTags->"OPESumSimplify"],
Cell[1869268, 58551, 1621, 39, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1870926, 58595, 328, 8, 70, "Input",
  CellTags->"OPESumSimplify"],
Cell[1871257, 58605, 330, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1871624, 58620, 535, 14, 70, "Input",
  CellTags->"OPESumSimplify"],
Cell[1872162, 58636, 718, 21, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1872917, 58662, 144, 3, 70, "Input",
  CellTags->"OPESumSimplify"],
Cell[1873064, 58667, 460, 12, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1873585, 58686, 46, 1, 70, "ObjectName",
  CellTags->"Pair"],

Cell[CellGroupData[{
Cell[1873656, 58691, 56, 1, 70, "Subsubsection",
  CellTags->"Pair"],
Cell[1873715, 58694, 512, 11, 70, "Text",
  CellTags->"Pair"],
Cell[1874230, 58707, 1082, 49, 70, "Text",
  CellTags->"Pair"]
}, Closed]],

Cell[CellGroupData[{
Cell[1875349, 58761, 53, 1, 70, "Subsubsection",
  CellTags->"Pair"],
Cell[1875405, 58764, 85, 1, 70, "Text",
  CellTags->"Pair"],

Cell[CellGroupData[{
Cell[1875515, 58769, 260, 6, 70, "Input",
  CellTags->"Pair"],
Cell[1875778, 58777, 195, 5, 70, "Output"]
}, Closed]],
Cell[1875988, 58785, 74, 1, 70, "Text",
  CellTags->"Pair"],

Cell[CellGroupData[{
Cell[1876087, 58790, 322, 8, 70, "Input",
  CellTags->"Pair"],
Cell[1876412, 58800, 400, 12, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1876849, 58817, 250, 6, 70, "Input",
  CellTags->"Pair"],
Cell[1877102, 58825, 289, 9, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1877428, 58839, 239, 6, 70, "Input",
  CellTags->"Pair"],
Cell[1877670, 58847, 269, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1877976, 58859, 239, 6, 70, "Input",
  CellTags->"Pair"],
Cell[1878218, 58867, 184, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1878439, 58877, 270, 7, 70, "Input",
  CellTags->"Pair"],
Cell[1878712, 58886, 349, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1879098, 58901, 272, 7, 70, "Input",
  CellTags->"Pair"],
Cell[1879373, 58910, 184, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1879594, 58920, 272, 7, 70, "Input",
  CellTags->"Pair"],
Cell[1879869, 58929, 184, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1880090, 58939, 376, 10, 70, "Input",
  CellTags->"Pair"],
Cell[1880469, 58951, 109, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1880615, 58958, 328, 8, 70, "Input",
  CellTags->"Pair"],
Cell[1880946, 58968, 387, 11, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1881370, 58984, 460, 12, 70, "Input",
  CellTags->"Pair"],
Cell[1881833, 58998, 109, 2, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1882003, 59007, 54, 1, 70, "ObjectName",
  CellTags->"PartialD"],

Cell[CellGroupData[{
Cell[1882082, 59012, 60, 1, 70, "Subsubsection",
  CellTags->"PartialD"],
Cell[1882145, 59015, 917, 31, 70, "Text",
  CellTags->"PartialD"],
Cell[1883065, 59048, 492, 19, 70, "Text",
  CellTags->"PartialD"]
}, Closed]],

Cell[CellGroupData[{
Cell[1883594, 59072, 66, 1, 70, "Subsubsection",
  CellTags->"PartialD"],

Cell[CellGroupData[{
Cell[1883685, 59077, 280, 7, 70, "Input",
  CellTags->"PartialD"],
Cell[1883968, 59086, 358, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1884363, 59101, 144, 3, 70, "Input",
  CellTags->"PartialD"],
Cell[1884510, 59106, 358, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1884905, 59121, 142, 3, 70, "Input",
  CellTags->"PartialD"],
Cell[1885050, 59126, 332, 7, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1885443, 59140, 46, 1, 70, "ObjectName",
  CellTags->"PaVe"],

Cell[CellGroupData[{
Cell[1885514, 59145, 56, 1, 70, "Subsubsection",
  CellTags->"PaVe"],
Cell[1885573, 59148, 431, 8, 70, "Text",
  CellTags->"PaVe"],
Cell[1886007, 59158, 278, 8, 70, "Text",
  CellTags->"PaVe"],
Cell[1886288, 59168, 194, 9, 70, "Text",
  CellTags->"PaVe"]
}, Closed]],

Cell[CellGroupData[{
Cell[1886519, 59182, 53, 1, 70, "Subsubsection",
  CellTags->"PaVe"],
Cell[1886575, 59185, 79, 1, 70, "Text",
  CellTags->"PaVe"],

Cell[CellGroupData[{
Cell[1886679, 59190, 369, 10, 70, "Input",
  CellTags->"PaVe"],
Cell[1887051, 59202, 676, 12, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1887764, 59219, 333, 9, 70, "Input",
  CellTags->"PaVe"],
Cell[1888100, 59230, 2553, 60, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1890714, 59297, 56, 1, 70, "ObjectName",
  CellTags->"PaVeOrder"],

Cell[CellGroupData[{
Cell[1890795, 59302, 61, 1, 70, "Subsubsection",
  CellTags->"PaVeOrder"],
Cell[1890859, 59305, 356, 7, 70, "Text",
  CellTags->"PaVeOrder"],
Cell[1891218, 59314, 199, 9, 70, "Text",
  CellTags->"PaVeOrder"]
}, Closed]],

Cell[CellGroupData[{
Cell[1891454, 59328, 58, 1, 70, "Subsubsection",
  CellTags->"PaVeOrder"],

Cell[CellGroupData[{
Cell[1891537, 59333, 491, 12, 70, "Input",
  CellTags->"PaVeOrder"],
Cell[1892031, 59347, 778, 16, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1892846, 59368, 491, 12, 70, "Input",
  CellTags->"PaVeOrder"],
Cell[1893340, 59382, 778, 16, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1894155, 59403, 851, 20, 70, "Input",
  CellTags->"PaVeOrder"],
Cell[1895009, 59425, 1435, 28, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1896505, 59460, 58, 1, 70, "ObjectName",
  CellTags->"PaVeReduce"],

Cell[CellGroupData[{
Cell[1896588, 59465, 62, 1, 70, "Subsubsection",
  CellTags->"PaVeReduce"],
Cell[1896653, 59468, 168, 4, 70, "Text",
  CellTags->"PaVeReduce"],

Cell[CellGroupData[{
Cell[1896846, 59476, 148, 3, 70, "Input",
  CellTags->"PaVeReduce"],
Cell[1896997, 59481, 505, 12, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1897539, 59498, 134, 3, 70, "Input",
  CellTags->"PaVeReduce"],
Cell[1897676, 59503, 281, 4, 70, "Print"]
}, Closed]],
Cell[1897972, 59510, 302, 14, 70, "Text",
  CellTags->"PaVeReduce"]
}, Closed]],

Cell[CellGroupData[{
Cell[1898311, 59529, 59, 1, 70, "Subsubsection",
  CellTags->"PaVeReduce"],

Cell[CellGroupData[{
Cell[1898395, 59534, 643, 16, 70, "Input",
  CellTags->"PaVeReduce"],
Cell[1899041, 59552, 4058, 106, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1903136, 59663, 134, 3, 70, "Input",
  CellTags->"PaVeReduce"],
Cell[1903273, 59668, 142, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1903452, 59676, 135, 3, 70, "Input",
  CellTags->"PaVeReduce"],
Cell[1903590, 59681, 142, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1903769, 59689, 607, 15, 70, "Input",
  CellTags->"PaVeReduce"],
Cell[1904379, 59706, 510, 13, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1904926, 59724, 487, 12, 70, "Input",
  CellTags->"PaVeReduce"],
Cell[1905416, 59738, 599, 15, 70, "Output"]
}, Closed]],
Cell[1906030, 59756, 255, 7, 70, "Input",
  CellTags->"PaVeReduce"],
Cell[1906288, 59765, 199, 5, 70, "Input",
  CellTags->"PaVeReduce"],

Cell[CellGroupData[{
Cell[1906512, 59774, 790, 19, 70, "Input",
  CellTags->"PaVeReduce"],
Cell[1907305, 59795, 11681, 270, 70, "Output"]
}, Closed]],
Cell[1919001, 60068, 321, 8, 70, "Input",
  CellTags->"PaVeReduce"],

Cell[CellGroupData[{
Cell[1919347, 60080, 459, 11, 70, "Input",
  CellTags->"PaVeReduce"],
Cell[1919809, 60093, 4206, 78, 70, "Output"]
}, Closed]],
Cell[1924030, 60174, 299, 7, 70, "Input",
  CellTags->"PaVeReduce"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1924378, 60187, 70, 1, 70, "ObjectName",
  CellTags->"PlusDistribution"],

Cell[CellGroupData[{
Cell[1924473, 60192, 68, 1, 70, "Subsubsection",
  CellTags->"PlusDistribution"],
Cell[1924544, 60195, 148, 4, 70, "Text",
  CellTags->"PlusDistribution"],
Cell[1924695, 60201, 206, 9, 70, "Text",
  CellTags->"PlusDistribution"]
}, Closed]],

Cell[CellGroupData[{
Cell[1924938, 60215, 65, 1, 70, "Subsubsection",
  CellTags->"PlusDistribution"],

Cell[CellGroupData[{
Cell[1925028, 60220, 241, 6, 70, "Input",
  CellTags->"PlusDistribution"],
Cell[1925272, 60228, 228, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1925537, 60240, 308, 8, 70, "Input",
  CellTags->"PlusDistribution"],
Cell[1925848, 60250, 303, 9, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1926188, 60264, 398, 10, 70, "Input",
  CellTags->"PlusDistribution"],
Cell[1926589, 60276, 109, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1926735, 60283, 473, 12, 70, "Input",
  CellTags->"PlusDistribution"],
Cell[1927211, 60297, 109, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1927357, 60304, 510, 13, 70, "Input",
  CellTags->"PlusDistribution"],
Cell[1927870, 60319, 109, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1928016, 60326, 376, 10, 70, "Input",
  CellTags->"PlusDistribution"],
Cell[1928395, 60338, 443, 13, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1928899, 60358, 62, 1, 70, "ObjectName",
  CellTags->"Polarization"],

Cell[CellGroupData[{
Cell[1928986, 60363, 64, 1, 70, "Subsubsection",
  CellTags->"Polarization"],
Cell[1929053, 60366, 770, 12, 70, "Text",
  CellTags->"Polarization"],
Cell[1929826, 60380, 226, 9, 70, "Text",
  CellTags->"Polarization"]
}, Closed]],

Cell[CellGroupData[{
Cell[1930089, 60394, 61, 1, 70, "Subsubsection",
  CellTags->"Polarization"],

Cell[CellGroupData[{
Cell[1930175, 60399, 146, 3, 70, "Input",
  CellTags->"Polarization"],
Cell[1930324, 60404, 443, 12, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1930804, 60421, 192, 5, 70, "Input",
  CellTags->"Polarization"],
Cell[1930999, 60428, 172, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1931208, 60436, 196, 5, 70, "Input",
  CellTags->"Polarization"],
Cell[1931407, 60443, 649, 18, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1932093, 60466, 237, 6, 70, "Input",
  CellTags->"Polarization"],
Cell[1932333, 60474, 196, 4, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1932566, 60483, 187, 4, 70, "Input",
  CellTags->"Polarization"],
Cell[1932756, 60489, 652, 16, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1933445, 60510, 235, 6, 70, "Input",
  CellTags->"Polarization"],
Cell[1933683, 60518, 260, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1933980, 60529, 364, 9, 70, "Input",
  CellTags->"Polarization"],
Cell[1934347, 60540, 109, 2, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1934517, 60549, 68, 1, 70, "ObjectName",
  CellTags->"PolarizationSum"],

Cell[CellGroupData[{
Cell[1934610, 60554, 67, 1, 70, "Subsubsection",
  CellTags->"PolarizationSum"],
Cell[1934680, 60557, 278, 5, 70, "Text",
  CellTags->"PolarizationSum"],

Cell[CellGroupData[{
Cell[1934983, 60566, 158, 3, 70, "Input",
  CellTags->"PolarizationSum"],
Cell[1935144, 60571, 186, 5, 70, "Output"]
}, Closed]],
Cell[1935345, 60579, 211, 9, 70, "Text",
  CellTags->"PolarizationSum"]
}, Closed]],

Cell[CellGroupData[{
Cell[1935593, 60593, 64, 1, 70, "Subsubsection",
  CellTags->"PolarizationSum"],

Cell[CellGroupData[{
Cell[1935682, 60598, 187, 4, 70, "Input",
  CellTags->"PolarizationSum"],
Cell[1935872, 60604, 216, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1936125, 60615, 197, 4, 70, "Input",
  CellTags->"PolarizationSum"],
Cell[1936325, 60621, 1491, 43, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1937853, 60669, 207, 4, 70, "Input",
  CellTags->"PolarizationSum"],
Cell[1938063, 60675, 3887, 109, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1941987, 60789, 296, 7, 70, "Input",
  CellTags->"PolarizationSum"],
Cell[1942286, 60798, 9986, 268, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1952333, 61073, 74, 1, 70, "ObjectName",
  CellTags->"PolarizationVector"],

Cell[CellGroupData[{
Cell[1952432, 61078, 70, 1, 70, "Subsubsection",
  CellTags->"PolarizationVector"],
Cell[1952505, 61081, 104, 1, 70, "Text",
  CellTags->"PolarizationVector"],
Cell[1952612, 61084, 441, 18, 70, "Text",
  CellTags->"PolarizationVector"]
}, Closed]],

Cell[CellGroupData[{
Cell[1953090, 61107, 67, 1, 70, "Subsubsection",
  CellTags->"PolarizationVector"],

Cell[CellGroupData[{
Cell[1953182, 61112, 189, 4, 70, "Input",
  CellTags->"PolarizationVector"],
Cell[1953374, 61118, 431, 12, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1953842, 61135, 231, 5, 70, "Input",
  CellTags->"PolarizationVector"],
Cell[1954076, 61142, 441, 12, 70, "Output"]
}, Closed]],
Cell[1954532, 61157, 265, 9, 70, "Text",
  CellTags->"PolarizationVector"],

Cell[CellGroupData[{
Cell[1954822, 61170, 227, 5, 70, "Input",
  CellTags->"PolarizationVector"],
Cell[1955052, 61177, 338, 8, 70, "Output"]
}, Closed]],
Cell[1955405, 61188, 547, 18, 70, "Text",
  CellTags->"PolarizationVector"],

Cell[CellGroupData[{
Cell[1955977, 61210, 338, 8, 70, "Input",
  CellTags->"PolarizationVector"],
Cell[1956318, 61220, 770, 22, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1957125, 61247, 149, 3, 70, "Input",
  CellTags->"PolarizationVector"],
Cell[1957277, 61252, 109, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1957423, 61259, 371, 9, 70, "Input",
  CellTags->"PolarizationVector"],
Cell[1957797, 61270, 815, 23, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1958649, 61298, 149, 3, 70, "Input",
  CellTags->"PolarizationVector"],
Cell[1958801, 61303, 930, 25, 70, "Output"]
}, Closed]],
Cell[1959746, 61331, 1987, 53, 70, "Text",
  CellTags->"PolarizationVector"],

Cell[CellGroupData[{
Cell[1961758, 61388, 371, 9, 70, "Input",
  CellTags->"PolarizationVector"],
Cell[1962132, 61399, 555, 15, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1962724, 61419, 149, 3, 70, "Input",
  CellTags->"PolarizationVector"],
Cell[1962876, 61424, 930, 25, 70, "Output"]
}, Closed]],
Cell[1963821, 61452, 185, 4, 70, "Input",
  CellTags->"PolarizationVector"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1964055, 61462, 64, 1, 70, "ObjectName",
  CellTags->"PowerSimplify"],

Cell[CellGroupData[{
Cell[1964144, 61467, 65, 1, 70, "Subsubsection",
  CellTags->"PowerSimplify"],
Cell[1964212, 61470, 409, 7, 70, "Text",
  CellTags->"PowerSimplify"],
Cell[1964624, 61479, 215, 11, 70, "Text",
  CellTags->"PowerSimplify"]
}, Closed]],

Cell[CellGroupData[{
Cell[1964876, 61495, 62, 1, 70, "Subsubsection",
  CellTags->"PowerSimplify"],

Cell[CellGroupData[{
Cell[1964963, 61500, 288, 8, 70, "Input",
  CellTags->"PowerSimplify"],
Cell[1965254, 61510, 109, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1965400, 61517, 293, 8, 70, "Input",
  CellTags->"PowerSimplify"],
Cell[1965696, 61527, 192, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1965925, 61537, 293, 8, 70, "Input",
  CellTags->"PowerSimplify"],
Cell[1966221, 61547, 192, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1966450, 61557, 233, 6, 70, "Input",
  CellTags->"PowerSimplify"],
Cell[1966686, 61565, 192, 5, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1966939, 61577, 96, 1, 70, "ObjectName",
  CellTags->"PropagatorDenominatorExplicit"],

Cell[CellGroupData[{
Cell[1967060, 61582, 81, 1, 70, "Subsubsection",
  CellTags->"PropagatorDenominatorExplicit"],
Cell[1967144, 61585, 244, 5, 70, "Text",
  CellTags->"PropagatorDenominatorExplicit"],
Cell[1967391, 61592, 402, 14, 70, "Text",
  CellTags->"PropagatorDenominatorExplicit"]
}, Closed]],

Cell[CellGroupData[{
Cell[1967830, 61611, 78, 1, 70, "Subsubsection",
  CellTags->"PropagatorDenominatorExplicit"],

Cell[CellGroupData[{
Cell[1967933, 61616, 383, 11, 70, "Input",
  CellTags->"PropagatorDenominatorExplicit"],
Cell[1968319, 61629, 406, 12, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1968762, 61646, 217, 5, 70, "Input",
  CellTags->"PropagatorDenominatorExplicit"],
Cell[1968982, 61653, 1168, 33, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1970187, 61691, 159, 3, 70, "Input",
  CellTags->"PropagatorDenominatorExplicit"],
Cell[1970349, 61696, 673, 18, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1971083, 61721, 80, 1, 70, "ObjectName",
  CellTags->"PropagatorDenominator"],

Cell[CellGroupData[{
Cell[1971188, 61726, 73, 1, 70, "Subsubsection",
  CellTags->"PropagatorDenominator"],
Cell[1971264, 61729, 569, 15, 70, "Text",
  CellTags->"PropagatorDenominator"],
Cell[1971836, 61746, 418, 14, 70, "Text",
  CellTags->"PropagatorDenominator"]
}, Closed]],

Cell[CellGroupData[{
Cell[1972291, 61765, 70, 1, 70, "Subsubsection",
  CellTags->"PropagatorDenominator"],

Cell[CellGroupData[{
Cell[1972386, 61770, 215, 5, 70, "Input",
  CellTags->"PropagatorDenominator"],
Cell[1972604, 61777, 227, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1972868, 61788, 164, 3, 70, "Input",
  CellTags->"PropagatorDenominator"],
Cell[1973035, 61793, 164, 4, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1973236, 61802, 247, 6, 70, "Input",
  CellTags->"PropagatorDenominator"],
Cell[1973486, 61810, 227, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1973750, 61821, 190, 4, 70, "Input",
  CellTags->"PropagatorDenominator"],
Cell[1973943, 61827, 241, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1974221, 61837, 231, 5, 70, "Input",
  CellTags->"PropagatorDenominator"],
Cell[1974455, 61844, 241, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1974733, 61854, 173, 3, 70, "Input",
  CellTags->"PropagatorDenominator"],
Cell[1974909, 61859, 282, 8, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1975228, 61872, 155, 3, 70, "Input",
  CellTags->"PropagatorDenominator"],
Cell[1975386, 61877, 356, 9, 70, "Output"]
}, Closed]],
Cell[1975757, 61889, 149, 3, 70, "Input",
  CellTags->"PropagatorDenominator"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1975955, 61898, 62, 1, 70, "ObjectName",
  CellTags->"QuantumField"],

Cell[CellGroupData[{
Cell[1976042, 61903, 64, 1, 70, "Subsubsection",
  CellTags->"QuantumField"],
Cell[1976109, 61906, 357, 7, 70, "Text",
  CellTags->"QuantumField"],
Cell[1976469, 61915, 454, 19, 70, "Text",
  CellTags->"QuantumField"]
}, Closed]],

Cell[CellGroupData[{
Cell[1976960, 61939, 61, 1, 70, "Subsubsection",
  CellTags->"QuantumField"],
Cell[1977024, 61942, 72, 1, 70, "Text",
  CellTags->"QuantumField"],

Cell[CellGroupData[{
Cell[1977121, 61947, 146, 3, 70, "Input",
  CellTags->"QuantumField"],
Cell[1977270, 61952, 109, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1977416, 61959, 159, 3, 70, "Input",
  CellTags->"QuantumField"],
Cell[1977578, 61964, 141, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1977756, 61972, 155, 3, 70, "Input",
  CellTags->"QuantumField"],
Cell[1977914, 61977, 114, 2, 70, "Output"]
}, Closed]],
Cell[1978043, 61982, 81, 1, 70, "Text",
  CellTags->"QuantumField"],

Cell[CellGroupData[{
Cell[1978149, 61987, 206, 5, 70, "Input",
  CellTags->"QuantumField"],
Cell[1978358, 61994, 139, 3, 70, "Output"]
}, Closed]],
Cell[1978512, 62000, 95, 1, 70, "Text",
  CellTags->"QuantumField"],

Cell[CellGroupData[{
Cell[1978632, 62005, 254, 6, 70, "Input",
  CellTags->"QuantumField"],
Cell[1978889, 62013, 392, 13, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1979318, 62031, 142, 3, 70, "Input",
  CellTags->"QuantumField"],
Cell[1979463, 62036, 269, 5, 70, "Output"]
}, Closed]],
Cell[1979747, 62044, 409, 14, 70, "Text",
  CellTags->"QuantumField"],

Cell[CellGroupData[{
Cell[1980181, 62062, 248, 6, 70, "Input",
  CellTags->"QuantumField"],
Cell[1980432, 62070, 304, 9, 70, "Output"]
}, Closed]],
Cell[1980751, 62082, 186, 4, 70, "Text",
  CellTags->"QuantumField"],

Cell[CellGroupData[{
Cell[1980962, 62090, 293, 7, 70, "Input",
  CellTags->"QuantumField"],
Cell[1981258, 62099, 259, 5, 70, "Output"]
}, Closed]],
Cell[1981532, 62107, 89, 1, 70, "Text",
  CellTags->"QuantumField"],

Cell[CellGroupData[{
Cell[1981646, 62112, 261, 6, 70, "Input",
  CellTags->"QuantumField"],
Cell[1981910, 62120, 433, 13, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1982380, 62138, 228, 6, 70, "Input",
  CellTags->"QuantumField"],
Cell[1982611, 62146, 291, 8, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1982939, 62159, 306, 7, 70, "Input",
  CellTags->"QuantumField"],
Cell[1983248, 62168, 496, 15, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1983781, 62188, 349, 9, 70, "Input",
  CellTags->"QuantumField"],
Cell[1984133, 62199, 504, 15, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1984674, 62219, 273, 6, 70, "Input",
  CellTags->"QuantumField"],
Cell[1984950, 62227, 112, 2, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1985123, 62236, 58, 1, 70, "ObjectName",
  CellTags->"QuarkField"],

Cell[CellGroupData[{
Cell[1985206, 62241, 62, 1, 70, "Subsubsection",
  CellTags->"QuarkField"],
Cell[1985271, 62244, 190, 4, 70, "Text",
  CellTags->"QuarkField"],
Cell[1985464, 62250, 344, 14, 70, "Text",
  CellTags->"QuarkField"]
}, Closed]],

Cell[CellGroupData[{
Cell[1985845, 62269, 59, 1, 70, "Subsubsection",
  CellTags->"QuarkField"],

Cell[CellGroupData[{
Cell[1985929, 62274, 112, 2, 70, "Input",
  CellTags->"QuarkField"],
Cell[1986044, 62278, 114, 2, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1986219, 62287, 70, 1, 70, "ObjectName",
  CellTags->"QuarkGluonVertex"],

Cell[CellGroupData[{
Cell[1986314, 62292, 68, 1, 70, "Subsubsection",
  CellTags->"QuarkGluonVertex"],
Cell[1986385, 62295, 233, 7, 70, "Text",
  CellTags->"QuarkGluonVertex"],

Cell[CellGroupData[{
Cell[1986643, 62306, 160, 3, 70, "Input",
  CellTags->"QuarkGluonVertex"],
Cell[1986806, 62311, 485, 11, 70, "Output"]
}, Closed]],
Cell[1987306, 62325, 209, 9, 70, "Text",
  CellTags->"QuarkGluonVertex"]
}, Closed]],

Cell[CellGroupData[{
Cell[1987552, 62339, 65, 1, 70, "Subsubsection",
  CellTags->"QuarkGluonVertex"],

Cell[CellGroupData[{
Cell[1987642, 62344, 185, 4, 70, "Input",
  CellTags->"QuarkGluonVertex"],
Cell[1987830, 62350, 516, 15, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1988383, 62370, 245, 5, 70, "Input",
  CellTags->"QuarkGluonVertex"],
Cell[1988631, 62377, 862, 24, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1989530, 62406, 245, 5, 70, "Input",
  CellTags->"QuarkGluonVertex"],
Cell[1989778, 62413, 725, 20, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1990540, 62438, 245, 5, 70, "Input",
  CellTags->"QuarkGluonVertex"],
Cell[1990788, 62445, 827, 23, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1991652, 62473, 373, 9, 70, "Input",
  CellTags->"QuarkGluonVertex"],
Cell[1992028, 62484, 2982, 75, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1995047, 62564, 374, 9, 70, "Input",
  CellTags->"QuarkGluonVertex"],
Cell[1995424, 62575, 516, 15, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1996001, 62597, 68, 1, 70, "ObjectName",
  CellTags->"QuarkPropagator"],

Cell[CellGroupData[{
Cell[1996094, 62602, 67, 1, 70, "Subsubsection",
  CellTags->"QuarkPropagator"],
Cell[1996164, 62605, 175, 4, 70, "Text",
  CellTags->"QuarkPropagator"],

Cell[CellGroupData[{
Cell[1996364, 62613, 158, 3, 70, "Input",
  CellTags->"QuarkPropagator"],
Cell[1996525, 62618, 535, 12, 70, "Output"]
}, Closed]],
Cell[1997075, 62633, 364, 14, 70, "Text",
  CellTags->"QuarkPropagator"]
}, Closed]],

Cell[CellGroupData[{
Cell[1997476, 62652, 64, 1, 70, "Subsubsection",
  CellTags->"QuarkPropagator"],

Cell[CellGroupData[{
Cell[1997565, 62657, 152, 3, 70, "Input",
  CellTags->"QuarkPropagator"],
Cell[1997720, 62662, 413, 11, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1998170, 62678, 208, 5, 70, "Input",
  CellTags->"QuarkPropagator"],
Cell[1998381, 62685, 564, 15, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1998982, 62705, 189, 4, 70, "Input",
  CellTags->"QuarkPropagator"],
Cell[1999174, 62711, 413, 11, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1999648, 62729, 64, 1, 70, "ObjectName",
  CellTags->"RightPartialD"],

Cell[CellGroupData[{
Cell[1999737, 62734, 65, 1, 70, "Subsubsection",
  CellTags->"RightPartialD"],
Cell[1999805, 62737, 275, 10, 70, "Text",
  CellTags->"RightPartialD"],
Cell[2000083, 62749, 467, 19, 70, "Text",
  CellTags->"RightPartialD"]
}, Closed]],

Cell[CellGroupData[{
Cell[2000587, 62773, 62, 1, 70, "Subsubsection",
  CellTags->"RightPartialD"],

Cell[CellGroupData[{
Cell[2000674, 62778, 152, 3, 70, "Input",
  CellTags->"RightPartialD"],
Cell[2000829, 62783, 288, 8, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2001154, 62796, 302, 7, 70, "Input",
  CellTags->"RightPartialD"],
Cell[2001459, 62805, 359, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2001855, 62820, 149, 3, 70, "Input",
  CellTags->"RightPartialD"],
Cell[2002007, 62825, 433, 13, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2002477, 62843, 143, 3, 70, "Input",
  CellTags->"RightPartialD"],
Cell[2002623, 62848, 311, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2002971, 62859, 198, 5, 70, "Input",
  CellTags->"RightPartialD"],
Cell[2003172, 62866, 181, 3, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2003414, 62876, 62, 1, 70, "ObjectName",
  CellTags->"RussianTrick"],

Cell[CellGroupData[{
Cell[2003501, 62881, 64, 1, 70, "Subsubsection",
  CellTags->"RussianTrick"],
Cell[2003568, 62884, 319, 6, 70, "Text",
  CellTags->"RussianTrick"],
Cell[2003890, 62892, 91, 1, 70, "Text",
  CellTags->"RussianTrick"],
Cell[2003984, 62895, 349, 14, 70, "Text",
  CellTags->"RussianTrick"]
}, Closed]],

Cell[CellGroupData[{
Cell[2004370, 62914, 61, 1, 70, "Subsubsection",
  CellTags->"RussianTrick"],

Cell[CellGroupData[{
Cell[2004456, 62919, 469, 13, 70, "Input",
  CellTags->"RussianTrick"],
Cell[2004928, 62934, 619, 20, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2005584, 62959, 136, 3, 70, "Input",
  CellTags->"RussianTrick"],
Cell[2005723, 62964, 1584, 45, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2007344, 63014, 209, 5, 70, "Input",
  CellTags->"RussianTrick"],
Cell[2007556, 63021, 9151, 244, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2016744, 63270, 140, 3, 70, "Input",
  CellTags->"RussianTrick"],
Cell[2016887, 63275, 3600, 110, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2020524, 63390, 167, 4, 70, "Input",
  CellTags->"RussianTrick"],
Cell[2020694, 63396, 4131, 111, 70, "Output"]
}, Closed]],
Cell[2024840, 63510, 139, 3, 70, "Input",
  CellTags->"RussianTrick"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2025028, 63519, 64, 1, 70, "ObjectName",
  CellTags->"ScalarProduct"],

Cell[CellGroupData[{
Cell[2025117, 63524, 65, 1, 70, "Subsubsection",
  CellTags->"ScalarProduct"],
Cell[2025185, 63527, 875, 21, 70, "Text",
  CellTags->"ScalarProduct"],
Cell[2026063, 63550, 799, 33, 70, "Text",
  CellTags->"ScalarProduct"]
}, Closed]],

Cell[CellGroupData[{
Cell[2026899, 63588, 62, 1, 70, "Subsubsection",
  CellTags->"ScalarProduct"],

Cell[CellGroupData[{
Cell[2026986, 63593, 175, 4, 70, "Input",
  CellTags->"ScalarProduct"],
Cell[2027164, 63599, 269, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2027470, 63611, 228, 6, 70, "Input",
  CellTags->"ScalarProduct"],
Cell[2027701, 63619, 433, 12, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2028171, 63636, 175, 4, 70, "Input",
  CellTags->"ScalarProduct"],
Cell[2028349, 63642, 184, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2028570, 63652, 148, 3, 70, "Input",
  CellTags->"ScalarProduct"],
Cell[2028721, 63657, 184, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2028942, 63667, 216, 5, 70, "Input",
  CellTags->"ScalarProduct"],
Cell[2029161, 63674, 234, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2029432, 63684, 278, 7, 70, "Input",
  CellTags->"ScalarProduct"],
Cell[2029713, 63693, 296, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2030046, 63705, 301, 8, 70, "Input",
  CellTags->"ScalarProduct"],
Cell[2030350, 63715, 134, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2030521, 63723, 358, 9, 70, "Input",
  CellTags->"ScalarProduct"],
Cell[2030882, 63734, 1175, 33, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2032094, 63772, 343, 9, 70, "Input",
  CellTags->"ScalarProduct"],
Cell[2032440, 63783, 1175, 33, 70, "Output"]
}, Closed]],
Cell[2033630, 63819, 124, 2, 70, "Input",
  CellTags->"ScalarProduct"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2033803, 63827, 76, 1, 70, "ObjectName",
  CellTags->"ScalarProductCancel"],

Cell[CellGroupData[{
Cell[2033904, 63832, 71, 1, 70, "Subsubsection",
  CellTags->"ScalarProductCancel"],
Cell[2033978, 63835, 187, 4, 70, "Text",
  CellTags->"ScalarProductCancel"],

Cell[CellGroupData[{
Cell[2034190, 63843, 114, 2, 70, "Input",
  CellTags->"ScalarProductCancel"],
Cell[2034307, 63847, 127, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2034471, 63854, 162, 3, 70, "Input",
  CellTags->"ScalarProductCancel"],
Cell[2034636, 63859, 422, 9, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2035095, 63873, 134, 3, 70, "Input",
  CellTags->"ScalarProductCancel"],
Cell[2035232, 63878, 119, 2, 70, "Print"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2035400, 63886, 68, 1, 70, "Subsubsection",
  CellTags->"ScalarProductCancel"],
Cell[2035471, 63889, 257, 9, 70, "Text",
  CellTags->"ScalarProductCancel"],

Cell[CellGroupData[{
Cell[2035753, 63902, 541, 15, 70, "Input",
  CellTags->"ScalarProductCancel"],
Cell[2036297, 63919, 576, 17, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2036910, 63941, 188, 4, 70, "Input",
  CellTags->"ScalarProductCancel"],
Cell[2037101, 63947, 1091, 32, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2038229, 63984, 194, 4, 70, "Input",
  CellTags->"ScalarProductCancel"],
Cell[2038426, 63990, 881, 26, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2039344, 64021, 217, 5, 70, "Input",
  CellTags->"ScalarProductCancel"],
Cell[2039564, 64028, 881, 26, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2040482, 64059, 714, 19, 70, "Input",
  CellTags->"ScalarProductCancel"],
Cell[2041199, 64080, 2045, 59, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2043281, 64144, 234, 5, 70, "Input",
  CellTags->"ScalarProductCancel"],
Cell[2043518, 64151, 6533, 175, 70, "Output"]
}, Closed]],
Cell[2050066, 64329, 199, 5, 70, "Input",
  CellTags->"ScalarProductCancel"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2050314, 64340, 42, 1, 70, "ObjectName",
  CellTags->"SD"],

Cell[CellGroupData[{
Cell[2050381, 64345, 54, 1, 70, "Subsubsection",
  CellTags->"SD"],
Cell[2050438, 64348, 218, 5, 70, "Text",
  CellTags->"SD"],
Cell[2050659, 64355, 186, 9, 70, "Text",
  CellTags->"SD"]
}, Closed]],

Cell[CellGroupData[{
Cell[2050882, 64369, 51, 1, 70, "Subsubsection",
  CellTags->"SD"],

Cell[CellGroupData[{
Cell[2050958, 64374, 153, 4, 70, "Input",
  CellTags->"SD"],
Cell[2051114, 64380, 180, 4, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2051331, 64389, 162, 4, 70, "Input",
  CellTags->"SD"],
Cell[2051496, 64395, 238, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2051771, 64405, 162, 4, 70, "Input",
  CellTags->"SD"],
Cell[2051936, 64411, 150, 3, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2052147, 64421, 58, 1, 70, "ObjectName",
  CellTags->"SelectFree"],

Cell[CellGroupData[{
Cell[2052230, 64426, 62, 1, 70, "Subsubsection",
  CellTags->"SelectFree"],
Cell[2052295, 64429, 256, 5, 70, "Text",
  CellTags->"SelectFree"],
Cell[2052554, 64436, 78, 1, 70, "Text",
  CellTags->"SelectFree"],
Cell[2052635, 64439, 323, 14, 70, "Text",
  CellTags->"SelectFree"]
}, Closed]],

Cell[CellGroupData[{
Cell[2052995, 64458, 59, 1, 70, "Subsubsection",
  CellTags->"SelectFree"],

Cell[CellGroupData[{
Cell[2053079, 64463, 261, 7, 70, "Input",
  CellTags->"SelectFree"],
Cell[2053343, 64472, 136, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2053516, 64480, 203, 5, 70, "Input",
  CellTags->"SelectFree"],
Cell[2053722, 64487, 109, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2053868, 64494, 329, 8, 70, "Input",
  CellTags->"SelectFree"],
Cell[2054200, 64504, 136, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2054373, 64512, 169, 4, 70, "Input",
  CellTags->"SelectFree"],
Cell[2054545, 64518, 109, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2054691, 64525, 169, 4, 70, "Input",
  CellTags->"SelectFree"],
Cell[2054863, 64531, 109, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2055009, 64538, 169, 4, 70, "Input",
  CellTags->"SelectFree"],
Cell[2055181, 64544, 109, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2055327, 64551, 203, 5, 70, "Input",
  CellTags->"SelectFree"],
Cell[2055533, 64558, 109, 2, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2055703, 64567, 64, 1, 70, "ObjectName",
  CellTags->"SelectNotFree"],

Cell[CellGroupData[{
Cell[2055792, 64572, 65, 1, 70, "Subsubsection",
  CellTags->"SelectNotFree"],
Cell[2055860, 64575, 144, 4, 70, "Text",
  CellTags->"SelectNotFree"],
Cell[2056007, 64581, 271, 5, 70, "Text",
  CellTags->"SelectNotFree"],
Cell[2056281, 64588, 84, 1, 70, "Text",
  CellTags->"SelectNotFree"],
Cell[2056368, 64591, 317, 14, 70, "Text",
  CellTags->"SelectNotFree"]
}, Closed]],

Cell[CellGroupData[{
Cell[2056722, 64610, 62, 1, 70, "Subsubsection",
  CellTags->"SelectNotFree"],

Cell[CellGroupData[{
Cell[2056809, 64615, 250, 6, 70, "Input",
  CellTags->"SelectNotFree"],
Cell[2057062, 64623, 170, 4, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2057269, 64632, 330, 8, 70, "Input",
  CellTags->"SelectNotFree"],
Cell[2057602, 64642, 180, 4, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2057819, 64651, 175, 4, 70, "Input",
  CellTags->"SelectNotFree"],
Cell[2057997, 64657, 109, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2058143, 64664, 204, 5, 70, "Input",
  CellTags->"SelectNotFree"],
Cell[2058350, 64671, 109, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2058496, 64678, 175, 4, 70, "Input",
  CellTags->"SelectNotFree"],
Cell[2058674, 64684, 109, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2058820, 64691, 175, 4, 70, "Input",
  CellTags->"SelectNotFree"],
Cell[2058998, 64697, 109, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2059144, 64704, 209, 5, 70, "Input",
  CellTags->"SelectNotFree"],
Cell[2059356, 64711, 141, 3, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2059558, 64721, 52, 1, 70, "ObjectName",
  CellTags->"Series2"],

Cell[CellGroupData[{
Cell[2059635, 64726, 59, 1, 70, "Subsubsection",
  CellTags->"Series2"],
Cell[2059697, 64729, 295, 6, 70, "Text",
  CellTags->"Series2"],

Cell[CellGroupData[{
Cell[2060017, 64739, 142, 3, 70, "Input",
  CellTags->"Series2"],
Cell[2060162, 64744, 535, 13, 70, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2060746, 64763, 56, 1, 70, "Subsubsection",
  CellTags->"Series2"],

Cell[CellGroupData[{
Cell[2060827, 64768, 425, 12, 70, "Input",
  CellTags->"Series2"],
Cell[2061255, 64782, 363, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2061655, 64797, 218, 6, 70, "Input",
  CellTags->"Series2"],
Cell[2061876, 64805, 260, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2062173, 64817, 270, 7, 70, "Input",
  CellTags->"Series2"],
Cell[2062446, 64826, 384, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2062867, 64841, 218, 6, 70, "Input",
  CellTags->"Series2"],
Cell[2063088, 64849, 563, 16, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2063688, 64870, 346, 8, 70, "Input",
  CellTags->"Series2"],
Cell[2064037, 64880, 1381, 36, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2065455, 64921, 369, 10, 70, "Input",
  CellTags->"Series2"],
Cell[2065827, 64933, 1292, 35, 70, "Output"]
}, Closed]],
Cell[2067134, 64971, 114, 3, 70, "Text",
  CellTags->"Series2"],

Cell[CellGroupData[{
Cell[2067273, 64978, 672, 18, 70, "Input",
  CellTags->"Series2"],
Cell[2067948, 64998, 698, 20, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2068683, 65023, 799, 20, 70, "Input",
  CellTags->"Series2"],
Cell[2069485, 65045, 1404, 40, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2070926, 65090, 285, 6, 70, "Input",
  CellTags->"Series2"],
Cell[2071214, 65098, 1798, 48, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2073049, 65151, 239, 6, 70, "Input",
  CellTags->"Series2"],
Cell[2073291, 65159, 2793, 71, 70, "Output"]
}, Closed]],
Cell[2076099, 65233, 355, 10, 70, "Text",
  CellTags->"Series2"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2076503, 65249, 80, 1, 70, "ObjectName",
  CellTags->"SimplifyDeltaFunction"],

Cell[CellGroupData[{
Cell[2076608, 65254, 73, 1, 70, "Subsubsection",
  CellTags->"SimplifyDeltaFunction"],
Cell[2076684, 65257, 295, 6, 70, "Text",
  CellTags->"SimplifyDeltaFunction"],
Cell[2076982, 65265, 370, 14, 70, "Text",
  CellTags->"SimplifyDeltaFunction"]
}, Closed]],

Cell[CellGroupData[{
Cell[2077389, 65284, 70, 1, 70, "Subsubsection",
  CellTags->"SimplifyDeltaFunction"],

Cell[CellGroupData[{
Cell[2077484, 65289, 244, 6, 70, "Input",
  CellTags->"SimplifyDeltaFunction"],
Cell[2077731, 65297, 295, 8, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2078063, 65310, 196, 4, 70, "Input",
  CellTags->"SimplifyDeltaFunction"],
Cell[2078262, 65316, 454, 13, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2078753, 65334, 244, 6, 70, "Input",
  CellTags->"SimplifyDeltaFunction"],
Cell[2079000, 65342, 334, 9, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2079371, 65356, 196, 4, 70, "Input",
  CellTags->"SimplifyDeltaFunction"],
Cell[2079570, 65362, 988, 27, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2080595, 65394, 261, 6, 70, "Input",
  CellTags->"SimplifyDeltaFunction"],
Cell[2080859, 65402, 346, 9, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2081242, 65416, 196, 4, 70, "Input",
  CellTags->"SimplifyDeltaFunction"],
Cell[2081441, 65422, 226, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2081704, 65433, 315, 8, 70, "Input",
  CellTags->"SimplifyDeltaFunction"],
Cell[2082022, 65443, 396, 11, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2082455, 65459, 196, 4, 70, "Input",
  CellTags->"SimplifyDeltaFunction"],
Cell[2082654, 65465, 256, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2082947, 65477, 354, 9, 70, "Input",
  CellTags->"SimplifyDeltaFunction"],
Cell[2083304, 65488, 442, 12, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2083783, 65505, 196, 4, 70, "Input",
  CellTags->"SimplifyDeltaFunction"],
Cell[2083982, 65511, 109, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2084128, 65518, 315, 8, 70, "Input",
  CellTags->"SimplifyDeltaFunction"],
Cell[2084446, 65528, 396, 11, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2084879, 65544, 196, 4, 70, "Input",
  CellTags->"SimplifyDeltaFunction"],
Cell[2085078, 65550, 256, 7, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2085395, 65564, 68, 1, 70, "ObjectName",
  CellTags->"SimplifyPolyLog"],

Cell[CellGroupData[{
Cell[2085488, 65569, 67, 1, 70, "Subsubsection",
  CellTags->"SimplifyPolyLog"],
Cell[2085558, 65572, 200, 4, 70, "Text",
  CellTags->"SimplifyPolyLog"],
Cell[2085761, 65578, 196, 9, 70, "Text",
  CellTags->"SimplifyPolyLog"]
}, Closed]],

Cell[CellGroupData[{
Cell[2085994, 65592, 64, 1, 70, "Subsubsection",
  CellTags->"SimplifyPolyLog"],
Cell[2086061, 65595, 265, 6, 70, "Input",
  CellTags->"SimplifyPolyLog"],

Cell[CellGroupData[{
Cell[2086351, 65605, 238, 6, 70, "Input",
  CellTags->"SimplifyPolyLog"],
Cell[2086592, 65613, 845, 22, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2087474, 65640, 207, 5, 70, "Input",
  CellTags->"SimplifyPolyLog"],
Cell[2087684, 65647, 531, 14, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2088252, 65666, 271, 7, 70, "Input",
  CellTags->"SimplifyPolyLog"],
Cell[2088526, 65675, 815, 22, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2089378, 65702, 238, 6, 70, "Input",
  CellTags->"SimplifyPolyLog"],
Cell[2089619, 65710, 787, 21, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2090443, 65736, 338, 9, 70, "Input",
  CellTags->"SimplifyPolyLog"],
Cell[2090784, 65747, 836, 23, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2091657, 65775, 306, 8, 70, "Input",
  CellTags->"SimplifyPolyLog"],
Cell[2091966, 65785, 806, 22, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2092809, 65812, 348, 9, 70, "Input",
  CellTags->"SimplifyPolyLog"],
Cell[2093160, 65823, 957, 29, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2094154, 65857, 266, 7, 70, "Input",
  CellTags->"SimplifyPolyLog"],
Cell[2094423, 65866, 615, 17, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2095075, 65888, 238, 6, 70, "Input",
  CellTags->"SimplifyPolyLog"],
Cell[2095316, 65896, 112, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2095465, 65903, 238, 6, 70, "Input",
  CellTags->"SimplifyPolyLog"],
Cell[2095706, 65911, 1563, 43, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2097306, 65959, 338, 9, 70, "Input",
  CellTags->"SimplifyPolyLog"],
Cell[2097647, 65970, 1876, 51, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2099560, 66026, 271, 7, 70, "Input",
  CellTags->"SimplifyPolyLog"],
Cell[2099834, 66035, 1795, 50, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2101666, 66090, 338, 9, 70, "Input",
  CellTags->"SimplifyPolyLog"],
Cell[2102007, 66101, 3746, 102, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2105790, 66208, 234, 6, 70, "Input",
  CellTags->"SimplifyPolyLog"],
Cell[2106027, 66216, 375, 11, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2106439, 66232, 203, 5, 70, "Input",
  CellTags->"SimplifyPolyLog"],
Cell[2106645, 66239, 264, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2106946, 66251, 178, 4, 70, "Input",
  CellTags->"SimplifyPolyLog"],
Cell[2107127, 66257, 472, 14, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2107636, 66276, 178, 4, 70, "Input",
  CellTags->"SimplifyPolyLog"],
Cell[2107817, 66282, 403, 12, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2108257, 66299, 178, 4, 70, "Input",
  CellTags->"SimplifyPolyLog"],
Cell[2108438, 66305, 403, 12, 70, "Output"]
}, Closed]],
Cell[2108856, 66320, 144, 3, 70, "Input",
  CellTags->"SimplifyPolyLog"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2109049, 66329, 44, 1, 70, "ObjectName",
  CellTags->"SOD"],

Cell[CellGroupData[{
Cell[2109118, 66334, 55, 1, 70, "Subsubsection",
  CellTags->"SOD"],
Cell[2109176, 66337, 192, 5, 70, "Text",
  CellTags->"SOD"],
Cell[2109371, 66344, 535, 24, 70, "Text",
  CellTags->"SOD"]
}, Closed]],

Cell[CellGroupData[{
Cell[2109943, 66373, 52, 1, 70, "Subsubsection",
  CellTags->"SOD"],

Cell[CellGroupData[{
Cell[2110020, 66378, 128, 3, 70, "Input",
  CellTags->"SOD"],
Cell[2110151, 66383, 318, 9, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2110506, 66397, 155, 4, 70, "Input",
  CellTags->"SOD"],
Cell[2110664, 66403, 469, 14, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2111170, 66422, 206, 6, 70, "Input",
  CellTags->"SOD"],
Cell[2111379, 66430, 303, 7, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2111743, 66444, 50, 1, 70, "ObjectName",
  CellTags->"Solve2"],

Cell[CellGroupData[{
Cell[2111818, 66449, 58, 1, 70, "Subsubsection",
  CellTags->"Solve2"],
Cell[2111879, 66452, 346, 7, 70, "Text",
  CellTags->"Solve2"],

Cell[CellGroupData[{
Cell[2112250, 66463, 140, 3, 70, "Input",
  CellTags->"Solve2"],
Cell[2112393, 66468, 298, 7, 70, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2112740, 66481, 55, 1, 70, "Subsubsection",
  CellTags->"Solve2"],

Cell[CellGroupData[{
Cell[2112820, 66486, 491, 14, 70, "Input",
  CellTags->"Solve2"],
Cell[2113314, 66502, 449, 12, 70, "Output"]
}, Closed]],
Cell[2113778, 66517, 112, 3, 70, "Text",
  CellTags->"Solve2"],

Cell[CellGroupData[{
Cell[2113915, 66524, 190, 5, 70, "Input",
  CellTags->"Solve2"],
Cell[2114108, 66531, 197, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2114342, 66541, 322, 8, 70, "Input",
  CellTags->"Solve2"],
Cell[2114667, 66551, 197, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2114901, 66561, 549, 15, 70, "Input",
  CellTags->"Solve2"],
Cell[2115453, 66578, 371, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2115861, 66593, 490, 14, 70, "Input",
  CellTags->"Solve2"],
Cell[2116354, 66609, 503, 14, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2116918, 66630, 42, 1, 70, "ObjectName",
  CellTags->"SO"],

Cell[CellGroupData[{
Cell[2116985, 66635, 54, 1, 70, "Subsubsection",
  CellTags->"SO"],
Cell[2117042, 66638, 174, 4, 70, "Text",
  CellTags->"SO"],
Cell[2117219, 66644, 632, 28, 70, "Text",
  CellTags->"SO"]
}, Closed]],

Cell[CellGroupData[{
Cell[2117888, 66677, 51, 1, 70, "Subsubsection",
  CellTags->"SO"],

Cell[CellGroupData[{
Cell[2117964, 66682, 126, 3, 70, "Input",
  CellTags->"SO"],
Cell[2118093, 66687, 318, 9, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2118448, 66701, 153, 4, 70, "Input",
  CellTags->"SO"],
Cell[2118604, 66707, 469, 14, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2119110, 66726, 204, 6, 70, "Input",
  CellTags->"SO"],
Cell[2119317, 66734, 241, 5, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2119619, 66746, 42, 1, 70, "ObjectName",
  CellTags->"SP"],

Cell[CellGroupData[{
Cell[2119686, 66751, 54, 1, 70, "Subsubsection",
  CellTags->"SP"],
Cell[2119743, 66754, 353, 11, 70, "Text",
  CellTags->"SP"],
Cell[2120099, 66767, 462, 19, 70, "Text",
  CellTags->"SP"]
}, Closed]],

Cell[CellGroupData[{
Cell[2120598, 66791, 51, 1, 70, "Subsubsection",
  CellTags->"SP"],

Cell[CellGroupData[{
Cell[2120674, 66796, 225, 6, 70, "Input",
  CellTags->"SP"],
Cell[2120902, 66804, 510, 16, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2121449, 66825, 237, 7, 70, "Input",
  CellTags->"SP"],
Cell[2121689, 66834, 451, 12, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2122177, 66851, 290, 8, 70, "Input",
  CellTags->"SP"],
Cell[2122470, 66861, 513, 15, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2123020, 66881, 205, 5, 70, "Input",
  CellTags->"SP"],
Cell[2123228, 66888, 530, 16, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2123795, 66909, 194, 5, 70, "Input",
  CellTags->"SP"],
Cell[2123992, 66916, 150, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2124179, 66924, 235, 7, 70, "Input",
  CellTags->"SP"],
Cell[2124417, 66933, 234, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2124688, 66943, 271, 8, 70, "Input",
  CellTags->"SP"],
Cell[2124962, 66953, 150, 3, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2125173, 66963, 44, 1, 70, "ObjectName",
  CellTags->"SPD"],

Cell[CellGroupData[{
Cell[2125242, 66968, 55, 1, 70, "Subsubsection",
  CellTags->"SPD"],
Cell[2125300, 66971, 372, 11, 70, "Text",
  CellTags->"SPD"],
Cell[2125675, 66984, 463, 19, 70, "Text",
  CellTags->"SPD"]
}, Closed]],

Cell[CellGroupData[{
Cell[2126175, 67008, 52, 1, 70, "Subsubsection",
  CellTags->"SPD"],

Cell[CellGroupData[{
Cell[2126252, 67013, 228, 6, 70, "Input",
  CellTags->"SPD"],
Cell[2126483, 67021, 510, 16, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2127030, 67042, 239, 7, 70, "Input",
  CellTags->"SPD"],
Cell[2127272, 67051, 451, 12, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2127760, 67068, 292, 8, 70, "Input",
  CellTags->"SPD"],
Cell[2128055, 67078, 513, 15, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2128605, 67098, 207, 5, 70, "Input",
  CellTags->"SPD"],
Cell[2128815, 67105, 530, 16, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2129382, 67126, 196, 5, 70, "Input",
  CellTags->"SPD"],
Cell[2129581, 67133, 151, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2129769, 67141, 237, 7, 70, "Input",
  CellTags->"SPD"],
Cell[2130009, 67150, 296, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2130342, 67162, 273, 8, 70, "Input",
  CellTags->"SPD"],
Cell[2130618, 67172, 151, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2130806, 67180, 332, 9, 70, "Input",
  CellTags->"SPD"],
Cell[2131141, 67191, 151, 3, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2131353, 67201, 50, 1, 70, "ObjectName",
  CellTags->"Spinor"],

Cell[CellGroupData[{
Cell[2131428, 67206, 58, 1, 70, "Subsubsection",
  CellTags->"Spinor"],
Cell[2131489, 67209, 688, 20, 70, "Text",
  CellTags->"Spinor"],
Cell[2132180, 67231, 691, 29, 70, "Text",
  CellTags->"Spinor"]
}, Closed]],

Cell[CellGroupData[{
Cell[2132908, 67265, 55, 1, 70, "Subsubsection",
  CellTags->"Spinor"],

Cell[CellGroupData[{
Cell[2132988, 67270, 134, 3, 70, "Input",
  CellTags->"Spinor"],
Cell[2133125, 67275, 242, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2133404, 67286, 161, 4, 70, "Input",
  CellTags->"Spinor"],
Cell[2133568, 67292, 287, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2133892, 67303, 309, 8, 70, "Input",
  CellTags->"Spinor"],
Cell[2134204, 67313, 374, 9, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2134615, 67327, 173, 4, 70, "Input",
  CellTags->"Spinor"],
Cell[2134791, 67333, 212, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2135040, 67343, 259, 7, 70, "Input",
  CellTags->"Spinor"],
Cell[2135302, 67352, 212, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2135551, 67362, 202, 5, 70, "Input",
  CellTags->"Spinor"],
Cell[2135756, 67369, 212, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2136005, 67379, 257, 7, 70, "Input",
  CellTags->"Spinor"],
Cell[2136265, 67388, 212, 5, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2136538, 67400, 58, 1, 70, "ObjectName",
  CellTags->"SpinorUBar"],

Cell[CellGroupData[{
Cell[2136621, 67405, 62, 1, 70, "Subsubsection",
  CellTags->"SpinorUBar"],
Cell[2136686, 67408, 185, 7, 70, "Text",
  CellTags->"SpinorUBar"],
Cell[2136874, 67417, 548, 24, 70, "Text",
  CellTags->"SpinorUBar"]
}, Closed]],

Cell[CellGroupData[{
Cell[2137459, 67446, 59, 1, 70, "Subsubsection",
  CellTags->"SpinorUBar"],
Cell[2137521, 67449, 86, 1, 70, "Text",
  CellTags->"SpinorUBar"],

Cell[CellGroupData[{
Cell[2137632, 67454, 142, 3, 70, "Input",
  CellTags->"SpinorUBar"],
Cell[2137777, 67459, 278, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2138092, 67471, 169, 4, 70, "Input",
  CellTags->"SpinorUBar"],
Cell[2138264, 67477, 323, 8, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2138624, 67490, 210, 5, 70, "Input",
  CellTags->"SpinorUBar"],
Cell[2138837, 67497, 158, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2139032, 67505, 251, 7, 70, "Input",
  CellTags->"SpinorUBar"],
Cell[2139286, 67514, 212, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2139535, 67524, 287, 8, 70, "Input",
  CellTags->"SpinorUBar"],
Cell[2139825, 67534, 212, 5, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2140098, 67546, 52, 1, 70, "ObjectName",
  CellTags->"SpinorU"],

Cell[CellGroupData[{
Cell[2140175, 67551, 59, 1, 70, "Subsubsection",
  CellTags->"SpinorU"],
Cell[2140237, 67554, 80, 1, 70, "Text",
  CellTags->"SpinorU"],
Cell[2140320, 67557, 554, 24, 70, "Text",
  CellTags->"SpinorU"]
}, Closed]],

Cell[CellGroupData[{
Cell[2140911, 67586, 56, 1, 70, "Subsubsection",
  CellTags->"SpinorU"],

Cell[CellGroupData[{
Cell[2140992, 67591, 136, 3, 70, "Input",
  CellTags->"SpinorU"],
Cell[2141131, 67596, 190, 4, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2141358, 67605, 163, 4, 70, "Input",
  CellTags->"SpinorU"],
Cell[2141524, 67611, 237, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2141798, 67621, 204, 5, 70, "Input",
  CellTags->"SpinorU"],
Cell[2142005, 67628, 155, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2142197, 67636, 245, 7, 70, "Input",
  CellTags->"SpinorU"],
Cell[2142445, 67645, 212, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2142694, 67655, 281, 8, 70, "Input",
  CellTags->"SpinorU"],
Cell[2142978, 67665, 212, 5, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2143251, 67677, 58, 1, 70, "ObjectName",
  CellTags->"SpinorVBar"],

Cell[CellGroupData[{
Cell[2143334, 67682, 62, 1, 70, "Subsubsection",
  CellTags->"SpinorVBar"],
Cell[2143399, 67685, 190, 7, 70, "Text",
  CellTags->"SpinorVBar"],
Cell[2143592, 67694, 548, 24, 70, "Text",
  CellTags->"SpinorVBar"]
}, Closed]],

Cell[CellGroupData[{
Cell[2144177, 67723, 59, 1, 70, "Subsubsection",
  CellTags->"SpinorVBar"],

Cell[CellGroupData[{
Cell[2144261, 67728, 142, 3, 70, "Input",
  CellTags->"SpinorVBar"],
Cell[2144406, 67733, 278, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2144721, 67745, 169, 4, 70, "Input",
  CellTags->"SpinorVBar"],
Cell[2144893, 67751, 323, 8, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2145253, 67764, 210, 5, 70, "Input",
  CellTags->"SpinorVBar"],
Cell[2145466, 67771, 158, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2145661, 67779, 251, 7, 70, "Input",
  CellTags->"SpinorVBar"],
Cell[2145915, 67788, 238, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2146190, 67799, 287, 8, 70, "Input",
  CellTags->"SpinorVBar"],
Cell[2146480, 67809, 238, 6, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2146779, 67822, 52, 1, 70, "ObjectName",
  CellTags->"SpinorV"],

Cell[CellGroupData[{
Cell[2146856, 67827, 59, 1, 70, "Subsubsection",
  CellTags->"SpinorV"],
Cell[2146918, 67830, 80, 1, 70, "Text",
  CellTags->"SpinorV"],
Cell[2147001, 67833, 554, 24, 70, "Text",
  CellTags->"SpinorV"]
}, Closed]],

Cell[CellGroupData[{
Cell[2147592, 67862, 56, 1, 70, "Subsubsection",
  CellTags->"SpinorV"],

Cell[CellGroupData[{
Cell[2147673, 67867, 136, 3, 70, "Input",
  CellTags->"SpinorV"],
Cell[2147812, 67872, 190, 4, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2148039, 67881, 163, 4, 70, "Input",
  CellTags->"SpinorV"],
Cell[2148205, 67887, 237, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2148479, 67897, 204, 5, 70, "Input",
  CellTags->"SpinorV"],
Cell[2148686, 67904, 155, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2148878, 67912, 245, 7, 70, "Input",
  CellTags->"SpinorV"],
Cell[2149126, 67921, 238, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2149401, 67932, 281, 8, 70, "Input",
  CellTags->"SpinorV"],
Cell[2149685, 67942, 238, 6, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2149984, 67955, 72, 1, 70, "ObjectName",
  CellTags->"SplittingFunction"],

Cell[CellGroupData[{
Cell[2150081, 67960, 69, 1, 70, "Subsubsection",
  CellTags->"SplittingFunction"],
Cell[2150153, 67963, 231, 7, 70, "Text",
  CellTags->"SplittingFunction"],

Cell[CellGroupData[{
Cell[2150409, 67974, 162, 3, 70, "Input",
  CellTags->"SplittingFunction"],
Cell[2150574, 67979, 189, 5, 70, "Output"]
}, Closed]],
Cell[2150778, 67987, 231, 9, 70, "Text",
  CellTags->"SplittingFunction"]
}, Closed]],

Cell[CellGroupData[{
Cell[2151046, 68001, 66, 1, 70, "Subsubsection",
  CellTags->"SplittingFunction"],
Cell[2151115, 68004, 66, 1, 70, "Text",
  CellTags->"SplittingFunction"],
Cell[2151184, 68007, 264, 6, 70, "Input",
  CellTags->"SplittingFunction"],
Cell[2151451, 68015, 171, 4, 70, "Text",
  CellTags->"SplittingFunction"],

Cell[CellGroupData[{
Cell[2151647, 68023, 158, 3, 70, "Input",
  CellTags->"SplittingFunction"],
Cell[2151808, 68028, 682, 19, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2152527, 68052, 158, 3, 70, "Input",
  CellTags->"SplittingFunction"],
Cell[2152688, 68057, 345, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2153070, 68072, 158, 3, 70, "Input",
  CellTags->"SplittingFunction"],
Cell[2153231, 68077, 298, 8, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2153566, 68090, 158, 3, 70, "Input",
  CellTags->"SplittingFunction"],
Cell[2153727, 68095, 1059, 28, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2154823, 68128, 158, 3, 70, "Input",
  CellTags->"SplittingFunction"],
Cell[2154984, 68133, 1456, 38, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2156477, 68176, 158, 3, 70, "Input",
  CellTags->"SplittingFunction"],
Cell[2156638, 68181, 737, 20, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2157412, 68206, 158, 3, 70, "Input",
  CellTags->"SplittingFunction"],
Cell[2157573, 68211, 667, 18, 70, "Output"]
}, Closed]],
Cell[2158255, 68232, 158, 3, 70, "Input",
  CellTags->"SplittingFunction"],
Cell[2158416, 68237, 64, 1, 70, "Text",
  CellTags->"SplittingFunction"],
Cell[2158483, 68240, 264, 6, 70, "Input",
  CellTags->"SplittingFunction"],

Cell[CellGroupData[{
Cell[2158772, 68250, 158, 3, 70, "Input",
  CellTags->"SplittingFunction"],
Cell[2158933, 68255, 682, 19, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2159652, 68279, 158, 3, 70, "Input",
  CellTags->"SplittingFunction"],
Cell[2159813, 68284, 265, 8, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2160115, 68297, 158, 3, 70, "Input",
  CellTags->"SplittingFunction"],
Cell[2160276, 68302, 257, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2160570, 68314, 158, 3, 70, "Input",
  CellTags->"SplittingFunction"],
Cell[2160731, 68319, 1051, 29, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2161819, 68353, 158, 3, 70, "Input",
  CellTags->"SplittingFunction"],
Cell[2161980, 68358, 1591, 42, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2163608, 68405, 158, 3, 70, "Input",
  CellTags->"SplittingFunction"],
Cell[2163769, 68410, 613, 17, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2164419, 68432, 159, 3, 70, "Input",
  CellTags->"SplittingFunction"],
Cell[2164581, 68437, 540, 15, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2165158, 68457, 158, 3, 70, "Input",
  CellTags->"SplittingFunction"],
Cell[2165319, 68462, 540, 15, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2165896, 68482, 159, 3, 70, "Input",
  CellTags->"SplittingFunction"],
Cell[2166058, 68487, 540, 15, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2166635, 68507, 158, 3, 70, "Input",
  CellTags->"SplittingFunction"],
Cell[2166796, 68512, 1782, 46, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2168615, 68563, 159, 3, 70, "Input",
  CellTags->"SplittingFunction"],
Cell[2168777, 68568, 1782, 46, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2170596, 68619, 159, 3, 70, "Input",
  CellTags->"SplittingFunction"],
Cell[2170758, 68624, 799, 22, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2171594, 68651, 160, 3, 70, "Input",
  CellTags->"SplittingFunction"],
Cell[2171757, 68656, 7281, 177, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2179075, 68838, 158, 3, 70, "Input",
  CellTags->"SplittingFunction"],
Cell[2179236, 68843, 3749, 94, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2183022, 68942, 158, 3, 70, "Input",
  CellTags->"SplittingFunction"],
Cell[2183183, 68947, 4649, 118, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2187869, 69070, 158, 3, 70, "Input",
  CellTags->"SplittingFunction"],
Cell[2188030, 69075, 5663, 141, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2193754, 69223, 46, 1, 70, "ObjectName",
  CellTags->"SumP"],

Cell[CellGroupData[{
Cell[2193825, 69228, 56, 1, 70, "Subsubsection",
  CellTags->"SumP"],
Cell[2193884, 69231, 641, 20, 70, "Text",
  CellTags->"SumP"],
Cell[2194528, 69253, 284, 14, 70, "Text",
  CellTags->"SumP"]
}, Closed]],

Cell[CellGroupData[{
Cell[2194849, 69272, 53, 1, 70, "Subsubsection",
  CellTags->"SumP"],

Cell[CellGroupData[{
Cell[2194927, 69277, 186, 5, 70, "Input",
  CellTags->"SumP"],
Cell[2195116, 69284, 301, 8, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2195454, 69297, 186, 5, 70, "Input",
  CellTags->"SumP"],
Cell[2195643, 69304, 301, 8, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2195981, 69317, 157, 4, 70, "Input",
  CellTags->"SumP"],
Cell[2196141, 69323, 270, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2196448, 69335, 157, 4, 70, "Input",
  CellTags->"SumP"],
Cell[2196608, 69341, 136, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2196781, 69349, 384, 12, 70, "Input",
  CellTags->"SumP"],
Cell[2197168, 69363, 136, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2197341, 69371, 229, 6, 70, "Input",
  CellTags->"SumP"],
Cell[2197573, 69379, 963, 28, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2198573, 69412, 156, 4, 70, "Input",
  CellTags->"SumP"],
Cell[2198732, 69418, 136, 3, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2198929, 69428, 46, 1, 70, "ObjectName",
  CellTags->"SumS"],

Cell[CellGroupData[{
Cell[2199000, 69433, 56, 1, 70, "Subsubsection",
  CellTags->"SumS"],
Cell[2199059, 69436, 1267, 39, 70, "Text",
  CellTags->"SumS"],

Cell[CellGroupData[{
Cell[2200351, 69479, 136, 3, 70, "Input",
  CellTags->"SumS"],
Cell[2200490, 69484, 187, 5, 70, "Output"]
}, Closed]],
Cell[2200692, 69492, 284, 14, 70, "Text",
  CellTags->"SumS"]
}, Closed]],

Cell[CellGroupData[{
Cell[2201013, 69511, 53, 1, 70, "Subsubsection",
  CellTags->"SumS"],

Cell[CellGroupData[{
Cell[2201091, 69516, 186, 5, 70, "Input",
  CellTags->"SumS"],
Cell[2201280, 69523, 247, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2201564, 69535, 186, 5, 70, "Input",
  CellTags->"SumS"],
Cell[2201753, 69542, 247, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2202037, 69554, 181, 5, 70, "Input",
  CellTags->"SumS"],
Cell[2202221, 69561, 195, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2202453, 69571, 210, 5, 70, "Input",
  CellTags->"SumS"],
Cell[2202666, 69578, 311, 9, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2203014, 69592, 239, 6, 70, "Input",
  CellTags->"SumS"],
Cell[2203256, 69600, 418, 13, 70, "Output"]
}, Closed]],
Cell[2203689, 69616, 235, 6, 70, "Input",
  CellTags->"SumS"],

Cell[CellGroupData[{
Cell[2203949, 69626, 186, 5, 70, "Input",
  CellTags->"SumS"],
Cell[2204138, 69633, 624, 19, 70, "Output"]
}, Closed]],
Cell[2204777, 69655, 236, 6, 70, "Input",
  CellTags->"SumS"],

Cell[CellGroupData[{
Cell[2205038, 69665, 157, 4, 70, "Input",
  CellTags->"SumS"],
Cell[2205198, 69671, 136, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2205371, 69679, 215, 6, 70, "Input",
  CellTags->"SumS"],
Cell[2205589, 69687, 136, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2205762, 69695, 196, 5, 70, "Input",
  CellTags->"SumS"],
Cell[2205961, 69702, 248, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2206246, 69714, 178, 4, 70, "Input",
  CellTags->"SumS"],
Cell[2206427, 69720, 166, 4, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2206630, 69729, 181, 5, 70, "Input",
  CellTags->"SumS"],
Cell[2206814, 69736, 159, 4, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2207010, 69745, 157, 4, 70, "Input",
  CellTags->"SumS"],
Cell[2207170, 69751, 159, 4, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2207390, 69762, 46, 1, 70, "ObjectName",
  CellTags->"SumT"],

Cell[CellGroupData[{
Cell[2207461, 69767, 56, 1, 70, "Subsubsection",
  CellTags->"SumT"],
Cell[2207520, 69770, 536, 15, 70, "Text",
  CellTags->"SumT"],
Cell[2208059, 69787, 284, 14, 70, "Text",
  CellTags->"SumT"]
}, Closed]],

Cell[CellGroupData[{
Cell[2208380, 69806, 53, 1, 70, "Subsubsection",
  CellTags->"SumT"],

Cell[CellGroupData[{
Cell[2208458, 69811, 186, 5, 70, "Input",
  CellTags->"SumT"],
Cell[2208647, 69818, 278, 8, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2208962, 69831, 186, 5, 70, "Input",
  CellTags->"SumT"],
Cell[2209151, 69838, 278, 8, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2209466, 69851, 157, 4, 70, "Input",
  CellTags->"SumT"],
Cell[2209626, 69857, 207, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2209870, 69868, 210, 5, 70, "Input",
  CellTags->"SumT"],
Cell[2210083, 69875, 446, 14, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2210566, 69894, 157, 4, 70, "Input",
  CellTags->"SumT"],
Cell[2210726, 69900, 159, 4, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2210922, 69909, 303, 9, 70, "Input",
  CellTags->"SumT"],
Cell[2211228, 69920, 159, 4, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2211424, 69929, 196, 5, 70, "Input",
  CellTags->"SumT"],
Cell[2211623, 69936, 279, 8, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2211939, 69949, 168, 4, 70, "Input",
  CellTags->"SumT"],
Cell[2212110, 69955, 280, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2212427, 69966, 157, 4, 70, "Input",
  CellTags->"SumT"],
Cell[2212587, 69972, 159, 4, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2212783, 69981, 181, 5, 70, "Input",
  CellTags->"SumT"],
Cell[2212967, 69988, 159, 4, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2213163, 69997, 332, 10, 70, "Input",
  CellTags->"SumT"],
Cell[2213498, 70009, 899, 26, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2214434, 70040, 168, 4, 70, "Input",
  CellTags->"SumT"],
Cell[2214605, 70046, 191, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2214833, 70056, 192, 5, 70, "Input",
  CellTags->"SumT"],
Cell[2215028, 70063, 280, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2215345, 70074, 161, 4, 70, "Input",
  CellTags->"SumT"],
Cell[2215509, 70080, 553, 16, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2216099, 70101, 304, 9, 70, "Input",
  CellTags->"SumT"],
Cell[2216406, 70112, 553, 16, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2217020, 70135, 54, 1, 70, "ObjectName",
  CellTags->"SUNDelta"],

Cell[CellGroupData[{
Cell[2217099, 70140, 60, 1, 70, "Subsubsection",
  CellTags->"SUNDelta"],
Cell[2217162, 70143, 123, 3, 70, "Text",
  CellTags->"SUNDelta"],
Cell[2217288, 70148, 779, 33, 70, "Text",
  CellTags->"SUNDelta"]
}, Closed]],

Cell[CellGroupData[{
Cell[2218104, 70186, 57, 1, 70, "Subsubsection",
  CellTags->"SUNDelta"],

Cell[CellGroupData[{
Cell[2218186, 70191, 165, 4, 70, "Input",
  CellTags->"SUNDelta"],
Cell[2218354, 70197, 180, 4, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2218571, 70206, 316, 8, 70, "Input",
  CellTags->"SUNDelta"],
Cell[2218890, 70216, 392, 12, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2219319, 70233, 247, 6, 70, "Input",
  CellTags->"SUNDelta"],
Cell[2219569, 70241, 392, 12, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2219998, 70258, 206, 5, 70, "Input",
  CellTags->"SUNDelta"],
Cell[2220207, 70265, 156, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2220400, 70273, 247, 7, 70, "Input",
  CellTags->"SUNDelta"],
Cell[2220650, 70282, 238, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2220925, 70292, 283, 8, 70, "Input",
  CellTags->"SUNDelta"],
Cell[2221211, 70302, 150, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2221398, 70310, 241, 7, 70, "Input",
  CellTags->"SUNDelta"],
Cell[2221642, 70319, 238, 5, 70, "Output"]
}, Closed]],
Cell[2221895, 70327, 257, 5, 70, "Text",
  CellTags->"SUNDelta"],

Cell[CellGroupData[{
Cell[2222177, 70336, 380, 10, 70, "Input",
  CellTags->"SUNDelta"],
Cell[2222560, 70348, 624, 19, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2223221, 70372, 138, 3, 70, "Input",
  CellTags->"SUNDelta"],
Cell[2223362, 70377, 441, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2223840, 70392, 247, 7, 70, "Input",
  CellTags->"SUNDelta"],
Cell[2224090, 70401, 254, 5, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2224405, 70413, 46, 1, 70, "ObjectName",
  CellTags->"SUND"],

Cell[CellGroupData[{
Cell[2224476, 70418, 56, 1, 70, "Subsubsection",
  CellTags->"SUND"],
Cell[2224535, 70421, 199, 7, 70, "Text",
  CellTags->"SUND"],
Cell[2224737, 70430, 425, 19, 70, "Text",
  CellTags->"SUND"]
}, Closed]],

Cell[CellGroupData[{
Cell[2225199, 70454, 53, 1, 70, "Subsubsection",
  CellTags->"SUND"],

Cell[CellGroupData[{
Cell[2225277, 70459, 167, 4, 70, "Input",
  CellTags->"SUND"],
Cell[2225447, 70465, 199, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2225683, 70475, 249, 6, 70, "Input",
  CellTags->"SUND"],
Cell[2225935, 70483, 1603, 44, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2227575, 70532, 167, 4, 70, "Input",
  CellTags->"SUND"],
Cell[2227745, 70538, 199, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2227981, 70548, 167, 4, 70, "Input",
  CellTags->"SUND"],
Cell[2228151, 70554, 109, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2228297, 70561, 320, 8, 70, "Input",
  CellTags->"SUND"],
Cell[2228620, 70571, 300, 8, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2228957, 70584, 455, 12, 70, "Input",
  CellTags->"SUND"],
Cell[2229415, 70598, 370, 11, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2229822, 70614, 455, 12, 70, "Input",
  CellTags->"SUND"],
Cell[2230280, 70628, 640, 19, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2230957, 70652, 215, 6, 70, "Input",
  CellTags->"SUND"],
Cell[2231175, 70660, 162, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2231374, 70668, 249, 7, 70, "Input",
  CellTags->"SUND"],
Cell[2231626, 70677, 285, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2231948, 70688, 287, 8, 70, "Input",
  CellTags->"SUND"],
Cell[2232238, 70698, 162, 3, 70, "Output"]
}, Closed]],
Cell[2232415, 70704, 132, 3, 70, "Input",
  CellTags->"SUND"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2232596, 70713, 46, 1, 70, "ObjectName",
  CellTags->"SUNF"],

Cell[CellGroupData[{
Cell[2232667, 70718, 56, 1, 70, "Subsubsection",
  CellTags->"SUNF"],
Cell[2232726, 70721, 143, 4, 70, "Text",
  CellTags->"SUNF"],

Cell[CellGroupData[{
Cell[2232894, 70729, 136, 3, 70, "Input",
  CellTags->"SUNF"],
Cell[2233033, 70734, 189, 5, 70, "Output"]
}, Closed]],
Cell[2233237, 70742, 764, 34, 70, "Text",
  CellTags->"SUNF"]
}, Closed]],

Cell[CellGroupData[{
Cell[2234038, 70781, 53, 1, 70, "Subsubsection",
  CellTags->"SUNF"],

Cell[CellGroupData[{
Cell[2234116, 70786, 362, 10, 70, "Input",
  CellTags->"SUNF"],
Cell[2234481, 70798, 383, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2234901, 70813, 131, 3, 70, "Input",
  CellTags->"SUNF"],
Cell[2235035, 70818, 1108, 33, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2236180, 70856, 138, 3, 70, "Input",
  CellTags->"SUNF"],
Cell[2236321, 70861, 625, 19, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2236983, 70885, 167, 4, 70, "Input",
  CellTags->"SUNF"],
Cell[2237153, 70891, 199, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2237389, 70901, 200, 5, 70, "Input",
  CellTags->"SUNF"],
Cell[2237592, 70908, 109, 2, 70, "Output"]
}, Closed]],
Cell[2237716, 70913, 375, 11, 70, "Text",
  CellTags->"SUNF"],

Cell[CellGroupData[{
Cell[2238116, 70928, 222, 5, 70, "Input",
  CellTags->"SUNF"],
Cell[2238341, 70935, 1703, 44, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2240081, 70984, 320, 8, 70, "Input",
  CellTags->"SUNF"],
Cell[2240404, 70994, 467, 14, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2240908, 71013, 287, 7, 70, "Input",
  CellTags->"SUNF"],
Cell[2241198, 71022, 1727, 45, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2242962, 71072, 215, 6, 70, "Input",
  CellTags->"SUNF"],
Cell[2243180, 71080, 162, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2243379, 71088, 249, 7, 70, "Input",
  CellTags->"SUNF"],
Cell[2243631, 71097, 285, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2243953, 71108, 287, 8, 70, "Input",
  CellTags->"SUNF"],
Cell[2244243, 71118, 162, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2244442, 71126, 167, 4, 70, "Input",
  CellTags->"SUNF"],
Cell[2244612, 71132, 199, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2244848, 71142, 199, 5, 70, "Input",
  CellTags->"SUNF"],
Cell[2245050, 71149, 560, 17, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2245671, 71173, 54, 1, 70, "ObjectName",
  CellTags->"SUNIndex"],

Cell[CellGroupData[{
Cell[2245750, 71178, 60, 1, 70, "Subsubsection",
  CellTags->"SUNIndex"],
Cell[2245813, 71181, 77, 1, 70, "Text",
  CellTags->"SUNIndex"],
Cell[2245893, 71184, 437, 18, 70, "Text",
  CellTags->"SUNIndex"]
}, Closed]],

Cell[CellGroupData[{
Cell[2246367, 71207, 57, 1, 70, "Subsubsection",
  CellTags->"SUNIndex"],

Cell[CellGroupData[{
Cell[2246449, 71212, 138, 3, 70, "Input",
  CellTags->"SUNIndex"],
Cell[2246590, 71217, 109, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2246736, 71224, 138, 3, 70, "Input",
  CellTags->"SUNIndex"],
Cell[2246877, 71229, 129, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2247043, 71236, 247, 7, 70, "Input",
  CellTags->"SUNIndex"],
Cell[2247293, 71245, 238, 5, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2247592, 71257, 60, 1, 70, "ObjectName",
  CellTags->"SUNSimplify"],

Cell[CellGroupData[{
Cell[2247677, 71262, 63, 1, 70, "Subsubsection",
  CellTags->"SUNSimplify"],
Cell[2247743, 71265, 377, 7, 70, "Text",
  CellTags->"SUNSimplify"],

Cell[CellGroupData[{
Cell[2248145, 71276, 150, 3, 70, "Input",
  CellTags->"SUNSimplify"],
Cell[2248298, 71281, 567, 12, 70, "Output"]
}, Closed]],
Cell[2248880, 71296, 186, 9, 70, "Text",
  CellTags->"SUNSimplify"]
}, Closed]],

Cell[CellGroupData[{
Cell[2249103, 71310, 60, 1, 70, "Subsubsection",
  CellTags->"SUNSimplify"],

Cell[CellGroupData[{
Cell[2249188, 71315, 301, 8, 70, "Input",
  CellTags->"SUNSimplify"],
Cell[2249492, 71325, 286, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2249815, 71337, 145, 3, 70, "Input",
  CellTags->"SUNSimplify"],
Cell[2249963, 71342, 392, 12, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2250392, 71359, 231, 6, 70, "Input",
  CellTags->"SUNSimplify"],
Cell[2250626, 71367, 294, 9, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2250957, 71381, 145, 3, 70, "Input",
  CellTags->"SUNSimplify"],
Cell[2251105, 71386, 135, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2251277, 71394, 215, 5, 70, "Input",
  CellTags->"SUNSimplify"],
Cell[2251495, 71401, 224, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2251756, 71412, 308, 8, 70, "Input",
  CellTags->"SUNSimplify"],
Cell[2252067, 71422, 317, 8, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2252421, 71435, 145, 3, 70, "Input",
  CellTags->"SUNSimplify"],
Cell[2252569, 71440, 467, 14, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2253073, 71459, 323, 8, 70, "Input",
  CellTags->"SUNSimplify"],
Cell[2253399, 71469, 317, 8, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2253753, 71482, 145, 3, 70, "Input",
  CellTags->"SUNSimplify"],
Cell[2253901, 71487, 212, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2254150, 71497, 313, 8, 70, "Input",
  CellTags->"SUNSimplify"],
Cell[2254466, 71507, 317, 8, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2254820, 71520, 145, 3, 70, "Input",
  CellTags->"SUNSimplify"],
Cell[2254968, 71525, 467, 14, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2255472, 71544, 313, 8, 70, "Input",
  CellTags->"SUNSimplify"],
Cell[2255788, 71554, 317, 8, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2256142, 71567, 212, 5, 70, "Input",
  CellTags->"SUNSimplify"],
Cell[2256357, 71574, 109, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2256503, 71581, 467, 12, 70, "Input",
  CellTags->"SUNSimplify"],
Cell[2256973, 71595, 370, 11, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2257380, 71611, 472, 12, 70, "Input",
  CellTags->"SUNSimplify"],
Cell[2257855, 71625, 586, 17, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2258478, 71647, 294, 7, 70, "Input",
  CellTags->"SUNSimplify"],
Cell[2258775, 71656, 1727, 45, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2260539, 71706, 294, 7, 70, "Input",
  CellTags->"SUNSimplify"],
Cell[2260836, 71715, 1681, 44, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2262554, 71764, 327, 8, 70, "Input",
  CellTags->"SUNSimplify"],
Cell[2262884, 71774, 277, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2263198, 71786, 533, 14, 70, "Input",
  CellTags->"SUNSimplify"],
Cell[2263734, 71802, 565, 14, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2264336, 71821, 218, 5, 70, "Input",
  CellTags->"SUNSimplify"],
Cell[2264557, 71828, 1004, 31, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2265598, 71864, 280, 6, 70, "Input",
  CellTags->"SUNSimplify"],
Cell[2265881, 71872, 2022, 61, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2267940, 71938, 359, 9, 70, "Input",
  CellTags->"SUNSimplify"],
Cell[2268302, 71949, 650, 18, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2268989, 71972, 145, 3, 70, "Input",
  CellTags->"SUNSimplify"],
Cell[2269137, 71977, 949, 28, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2270123, 72010, 218, 5, 70, "Input",
  CellTags->"SUNSimplify"],
Cell[2270344, 72017, 887, 27, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2271268, 72049, 268, 7, 70, "Input",
  CellTags->"SUNSimplify"],
Cell[2271539, 72058, 552, 13, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2272128, 72076, 245, 6, 70, "Input",
  CellTags->"SUNSimplify"],
Cell[2272376, 72084, 667, 19, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2273080, 72108, 141, 3, 70, "Input",
  CellTags->"SUNSimplify"],
Cell[2273224, 72113, 273, 6, 70, "Output"]
}, Closed]],
Cell[2273512, 72122, 249, 6, 70, "Input",
  CellTags->"SUNSimplify"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2273810, 72134, 46, 1, 70, "ObjectName",
  CellTags->"SUNT"],

Cell[CellGroupData[{
Cell[2273881, 72139, 56, 1, 70, "Subsubsection",
  CellTags->"SUNT"],
Cell[2273940, 72142, 207, 7, 70, "Text",
  CellTags->"SUNT"],
Cell[2274150, 72151, 737, 34, 70, "Text",
  CellTags->"SUNT"]
}, Closed]],

Cell[CellGroupData[{
Cell[2274924, 72190, 53, 1, 70, "Subsubsection",
  CellTags->"SUNT"],

Cell[CellGroupData[{
Cell[2275002, 72195, 130, 3, 70, "Input",
  CellTags->"SUNT"],
Cell[2275135, 72200, 182, 5, 70, "Output"]
}, Closed]],
Cell[2275332, 72208, 216, 7, 70, "Text",
  CellTags->"SUNT"],

Cell[CellGroupData[{
Cell[2275573, 72219, 247, 6, 70, "Input",
  CellTags->"SUNT"],
Cell[2275823, 72227, 383, 12, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2276243, 72244, 177, 4, 70, "Input",
  CellTags->"SUNT"],
Cell[2276423, 72250, 457, 15, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2276917, 72270, 290, 7, 70, "Input",
  CellTags->"SUNT"],
Cell[2277210, 72279, 333, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2277580, 72294, 221, 5, 70, "Input",
  CellTags->"SUNT"],
Cell[2277804, 72301, 145, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2277986, 72309, 211, 5, 70, "Input",
  CellTags->"SUNT"],
Cell[2278200, 72316, 492, 15, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2278729, 72336, 290, 7, 70, "Input",
  CellTags->"SUNT"],
Cell[2279022, 72345, 333, 10, 70, "Output"]
}, Closed]],
Cell[2279370, 72358, 491, 15, 70, "Text",
  CellTags->"SUNT"],

Cell[CellGroupData[{
Cell[2279886, 72377, 198, 5, 70, "Input",
  CellTags->"SUNT"],
Cell[2280087, 72384, 437, 13, 70, "Output"]
}, Closed]],
Cell[2280539, 72400, 210, 7, 70, "Text",
  CellTags->"SUNT"],

Cell[CellGroupData[{
Cell[2280774, 72411, 240, 6, 70, "Input",
  CellTags->"SUNT"],
Cell[2281017, 72419, 467, 14, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2281521, 72438, 248, 7, 70, "Input",
  CellTags->"SUNT"],
Cell[2281772, 72447, 296, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2282105, 72459, 208, 6, 70, "Input",
  CellTags->"SUNT"],
Cell[2282316, 72467, 164, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2282517, 72475, 242, 7, 70, "Input",
  CellTags->"SUNT"],
Cell[2282762, 72484, 125, 2, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2282948, 72493, 54, 1, 70, "ObjectName",
  CellTags->"SUNTrace"],

Cell[CellGroupData[{
Cell[2283027, 72498, 60, 1, 70, "Subsubsection",
  CellTags->"SUNTrace"],
Cell[2283090, 72501, 82, 1, 70, "Text",
  CellTags->"SUNTrace"],

Cell[CellGroupData[{
Cell[2283197, 72506, 144, 3, 70, "Input",
  CellTags->"SUNTrace"],
Cell[2283344, 72511, 189, 5, 70, "Output"]
}, Closed]],
Cell[2283548, 72519, 303, 14, 70, "Text",
  CellTags->"SUNTrace"]
}, Closed]],

Cell[CellGroupData[{
Cell[2283888, 72538, 57, 1, 70, "Subsubsection",
  CellTags->"SUNTrace"],

Cell[CellGroupData[{
Cell[2283970, 72543, 202, 5, 70, "Input",
  CellTags->"SUNTrace"],
Cell[2284175, 72550, 437, 13, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2284649, 72568, 212, 5, 70, "Input",
  CellTags->"SUNTrace"],
Cell[2284864, 72575, 736, 22, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2285637, 72602, 288, 7, 70, "Input",
  CellTags->"SUNTrace"],
Cell[2285928, 72611, 1188, 35, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2287153, 72651, 222, 5, 70, "Input",
  CellTags->"SUNTrace"],
Cell[2287378, 72658, 900, 27, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2288315, 72690, 334, 8, 70, "Input",
  CellTags->"SUNTrace"],
Cell[2288652, 72700, 6262, 183, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2294951, 72888, 214, 5, 70, "Input",
  CellTags->"SUNTrace"],
Cell[2295168, 72895, 900, 27, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2296105, 72927, 355, 9, 70, "Input",
  CellTags->"SUNTrace"],
Cell[2296463, 72938, 17504, 440, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2314004, 73383, 214, 5, 70, "Input",
  CellTags->"SUNTrace"],
Cell[2314221, 73390, 1064, 32, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2315322, 73427, 324, 8, 70, "Input",
  CellTags->"SUNTrace"],
Cell[2315649, 73437, 109, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2315795, 73444, 324, 8, 70, "Input",
  CellTags->"SUNTrace"],
Cell[2316122, 73454, 109, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2316268, 73461, 324, 8, 70, "Input",
  CellTags->"SUNTrace"],
Cell[2316595, 73471, 109, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2316741, 73478, 324, 8, 70, "Input",
  CellTags->"SUNTrace"],
Cell[2317068, 73488, 740, 22, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2317869, 73517, 58, 1, 70, "ObjectName",
  CellTags->"Symmetrize"],

Cell[CellGroupData[{
Cell[2317952, 73522, 62, 1, 70, "Subsubsection",
  CellTags->"Symmetrize"],
Cell[2318017, 73525, 146, 4, 70, "Text",
  CellTags->"Symmetrize"],
Cell[2318166, 73531, 205, 8, 70, "Text",
  CellTags->"Symmetrize"]
}, Closed]],

Cell[CellGroupData[{
Cell[2318408, 73544, 59, 1, 70, "Subsubsection",
  CellTags->"Symmetrize"],

Cell[CellGroupData[{
Cell[2318492, 73549, 294, 8, 70, "Input",
  CellTags->"Symmetrize"],
Cell[2318789, 73559, 376, 11, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2319202, 73575, 314, 8, 70, "Input",
  CellTags->"Symmetrize"],
Cell[2319519, 73585, 768, 19, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2320348, 73611, 46, 1, 70, "ObjectName",
  CellTags->"Tdec"],

Cell[CellGroupData[{
Cell[2320419, 73616, 56, 1, 70, "Subsubsection",
  CellTags->"Tdec"],
Cell[2320478, 73619, 257, 5, 70, "Text",
  CellTags->"Tdec"],

Cell[CellGroupData[{
Cell[2320760, 73628, 136, 3, 70, "Input",
  CellTags->"Tdec"],
Cell[2320899, 73633, 524, 11, 70, "Output"]
}, Closed]],
Cell[2321438, 73647, 422, 19, 70, "Text",
  CellTags->"Tdec"]
}, Closed]],

Cell[CellGroupData[{
Cell[2321897, 73671, 53, 1, 70, "Subsubsection",
  CellTags->"Tdec"],
Cell[2321953, 73674, 756, 23, 70, "Text",
  CellTags->"Tdec"],

Cell[CellGroupData[{
Cell[2322734, 73701, 250, 7, 70, "Input",
  CellTags->"Tdec"],
Cell[2322987, 73710, 902, 25, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2323926, 73740, 245, 7, 70, "Input",
  CellTags->"Tdec"],
Cell[2324174, 73749, 589, 18, 70, "Output"]
}, Closed]],
Cell[2324778, 73770, 923, 28, 70, "Text",
  CellTags->"Tdec"],
Cell[2325704, 73800, 697, 19, 70, "Input",
  CellTags->"Tdec"],

Cell[CellGroupData[{
Cell[2326426, 73823, 245, 7, 70, "Input",
  CellTags->"Tdec"],
Cell[2326674, 73832, 14163, 357, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2340874, 74194, 469, 13, 70, "Input",
  CellTags->"Tdec"],
Cell[2341346, 74209, 752, 21, 70, "Output"]
}, Closed]],
Cell[2342113, 74233, 153, 4, 70, "Input",
  CellTags->"Tdec"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2342315, 74243, 66, 1, 70, "ObjectName",
  CellTags->"Tensorfunction"],

Cell[CellGroupData[{
Cell[2342406, 74248, 66, 1, 70, "Subsubsection",
  CellTags->"Tensorfunction"],
Cell[2342475, 74251, 361, 7, 70, "Text",
  CellTags->"Tensorfunction"],
Cell[2342839, 74260, 204, 9, 70, "Text",
  CellTags->"Tensorfunction"]
}, Closed]],

Cell[CellGroupData[{
Cell[2343080, 74274, 63, 1, 70, "Subsubsection",
  CellTags->"Tensorfunction"],

Cell[CellGroupData[{
Cell[2343168, 74279, 217, 5, 70, "Input",
  CellTags->"Tensorfunction"],
Cell[2343388, 74286, 223, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2343648, 74296, 144, 3, 70, "Input",
  CellTags->"Tensorfunction"],
Cell[2343795, 74301, 202, 4, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2344034, 74310, 241, 6, 70, "Input",
  CellTags->"Tensorfunction"],
Cell[2344278, 74318, 445, 13, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2344760, 74336, 144, 3, 70, "Input",
  CellTags->"Tensorfunction"],
Cell[2344907, 74341, 391, 9, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2345335, 74355, 277, 7, 70, "Input",
  CellTags->"Tensorfunction"],
Cell[2345615, 74364, 289, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2345941, 74376, 277, 7, 70, "Input",
  CellTags->"Tensorfunction"],
Cell[2346221, 74385, 289, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2346547, 74397, 144, 3, 70, "Input",
  CellTags->"Tensorfunction"],
Cell[2346694, 74402, 262, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2346993, 74413, 146, 3, 70, "Input",
  CellTags->"Tensorfunction"],
Cell[2347142, 74418, 131, 3, 70, "Output"]
}, Closed]],
Cell[2347288, 74424, 186, 4, 70, "Input",
  CellTags->"Tensorfunction"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2347523, 74434, 44, 1, 70, "ObjectName",
  CellTags->"TFi"],

Cell[CellGroupData[{
Cell[2347592, 74439, 55, 1, 70, "Subsubsection",
  CellTags->"TFi"],
Cell[2347650, 74442, 579, 10, 70, "Text",
  CellTags->"TFi"],
Cell[2348232, 74454, 250, 8, 70, "Text",
  CellTags->"TFi"],
Cell[2348485, 74464, 186, 4, 70, "Text",
  CellTags->"TFi"],
Cell[2348674, 74470, 288, 13, 70, "Text",
  CellTags->"TFi"]
}, Closed]],

Cell[CellGroupData[{
Cell[2348999, 74488, 52, 1, 70, "Subsubsection",
  CellTags->"TFi"],

Cell[CellGroupData[{
Cell[2349076, 74493, 629, 17, 70, "Input",
  CellTags->"TFi"],
Cell[2349708, 74512, 1146, 34, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2350891, 74551, 365, 10, 70, "Input",
  CellTags->"TFi"],
Cell[2351259, 74563, 1136, 34, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2352456, 74604, 46, 1, 70, "ObjectName",
  CellTags->"TIDL"],

Cell[CellGroupData[{
Cell[2352527, 74609, 56, 1, 70, "Subsubsection",
  CellTags->"TIDL"],
Cell[2352586, 74612, 88, 1, 70, "Text",
  CellTags->"TIDL"],
Cell[2352677, 74615, 166, 8, 70, "Text",
  CellTags->"TIDL"]
}, Closed]],
Cell[2352858, 74626, 53, 1, 70, "Subsubsection",
  CellTags->"TIDL"],

Cell[CellGroupData[{
Cell[2352936, 74631, 171, 5, 70, "Subsubsection",
  CellTags->"TIDL"],
Cell[2353110, 74638, 507, 14, 70, "Text",
  CellTags->"TIDL"],

Cell[CellGroupData[{
Cell[2353642, 74656, 250, 7, 70, "Input",
  CellTags->"TIDL"],
Cell[2353895, 74665, 642, 20, 70, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2354586, 74691, 176, 5, 70, "Subsubsection",
  CellTags->"TIDL"],

Cell[CellGroupData[{
Cell[2354787, 74700, 390, 11, 70, "Input",
  CellTags->"TIDL"],
Cell[2355180, 74713, 2967, 82, 70, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2358196, 74801, 171, 5, 70, "Subsubsection",
  CellTags->"TIDL"],

Cell[CellGroupData[{
Cell[2358392, 74810, 345, 10, 70, "Input",
  CellTags->"TIDL"],
Cell[2358740, 74822, 4307, 118, 70, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2363096, 74946, 176, 5, 70, "Subsubsection",
  CellTags->"TIDL"],

Cell[CellGroupData[{
Cell[2363297, 74955, 485, 14, 70, "Input",
  CellTags->"TIDL"],
Cell[2363785, 74971, 41474, 950, 70, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2405308, 75927, 182, 5, 70, "Subsubsection",
  CellTags->"TIDL"],
Cell[2405493, 75934, 548, 15, 70, "Input",
  CellTags->"TIDL"]
}, Closed]],

Cell[CellGroupData[{
Cell[2406078, 75954, 190, 5, 70, "Subsubsection",
  CellTags->"TIDL"],
Cell[2406271, 75961, 637, 17, 70, "Input",
  CellTags->"TIDL"]
}, Closed]],

Cell[CellGroupData[{
Cell[2406945, 75983, 171, 5, 70, "Subsubsection",
  CellTags->"TIDL"],

Cell[CellGroupData[{
Cell[2407141, 75992, 387, 11, 70, "Input",
  CellTags->"TIDL"],
Cell[2407531, 76005, 25266, 599, 70, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2432846, 76610, 176, 5, 70, "Subsubsection",
  CellTags->"TIDL"],
Cell[2433025, 76617, 473, 14, 70, "Input",
  CellTags->"TIDL"]
}, Closed]],

Cell[CellGroupData[{
Cell[2433535, 76636, 182, 5, 70, "Subsubsection",
  CellTags->"TIDL"],
Cell[2433720, 76643, 560, 16, 70, "Input",
  CellTags->"TIDL"]
}, Closed]],

Cell[CellGroupData[{
Cell[2434317, 76664, 190, 5, 70, "Subsubsection",
  CellTags->"TIDL"],
Cell[2434510, 76671, 664, 18, 70, "Input",
  CellTags->"TIDL"],

Cell[CellGroupData[{
Cell[2435199, 76693, 287, 7, 70, "Input",
  CellTags->"TIDL"],
Cell[2435489, 76702, 185, 5, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2435735, 76714, 44, 1, 70, "ObjectName",
  CellTags->"TID"],

Cell[CellGroupData[{
Cell[2435804, 76719, 55, 1, 70, "Subsubsection",
  CellTags->"TID"],
Cell[2435862, 76722, 81, 1, 70, "Text",
  CellTags->"TID"],

Cell[CellGroupData[{
Cell[2435968, 76727, 134, 3, 70, "Input",
  CellTags->"TID"],
Cell[2436105, 76732, 730, 14, 70, "Output"]
}, Closed]],
Cell[2436850, 76749, 316, 14, 70, "Text",
  CellTags->"TID"]
}, Closed]],

Cell[CellGroupData[{
Cell[2437203, 76768, 52, 1, 70, "Subsubsection",
  CellTags->"TID"],

Cell[CellGroupData[{
Cell[2437280, 76773, 458, 12, 70, "Input",
  CellTags->"TID"],
Cell[2437741, 76787, 1559, 45, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2439337, 76837, 224, 6, 70, "Input",
  CellTags->"TID"],
Cell[2439564, 76845, 18274, 425, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2457875, 77275, 332, 9, 70, "Input",
  CellTags->"TID"],
Cell[2458210, 77286, 1144, 34, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2459391, 77325, 155, 4, 70, "Input",
  CellTags->"TID"],
Cell[2459549, 77331, 2418, 69, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2462004, 77405, 236, 6, 70, "Input",
  CellTags->"TID"],
Cell[2462243, 77413, 998, 29, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2463302, 77449, 66, 1, 70, "ObjectName",
  CellTags->"ToDistribution"],

Cell[CellGroupData[{
Cell[2463393, 77454, 66, 1, 70, "Subsubsection",
  CellTags->"ToDistribution"],
Cell[2463462, 77457, 425, 7, 70, "Text",
  CellTags->"ToDistribution"],

Cell[CellGroupData[{
Cell[2463912, 77468, 156, 3, 70, "Input",
  CellTags->"ToDistribution"],
Cell[2464071, 77473, 200, 5, 70, "Output"]
}, Closed]],
Cell[2464286, 77481, 222, 9, 70, "Text",
  CellTags->"ToDistribution"]
}, Closed]],

Cell[CellGroupData[{
Cell[2464545, 77495, 63, 1, 70, "Subsubsection",
  CellTags->"ToDistribution"],

Cell[CellGroupData[{
Cell[2464633, 77500, 258, 6, 70, "Input",
  CellTags->"ToDistribution"],
Cell[2464894, 77508, 208, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2465139, 77518, 347, 10, 70, "Input",
  CellTags->"ToDistribution"],
Cell[2465489, 77530, 1664, 47, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2467190, 77582, 245, 6, 70, "Input",
  CellTags->"ToDistribution"],
Cell[2467438, 77590, 200, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2467675, 77600, 347, 10, 70, "Input",
  CellTags->"ToDistribution"],
Cell[2468025, 77612, 1682, 49, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2469744, 77666, 563, 14, 70, "Input",
  CellTags->"ToDistribution"],
Cell[2470310, 77682, 428, 12, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2470775, 77699, 146, 3, 70, "Input",
  CellTags->"ToDistribution"],
Cell[2470924, 77704, 373, 9, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2471334, 77718, 513, 14, 70, "Input",
  CellTags->"ToDistribution"],
Cell[2471850, 77734, 428, 12, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2472339, 77753, 70, 1, 70, "ObjectName",
  CellTags->"ToHypergeometric"],

Cell[CellGroupData[{
Cell[2472434, 77758, 68, 1, 70, "Subsubsection",
  CellTags->"ToHypergeometric"],
Cell[2472505, 77761, 1437, 42, 70, "Text",
  CellTags->"ToHypergeometric"],
Cell[2473945, 77805, 512, 19, 70, "Text",
  CellTags->"ToHypergeometric"]
}, Closed]],

Cell[CellGroupData[{
Cell[2474494, 77829, 65, 1, 70, "Subsubsection",
  CellTags->"ToHypergeometric"],

Cell[CellGroupData[{
Cell[2474584, 77834, 496, 14, 70, "Input",
  CellTags->"ToHypergeometric"],
Cell[2475083, 77850, 2200, 55, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2477320, 77910, 603, 16, 70, "Input",
  CellTags->"ToHypergeometric"],
Cell[2477926, 77928, 1948, 49, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2479911, 77982, 496, 14, 70, "Input",
  CellTags->"ToHypergeometric"],
Cell[2480410, 77998, 2285, 57, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2482732, 78060, 603, 16, 70, "Input",
  CellTags->"ToHypergeometric"],
Cell[2483338, 78078, 2059, 52, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2485458, 78137, 52, 1, 70, "ObjectName",
  CellTags->"ToLarin"],

Cell[CellGroupData[{
Cell[2485535, 78142, 59, 1, 70, "Subsubsection",
  CellTags->"ToLarin"],
Cell[2485597, 78145, 693, 20, 70, "Text",
  CellTags->"ToLarin"],
Cell[2486293, 78167, 176, 9, 70, "Text",
  CellTags->"ToLarin"]
}, Closed]],

Cell[CellGroupData[{
Cell[2486506, 78181, 56, 1, 70, "Subsubsection",
  CellTags->"ToLarin"],

Cell[CellGroupData[{
Cell[2486587, 78186, 269, 6, 70, "Input",
  CellTags->"ToLarin"],
Cell[2486859, 78194, 477, 14, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2487373, 78213, 136, 3, 70, "Input",
  CellTags->"ToLarin"],
Cell[2487512, 78218, 1475, 44, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2489048, 78269, 48, 1, 70, "ObjectName",
  CellTags->"ToTFi"],

Cell[CellGroupData[{
Cell[2489121, 78274, 57, 1, 70, "Subsubsection",
  CellTags->"ToTFi"],
Cell[2489181, 78277, 275, 6, 70, "Text",
  CellTags->"ToTFi"],
Cell[2489459, 78285, 284, 13, 70, "Text",
  CellTags->"ToTFi"]
}, Closed]],

Cell[CellGroupData[{
Cell[2489780, 78303, 54, 1, 70, "Subsubsection",
  CellTags->"ToTFi"],

Cell[CellGroupData[{
Cell[2489859, 78308, 404, 11, 70, "Input",
  CellTags->"ToTFi"],
Cell[2490266, 78321, 3153, 76, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2493456, 78402, 181, 4, 70, "Input",
  CellTags->"ToTFi"],
Cell[2493640, 78408, 1134, 34, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2494811, 78447, 135, 3, 70, "Input",
  CellTags->"ToTFi"],
Cell[2494949, 78452, 658, 17, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2495644, 78474, 574, 15, 70, "Input",
  CellTags->"ToTFi"],
Cell[2496221, 78491, 2089, 59, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2498347, 78555, 132, 3, 70, "Input",
  CellTags->"ToTFi"],
Cell[2498482, 78560, 1177, 35, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2499696, 78600, 135, 3, 70, "Input",
  CellTags->"ToTFi"],
Cell[2499834, 78605, 774, 20, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2500669, 78632, 42, 1, 70, "ObjectName",
  CellTags->"Tr"],

Cell[CellGroupData[{
Cell[2500736, 78637, 54, 1, 70, "Subsubsection",
  CellTags->"Tr"],
Cell[2500793, 78640, 261, 5, 70, "Text",
  CellTags->"Tr"],

Cell[CellGroupData[{
Cell[2501079, 78649, 132, 3, 70, "Input",
  CellTags->"Tr"],
Cell[2501214, 78654, 746, 16, 70, "Output"]
}, Closed]],
Cell[2501975, 78673, 578, 23, 70, "Text",
  CellTags->"Tr"]
}, Closed]],

Cell[CellGroupData[{
Cell[2502590, 78701, 51, 1, 70, "Subsubsection",
  CellTags->"Tr"],

Cell[CellGroupData[{
Cell[2502666, 78706, 161, 4, 70, "Input",
  CellTags->"Tr"],
Cell[2502830, 78712, 218, 5, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2503085, 78722, 126, 3, 70, "Input",
  CellTags->"Tr"],
Cell[2503214, 78727, 221, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2503472, 78738, 453, 12, 70, "Input",
  CellTags->"Tr"],
Cell[2503928, 78752, 2322, 66, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2506287, 78823, 256, 7, 70, "Input",
  CellTags->"Tr"],
Cell[2506546, 78832, 775, 22, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2507358, 78859, 288, 7, 70, "Input",
  CellTags->"Tr"],
Cell[2507649, 78868, 17178, 441, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2524864, 79314, 99, 2, 70, "Input",
  CellTags->"Tr"],
Cell[2524966, 79318, 112, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2525115, 79325, 119, 3, 70, "Input",
  CellTags->"Tr"],
Cell[2525237, 79330, 335, 5, 70, "Print"]
}, Closed]],
Cell[2525587, 79338, 167, 4, 70, "Text",
  CellTags->"Tr"],

Cell[CellGroupData[{
Cell[2525779, 79346, 128, 3, 70, "Input",
  CellTags->"Tr"],
Cell[2525910, 79351, 113, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2526060, 79358, 511, 13, 70, "Input",
  CellTags->"Tr"],
Cell[2526574, 79373, 8493, 217, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2535104, 79595, 208, 5, 70, "Input",
  CellTags->"Tr"],
Cell[2535315, 79602, 1614, 45, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2536966, 79652, 540, 14, 70, "Input",
  CellTags->"Tr"],
Cell[2537509, 79668, 470, 13, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2538016, 79686, 272, 7, 70, "Input",
  CellTags->"Tr"],
Cell[2538291, 79695, 226, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2538554, 79706, 132, 3, 70, "Input",
  CellTags->"Tr"],
Cell[2538689, 79711, 192, 4, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2538918, 79720, 413, 10, 70, "Input",
  CellTags->"Tr"],
Cell[2539334, 79732, 236, 6, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2539607, 79743, 132, 3, 70, "Input",
  CellTags->"Tr"],
Cell[2539742, 79748, 202, 4, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2540005, 79759, 68, 1, 70, "ObjectName",
  CellTags->"TrickMandelstam"],

Cell[CellGroupData[{
Cell[2540098, 79764, 67, 1, 70, "Subsubsection",
  CellTags->"TrickMandelstam"],
Cell[2540168, 79767, 1102, 37, 70, "Text",
  CellTags->"TrickMandelstam"]
}, Closed]],

Cell[CellGroupData[{
Cell[2541307, 79809, 64, 1, 70, "Subsubsection",
  CellTags->"TrickMandelstam"],

Cell[CellGroupData[{
Cell[2541396, 79814, 664, 18, 70, "Input",
  CellTags->"TrickMandelstam"],
Cell[2542063, 79834, 279, 8, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2542379, 79847, 721, 18, 70, "Input",
  CellTags->"TrickMandelstam"],
Cell[2543103, 79867, 277, 8, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2543441, 79882, 48, 1, 70, "ObjectName",
  CellTags->"Trick"],

Cell[CellGroupData[{
Cell[2543514, 79887, 57, 1, 70, "Subsubsection",
  CellTags->"Trick"],
Cell[2543574, 79890, 175, 4, 70, "Text",
  CellTags->"Trick"],
Cell[2543752, 79896, 678, 29, 70, "Text",
  CellTags->"Trick"]
}, Closed]],

Cell[CellGroupData[{
Cell[2544467, 79930, 63, 1, 70, "Subsubsection",
  CellTags->"Trick"],
Cell[2544533, 79933, 420, 15, 70, "Text",
  CellTags->"Trick"],

Cell[CellGroupData[{
Cell[2544978, 79952, 428, 11, 70, "Input",
  CellTags->"Trick"],
Cell[2545409, 79965, 329, 10, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2545775, 79980, 397, 11, 70, "Input",
  CellTags->"Trick"],
Cell[2546175, 79993, 619, 18, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2546831, 80016, 132, 3, 70, "Input",
  CellTags->"Trick"],
Cell[2546966, 80021, 777, 22, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2547780, 80048, 269, 6, 70, "Input",
  CellTags->"Trick"],
Cell[2548052, 80056, 491, 14, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2548580, 80075, 165, 4, 70, "Input",
  CellTags->"Trick"],
Cell[2548748, 80081, 234, 5, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2549043, 80093, 76, 1, 70, "ObjectName",
  CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{
Cell[2549144, 80098, 71, 1, 70, "Subsubsection",
  CellTags->"Twist2GluonOperator"],
Cell[2549218, 80101, 965, 15, 70, "Text",
  CellTags->"Twist2GluonOperator"],
Cell[2550186, 80118, 236, 9, 70, "Text",
  CellTags->"Twist2GluonOperator"]
}, Closed]],

Cell[CellGroupData[{
Cell[2550459, 80132, 100, 1, 70, "Subsubsection",
  CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{
Cell[2550584, 80137, 388, 8, 70, "Input",
  CellTags->"Twist2GluonOperator"],
Cell[2550975, 80147, 487, 11, 70, "Output"]
}, Closed]],
Cell[2551477, 80161, 63, 1, 70, "Text",
  CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{
Cell[2551565, 80166, 325, 8, 70, "Input",
  CellTags->"Twist2GluonOperator"],
Cell[2551893, 80176, 1176, 35, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2553106, 80216, 375, 9, 70, "Input",
  CellTags->"Twist2GluonOperator"],
Cell[2553484, 80227, 1556, 45, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2555077, 80277, 263, 6, 70, "Input",
  CellTags->"Twist2GluonOperator"],
Cell[2555343, 80285, 391, 11, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2555771, 80301, 313, 7, 70, "Input",
  CellTags->"Twist2GluonOperator"],
Cell[2556087, 80310, 989, 28, 70, "Output"]
}, Closed]],
Cell[2557091, 80341, 63, 1, 70, "Text",
  CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{
Cell[2557179, 80346, 420, 10, 70, "Input",
  CellTags->"Twist2GluonOperator"],
Cell[2557602, 80358, 1608, 48, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2559247, 80411, 390, 10, 70, "Input",
  CellTags->"Twist2GluonOperator"],
Cell[2559640, 80423, 590, 17, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2560267, 80445, 440, 11, 70, "Input",
  CellTags->"Twist2GluonOperator"],
Cell[2560710, 80458, 16839, 419, 70, "Output"]
}, Closed]],
Cell[2577564, 80880, 63, 1, 70, "Text",
  CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{
Cell[2577652, 80885, 507, 12, 70, "Input",
  CellTags->"Twist2GluonOperator"],
Cell[2578162, 80899, 7225, 184, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2585424, 81088, 467, 12, 70, "Input",
  CellTags->"Twist2GluonOperator"],
Cell[2585894, 81102, 734, 21, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2586665, 81128, 517, 13, 70, "Input",
  CellTags->"Twist2GluonOperator"],
Cell[2587185, 81143, 36980, 900, 70, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2624214, 82049, 101, 1, 70, "Subsubsection",
  CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{
Cell[2624340, 82054, 317, 7, 70, "Input",
  CellTags->"Twist2GluonOperator"],
Cell[2624660, 82063, 487, 11, 70, "Output"]
}, Closed]],
Cell[2625162, 82077, 63, 1, 70, "Text",
  CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{
Cell[2625250, 82082, 325, 8, 70, "Input",
  CellTags->"Twist2GluonOperator"],
Cell[2625578, 82092, 1191, 36, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2626806, 82133, 375, 9, 70, "Input",
  CellTags->"Twist2GluonOperator"],
Cell[2627184, 82144, 4148, 112, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2631369, 82261, 263, 6, 70, "Input",
  CellTags->"Twist2GluonOperator"],
Cell[2631635, 82269, 391, 11, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2632063, 82285, 313, 7, 70, "Input",
  CellTags->"Twist2GluonOperator"],
Cell[2632379, 82294, 3566, 94, 70, "Output"]
}, Closed]],
Cell[2635960, 82391, 63, 1, 70, "Text",
  CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{
Cell[2636048, 82396, 420, 10, 70, "Input",
  CellTags->"Twist2GluonOperator"],
Cell[2636471, 82408, 1693, 50, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2638201, 82463, 390, 10, 70, "Input",
  CellTags->"Twist2GluonOperator"],
Cell[2638594, 82475, 590, 17, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2639221, 82497, 440, 11, 70, "Input",
  CellTags->"Twist2GluonOperator"],
Cell[2639664, 82510, 27285, 681, 70, "Output"]
}, Closed]],
Cell[2666964, 83194, 63, 1, 70, "Text",
  CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{
Cell[2667052, 83199, 507, 12, 70, "Input",
  CellTags->"Twist2GluonOperator"],
Cell[2667562, 83213, 7240, 185, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2674839, 83403, 467, 12, 70, "Input",
  CellTags->"Twist2GluonOperator"],
Cell[2675309, 83417, 734, 21, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2676080, 83443, 517, 13, 70, "Input",
  CellTags->"Twist2GluonOperator"],
Cell[2676600, 83458, 52492, 1324, 70, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2729141, 84788, 77, 1, 70, "Subsubsection",
  CellTags->"Twist2GluonOperator"],
Cell[2729221, 84791, 98, 1, 70, "Text",
  CellTags->"Twist2GluonOperator"],
Cell[2729322, 84794, 334, 7, 70, "Input",
  CellTags->"Twist2GluonOperator"],
Cell[2729659, 84803, 463, 12, 70, "Input",
  CellTags->"Twist2GluonOperator"]
}, Closed]],

Cell[CellGroupData[{
Cell[2730159, 84820, 103, 1, 70, "Subsubsection",
  CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{
Cell[2730287, 84825, 316, 6, 70, "Input",
  CellTags->"Twist2GluonOperator"],
Cell[2730606, 84833, 486, 11, 70, "Output"]
}, Closed]],
Cell[2731107, 84847, 63, 1, 70, "Text",
  CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{
Cell[2731195, 84852, 385, 10, 70, "Input",
  CellTags->"Twist2GluonOperator"],
Cell[2731583, 84864, 5497, 131, 70, "Output"]
}, Closed]],
Cell[2737095, 84998, 63, 1, 70, "Text",
  CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{
Cell[2737183, 85003, 420, 10, 70, "Input",
  CellTags->"Twist2GluonOperator"],
Cell[2737606, 85015, 91934, 1866, 70, "Output"]
}, Closed]],
Cell[2829555, 86884, 63, 1, 70, "Text",
  CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{
Cell[2829643, 86889, 563, 13, 70, "Input",
  CellTags->"Twist2GluonOperator"],
Cell[2830209, 86904, 7225, 184, 70, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2837483, 87094, 105, 1, 70, "Subsubsection",
  CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{
Cell[2837613, 87099, 316, 6, 70, "Input",
  CellTags->"Twist2GluonOperator"],
Cell[2837932, 87107, 486, 11, 70, "Output"]
}, Closed]],
Cell[2838433, 87121, 63, 1, 70, "Text",
  CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{
Cell[2838521, 87126, 385, 10, 70, "Input",
  CellTags->"Twist2GluonOperator"],
Cell[2838909, 87138, 4792, 128, 70, "Output"]
}, Closed]],
Cell[2843716, 87269, 63, 1, 70, "Text",
  CellTags->"Twist2GluonOperator"],
Cell[2843782, 87272, 463, 12, 70, "Input",
  CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{
Cell[2844270, 87288, 390, 10, 70, "Input",
  CellTags->"Twist2GluonOperator"],
Cell[2844663, 87300, 4793, 128, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2849493, 87433, 440, 11, 70, "Input",
  CellTags->"Twist2GluonOperator"],
Cell[2849936, 87446, 4793, 128, 70, "Output"]
}, Closed]],
Cell[2854744, 87577, 63, 1, 70, "Text",
  CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{
Cell[2854832, 87582, 563, 13, 70, "Input",
  CellTags->"Twist2GluonOperator"],
Cell[2855398, 87597, 7240, 185, 70, "Output"]
}, Closed]],
Cell[2862653, 87785, 79, 1, 70, "Text",
  CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{
Cell[2862757, 87790, 629, 16, 70, "Input",
  CellTags->"Twist2GluonOperator"],
Cell[2863389, 87808, 12315, 297, 70, "Output"]
}, Closed]],
Cell[2875719, 88108, 97, 1, 70, "Text",
  CellTags->"Twist2GluonOperator"],
Cell[2875819, 88111, 334, 7, 70, "Input",
  CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{
Cell[2876178, 88122, 522, 13, 70, "Input",
  CellTags->"Twist2GluonOperator"],
Cell[2876703, 88137, 8751, 198, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2885515, 88342, 76, 1, 70, "ObjectName",
  CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{
Cell[2885616, 88347, 71, 1, 70, "Subsubsection",
  CellTags->"Twist2QuarkOperator"],
Cell[2885690, 88350, 981, 15, 70, "Text",
  CellTags->"Twist2QuarkOperator"],
Cell[2886674, 88367, 236, 9, 70, "Text",
  CellTags->"Twist2QuarkOperator"]
}, Closed]],
Cell[2886925, 88379, 68, 1, 70, "Subsubsection",
  CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{
Cell[2887018, 88384, 99, 1, 70, "Subsubsection",
  CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{
Cell[2887142, 88389, 317, 7, 70, "Input",
  CellTags->"Twist2QuarkOperator"],
Cell[2887462, 88398, 486, 11, 70, "Output"]
}, Closed]],
Cell[2887963, 88412, 76, 1, 70, "Text",
  CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{
Cell[2888064, 88417, 188, 4, 70, "Input",
  CellTags->"Twist2QuarkOperator"],
Cell[2888255, 88423, 822, 22, 70, "Output"]
}, Closed]],
Cell[2889092, 88448, 82, 1, 70, "Text",
  CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{
Cell[2889199, 88453, 369, 10, 70, "Input",
  CellTags->"Twist2QuarkOperator"],
Cell[2889571, 88465, 2162, 57, 70, "Output"]
}, Closed]],
Cell[2891748, 88525, 88, 1, 70, "Text",
  CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{
Cell[2891861, 88530, 457, 12, 70, "Input",
  CellTags->"Twist2QuarkOperator"],
Cell[2892321, 88544, 7442, 167, 70, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2899812, 88717, 101, 1, 70, "Subsubsection",
  CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{
Cell[2899938, 88722, 305, 6, 70, "Input",
  CellTags->"Twist2QuarkOperator"],
Cell[2900246, 88730, 486, 11, 70, "Output"]
}, Closed]],
Cell[2900747, 88744, 76, 1, 70, "Text",
  CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{
Cell[2900848, 88749, 188, 4, 70, "Input",
  CellTags->"Twist2QuarkOperator"],
Cell[2901039, 88755, 646, 17, 70, "Output"]
}, Closed]],
Cell[2901700, 88775, 82, 1, 70, "Text",
  CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{
Cell[2901807, 88780, 369, 10, 70, "Input",
  CellTags->"Twist2QuarkOperator"],
Cell[2902179, 88792, 2087, 55, 70, "Output"]
}, Closed]],
Cell[2904281, 88850, 88, 1, 70, "Text",
  CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{
Cell[2904394, 88855, 457, 12, 70, "Input",
  CellTags->"Twist2QuarkOperator"],
Cell[2904854, 88869, 7734, 172, 70, "Output"]
}, Closed]],
Cell[2912603, 89044, 94, 1, 70, "Text",
  CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{
Cell[2912722, 89049, 238, 6, 70, "Input",
  CellTags->"Twist2QuarkOperator"],
Cell[2912963, 89057, 280, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2913280, 89069, 439, 10, 70, "Input",
  CellTags->"Twist2QuarkOperator"],
Cell[2913722, 89081, 2920, 78, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2916679, 89164, 523, 12, 70, "Input",
  CellTags->"Twist2QuarkOperator"],
Cell[2917205, 89178, 17265, 362, 70, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2934519, 89546, 103, 1, 70, "Subsubsection",
  CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{
Cell[2934647, 89551, 318, 7, 70, "Input",
  CellTags->"Twist2QuarkOperator"],
Cell[2934968, 89560, 487, 11, 70, "Output"]
}, Closed]],
Cell[2935470, 89574, 179, 4, 70, "Text",
  CellTags->"Twist2QuarkOperator"],
Cell[2935652, 89580, 276, 5, 70, "Text",
  CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{
Cell[2935953, 89589, 248, 6, 70, "Input",
  CellTags->"Twist2QuarkOperator"],
Cell[2936204, 89597, 1127, 30, 70, "Output"]
}, Closed]],
Cell[2937346, 89630, 101, 1, 70, "Text",
  CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{
Cell[2937472, 89635, 369, 10, 70, "Input",
  CellTags->"Twist2QuarkOperator"],
Cell[2937844, 89647, 4117, 95, 70, "Output"]
}, Closed]],
Cell[2941976, 89745, 88, 1, 70, "Text",
  CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{
Cell[2942089, 89750, 188, 4, 70, "Input",
  CellTags->"Twist2QuarkOperator"],
Cell[2942280, 89756, 1322, 33, 70, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2943651, 89795, 105, 1, 70, "Subsubsection",
  CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{
Cell[2943781, 89800, 318, 7, 70, "Input",
  CellTags->"Twist2QuarkOperator"],
Cell[2944102, 89809, 487, 11, 70, "Output"]
}, Closed]],
Cell[2944604, 89823, 76, 1, 70, "Text",
  CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{
Cell[2944705, 89828, 248, 6, 70, "Input",
  CellTags->"Twist2QuarkOperator"],
Cell[2944956, 89836, 1127, 30, 70, "Output"]
}, Closed]],
Cell[2946098, 89869, 82, 1, 70, "Text",
  CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{
Cell[2946205, 89874, 369, 10, 70, "Input",
  CellTags->"Twist2QuarkOperator"],
Cell[2946577, 89886, 4117, 95, 70, "Output"]
}, Closed]],
Cell[2950709, 89984, 252, 6, 70, "Input",
  CellTags->"Twist2QuarkOperator"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2951010, 89996, 58, 1, 70, "ObjectName",
  CellTags->"Uncontract"],

Cell[CellGroupData[{
Cell[2951093, 90001, 62, 1, 70, "Subsubsection",
  CellTags->"Uncontract"],
Cell[2951158, 90004, 247, 5, 70, "Text",
  CellTags->"Uncontract"],

Cell[CellGroupData[{
Cell[2951430, 90013, 148, 3, 70, "Input",
  CellTags->"Uncontract"],
Cell[2951581, 90018, 410, 10, 70, "Output"]
}, Closed]],
Cell[2952006, 90031, 194, 9, 70, "Text",
  CellTags->"Uncontract"]
}, Closed]],

Cell[CellGroupData[{
Cell[2952237, 90045, 59, 1, 70, "Subsubsection",
  CellTags->"Uncontract"],

Cell[CellGroupData[{
Cell[2952321, 90050, 282, 7, 70, "Input",
  CellTags->"Uncontract"],
Cell[2952606, 90059, 544, 16, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2953187, 90080, 175, 4, 70, "Input",
  CellTags->"Uncontract"],
Cell[2953365, 90086, 1051, 30, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2954453, 90121, 170, 4, 70, "Input",
  CellTags->"Uncontract"],
Cell[2954626, 90127, 284, 7, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2954947, 90139, 175, 4, 70, "Input",
  CellTags->"Uncontract"],
Cell[2955125, 90145, 668, 19, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2955830, 90169, 185, 4, 70, "Input",
  CellTags->"Uncontract"],
Cell[2956018, 90175, 1513, 43, 70, "Output"]
}, Closed]],
Cell[2957546, 90221, 90, 1, 70, "Text",
  CellTags->"Uncontract"],

Cell[CellGroupData[{
Cell[2957661, 90226, 251, 6, 70, "Input",
  CellTags->"Uncontract"],
Cell[2957915, 90234, 269, 7, 70, "Output"]
}, Closed]],
Cell[2958199, 90244, 153, 4, 70, "Text",
  CellTags->"Uncontract"],

Cell[CellGroupData[{
Cell[2958377, 90252, 296, 7, 70, "Input",
  CellTags->"Uncontract"],
Cell[2958676, 90261, 712, 21, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2959425, 90287, 329, 8, 70, "Input",
  CellTags->"Uncontract"],
Cell[2959757, 90297, 1308, 39, 70, "Output"]
}, Closed]],
Cell[2961080, 90339, 166, 4, 70, "Input",
  CellTags->"Uncontract"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2961295, 90349, 84, 1, 70, "ObjectName",
  CellTags->"UnDeclareNonCommutative"],

Cell[CellGroupData[{
Cell[2961404, 90354, 75, 1, 70, "Subsubsection",
  CellTags->"UnDeclareNonCommutative"],
Cell[2961482, 90357, 199, 4, 70, "Text",
  CellTags->"UnDeclareNonCommutative"],
Cell[2961684, 90363, 366, 14, 70, "Text",
  CellTags->"UnDeclareNonCommutative"]
}, Closed]],

Cell[CellGroupData[{
Cell[2962087, 90382, 72, 1, 70, "Subsubsection",
  CellTags->"UnDeclareNonCommutative"],
Cell[2962162, 90385, 166, 3, 70, "Input",
  CellTags->"UnDeclareNonCommutative"],
Cell[2962331, 90390, 154, 4, 70, "Text",
  CellTags->"UnDeclareNonCommutative"],

Cell[CellGroupData[{
Cell[2962510, 90398, 132, 2, 70, "Input",
  CellTags->"UnDeclareNonCommutative"],
Cell[2962645, 90402, 112, 2, 70, "Output"]
}, Closed]],
Cell[2962772, 90407, 104, 1, 70, "Text",
  CellTags->"UnDeclareNonCommutative"],
Cell[2962879, 90410, 168, 3, 70, "Input",
  CellTags->"UnDeclareNonCommutative"],

Cell[CellGroupData[{
Cell[2963072, 90417, 193, 4, 70, "Input",
  CellTags->"UnDeclareNonCommutative"],
Cell[2963268, 90423, 113, 2, 70, "Output"]
}, Closed]],
Cell[2963396, 90428, 193, 4, 70, "Input",
  CellTags->"UnDeclareNonCommutative"],

Cell[CellGroupData[{
Cell[2963614, 90436, 203, 4, 70, "Input",
  CellTags->"UnDeclareNonCommutative"],
Cell[2963820, 90442, 171, 4, 70, "Output"]
}, Closed]],
Cell[2964006, 90449, 195, 4, 70, "Input",
  CellTags->"UnDeclareNonCommutative"],

Cell[CellGroupData[{
Cell[2964226, 90457, 203, 4, 70, "Input",
  CellTags->"UnDeclareNonCommutative"],
Cell[2964432, 90463, 173, 4, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2964666, 90474, 50, 1, 70, "ObjectName",
  CellTags->"Write2"],

Cell[CellGroupData[{
Cell[2964741, 90479, 58, 1, 70, "Subsubsection",
  CellTags->"Write2"],
Cell[2964802, 90482, 298, 6, 70, "Text",
  CellTags->"Write2"],
Cell[2965103, 90490, 154, 4, 70, "Text",
  CellTags->"Write2"],

Cell[CellGroupData[{
Cell[2965282, 90498, 166, 4, 70, "Input",
  CellTags->"Write2"],
Cell[2965451, 90504, 286, 8, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2965774, 90517, 140, 3, 70, "Input",
  CellTags->"Write2"],
Cell[2965917, 90522, 637, 13, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2966591, 90540, 143, 3, 70, "Input",
  CellTags->"Write2"],
Cell[2966737, 90545, 143, 3, 70, "Output"]
}, Closed]],
Cell[2966895, 90551, 313, 14, 70, "Text",
  CellTags->"Write2"]
}, Closed]],

Cell[CellGroupData[{
Cell[2967245, 90570, 55, 1, 70, "Subsubsection",
  CellTags->"Write2"],

Cell[CellGroupData[{
Cell[2967325, 90575, 553, 15, 70, "Input",
  CellTags->"Write2"],
Cell[2967881, 90592, 1036, 29, 70, "Output"]
}, Closed]],
Cell[2968932, 90624, 259, 7, 70, "Input",
  CellTags->"Write2"],
Cell[2969194, 90633, 79, 1, 70, "Text",
  CellTags->"Write2"],
Cell[2969276, 90636, 227, 6, 70, "Input",
  CellTags->"Write2"],
Cell[2969506, 90644, 74, 1, 70, "Text",
  CellTags->"Write2"],

Cell[CellGroupData[{
Cell[2969605, 90649, 446, 11, 70, "Input",
  CellTags->"Write2"],
Cell[2970054, 90662, 645, 16, 70, "Output"]
}, Closed]],
Cell[2970714, 90681, 350, 9, 70, "Input",
  CellTags->"Write2"],

Cell[CellGroupData[{
Cell[2971089, 90694, 283, 7, 70, "Input",
  CellTags->"Write2"],
Cell[2971375, 90703, 853, 26, 70, "Output"]
}, Closed]],
Cell[2972243, 90732, 228, 6, 70, "Input",
  CellTags->"Write2"],

Cell[CellGroupData[{
Cell[2972496, 90742, 446, 11, 70, "Input",
  CellTags->"Write2"],
Cell[2972945, 90755, 1046, 24, 70, "Output"]
}, Closed]],
Cell[2974006, 90782, 350, 9, 70, "Input",
  CellTags->"Write2"],
Cell[2974359, 90793, 107, 3, 70, "Text",
  CellTags->"Write2"],
Cell[2974469, 90798, 296, 8, 70, "Input",
  CellTags->"Write2"],

Cell[CellGroupData[{
Cell[2974790, 90810, 446, 11, 70, "Input",
  CellTags->"Write2"],
Cell[2975239, 90823, 890, 20, 70, "Output"]
}, Closed]],
Cell[2976144, 90846, 483, 13, 70, "Input",
  CellTags->"Write2"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2976676, 90865, 48, 1, 70, "ObjectName",
  CellTags->"Zeta2"],

Cell[CellGroupData[{
Cell[2976749, 90870, 57, 1, 70, "Subsubsection",
  CellTags->"Zeta2"],
Cell[2976809, 90873, 95, 1, 70, "Text",
  CellTags->"Zeta2"],
Cell[2976907, 90876, 203, 8, 70, "Text",
  CellTags->"Zeta2"]
}, Closed]],

Cell[CellGroupData[{
Cell[2977147, 90889, 54, 1, 70, "Subsubsection",
  CellTags->"Zeta2"],

Cell[CellGroupData[{
Cell[2977226, 90894, 102, 2, 70, "Input",
  CellTags->"Zeta2"],
Cell[2977331, 90898, 147, 3, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2977515, 90906, 132, 3, 70, "Input",
  CellTags->"Zeta2"],
Cell[2977650, 90911, 127, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2977814, 90918, 170, 4, 70, "Input",
  CellTags->"Zeta2"],
Cell[2977987, 90924, 176, 4, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2978224, 90935, 46, 1, 70, "ObjectName",
  CellTags->"$FCT"],

Cell[CellGroupData[{
Cell[2978295, 90940, 56, 1, 70, "Subsubsection",
  CellTags->"$FCT"],
Cell[2978354, 90943, 178, 4, 70, "Text",
  CellTags->"$FCT"],
Cell[2978535, 90949, 160, 4, 70, "Input",
  CellTags->"$FCT"],

Cell[CellGroupData[{
Cell[2978720, 90957, 206, 5, 70, "Input",
  CellTags->"$FCT"],
Cell[2978929, 90964, 218, 5, 70, "Output"]
}, Closed]],
Cell[2979162, 90972, 161, 4, 70, "Input",
  CellTags->"$FCT"],

Cell[CellGroupData[{
Cell[2979348, 90980, 206, 5, 70, "Input",
  CellTags->"$FCT"],
Cell[2979557, 90987, 218, 5, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2979836, 90999, 68, 1, 70, "ObjectName",
  CellTags->"$LorentzIndices"],

Cell[CellGroupData[{
Cell[2979929, 91004, 67, 1, 70, "Subsubsection",
  CellTags->"$LorentzIndices"],
Cell[2979999, 91007, 165, 4, 70, "Text",
  CellTags->"$LorentzIndices"],
Cell[2980167, 91013, 172, 4, 70, "Input",
  CellTags->"$LorentzIndices"],

Cell[CellGroupData[{
Cell[2980364, 91021, 391, 9, 70, "Input",
  CellTags->"$LorentzIndices"],
Cell[2980758, 91032, 894, 27, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2981689, 91064, 145, 3, 70, "Input",
  CellTags->"$LorentzIndices"],
Cell[2981837, 91069, 511, 12, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2982385, 91086, 361, 9, 70, "Input",
  CellTags->"$LorentzIndices"],
Cell[2982749, 91097, 1189, 37, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2983975, 91139, 145, 3, 70, "Input",
  CellTags->"$LorentzIndices"],
Cell[2984123, 91144, 744, 18, 70, "Output"]
}, Closed]],
Cell[2984882, 91165, 173, 4, 70, "Input",
  CellTags->"$LorentzIndices"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2985104, 91175, 64, 1, 70, "ObjectName",
  CellTags->"$PairBrackets"],

Cell[CellGroupData[{
Cell[2985193, 91180, 65, 1, 70, "Subsubsection",
  CellTags->"$PairBrackets"],
Cell[2985261, 91183, 156, 4, 70, "Text",
  CellTags->"$PairBrackets"],

Cell[CellGroupData[{
Cell[2985442, 91191, 118, 2, 70, "Input",
  CellTags->"$PairBrackets"],
Cell[2985563, 91195, 113, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2985713, 91202, 250, 7, 70, "Input",
  CellTags->"$PairBrackets"],
Cell[2985966, 91211, 616, 19, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2986619, 91235, 146, 3, 70, "Input",
  CellTags->"$PairBrackets"],
Cell[2986768, 91240, 112, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2986917, 91247, 250, 7, 70, "Input",
  CellTags->"$PairBrackets"],
Cell[2987170, 91256, 692, 19, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2987899, 91280, 147, 3, 70, "Input",
  CellTags->"$PairBrackets"],
Cell[2988049, 91285, 113, 2, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2988223, 91294, 62, 1, 70, "ObjectName",
  CellTags->"$VeryVerbose"],

Cell[CellGroupData[{
Cell[2988310, 91299, 64, 1, 70, "Subsubsection",
  CellTags->"$VeryVerbose"],

Cell[CellGroupData[{
Cell[2988399, 91304, 136, 3, 70, "Input",
  CellTags->"$VeryVerbose"],
Cell[2988538, 91309, 235, 3, 70, "Print"]
}, Closed]],

Cell[CellGroupData[{
Cell[2988810, 91317, 116, 2, 70, "Input",
  CellTags->"$VeryVerbose"],
Cell[2988929, 91321, 109, 2, 70, "Output"]
}, Closed]],
Cell[2989053, 91326, 173, 4, 70, "Input",
  CellTags->"$VeryVerbose"],

Cell[CellGroupData[{
Cell[2989251, 91334, 326, 9, 70, "Input",
  CellTags->"$VeryVerbose"],
Cell[2989580, 91345, 94, 2, 70, "Print"],
Cell[2989677, 91349, 257, 6, 70, "Print"],
Cell[2989937, 91357, 275, 6, 70, "Print"],
Cell[2990215, 91365, 1107, 31, 70, "Output"]
}, Closed]],
Cell[2991337, 91399, 163, 4, 70, "Input",
  CellTags->"$VeryVerbose"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2991549, 91409, 48, 1, 70, "ObjectName",
  CellTags->"$West"],

Cell[CellGroupData[{
Cell[2991622, 91414, 57, 1, 70, "Subsubsection",
  CellTags->"$West"],

Cell[CellGroupData[{
Cell[2991704, 91419, 122, 3, 70, "Input",
  CellTags->"$West"],
Cell[2991829, 91424, 335, 5, 70, "Print"]
}, Closed]],
Cell[2992179, 91432, 170, 8, 70, "Text",
  CellTags->"$West"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2992398, 91446, 54, 0, 70, "Commentary"],

Cell[CellGroupData[{
Cell[2992477, 91450, 158, 4, 70, "Input"],
Cell[2992638, 91456, 119, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2992794, 91463, 112, 2, 70, "Input"],
Cell[2992909, 91467, 116, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2993062, 91474, 114, 2, 70, "Input"],
Cell[2993179, 91478, 116, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2993332, 91485, 109, 2, 70, "Input"],
Cell[2993444, 91489, 127, 2, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

