(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    612681,      16596]*)
(*NotebookOutlinePosition[    636436,      17344]*)
(*  CellTagsIndexPosition[    630660,      17159]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["TARCER 1.95", "Title",
  TextAlignment->Center,
  CellTags->"T1.1"],

Cell[TextData[{
  "A ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " program for the reduction of two-loop propagator integrals "
}], "Text",
  TextAlignment->Center],

Cell[TextData[{
  "Rolf Mertig\n",
  ButtonBox["Mertig Research & Consulting\n",
    ButtonData:>{
      URL[ "http://www.mertig.com"], None},
    ButtonStyle->"Hyperlink"],
  "and\nRainer Scharf\n",
  ButtonBox["Universit\[ADoubleDot]t Leipzig",
    ButtonData:>{
      URL[ "http://www.physik.uni-leipzig.de/~scharf/"], None},
    ButtonStyle->"Hyperlink"]
}], "Text",
  Editable->False,
  TextAlignment->Center,
  CellTags->"T1.2"],

Cell["April 23, 1999", "Text",
  TextAlignment->Center],

Cell["\<\
COMMENTS (FO 15.3.2001.): Changed PreFactor into Prefactor1 to \
avoid conflict with FeynArts and FeynCalc.\
\>", "Text"],

Cell["\<\
COMMENTS (FO 15.3.2001.): Changed context of Zeta2 and made \
definition dependent on not having loaded FeynCalc.\
\>", "Text"],

Cell[TextData[{
  "COMMENTS (RM 25.4.): ",
  ButtonBox["TFISimplify",
    ButtonData:>"T1.7.1.1",
    ButtonStyle->"Hyperlink"],
  " (like TFIRecurse, but without trule[9])."
}], "Text"],

Cell[TextData[{
  "COMMENTS (RM 23.4.): bug fixed in ",
  ButtonBox["tlrule[17]",
    ButtonData:>"tlrule17",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "COMMENTS (RM 6.4.):  ",
  ButtonBox["special TVR relations",
    ButtonData:>"specialTVR",
    ButtonStyle->"Hyperlink"],
  " added to TVR."
}], "Text"],

Cell[TextData[{
  "COMMENTS (RM 22.3.):  ",
  ButtonBox["TVI Symmetry",
    ButtonData:>"Tsymmetry",
    ButtonStyle->"Hyperlink"],
  " added to TVR."
}], "Text"],

Cell[TextData[{
  "COMMENTS (RM 18.3.): More rules added to ",
  ButtonBox["$TTable",
    ButtonData:>"$TTable",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell[TextData[{
  "COMMENTS (RM 18.2.): More rules added to ",
  ButtonBox["$TTable",
    ButtonData:>"$TTable",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell[TextData[{
  "COMMENTS (RM 21.2.): Included ",
  ButtonBox["$TTable",
    ButtonData:>"$TTable",
    ButtonStyle->"Hyperlink"],
  ". added tlrule[25]"
}], "Text"],

Cell["\<\
COMMENTS (RM 20.2.): $RankLimit = {0,6} ;  Changed TarcerRecurse \
such that special TJR and TVR (reducing D -> D-2) are used first.\
\>", "Text"],

Cell["\<\
COMMENTS (RM 15.2.): $RankLimit = {0,8} ;  
                                              The following test now works:
                                              
                                                 Print[\"test 1 :  TFI[D, pp, \
{0, 0, 0, 1, 3}, {{1, MW}, {1, MZ}, {0, 0}, {1, MZ}, {1,MW}}] = \",
                                                            Timing[t1 \
=TarcerRecurse[TFI[D, pp, {0, 0, 0, 1, 3}, {{1, MW}, {1, MZ}, {0, 0}, {1, \
MZ}, {1,MW}}]]
                                                                       ] // \
InputForm
                                                         ]

                                                  Print[\"test 2 :  TFI[d, \
pp, 0, {0, 0, 0, 0, 4},{{1, m1}, {1, m2}, 0, 0, 0}] = \",
                                                           Timing[t2 \
=TarcerRecurse[TFI[D, pp,  0, {0, 0, 0, 0, 4},{{1, m1}, {1, m2}, 0, 0, 0}]];
                                                                       ] // \
InputForm
                                                          ]
\
\>", "Text"],

Cell["\<\
COMMENTS (RM 13.2.): tlrule[11] and trule[12] made more \
restrictive: inhibiting thus a recursion if {n5,m5} equals {0,0}.\
\>", "Text"],

Cell["\<\
COMMENTS (RM 12.2.): tlrule[15] made safer (in order to not get   0 \
:> 0 );
                                             TFIRecurse made safer (to not \
get into a recursion);
                                                  There is still something \
wrong with the tlrule's ; since 
                                         TFIRecurse[TFI[D, pp, {0, 0, 0, 1, \
3}, {{1, MW}, {1, MZ}, {0, 0}, {1, MZ}, {1,   MW}}]]
                                         doesn't work ..\
\>", "Text"],

Cell["\<\
COMMENTS (RM 5.2.): tlrule[10] slightly changed to cover more \
cases.\
\>", "Text"],

Cell["\<\
COMMENTS (RM 2.2.):  FunctionExpand added in tlrule[9]. Option \
TimeConstraint added to TarcerRecurse (because TimeConstrained is buggy under \
Linux).\
\>", "Text"],

Cell[TextData[{
  "COMMENTS (RM 1.2.):  Changed TarcerRecurse. New TLR ",
  ButtonBox["definition",
    ButtonData:>"TLRdef",
    ButtonStyle->"Hyperlink"],
  ". \n                          default $RankLimit={0,6};"
}], "Text"],

Cell[BoxData[
    \(\($Remember = False;\)\)], "Input"],

Cell["\<\
COMMENTS (RM 19.1.):   changes are:  tlrule[22] and tlrule[23], \
minor efficiency changes (Expand3 = Identity) and other small programming \
optimizations.\
\>", "Text"],

Cell["\<\
COMMENTS (RM 22.1.):   changes are: bug in tlrule[23] fixed, new \
tlrule[24], new option Factor to TarcerReduce (doesn't change anything by \
default, but allows for improved Factor-ing).\
\>", "Text"],

Cell[TextData[{
  "See also: ",
  ButtonBox["hep-ph/9801383",
    ButtonData:>{
      URL[ "http://xxx.lanl.gov/abs/hep-ph/9801383"], None},
    ButtonStyle->"Hyperlink"],
  ", published in Comput. Phys. Commun. 111 (1998) 265-273"
}], "Text",
  Editable->False],

Cell[CellGroupData[{

Cell["Table of contents", "Section",
  CellDingbat->"\[FilledSmallCircle]"],

Cell[TextData[ButtonBox["Preliminaries",
  ButtonData:>"T1.1.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Usages",
  ButtonData:>"T1.2.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Creating the tarcerij.mx file",
  ButtonData:>"T1.2.1.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Prologue (setting of $RankLimit)",
  ButtonData:>"T1.3.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Typesetting rules",
  ButtonData:>"T1.3.1.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["The Palettes",
  ButtonData:>"T1.3.2.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["OperatorApply",
  ButtonData:>"T1.3.3.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MassDerivative",
  ButtonData:>"T1.3.4.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["TarasovT",
  ButtonData:>"T1.3.5.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["ApplyTarasovT",
  ButtonData:>"T1.3.6.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Misc",
  ButtonData:>"T1.3.7.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Colors",
  ButtonData:>"T1.3.7.1.1",
  ButtonStyle->"Hyperlink"]], "SmallText"],

Cell[TextData[ButtonBox["PQ",
  ButtonData:>"T1.3.7.2.1",
  ButtonStyle->"Hyperlink"]], "SmallText"],

Cell[TextData[ButtonBox["PNQ",
  ButtonData:>"T1.3.7.3.1",
  ButtonStyle->"Hyperlink"]], "SmallText"],

Cell[TextData[ButtonBox["FactorC",
  ButtonData:>"T1.3.7.4.1",
  ButtonStyle->"Hyperlink"]], "SmallText"],

Cell[TextData[ButtonBox["TFI",
  ButtonData:>"T1.3.7.5.1",
  ButtonStyle->"Hyperlink"]], "SmallText"],

Cell[TextData[ButtonBox["TJI",
  ButtonData:>"T1.3.7.6.1",
  ButtonStyle->"Hyperlink"]], "SmallText"],

Cell[TextData[ButtonBox["TBI",
  ButtonData:>"T1.3.7.7.1",
  ButtonStyle->"Hyperlink"]], "SmallText"],

Cell[TextData[ButtonBox["TAI",
  ButtonData:>"T1.3.7.8.1",
  ButtonStyle->"Hyperlink"]], "SmallText"],

Cell[TextData[ButtonBox["Definitions and notation",
  ButtonData:>"T1.4.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[StyleBox[ButtonBox["ToArgs",
  ButtonData:>"T1.4.1.1",
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0.2, 0.6, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Cayley",
  ButtonData:>"T1.4.2.1",
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[1, 0, 0.4]]], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      ButtonBox[
        StyleBox[
          RowBox[{
            RowBox[{
              StyleBox["Cayley",
                FontColor->RGBColor[1, 0, 0.4]], "[", "i", "]"}], 
            "=", \(\[CapitalDelta]\_i\)}],
          SingleLetterItalics->False],
        ButtonFunction:>(FrontEndExecute[ {
            FrontEnd`NotebookLocate[ #2]}]&),
        ButtonData:>"T1.4.3.1",
        Active->True,
        Background->GrayLevel[1],
        ButtonNote->ButtonData], TextForm]]]], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      ButtonBox[
        StyleBox[
          RowBox[{
            RowBox[{
              StyleBox["CayleyD",
                FontColor->RGBColor[1, 0.2, 1]], "[", "i", "]"}], 
            "=", \(\[CapitalDelta]\_i/\[CapitalDelta]\)}],
          SingleLetterItalics->False],
        ButtonFunction:>(FrontEndExecute[ {
            FrontEnd`NotebookLocate[ #2]}]&),
        ButtonData:>"T1.4.4.1",
        Active->True,
        Background->GrayLevel[1],
        ButtonNote->ButtonData], TextForm]]]], "Text"],

Cell[TextData[ButtonBox["Utility Functions",
  ButtonData:>"T1.5.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun and friends",
  ButtonData:>"T1.5.1.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Interchange",
  ButtonData:>"T1.5.1.1.1",
  ButtonStyle->"Hyperlink"]], "SmallText"],

Cell[TextData[{
  ButtonBox["\[Nu]",
    ButtonData:>"T1.5.2.1",
    ButtonStyle->"Hyperlink"],
  ButtonBox["explicit",
    ButtonData:>"T1.5.2.1",
    ButtonStyle->"Hyperlink"]
}], "Text"],

Cell[TextData[ButtonBox["TA",
  ButtonData:>"T1.5.2.1.1",
  ButtonStyle->"Hyperlink"]], "SmallText"],

Cell[TextData[ButtonBox["CheckRecursion",
  ButtonData:>"T1.5.3.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["CheckTVIRecursion",
  ButtonData:>"T1.5.3.1.1",
  ButtonStyle->"Hyperlink"]], "SmallText"],

Cell[TextData[ButtonBox["CheckTJIRecursion",
  ButtonData:>"T1.5.3.2.1",
  ButtonStyle->"Hyperlink"]], "SmallText"],

Cell[TextData[ButtonBox["Recurrence Relations Input and Recursion Function \
Generation",
  ButtonData:>"T1.6.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Input (35)",
  ButtonData:>"T1.6.1.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (35)",
  ButtonData:>"T1.6.2.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      ButtonBox[
        StyleBox[
          RowBox[{
            FormBox[\(1\^\(\(+\)\(\ \)\)\),
              "TraditionalForm"], \(\(\ \)(\(35  _\) 1)\)}],
          SingleLetterItalics->False],
        ButtonFunction:>(FrontEndExecute[ {
            FrontEnd`NotebookLocate[ #2]}]&),
        ButtonData:>"T1.6.2.1.1",
        Active->True,
        Background->GrayLevel[1],
        ButtonNote->ButtonData], TraditionalForm]]]], "SmallText"],

Cell[TextData[Cell[BoxData[
    FormBox[
      ButtonBox[
        StyleBox[
          RowBox[{
            FormBox[\(2\^\(\(+\)\(\ \)\)\),
              "TraditionalForm"], \(\(\ \)(\(35  _\) 2)\)}],
          SingleLetterItalics->False],
        ButtonFunction:>(FrontEndExecute[ {
            FrontEnd`NotebookLocate[ #2]}]&),
        ButtonData:>"T1.6.2.2.1",
        Active->True,
        Background->GrayLevel[1],
        ButtonNote->ButtonData], TraditionalForm]]]], "SmallText"],

Cell[TextData[Cell[BoxData[
    FormBox[
      ButtonBox[
        StyleBox[
          RowBox[{
            FormBox[\(3\^\(\(+\)\(\ \)\)\),
              "TraditionalForm"], \(\(\ \)(\(35  _\) 3)\)}],
          SingleLetterItalics->False],
        ButtonFunction:>(FrontEndExecute[ {
            FrontEnd`NotebookLocate[ #2]}]&),
        ButtonData:>"T1.6.2.3.1",
        Active->True,
        Background->GrayLevel[1],
        ButtonNote->ButtonData], TraditionalForm]]]], "SmallText"],

Cell[TextData[Cell[BoxData[
    FormBox[
      ButtonBox[
        StyleBox[
          RowBox[{
            FormBox[\(4\^\(\(+\)\(\ \)\)\),
              "TraditionalForm"], \(\(\ \)(\(35  _\) 4)\)}],
          SingleLetterItalics->False],
        ButtonFunction:>(FrontEndExecute[ {
            FrontEnd`NotebookLocate[ #2]}]&),
        ButtonData:>"T1.6.2.4.1",
        Active->True,
        Background->GrayLevel[1],
        ButtonNote->ButtonData], TraditionalForm]]]], "SmallText"],

Cell[TextData[ButtonBox["Input (3501)",
  ButtonData:>"T1.6.3.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      ButtonBox[
        StyleBox[
          
          RowBox[{\(\(MakeFun\ \((3501)\)\ \[CapitalDelta]\)\(=\)\(0\)\(\ \
\)\), 
            FormBox[\((p\^2 = m\^2)\),
              "TraditionalForm"]}],
          SingleLetterItalics->False],
        ButtonFunction:>(FrontEndExecute[ {
            FrontEnd`NotebookLocate[ #2]}]&),
        ButtonData:>"T1.6.4.1",
        Active->True,
        Background->GrayLevel[1],
        ButtonNote->ButtonData], TraditionalForm]]]], "Text"],

Cell[TextData[ButtonBox["Input (3502)",
  ButtonData:>"T1.6.5.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      ButtonBox[
        StyleBox[
          
          RowBox[{\(\(MakeFun\ \((3502)\)\ \[CapitalDelta]\)\(=\)\(0\)\(\ \
\)\), 
            FormBox[\((p\^2 = m\^2)\),
              "TraditionalForm"]}],
          SingleLetterItalics->False],
        ButtonFunction:>(FrontEndExecute[ {
            FrontEnd`NotebookLocate[ #2]}]&),
        ButtonData:>"T1.6.6.1",
        Active->True,
        Background->GrayLevel[1],
        ButtonNote->ButtonData], TraditionalForm]]]], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      ButtonBox[
        StyleBox[
          
          RowBox[{\(\(MakeFun\ \((3503)\)\ \[CapitalDelta]\)\(=\)\(0\)\(\ \
\)\), 
            FormBox[\((p\^2 = m\^2)\),
              "TraditionalForm"]}],
          SingleLetterItalics->False],
        ButtonFunction:>(FrontEndExecute[ {
            FrontEnd`NotebookLocate[ #2]}]&),
        ButtonData:>"T1.6.7.1",
        Active->True,
        Background->GrayLevel[1],
        ButtonNote->ButtonData], TraditionalForm]]]], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      ButtonBox[
        StyleBox[
          
          RowBox[{\(\(MakeFun\ \((3504)\)\ \[CapitalDelta]\)\(=\)\(0\)\(\ \
\)\), 
            FormBox[\((p\^2 = m\^2)\),
              "TraditionalForm"]}],
          SingleLetterItalics->False],
        ButtonFunction:>(FrontEndExecute[ {
            FrontEnd`NotebookLocate[ #2]}]&),
        ButtonData:>"T1.6.8.1",
        Active->True,
        Background->GrayLevel[1],
        ButtonNote->ButtonData], TraditionalForm]]]], "Text"],

Cell[TextData[ButtonBox["Input (41)",
  ButtonData:>"T1.6.9.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (41)",
  ButtonData:>"T1.6.10.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Input (43)",
  ButtonData:>"T1.6.11.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Input (44)",
  ButtonData:>"T1.6.12.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Input (45)",
  ButtonData:>"T1.6.13.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (43) and (44)",
  ButtonData:>"T1.6.14.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (50)",
  ButtonData:>"T1.6.15.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Input (51)",
  ButtonData:>"T1.6.16.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (51)",
  ButtonData:>"T1.6.17.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Input (52)",
  ButtonData:>"T1.6.18.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (52)",
  ButtonData:>"T1.6.19.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (53)",
  ButtonData:>"T1.6.20.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Input (54)",
  ButtonData:>"T1.6.21.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (54)",
  ButtonData:>"T1.6.22.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Input (55)",
  ButtonData:>"T1.6.23.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (55)",
  ButtonData:>"T1.6.24.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Input (56)",
  ButtonData:>"T1.6.25.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (56)",
  ButtonData:>"T1.6.26.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Input (59)",
  ButtonData:>"T1.6.27.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (59)",
  ButtonData:>"T1.6.28.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Input (60)",
  ButtonData:>"T1.6.29.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (60)",
  ButtonData:>"T1.6.30.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Input (61)",
  ButtonData:>"T1.6.31.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (61)",
  ButtonData:>"T1.6.32.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (6153)",
  ButtonData:>"T1.6.33.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Input (62)",
  ButtonData:>"T1.6.34.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (62)",
  ButtonData:>"T1.6.35.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Input (63)",
  ButtonData:>"T1.6.36.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (63)",
  ButtonData:>"T1.6.37.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (6552)",
  ButtonData:>"T1.6.38.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (6552)",
  ButtonData:>"T1.6.39.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (6553)",
  ButtonData:>"T1.6.40.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Input (66)",
  ButtonData:>"T1.6.41.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (66)",
  ButtonData:>"T1.6.42.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Input (alternative67)",
  ButtonData:>"T1.6.43.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Input (67)",
  ButtonData:>"T1.6.44.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (67)",
  ButtonData:>"T1.6.45.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (6713)",
  ButtonData:>"T1.6.46.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Input (68)",
  ButtonData:>"T1.6.47.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (68)",
  ButtonData:>"T1.6.48.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (6813)",
  ButtonData:>"T1.6.49.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Input (70)",
  ButtonData:>"T1.6.50.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (70)",
  ButtonData:>"T1.6.51.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Input (71)",
  ButtonData:>"T1.6.52.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (71)",
  ButtonData:>"T1.6.53.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (7123)",
  ButtonData:>"T1.6.54.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (7113)",
  ButtonData:>"T1.6.55.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Input (78)",
  ButtonData:>"T1.6.56.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (78)",
  ButtonData:>"T1.6.57.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Input (80)",
  ButtonData:>"T1.6.58.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (80)",
  ButtonData:>"T1.6.59.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Input (81)",
  ButtonData:>"T1.6.60.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (81)",
  ButtonData:>"T1.6.61.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (8123)",
  ButtonData:>"T1.6.62.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (8113)",
  ButtonData:>"T1.6.63.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Input (82)",
  ButtonData:>"T1.6.64.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (82)",
  ButtonData:>"T1.6.65.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (8213)",
  ButtonData:>"T1.6.66.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (8212)",
  ButtonData:>"T1.6.67.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Input (83)",
  ButtonData:>"T1.6.68.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (83)",
  ButtonData:>"T1.6.69.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Input (87)",
  ButtonData:>"T1.6.70.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["(88)",
  ButtonData:>"T1.6.70.1.1",
  ButtonStyle->"Hyperlink"]], "SmallText"],

Cell[TextData[ButtonBox["(89)",
  ButtonData:>"T1.6.70.2.1",
  ButtonStyle->"Hyperlink"]], "SmallText"],

Cell[TextData[ButtonBox["MakeFun (87)",
  ButtonData:>"T1.6.71.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Input (90)",
  ButtonData:>"T1.6.72.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (90)",
  ButtonData:>"T1.6.73.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Input (91)",
  ButtonData:>"T1.6.74.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (911)",
  ButtonData:>"T1.6.75.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (912)",
  ButtonData:>"T1.6.76.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (913)",
  ButtonData:>"T1.6.77.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (914)",
  ButtonData:>"T1.6.78.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Input (92)",
  ButtonData:>"T1.6.79.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Input (93)",
  ButtonData:>"T1.6.80.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (93)",
  ButtonData:>"T1.6.81.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Input (94)",
  ButtonData:>"T1.6.82.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (94)",
  ButtonData:>"T1.6.83.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (9401)",
  ButtonData:>"T1.6.84.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (9402)",
  ButtonData:>"T1.6.85.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Input (95)",
  ButtonData:>"T1.6.86.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (95)",
  ButtonData:>"T1.6.87.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Input (96)",
  ButtonData:>"T1.6.88.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (96)",
  ButtonData:>"T1.6.89.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Input (97)",
  ButtonData:>"T1.6.90.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (97)",
  ButtonData:>"T1.6.91.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Input (98)",
  ButtonData:>"T1.6.92.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (98)",
  ButtonData:>"T1.6.93.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Input (99)",
  ButtonData:>"T1.6.94.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (99)",
  ButtonData:>"T1.6.95.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (9912)",
  ButtonData:>"T1.6.96.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (9913)",
  ButtonData:>"T1.6.97.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Input (100)",
  ButtonData:>"T1.6.98.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (100)",
  ButtonData:>"T1.6.99.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (1002)",
  ButtonData:>"T1.6.100.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (1003)",
  ButtonData:>"T1.6.101.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (1004)",
  ButtonData:>"T1.6.102.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (1005)",
  ButtonData:>"T1.6.103.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (1006)",
  ButtonData:>"T1.6.104.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Input (150)",
  ButtonData:>"T1.6.105.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (150)",
  ButtonData:>"T1.6.106.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Input (151)",
  ButtonData:>"T1.6.107.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (151)",
  ButtonData:>"T1.6.108.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Input (152)",
  ButtonData:>"T1.6.109.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (152)",
  ButtonData:>"T1.6.110.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Input (153)",
  ButtonData:>"T1.6.111.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (153)",
  ButtonData:>"T1.6.112.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Input (200)",
  ButtonData:>"T1.6.113.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (200)",
  ButtonData:>"T1.6.114.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (201)",
  ButtonData:>"T1.6.115.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (202)",
  ButtonData:>"T1.6.116.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (203)",
  ButtonData:>"T1.6.117.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (204)",
  ButtonData:>"T1.6.118.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["MakeFun (205)",
  ButtonData:>"T1.6.119.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Input (1xxxx)",
  ButtonData:>"T1.6.120.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["five -> four",
  ButtonData:>"T1.6.121.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["four -> three",
  ButtonData:>"T1.6.122.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["three -> two",
  ButtonData:>"T1.6.123.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["two -> one",
  ButtonData:>"T1.6.124.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["TarcerRecurse and TFIRecurse",
  ButtonData:>"T1.7.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["TFIRecurse",
  ButtonData:>"T1.7.1.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["T*IS",
  ButtonData:>"T1.7.2.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["TComment",
  ButtonData:>"T1.7.3.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["TarcerRecurse",
  ButtonData:>"T1.7.4.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["TarcerExpand",
  ButtonData:>"T1.8.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Construct T's",
  ButtonData:>"T1.9.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["$BasisIntegrals",
  ButtonData:>"T1.10.1",
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[TextData[ButtonBox["Save",
  ButtonData:>"T1.9.1",
  ButtonStyle->"Hyperlink"]], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Preliminaries", "Section",
  CellDingbat->"\[FilledSmallCircle]",
  CellTags->"T1.1.1"],

Cell[TextData[{
  "This is free software.\nYou may use it, distribute it, change it, improve \
it, etc..\nIf you have ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " questions, ask them to support@wolfram.com or to your local ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " reseller."
}], "SmallText",
  Editable->False],

Cell["\<\
 We consider the following type of integrals, where a,b,u,v,r,s,t \
are non-negative integers.\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(TFI\)\([\)\(d, 
        p\^2, \[CapitalDelta]p, {a, b}, {u, v, r, s, t}\)\)\)]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{
                RowBox[{
                  RowBox[{
                    RowBox[{
                      FormBox[\({{\[Nu]\_1, m\_1}, {\(\[Nu]\_2\)\(,\)\),
                        "TraditionalForm"], \(m\_2\)}], "}"}], 
                  ",", \({\[Nu]\_3, m\_3}\), ",", \({\[Nu]\_4, m\_4}\), 
                  ",", \({\[Nu]\_5, m\_5}\)}], "}"}], "]"}], " ", "="}], 
          " "}], TraditionalForm]]],
  "\n\n",
  Cell[BoxData[
      \(TraditionalForm\`1\/\[Pi]\^d\)]],
  "\[Integral] \[Integral] ",
  Cell[BoxData[
      FormBox[
        FractionBox[
          RowBox[{
            
            FormBox[\(\(d\^d\) k\_1\ \(d\^d\) 
                k\_2\ \(\((\[CapitalDelta]\[CenterDot]
                        k\_1)\)\^a\) \((\[CapitalDelta]\[CenterDot]k\_1)\)\^b\
\),
              
              "TraditionalForm"], \(\((k\_1\%2)\)\^u\), \(\((k\_2\%2)\)\^v\), \
\(\((p\[CenterDot]k\_1)\)\^r\), \(\((p\[CenterDot]
                    k\_2)\)\^s\), \(\((k\_1\[CenterDot]
                    k\_2)\)\^t\)}], \(\(\(\(\(\(\([\)\(k\_1\%2 - 
                                        m\_1\%2\)\(]\)\)\^\[Nu]\_1\)[
                                  k\_2\%2 - 
                                    m\_2\%2]\^\[Nu]\_2\)[\((k\_1 - p)\)\^2 - 
                              m\_3\%2]\^\[Nu]\_3\)[\((k\_2 - p)\)\^2 - 
                        m\_4\%2]\^\[Nu]\_4\)[\((k\_1 - k\_2)\)\^2 - 
                  m\_5\%2]\^\[Nu]\_5\)], TraditionalForm]]]
}], "Text"],

Cell["\<\
Putting the        $Post = (#;)&;       instruction after   
Unset[$Post]   suppresses all output cells.
Putting Unset[$Post] behind  $Post=(#:)&;
will produce a lot of typsetted reduction formulae.\
\>", "Text"],

Cell[BoxData[
    \(\(Unset[$Post];\)\)], "Input"],

Cell[BoxData[
    \(\($Post\  = \ \((\(#;\))\) &;\)\)], "Input"],

Cell[BoxData[
    \(\(If[$Notebooks =!= True, $Post\  = \ \((\(#;\))\) &];\)\)], "Input"],

Cell[BoxData[
    \(\($HistoryLength = 0;\)\)], "Input"],

Cell["\<\
This determines the directory into which the resulting file \
tarcer.mx is written.\
\>", "Text"],

Cell[BoxData[
    \(If[$Notebooks, 
      SetDirectory[
        ToFileName[
          First["\<FileName\>" /. 
              NotebookInformation[InputNotebook[]]]]]]\)], "Input"],

Cell[TextData[{
  "Somehow ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " crashes on my (R.M.) good old NeXTStation if I don't open all cells first \
...; this opens all cells automatically:"
}], "SmallText"],

Cell[BoxData[
    \(If[$System === "\<NeXT\>", 
      SelectionMove[EvaluationNotebook[], All, Notebook]; 
      FrontEndExecute[{FrontEnd`FrontEndToken[
            EvaluationNotebook[], "\<SelectionOpenAllGroups\>"]}]]\)], "Input"],

Cell[BoxData[
    \(\(Off[General::spell];\)\)], "Input"],

Cell[BoxData[
    \(\(Off[General::spell1];\)\)], "Input"],

Cell[CellGroupData[{

Cell["Creating the tarcerij.mx file", "Subsubsection",
  CellTags->"T1.2.1.1"],

Cell[TextData[{
  "Running this notebook will produce a tarcerij.mx file where ij will be \
replaced by \nthe two number set by the variable $RankLimit (default 33). \n\
In the same directory as this notebook which can be loaded  into ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " by    <<tarcer33.mx,\nor, when running in Terminal mode, on Unix systems, \
already when starting ",
  StyleBox["Mathematica, ",
    FontSlant->"Italic"],
  "as \nmyshellprompt>  math -initfile tarcer33.mx"
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Usages", "Section",
  CellDingbat->"\[FilledSmallCircle]",
  CellTags->"T1.2.1"],

Cell[BoxData[
    \(\(BeginPackage["\<HighEnergyPhysics`Tarcer`\>"];\)\)], "Input"],

Cell[BoxData[
    \(\(TarcerRecurse::usage = "\<TarcerRecurse[expr] applies recurrence \
relations for all TFI's (and TVI, TJI, TBI, TAI) in expr. For evaluation and \
Laurent expansion of the resulting basis integrals use \
TarcerExpand.\>";\)\)], "Input"],

Cell[BoxData[
    \(\(TarcerExpand::usage = "\<TarcerExpand[expr, d -> (4+e), order] or \
TarcerExpand[epxr, d -> (4-e), order] or TarcerExpand[expr, d -> (4 - 2 \
om)substitutes integrals as specified by the option TarcerRules, and does a \
Laurent expansion in the variable around 0 at the right hand side of the \
second argument (i.e., you can use whatever convention you like ...). The \
same effect as TarcerExpand[TarcerRecurse[expr], ...] can be achieved by \
setting the option TarcerRecurse of TarcerExpand to True. TarcerExpand[expr, \
d -> (4+e)] is equivalent to TarcerExpand[expr, d -> (4+e), 0].\>";\)\)], \
"Input"],

Cell[BoxData[
    \(\(TarcerReduce::usage = "\<TarcerReduce is an option to TarcerExpand. \
It should be set to a list of basic integrals.\>";\)\)], "Input"],

Cell[BoxData[
    \(\(Cayley::usage = "\<Cayley[m1,m2,m3,m4,m5,Sqrt[pp]] is the Cayley \
determinant.\>";\)\)], "Input"],

Cell[BoxData[
    \(\(Cayleyu::usage = "\<Cayleyu are the sub-Cayley-determinants as \
described in Tarasov's paper.\>";\)\)], "Input"],

Cell[BoxData[
    \(\(CayleyD::usage = "\<CayleyD are the sub-Cayley-determinants as \
described in Tarasov's paper.\>";\)\)], "Input"],

Cell[BoxData[
    \(\(Prefactor1::usage = "\<Prefactor1[expr] may be used to prohibit \
TarcerExpand from Taylor-expanding expr.\>";\)\)], "Input"],

Cell[BoxData[
    \(\(SEpsilon::usage = "\<Sepsilon[d] is an abbreviation for Exp[(d-4)/2 \
EulerGamma].\>";\)\)], "Input"],

Cell[BoxData[
    \(\(TFI::usage = "\<TFI[d, pp, dp, {a,b},{u,v,r,s,t},{ \
{n1,m1},{n2,m2},{n3,m3},{n4,m4},{n5,m5} }] is the massive 2-loop selfenergy \
type integral with five propagators in d dimensions. \n\t\tSee the TARCER \
paper for a detailed descriptioin of the notation used.\>";\)\)], "Input"],

Cell[BoxData[
    \(\(TFIRecurse::usage = "\<TFIRecurse[expr] applies the recursion \
algorithm implemented in TARCER.nb (following Tarasov) to TFI's (and TVI's, \
TJI's, TBI's, TAI's in expr.\>";\)\)], "Input"],

Cell[BoxData[
    \(\(TFISimplify::usage = "\<TFISimplify[expr] applies the recursion \
algorithm implemented in TARCER.nb (following Tarasov) to TFI's (and TVI's, \
TJI's, TBI's, TAI's in expr, except k1.k2.\>";\)\)], "Input"],

Cell[BoxData[
    \(\(TVI::usage = "\<TVI[d,pp,{ {n1,m1},{n2,m2},{n3,m3},{n4,m4}}] is the \
massive 2-loop integral with four propagators in d dimensions. \>";\)\)], \
"Input"],

Cell[BoxData[
    \(\(TJI::usage = "\<TJI[d, pp, { {n1,m1},{n2,m2},{n3,m3} }] is the \
massive 2-loop integral with three propagators in d dimensions. \>";\)\)], \
"Input"],

Cell[BoxData[
    \(\(TKI::usage = "\<TKI[d, 0, { {n1,m1},{n2,m2},{n3,m3} }] is the bubble \
massive 2-loop selfenergy type integral with three propagators in d \
dimensions. \>";\)\)], "Input"],

Cell[BoxData[
    \(\(TBI::usage = "\<TBI[d, pp, { {n1,m1},{n2,m2} }] is the massive 1-loop \
selfenergy type integral with two propagators in d dimensions.\>";\)\)], \
"Input"],

Cell[BoxData[
    \(\(TAI::usage = "\<TAI[d, pp, { {n1,m1} }] is the massive 1-loop \
selfenergy type integral with one propagator in d dimensions.\>";\)\)], \
"Input"],

Cell[BoxData[
    \(\(TFR::usage = "\<TFR is similar in syntax to TFI but applies once the \
recurrence relations derived for TFI.\>";\)\)], "Input"],

Cell[BoxData[
    \(\(TVR::usage = "\<TVR is similar in syntax to TVI but applies once the \
recurrence relations derived for TVI.\>";\)\)], "Input"],

Cell[BoxData[
    \(\(TJR::usage = "\<TJR is similar in syntax to TJI but applies once the \
recurrence relations derived for TJI.\>";\)\)], "Input"],

Cell[BoxData[
    \(\(TBR::usage = "\<TBR is similar in syntax to TBI but applies once the \
recurrence relations derived for TBI.\>";\)\)], "Input"],

Cell[BoxData[
    \(\(TAR::usage = "\<TAR is similar in syntax to TAI but applies once the \
recurrence relations derived for TAI.\>";\)\)], "Input"],

Cell[BoxData[
    \(\($RankLimit::usage = "\<$RankLimit is the list of integers specifying \
the highest possible sums of exponents of scalar products; i.e., {a+b, r+s} \
means that at most (Delta.k1)^a * (Delta.k2)^2 * (p.k1)^r * (p.k2)^s in the \
numerator will be calculated (a,b,r,s have to be non-negative integares). \
$RankLimit has to be set in the TARCER.nb notebook. In the tarcer.mx file \
this is not possible anymore.\>";\)\)], "Input"],

Cell[BoxData[
    \(\($TarcerRecursed::usage = "\<If $Comment is set to True all integrals\n\
\t\twhich are reduced are collected in the global variable \
$TarcerRecured.\>";\)\)], "Input"],

Cell[BoxData[
    \(\($BasisIntegrals::usage = "\<$BasisIntegrals is a list of some basis \
integrals. It is the default setting of TarcerReduce of \
TarcerExpand.\>";\)\)], "Input"],

Cell[BoxData[
    \(\($Comment::usage = "\<$Comment can be set to True or False. If set to \
False no comments are generated.\>";\)\)], "Input"],

Cell[BoxData[
    \(\($CommentNotebook::usage = "\<$Comment can be set to True or False. \
Setting it to True will generate a separate notebook (if and only if $Comment \
is True) where the used recursion relations are displayed.\>";\)\)], "Input"],

Cell[BoxData[
    \(\($TTable::usage = "\<$TTable is a list of precomputed reductions. \
$TTable is the default setting of the option Table of TarcerRecurse. \
\>";\)\)], "Input"],

Cell[BoxData[
    \(\(Begin["\<`Private`\>"];\)\)], "Input"],

Cell[BoxData[
    \(\(Expand3 = Identity;\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Prologue (setting of $RankLimit)", "Section",
  CellDingbat->"\[FilledSmallCircle]",
  CellTags->"T1.3.1"],

Cell[TextData[{
  "This sets the limit up to which the ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  "-operators are constructed automatically, i.e., $RankLimit = {a+b, r+s} , \
concerning: ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\((\[CapitalDelta]\[CenterDot]
              k\_1)\)\^a\)\(\ \)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\((\[CapitalDelta]\[CenterDot]k\_2)\)\^b\)]],
  " ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{"(", 
            FormBox[\(p\[CenterDot]k\_1\),
              "TraditionalForm"], ")"}], "r"], TraditionalForm]]],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{"(", 
            FormBox[\(p\[CenterDot]k\_2\),
              "TraditionalForm"], ")"}], "s"], TraditionalForm]]]
}], "Text"],

Cell[BoxData[
    \(\($RankLimit = {0, 6};\)\)], "Input"],

Cell["Check recursion relations by changing False to True here:", "Text"],

Cell[BoxData[
    \(\($CheckRecursion = False;\)\)], "Input"],

Cell["\<\
Change False to True for getting the input palettes for entering \
new recursion relations.\
\>", "Text"],

Cell[BoxData[
    \(\($PutPalettes = False;\)\)], "Input"],

Cell[TextData[{
  "Notice:  Instead of using shift operators",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            RowBox[{"  ", 
              StyleBox[\(1\^+\),
                FontWeight->"Bold"]}],
            "TraditionalForm"], ",", 
          StyleBox[\(2\^+\),
            FontWeight->"Bold"]}], TraditionalForm]]],
  " etc. the \[Nu]-indices are colored blue; instead of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            RowBox[{"  ", 
              StyleBox[\(1\^-\),
                FontWeight->"Bold"]}],
            "TraditionalForm"], ",", 
          StyleBox[\(2\^-\),
            FontWeight->"Bold"]}], TraditionalForm]]],
  " etc. the \[Nu]-indices are colored red."
}], "Text"],

Cell[CellGroupData[{

Cell["Typesetting rules", "Subsection",
  CellTags->"T1.3.1.1"],

Cell[BoxData[
    \(\(atime = AbsoluteTime[];\)\)], "Input"],

Cell[BoxData[
    \(SEpsilon /: MakeBoxes[SEpsilon[d_], fmt_] := 
      InterpretationBox @@ {StyleBox[
            SubscriptBox["\<S\>", First[Variables[d]]], 
            FontWeight \[Rule] "\<Bold\>"], SEpsilon[d], 
          Editable \[Rule] False}\)], "Input"],

Cell[BoxData[
    \(MakeBoxes[SEpsilon[d_]\^n_, fmt_] := 
      InterpretationBox @@ {StyleBox[
            SubsuperscriptBox["\<S\>", First[Variables[d]], n], 
            FontWeight \[Rule] "\<Bold\>"], SEpsilon[d], 
          Editable \[Rule] False}\)], "Input"],

Cell[BoxData[
    \(Prefactor1 /: MakeBoxes[Prefactor1[d_], fmt_] := 
      InterpretationBox @@ {MakeBoxes[d, fmt], Prefactor1[d], 
          Editable -> False}\)], "Input"],

Cell["\<\
Don't mess with the InterpretationBox's !! (important for the \
palette and OperatorApply).\
\>", "Text"],

Cell[BoxData[
    \(MakeBoxes[Schiebe[i_, pm_String]\ , fmt_] := 
      InterpretationBox[
        StyleBox[SuperscriptBox[i, pm], FontWeight -> "\<Bold\>"], 
        Schiebe[i, pm], Editable -> True]\)], "Input"],

Cell[BoxData[
    \(\(CayleyD /: MakeBoxes[\(CayleyD[i_Integer]\)[args_], fmt_] := 
        FractionBox[
          SubscriptBox["\<\[CapitalDelta]\>", \ 
            i], "\<\[CapitalDelta]\>"];\)\)], "Input"],

Cell[BoxData[
    \(\(CayleyD /: MakeBoxes[\(CayleyD[i_Integer, j_Integer]\)[args_], fmt_] := 
        FractionBox[
          SubscriptBox["\<\[CapitalDelta]\>", 
            10\ i + j], "\<\[CapitalDelta]\>"];\)\)], "Input"],

Cell[BoxData[
    \(\(CayleyD /: 
        MakeBoxes[\(CayleyD[i_Integer, j_Integer, k_Integer]\)[args_], fmt_] := 
        FractionBox[
          SubscriptBox["\<\[CapitalDelta]\>", 
            100\ \ i + 10  j + k], "\<\[CapitalDelta]\>"];\)\)], "Input"],

Cell[BoxData[
    \(\(Cayley /: MakeBoxes[\(Cayley[i_Integer]\)[args_], fmt_] := 
        SubscriptBox["\<\[CapitalDelta]\>", \ i];\)\)], "Input"],

Cell[BoxData[
    \(\(Cayley /: MakeBoxes[\(Cayley[i_Integer, j_Integer]\)[args_], fmt_] := 
        SubscriptBox["\<\[CapitalDelta]\>", 10\ i + j];\)\)], "Input"],

Cell[BoxData[
    \(\(Cayley /: 
        MakeBoxes[\(Cayley[i_Integer, j_Integer, k_Integer]\)[args_], fmt_] := 
        SubscriptBox["\<\[CapitalDelta]\>", 
          100\ \ i + 10  j + k];\)\)], "Input"],

Cell[BoxData[
    \(\(Cayleyu /: 
        MakeBoxes[\(Cayleyu[i_Integer, j_Integer, k_Integer]\)[args_], fmt_] := 
        SubscriptBox["\<u\>", 100\ \ i + 10  j + k];\)\)], "Input"],

Cell["\<\
MakeBoxes[PP, fm_] := InterpretationBox[SuperscriptBox[p, 2], PP]; 
MakeBoxes[m1^(p_), _] := InterpretationBox[SubsuperscriptBox[m, 1, p], m1^p]; \

MakeBoxes[m2^(p_), _] := InterpretationBox[SubsuperscriptBox[m, 2, p], m2^p]; \

MakeBoxes[m3^(p_), _] := InterpretationBox[SubsuperscriptBox[m, 3, p], m3^p]; \

MakeBoxes[m4^(p_), _] := InterpretationBox[SubsuperscriptBox[m, 4, p], m4^p]; \

MakeBoxes[m5^(p_), _] := InterpretationBox[SubsuperscriptBox[m, 5, p], m5^p]; \

m6 = Sqrt[PP]; \
\>", "Input"],

Cell[BoxData[
    \(\(MakeBoxes[m1, _] := 
        InterpretationBox[SubscriptBox[m, 1], m1];\)\)], "Input"],

Cell[BoxData[
    \(\(MakeBoxes[m2, _] := 
        InterpretationBox[SubscriptBox[m, 2], m2];\)\)], "Input"],

Cell[BoxData[
    \(\(MakeBoxes[m3, _] := 
        InterpretationBox[SubscriptBox[m, 3], m3];\)\)], "Input"],

Cell[BoxData[
    \(\(MakeBoxes[m4, _] := 
        InterpretationBox[SubscriptBox[m, 4], m4];\)\)], "Input"],

Cell[BoxData[
    \(\(MakeBoxes[m5, _] := 
        InterpretationBox[SubscriptBox[m, 5], m5];\)\)], "Input"],

Cell[BoxData[
    \(\(mbt[z_] := ToBoxes[z, TraditionalForm];\)\)], "Input"],

Cell[BoxData[
    \(\(redblue[z_ /; Head[z] =!= Plus] := mbt[z];\)\)], "Input"],

Cell[BoxData[
    \(\(redblue[z_ - 1] := 
        StyleBox[mbt[z], FontColor \[Rule] RGBColor[1, 0, 0]];\)\)], "Input"],

Cell[BoxData[
    \(\(redblue[z_Subscript - 2] := 
        StyleBox[
          SubscriptBox[
            OverscriptBox[
              z\[LeftDoubleBracket]1\[RightDoubleBracket], "\<_\>"], 
            z\[LeftDoubleBracket]2\[RightDoubleBracket]], 
          FontColor \[Rule] RGBColor[1, 0, 0]];\)\)], "Input"],

Cell[BoxData[
    \(\(redblue[z_ - 2] := 
        StyleBox[OverscriptBox[mbt[z], "\<_\>"], 
          FontColor \[Rule] RGBColor[1, 0, 0]];\)\)], "Input"],

Cell[BoxData[
    \(\(redblue[z_ - 3] := 
        StyleBox[UnderscriptBox[OverscriptBox[mbt[z], "\<_\>"], "\<_\>"], 
          FontColor \[Rule] RGBColor[1, 0, 0]];\)\)], "Input"],

Cell[BoxData[
    \(\(redblue[z_ + 1] := 
        StyleBox[mbt[z], FontColor \[Rule] RGBColor[0, 0, 1]];\)\)], "Input"],

Cell[BoxData[
    \(\(redblue[z_ + 2] := 
        StyleBox[OverscriptBox[mbt[z], "\<_\>"], 
          FontColor \[Rule] RGBColor[0, 0, 1]];\)\)], "Input"],

Cell[BoxData[
    \(\(redblue[z_Subscript + 2] := 
        StyleBox[
          SubscriptBox[
            OverscriptBox[
              z\[LeftDoubleBracket]1\[RightDoubleBracket], "\<_\>"], 
            z\[LeftDoubleBracket]2\[RightDoubleBracket]], 
          FontColor \[Rule] RGBColor[0, 0, 1]];\)\)], "Input"],

Cell[BoxData[
    \(\(TFI /: 
        MakeBoxes[TFI[d_, pp_, {ur__}, {den__}], 
          fmt_] := \n\t\((InterpretationBox @@ {SubsuperscriptBox[
                  StyleBox["\<F\>", SingleLetterItalics -> False, 
                    FontWeight -> "\<Bold\>"], 
                  RowBox @@ {\((redblue /@ {den})\)}, 
                  RowBox[{"\<(\>", 
                      ToBoxes[d, TraditionalForm], "\<)\>", "\< \>", 
                      ur}]], \n\t\tTFI[d, pp, {ur}, {den}], 
                Editable -> True})\) /; 
          MemberQ[{StandardForm, TraditionalForm}, fmt];\)\)], "Input"],

Cell[BoxData[
    \(\(TFI /: 
        MakeBoxes[TFI[d_, pp_, dp_, any__, {den__}], 
          fmt_] := \n\t\(\((InterpretationBox @@ {SubsuperscriptBox[
                    StyleBox["\<F\>", SingleLetterItalics -> False, 
                      FontWeight -> "\<Bold\>"], 
                    RowBox @@ {\((redblue /@ {den})\)}, 
                    RowBox[{"\<(\>", 
                        ToBoxes[d, TraditionalForm], "\<)\>", "\< \>", 
                        Apply[Sequence, Flatten[{any}]]}]], \n\t\tTFI[d, pp, 
                    dp, any, {den}], Editable -> True})\) /; 
            MemberQ[{StandardForm, TraditionalForm}, fmt]\) /; 
          Head[dp] =!= List;\)\)], "Input"],

Cell[BoxData[
    \(\(TFI /: 
        MakeBoxes[TFI[dpp__, {den__}], 
          fmt_] := \n\t\((InterpretationBox @@ {SubsuperscriptBox[
                  StyleBox["\<F\>", SingleLetterItalics -> False, 
                    FontWeight -> "\<Bold\>"], 
                  RowBox @@ {\((redblue /@ {den})\)}, 
                  RowBox[{"\<(\>", 
                      ToBoxes[First[{dpp}], 
                        TraditionalForm], "\<)\>"}]], \n\t\tTFI[dpp, {den}], 
                Editable -> True})\) /; 
          MemberQ[{StandardForm, TraditionalForm}, fmt] && 
            Head[Last[{dpp}]] =!= List;\)\)], "Input"],

Cell[BoxData[
    \(\(TVI /: 
        MakeBoxes[TVI[dpp__, {den__}], 
          fmt_] := \n\((\t\((InterpretationBox @@ {SubsuperscriptBox[
                      StyleBox["\<V\>", SingleLetterItalics -> False, 
                        FontWeight -> "\<Bold\>"], 
                      RowBox @@ {\((redblue /@ {den})\)}, 
                      RowBox[{"\<(\>", 
                          ToBoxes[{dpp}[\([1]\)], 
                            TraditionalForm], "\<)\>"}]], \n\t\(Hold[TVI]\)[
                      dpp, {den}], Editable -> True})\) /. 
              Hold[TVI] -> TVI)\) /; 
          MemberQ[{StandardForm, TraditionalForm}, fmt] && 
            Head[Last[{dpp}]] =!= List;\)\)], "Input"],

Cell[BoxData[
    \({TVI[d, {\[Alpha], \[Beta], \[Gamma], \[Delta]}], 
      TVI[d, {\[Alpha] + 1, \[Beta], \[Gamma], \[Delta]}], 
      TVI[d, {\[Alpha] - 1, \[Beta], \[Gamma], \[Delta]}]}\)], "Input"],

Cell[BoxData[
    \(TJI /: 
      MakeBoxes[TJI[d_, 0, {den__}], 
        fmt_] := \t\((\n\((\((InterpretationBox @@ {SubsuperscriptBox[
                        StyleBox["\<K\>", SingleLetterItalics -> False, 
                          FontWeight -> "\<Bold\>"], 
                        RowBox @@ {\((redblue /@ {den})\)}, 
                        RowBox[{"\<(\>", 
                            ToBoxes[d, 
                              TraditionalForm], "\<)\>"}]], \n\t\t\(Hold[
                          TJI]\)[d, 0, {den}], Editable -> True})\) /. 
                Hold[TJI] -> TJI)\) /; 
            MemberQ[{StandardForm, TraditionalForm}, fmt]\n\t)\) /; 
        MemberQ[{StandardForm, TraditionalForm}, fmt]\)], "Input"],

Cell[BoxData[
    \(TJI /: 
      MakeBoxes[TJI[dpp__, {den__}], 
        fmt_] := \t\((\((InterpretationBox @@ {SubsuperscriptBox[
                    StyleBox["\<J\>", SingleLetterItalics -> False, 
                      FontWeight -> "\<Bold\>"], 
                    RowBox @@ {\((redblue /@ {den})\)}, 
                    RowBox[{"\<(\>", 
                        ToBoxes[{dpp}[\([1]\)], 
                          TraditionalForm], "\<)\>"}]], \n\t\t\(Hold[TJI]\)[
                    dpp, {den}], Editable -> True})\) /. Hold[TJI] -> TJI)\) /; 
        MemberQ[{StandardForm, TraditionalForm}, fmt]\)], "Input"],

Cell[BoxData[
    \(\(TKI /: 
        MakeBoxes[TKI[d_, pp___, {den__}], 
          fmt_] := \n\t\((SubsuperscriptBox[
              StyleBox["\<K\>", SingleLetterItalics -> False, 
                FontWeight -> "\<Bold\>"], 
              RowBox @@ {\((redblue /@ {den})\)}, 
              RowBox[{"\<(\>", ToBoxes[d, TraditionalForm], "\<)\>"}]])\) /; 
          MemberQ[{StandardForm, TraditionalForm}, fmt];\)\)], "Input"],

Cell[BoxData[
    \(TKI /: 
      MakeBoxes[TKI[dpp__, {den__}], 
        fmt_] := \t\((\((InterpretationBox @@ {SubsuperscriptBox[
                    StyleBox["\<K\>", SingleLetterItalics -> False, 
                      FontWeight -> "\<Bold\>"], 
                    RowBox @@ {\((redblue /@ {den})\)}, 
                    RowBox[{"\<(\>", 
                        ToBoxes[{dpp}[\([1]\)], 
                          TraditionalForm], "\<)\>"}]], \n\t\t\(Hold[TKI]\)[
                    dpp, {den}], Editable -> True})\) /. Hold[TKI] -> TKI)\) /; 
        MemberQ[{StandardForm, TraditionalForm}, fmt]\)], "Input"],

Cell[BoxData[
    \({TKI[d, {\[Alpha], \[Beta], \[Gamma]}], 
      TKI[d, {\[Alpha] + 1, \[Beta], \[Gamma]}], 
      TKI[d, {\[Alpha] - 1, \[Beta], \[Gamma]}]}\)], "Input"],

Cell[BoxData[
    \(\(TBI /: 
        MakeBoxes[TBI[d_, pp___, {den__}], 
          fmt_] := \n\t\((SubsuperscriptBox[
              StyleBox["\<B\>", SingleLetterItalics -> False, 
                FontWeight -> "\<Bold\>"], 
              RowBox @@ {\((redblue /@ {den})\)}, 
              RowBox[{"\<(\>", ToBoxes[d, TraditionalForm], "\<)\>"}]])\) /; 
          MemberQ[{StandardForm, TraditionalForm}, fmt];\)\)], "Input"],

Cell[BoxData[
    \(\(TBI /: 
        MakeBoxes[TBI[d_, pp___, {den__}], 
          fmt_] := \n\t\((InterpretationBox @@ {SubsuperscriptBox[
                  StyleBox["\<B\>", SingleLetterItalics -> False, 
                    FontWeight -> "\<Bold\>"], 
                  RowBox @@ {\((redblue /@ {den})\)}, 
                  RowBox[{"\<(\>", 
                      ToBoxes[d, TraditionalForm], "\<)\>"}]], \n\t\tTBI[d, 
                  pp, {den}], Editable -> True})\) /; 
          MemberQ[{StandardForm, TraditionalForm}, fmt];\)\)], "Input"],

Cell[BoxData[
    \({TBI[d, {\[Alpha], \[Beta]}], TBI[d, {\[Alpha] + 1, \[Beta]}], 
      TBI[d, {\[Alpha] - 1, \[Beta]}]}\)], "Input"],

Cell[BoxData[
    \(\(TAI /: 
        MakeBoxes[TAI[d_, pp___, {den__}], 
          fmt_] := \n\t\((InterpretationBox @@ {SubsuperscriptBox[
                  StyleBox["\<A\>", SingleLetterItalics -> False, 
                    FontWeight -> "\<Bold\>"], 
                  RowBox @@ {\((redblue /@ {den})\)}, 
                  RowBox[{"\<(\>", 
                      ToBoxes[d, TraditionalForm], "\<)\>"}]], \n\t\tTAI[
                  d, {den}], Editable -> True})\) /; 
          MemberQ[{StandardForm, TraditionalForm}, fmt];\)\)], "Input"],

Cell[BoxData[
    \({TAI[d, {\[Alpha]}], TAI[d, {\[Alpha] + 1}], 
      TAI[d, {\[Alpha] - 1}]}\)], "Input"],

Cell["\<\
T*IC are just like T*I , but used only for commentary in the 
recursion (TComment).\
\>", "Text"],

Cell[BoxData[
    \(\(TFIC /: 
        MakeBoxes[TFIC[d_, pp_, {0, 0, i_, 0, 0}, {den__}], 
          fmt_] := \n\t\((InterpretationBox @@ {SubsuperscriptBox[
                  StyleBox["\<F\>", SingleLetterItalics -> False, 
                    FontWeight -> "\<Bold\>"], 
                  RowBox @@ {\((redblue /@ {den})\)}, 
                  RowBox[{"\<(\>", 
                      ToBoxes[d, TraditionalForm], "\<)\>", "\< \>", 
                      i, "\<0\>"}]], \n\t\tTFIC[d, 
                  pp, {0, 0, i, 0, 0}, {den}], Editable -> True})\) /; 
          MemberQ[{StandardForm, TraditionalForm}, fmt];\)\)], "Input"],

Cell[BoxData[
    \(\(TFIC /: 
        MakeBoxes[TFIC[d_, pp_, {0, 0, 0, i_, 0}, {den__}], 
          fmt_] := \n\t\((InterpretationBox @@ {SubsuperscriptBox[
                  StyleBox["\<F\>", SingleLetterItalics -> False, 
                    FontWeight -> "\<Bold\>"], 
                  RowBox @@ {\((redblue /@ {den})\)}, 
                  RowBox[{"\<(\>", 
                      ToBoxes[d, TraditionalForm], "\<)\>", "\< \>", "\<0\>", 
                      i}]], \n\t\tTFIC[d, pp, {0, 0, 0, i, 0}, {den}], 
                Editable -> True})\) /; 
          MemberQ[{StandardForm, TraditionalForm}, fmt];\)\)], "Input"],

Cell[BoxData[
    \(\(TFIC /: 
        MakeBoxes[TFIC[dpp__, {den__}], 
          fmt_] := \n\t\((InterpretationBox @@ {SubsuperscriptBox[
                  StyleBox["\<F\>", SingleLetterItalics -> False, 
                    FontWeight -> "\<Bold\>"], 
                  RowBox @@ {\((redblue /@ {den})\)}, 
                  RowBox[{"\<(\>", 
                      ToBoxes[First[{dpp}], 
                        TraditionalForm], "\<)\>"}]], \n\t\tTFIC[dpp, {den}], 
                Editable -> True})\) /; 
          MemberQ[{StandardForm, TraditionalForm}, fmt] && 
            Head[Last[{dpp}]] =!= List;\)\)], "Input"],

Cell[BoxData[
    \(\(TVIC /: 
        MakeBoxes[TVIC[dpp__, {den__}], 
          fmt_] := \n\((\t\((InterpretationBox @@ {SubsuperscriptBox[
                      StyleBox["\<V\>", SingleLetterItalics -> False, 
                        FontWeight -> "\<Bold\>"], 
                      RowBox @@ {\((redblue /@ {den})\)}, 
                      RowBox[{"\<(\>", 
                          ToBoxes[{dpp}[\([1]\)], 
                            TraditionalForm], "\<)\>"}]], \n\t\(Hold[TVIC]\)[
                      dpp, {den}], Editable -> True})\) /. 
              Hold[TVIC] -> TVIC)\) /; 
          MemberQ[{StandardForm, TraditionalForm}, fmt] && 
            Head[Last[{dpp}]] =!= List;\)\)], "Input"],

Cell[BoxData[
    \(TJIC /: 
      MakeBoxes[TJIC[d_, 0, {den__}], 
        fmt_] := \t\((\n\((\((InterpretationBox @@ {SubsuperscriptBox[
                        StyleBox["\<K\>", SingleLetterItalics -> False, 
                          FontWeight -> "\<Bold\>"], 
                        RowBox @@ {\((redblue /@ {den})\)}, 
                        RowBox[{"\<(\>", 
                            ToBoxes[d, 
                              TraditionalForm], "\<)\>"}]], \n\t\t\(Hold[
                          TJIC]\)[d, 0, {den}], Editable -> True})\) /. 
                Hold[TJIC] -> TJIC)\) /; 
            MemberQ[{StandardForm, TraditionalForm}, fmt]\n\t)\) /; 
        MemberQ[{StandardForm, TraditionalForm}, fmt]\)], "Input"],

Cell[BoxData[
    \(TJIC /: 
      MakeBoxes[TJIC[dpp__, {den__}], 
        fmt_] := \t\((\((InterpretationBox @@ {SubsuperscriptBox[
                    StyleBox["\<J\>", SingleLetterItalics -> False, 
                      FontWeight -> "\<Bold\>"], 
                    RowBox @@ {\((redblue /@ {den})\)}, 
                    RowBox[{"\<(\>", 
                        ToBoxes[{dpp}[\([1]\)], 
                          TraditionalForm], "\<)\>"}]], \n\t\t\(Hold[TJIC]\)[
                    dpp, {den}], Editable -> True})\) /. 
            Hold[TJIC] -> TJIC)\) /; 
        MemberQ[{StandardForm, TraditionalForm}, fmt]\)], "Input"],

Cell[BoxData[
    \(\(TBIC /: 
        MakeBoxes[TBIC[d_, pp___, {den__}], 
          fmt_] := \n\t\((SubsuperscriptBox[
              StyleBox["\<B\>", SingleLetterItalics -> False, 
                FontWeight -> "\<Bold\>"], 
              RowBox @@ {\((redblue /@ {den})\)}, 
              RowBox[{"\<(\>", ToBoxes[d, TraditionalForm], "\<)\>"}]])\) /; 
          MemberQ[{StandardForm, TraditionalForm}, fmt];\)\)], "Input"],

Cell[BoxData[
    \(\(TBIC /: 
        MakeBoxes[TBIC[d_, pp___, {den__}], 
          fmt_] := \n\t\((InterpretationBox @@ {SubsuperscriptBox[
                  StyleBox["\<B\>", SingleLetterItalics -> False, 
                    FontWeight -> "\<Bold\>"], 
                  RowBox @@ {\((redblue /@ {den})\)}, 
                  RowBox[{"\<(\>", 
                      ToBoxes[d, TraditionalForm], "\<)\>"}]], \n\t\tTBIC[d, 
                  pp, {den}], Editable -> True})\) /; 
          MemberQ[{StandardForm, TraditionalForm}, fmt];\)\)], "Input"],

Cell[BoxData[
    \(\(TAIC /: 
        MakeBoxes[TAIC[d_, pp___, {den__}], 
          fmt_] := \n\t\((InterpretationBox @@ {SubsuperscriptBox[
                  StyleBox["\<A\>", SingleLetterItalics -> False, 
                    FontWeight -> "\<Bold\>"], 
                  RowBox @@ {\((redblue /@ {den})\)}, 
                  RowBox[{"\<(\>", 
                      ToBoxes[d, TraditionalForm], "\<)\>"}]], \n\t\tTAIC[
                  d, {den}], Editable -> True})\) /; 
          MemberQ[{StandardForm, TraditionalForm}, fmt];\)\)], "Input"],

Cell[BoxData[
    \(\(TFR /: 
        MakeBoxes[TFR[d_, pp_, {0, 0, i_, 0, 0}, {den__}], 
          fmt_] := \n\t\((InterpretationBox @@ {SubsuperscriptBox[
                  StyleBox["\<F\>", SingleLetterItalics -> False, 
                    FontWeight -> "\<Bold\>"], 
                  RowBox @@ {\((redblue /@ {den})\)}, 
                  RowBox[{"\<(\>", 
                      ToBoxes[d, TraditionalForm], "\<)\>", "\< \>", 
                      i, "\<0\>"}]], \n\t\tTFR[d, 
                  pp, {0, 0, i, 0, 0}, {den}], Editable -> True})\) /; 
          MemberQ[{StandardForm, TraditionalForm}, fmt];\)\)], "Input"],

Cell[BoxData[
    \(\(TFR /: 
        MakeBoxes[TFR[d_, pp_, {0, 0, 0, i_, 0}, {den__}], 
          fmt_] := \n\t\((InterpretationBox @@ {SubsuperscriptBox[
                  StyleBox["\<F\>", SingleLetterItalics -> False, 
                    FontWeight -> "\<Bold\>"], 
                  RowBox @@ {\((redblue /@ {den})\)}, 
                  RowBox[{"\<(\>", 
                      ToBoxes[d, TraditionalForm], "\<)\>", "\< \>", "\<0\>", 
                      i}]], \n\t\tTFR[d, pp, {0, 0, 0, i, 0}, {den}], 
                Editable -> True})\) /; 
          MemberQ[{StandardForm, TraditionalForm}, fmt];\)\)], "Input"],

Cell[BoxData[
    \(\(TFR /: 
        MakeBoxes[TFR[dpp__, {den__}], 
          fmt_] := \n\t\((InterpretationBox @@ {SubsuperscriptBox[
                  StyleBox["\<F\>", SingleLetterItalics -> False, 
                    FontWeight -> "\<Bold\>"], 
                  RowBox @@ {\((redblue /@ {den})\)}, 
                  RowBox[{"\<(\>", 
                      ToBoxes[First[{dpp}], 
                        TraditionalForm], "\<)\>"}]], \n\t\tTFR[dpp, {den}], 
                Editable -> True})\) /; 
          MemberQ[{StandardForm, TraditionalForm}, fmt] && 
            Head[Last[{dpp}]] =!= List;\)\)], "Input"],

Cell[BoxData[
    \(\(TVR /: 
        MakeBoxes[TVR[dpp__, {den__}], 
          fmt_] := \n\((\t\((InterpretationBox @@ {SubsuperscriptBox[
                      StyleBox["\<V\>", SingleLetterItalics -> False, 
                        FontWeight -> "\<Bold\>"], 
                      RowBox @@ {\((redblue /@ {den})\)}, 
                      RowBox[{"\<(\>", 
                          ToBoxes[{dpp}[\([1]\)], 
                            TraditionalForm], "\<)\>"}]], \n\t\(Hold[TVR]\)[
                      dpp, {den}], Editable -> True})\) /. 
              Hold[TVR] -> TVR)\) /; 
          MemberQ[{StandardForm, TraditionalForm}, fmt] && 
            Head[Last[{dpp}]] =!= List;\)\)], "Input"],

Cell[BoxData[
    \(TJR /: 
      MakeBoxes[TJR[d_, 0, {den__}], 
        fmt_] := \t\((\n\((\((InterpretationBox @@ {SubsuperscriptBox[
                        StyleBox["\<K\>", SingleLetterItalics -> False, 
                          FontWeight -> "\<Bold\>"], 
                        RowBox @@ {\((redblue /@ {den})\)}, 
                        RowBox[{"\<(\>", 
                            ToBoxes[d, 
                              TraditionalForm], "\<)\>"}]], \n\t\t\(Hold[
                          TJR]\)[d, 0, {den}], Editable -> True})\) /. 
                Hold[TJR] -> TJR)\) /; 
            MemberQ[{StandardForm, TraditionalForm}, fmt]\n\t)\) /; 
        MemberQ[{StandardForm, TraditionalForm}, fmt]\)], "Input"],

Cell[BoxData[
    \(TJR /: 
      MakeBoxes[TJR[dpp__, {den__}], 
        fmt_] := \t\((\((InterpretationBox @@ {SubsuperscriptBox[
                    StyleBox["\<J\>", SingleLetterItalics -> False, 
                      FontWeight -> "\<Bold\>"], 
                    RowBox @@ {\((redblue /@ {den})\)}, 
                    RowBox[{"\<(\>", 
                        ToBoxes[{dpp}[\([1]\)], 
                          TraditionalForm], "\<)\>"}]], \n\t\t\(Hold[TJR]\)[
                    dpp, {den}], Editable -> True})\) /. Hold[TJR] -> TJR)\) /; 
        MemberQ[{StandardForm, TraditionalForm}, fmt]\)], "Input"],

Cell[BoxData[
    \(\(TBR /: 
        MakeBoxes[TBR[d_, pp___, {den__}], 
          fmt_] := \n\t\((SubsuperscriptBox[
              StyleBox["\<B\>", SingleLetterItalics -> False, 
                FontWeight -> "\<Bold\>"], 
              RowBox @@ {\((redblue /@ {den})\)}, 
              RowBox[{"\<(\>", ToBoxes[d, TraditionalForm], "\<)\>"}]])\) /; 
          MemberQ[{StandardForm, TraditionalForm}, fmt];\)\)], "Input"],

Cell[BoxData[
    \(\(TBR /: 
        MakeBoxes[TBR[d_, pp___, {den__}], 
          fmt_] := \n\t\((InterpretationBox @@ {SubsuperscriptBox[
                  StyleBox["\<B\>", SingleLetterItalics -> False, 
                    FontWeight -> "\<Bold\>"], 
                  RowBox @@ {\((redblue /@ {den})\)}, 
                  RowBox[{"\<(\>", 
                      ToBoxes[d, TraditionalForm], "\<)\>"}]], \n\t\tTBR[d, 
                  pp, {den}], Editable -> True})\) /; 
          MemberQ[{StandardForm, TraditionalForm}, fmt];\)\)], "Input"],

Cell[BoxData[
    \(\(TAR /: 
        MakeBoxes[TAR[d_, pp___, {den__}], 
          fmt_] := \n\t\((InterpretationBox @@ {SubsuperscriptBox[
                  StyleBox["\<A\>", SingleLetterItalics -> False, 
                    FontWeight -> "\<Bold\>"], 
                  RowBox @@ {\((redblue /@ {den})\)}, 
                  RowBox[{"\<(\>", 
                      ToBoxes[d, TraditionalForm], "\<)\>"}]], \n\t\tTAR[
                  d, {den}], Editable -> True})\) /; 
          MemberQ[{StandardForm, TraditionalForm}, fmt];\)\)], "Input"],

Cell[BoxData[
    \(\(n1 /: MakeBoxes[n1, TraditionalForm] := 
        SubscriptBox["\<\[Nu]\>", 1];\)\)], "Input"],

Cell[BoxData[
    \(\(n2 /: MakeBoxes[n2, TraditionalForm] := 
        SubscriptBox["\<\[Nu]\>", 2];\)\)], "Input"],

Cell[BoxData[
    \(\(n3 /: MakeBoxes[n3, TraditionalForm] := 
        SubscriptBox["\<\[Nu]\>", 3];\)\)], "Input"],

Cell[BoxData[
    \(\(n4 /: MakeBoxes[n4, TraditionalForm] := 
        SubscriptBox["\<\[Nu]\>", 4];\)\)], "Input"],

Cell[BoxData[
    \(\(n5 /: MakeBoxes[n5, TraditionalForm] := 
        SubscriptBox["\<\[Nu]\>", 5];\)\)], "Input"],

Cell[BoxData[
    \(\(MakeBoxes[ParD[i_]\^j_, TraditionalForm] := 
        SubsuperscriptBox["\<\[PartialD]\>", i, j];\)\)], "Input"],

Cell[BoxData[
    \(\(MakeBoxes[ParD[i_], TraditionalForm] ^= 
        SubscriptBox["\<\[PartialD]\>", i];\)\)], "Input"],

Cell[BoxData[
    \(\(MakeBoxes[DPlus, TraditionalForm] := 
        StyleBox[SuperscriptBox["\<d\>", "\<+\>"], 
          FontWeight \[Rule] "\<Bold\>", 
          SingleLetterItalics \[Rule] False];\)\)], "Input"],

Cell[BoxData[
    \(MakeBoxes[TpD[_, b_], TraditionalForm] := 
      MakeBoxes[b, TraditionalForm]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Palettes", "Subsection",
  CellTags->"T1.3.2.1"],

Cell[BoxData[
    \(\(If[$PutPalettes === 
          True, \n\t\(\(tobut[a_]\  := \ 
            ButtonBox[ToBoxes[a, StandardForm], \ 
              ButtonStyle -> "\<Paste\>"];\)\(\n\)
        \(\ \)\(If[Head[pal1] === NotebookObject, \n\t
            NotebookClose[pal1]];\)\(\n\)
        \(\t\)\(pal1 = 
            NotebookPut[
              Notebook[{Cell[
                    BoxData[
                      GridBox[\n\t\t\t\t\t\t\tJoin[
                          Transpose@{\n\t\t\t\t\t\t\t\t\tTable[
                                tobut@\(m\_j\^2\), {j, 
                                  5}], \n\t\t\t\t\t\t\t\t\tTable[
                                tobut@\[Nu]\_j, {j, 
                                  5}], \n\t\t\t\t\t\t\t\t\tTable[
                                tobut@Schiebe[i, "\<+\>"], {i, 
                                  5}], \n\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
Table[tobut@Schiebe[i, "\<-\>"], {i, 5}]}, \n\t\t\t\t\t\t\t\(\({\t
                            tobut /@ {PP, \[CapitalDelta]\_\[Placeholder], 
                                u\_\[Placeholder], \[ScriptCapitalC]\ }}\)\(\n\
\)\)\t\t\t\t\t\t\t], RowSpacings -> 0, \n\ \ \ \ \ \ ColumnSpacings -> 0]], 
                    NotebookDefault]}, \n\tEditable -> True, \n
                WindowToolbars -> {}, \nWindowSize -> {Fit, \ Fit}, \n
                WindowMargins -> {{0, \ Automatic}, \ {0, Automatic}}, \n
                WindowFrame -> "\<Palette\>", \nWindowElements -> {}, \n
                WindowFrameElements -> "\<CloseBox\>", \n
                WindowClickSelect -> False, \n
                ScrollingOptions -> {"\<PagewiseScrolling\>" -> True}, \n
                ShowCellBracket -> False, \n
                CellMargins -> {{0, \ 0}, \ {0, \ 0}}, \nActive -> True, \n
                CellOpen -> True, \nShowCellLabel -> False, \n
                ShowCellTags -> False, \n
                ImageMargins -> {{0, \ 0}, \ {0, \ 0}}, \nMagnification -> 2, 
                Visible -> True]];\)\(\n\)
        \(SetOptions[pal1, 
            WindowMargins -> {{0, Automatic}, {Automatic, 0}}];\)\(\n\)
        \(SetOptions[pal1, Visible -> True, 
            WindowSize -> {Fit, Fit}];\)\(\n\)
        \(\ \)\(If[Head[pal2] === NotebookObject, \n\t
            NotebookClose[pal2]];\)\(\n\)
        \(\t\)\(pal2 = 
            NotebookPut[
              Notebook[{Cell[
                    BoxData[
                      GridBox[\n\t\t\t\t\t\t\tJJJ = 
                          Join[{tobut /@ {TFI[
                                    d + 2, {\[Nu]\_1, \[Nu]\_2, \[Nu]\_3, \
\[Nu]\_4, \[Nu]\_5}], TVI[d + 2, {\[Nu]\_1, \[Nu]\_2, \[Nu]\_3, \[Nu]\_4}], 
                                  TJI[d + 2, {\[Nu]\_1, \[Nu]\_2, \[Nu]\_3}], 
                                  TKI[d, {\[Nu]\_1, \[Nu]\_2, \[Nu]\_3}], 
                                  TBI[d, {\[Nu]\_1, \[Nu]\_2}], 
                                  TAI[d, {\[Nu]\_1}]}}, \n\t\t\t\t\t\t\t\t\
\(\({tobut /@ {TFI[d, {\[Nu]\_1, \[Nu]\_2, \[Nu]\_3, \[Nu]\_4, \[Nu]\_5}], 
                                  TVI[d, {\[Nu]\_1, \[Nu]\_2, \[Nu]\_3, \[Nu]\
\_4}], TJI[d, {\[Nu]\_1, \[Nu]\_2, \[Nu]\_3}], 
                                  TKI[d - 2, {\[Nu]\_1, \[Nu]\_2, \[Nu]\_3}], 
                                  TBI[d - 2, {\[Nu]\_1, \[Nu]\_2}], 
                                  TAI[d - 
                                      2, {\[Nu]\_1}]}}\)\(\n\)\)\t\t\t\t\t\t\t\
], RowSpacings -> 0, \n\ \ \ \ \ \ ColumnSpacings -> 0]], 
                    NotebookDefault]}, \n\tEditable -> True, \n
                WindowToolbars -> {}, \nWindowSize -> {FitAll, \ FitAll}, \n
                WindowMargins -> {{0, Automatic}, \ {0, Automatic}}, \n
                WindowFrame -> "\<Palette\>", \nWindowElements -> {}, \n
                WindowFrameElements -> "\<CloseBox\>", \n
                WindowClickSelect -> False, \n
                ScrollingOptions -> {"\<PagewiseScrolling\>" -> True}, \n
                ShowCellBracket -> False, \n
                CellMargins -> {{0, 0}, \ {0, 0}}, \nActive -> True, \n
                CellOpen -> True, \nShowCellLabel -> False, \n
                ShowCellTags -> False, \n
                ImageMargins -> {{0, 0}, \ {0, \ 0}}, \nMagnification -> 2, 
                Visible -> True]];\)\(\n\)
        \(SetOptions[pal2, 
            WindowMargins -> {{Automatic, 15}, {Automatic, 4}}];\)\(\n\)
        \(SetOptions[pal2, Visible -> True, 
            WindowSize -> {Fit, Fit}];\)\(\n\)
        \(\t\)\(SetOptions[pal2, 
          WindowSize -> {Fit, Fit}]\)\(\n\)\)\t];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["OperatorApply", "Subsection",
  CellTags->"T1.3.3.1"],

Cell[BoxData[
    \(\(OperatorApplyF[x_ == y_] := 
        Block[{sch}, \n\t\tsch\  = \ {Schiebe[i_, "\<+\>"]\^ni_. \ TFI[
                    d_, {n15__}] :> \n\t\t\t\t\tTFI[d, 
                  ReplacePart[{n15}, {n15}[\([i]\)] + ni, 
                    i]], \n\t\t\t\t\(\(Schiebe[i_, "\<-\>"]\^ni_. \ TFI[
                    d_, {n15__}]\)\(:>\)\(\n\)\(\t\t\t\t\t\)\(TFI[d, 
                  ReplacePart[{n15}, {n15}[\([i]\)] - ni, 
                    i]]\)\(\n\)\)\t\t\t}; 
          Map[Collect[Expand[#] //. sch, TFI[__], Factor] &, \n\t\t\tx == 
              y]];\)\)], "Input"],

Cell[BoxData[
    \(\(OperatorApplyV[x_ == y_] := 
        Block[{sch}, \n\t\tsch\  = \ {Schiebe[i_, "\<+\>"]\^ni_. \ TVI[
                    d_, {n15__}] :> \n\t\t\t\t\tTVI[d, 
                  ReplacePart[{n15}, {n15}[\([i]\)] + ni, 
                    i]], \n\t\t\t\t\(\(Schiebe[i_, "\<-\>"]\^ni_. \ TVI[
                    d_, {n15__}]\)\(:>\)\(\n\)\(\t\t\t\t\t\)\(TVI[d, 
                  ReplacePart[{n15}, {n15}[\([i]\)] - ni, 
                    i]]\)\(\n\)\)\t\t\t}; 
          Map[Collect[Expand[#] //. sch, TVI[__], Factor] &, \n\t\t\tx == 
              y]];\)\)], "Input"],

Cell[BoxData[
    \(\(OperatorApplyJ[x_ == y_] := 
        Block[{sch}, \n\t\tsch\  = \ {Schiebe[i_, "\<+\>"]\^ni_. \ TJI[
                    d_, {n15__}] :> \n\t\t\t\t\tTJI[d, 
                  ReplacePart[{n15}, {n15}[\([i]\)] + ni, 
                    i]], \n\t\t\t\t\(\(Schiebe[i_, "\<-\>"]\^ni_. \ TJI[
                    d_, {n15__}]\)\(:>\)\(\n\)\(\t\t\t\t\t\)\(TJI[d, 
                  ReplacePart[{n15}, {n15}[\([i]\)] - ni, 
                    i]]\)\(\n\)\)\t\t\t}; 
          Map[Collect[Expand[#] //. sch, TJI[__], Factor] &, \n\t\t\tx == 
              y]];\)\)], "Input"],

Cell[BoxData[
    \(\(OperatorApplyK[x_ == y_] := 
        Block[{sch}, \n\t\tsch\  = \ {Schiebe[i_, "\<+\>"]\^ni_. \ TKI[
                    d_, {n15__}] :> \n\t\t\t\t\tTKI[d, 
                  ReplacePart[{n15}, {n15}[\([i]\)] + ni, 
                    i]], \n\t\t\t\t\(\(Schiebe[i_, "\<-\>"]\^ni_. \ TKI[
                    d_, {n15__}]\)\(:>\)\(\n\)\(\t\t\t\t\t\)\(TKI[d, 
                  ReplacePart[{n15}, {n15}[\([i]\)] - ni, 
                    i]]\)\(\n\)\)\t\t\t}; 
          Map[Collect[Expand[#] //. sch, TKI[__], Factor] &, \n\t\t\tx == 
              y]];\)\)], "Input"],

Cell[BoxData[
    \(\(OperatorApplyK[x_ == y_] := 
        Block[{sch}, \n\t\tsch\  = \ {Schiebe[i_, "\<+\>"]\^ni_. \ TKI[
                    d_, {n15__}] :> \n\t\t\t\t\tTKI[d, 
                  ReplacePart[{n15}, {n15}[\([i]\)] + ni, 
                    i]], \n\t\t\t\t\(\(Schiebe[i_, "\<-\>"]\^ni_. \ TKI[
                    d_, {n15__}]\)\(:>\)\(\n\)\(\t\t\t\t\t\)\(TKI[d, 
                  ReplacePart[{n15}, {n15}[\([i]\)] - ni, 
                    i]]\)\(\n\)\)\t\t\t}; 
          Map[Collect[Expand[#] //. sch, TKI[__], Factor] &, \n\t\t\tx == 
              y]];\)\)], "Input"],

Cell[BoxData[
    \(\(OperatorApplyB[x_ == y_] := 
        Block[{sch}, \n\t\tsch\  = \ {Schiebe[i_, "\<+\>"]\^ni_. \ TBI[
                    d_, {n15__}] :> \n\t\t\t\t\tTBI[d, 
                  ReplacePart[{n15}, {n15}[\([i]\)] + ni, 
                    i]], \n\t\t\t\t\(\(Schiebe[i_, "\<-\>"]\^ni_. \ TBI[
                    d_, {n15__}]\)\(:>\)\(\n\)\(\t\t\t\t\t\)\(TBI[d, 
                  ReplacePart[{n15}, {n15}[\([i]\)] - ni, 
                    i]]\)\(\n\)\)\t\t\t}; 
          Map[Collect[Expand[#] //. sch, TBI[__], Factor] &, \n\t\t\tx == 
              y]];\)\)], "Input"],

Cell[BoxData[
    \(\(OperatorApplyA[x_ == y_] := 
        Block[{sch}, \n\t\tsch\  = \ {Schiebe[i_, "\<+\>"]\^ni_. \ TAI[
                    d_, {n15__}] :> \n\t\t\t\t\tTAI[d, 
                  ReplacePart[{n15}, {n15}[\([i]\)] + ni, 
                    i]], \n\t\t\t\t\(\(Schiebe[i_, "\<-\>"]\^ni_. \ TAI[
                    d_, {n15__}]\)\(:>\)\(\n\)\(\t\t\t\t\t\)\(TAI[d, 
                  ReplacePart[{n15}, {n15}[\([i]\)] - ni, 
                    i]]\)\(\n\)\)\t\t\t}; 
          Map[Collect[Expand[#] //. sch, TAI[__], Factor] &, \n\t\t\tx == 
              y]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MassDerivative", "Subsection",
  CellTags->"T1.3.4.1"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(MassDerivative[
          STLI[any__, {\n\ \ \ \ \ \ \ {al_, m1_}, {be_, m2_}, {ga_, 
                m3_}, {de_, m4_}, {ep_, m5_}}], {{0, d1_}, {0, d2_}, \ {0, 
              d3_}, \ {0, d4_}, \ {0, d5_}}]\), 
        StyleBox[" ",
          FontWeight->"Plain"], 
        StyleBox[":=",
          FontWeight->"Plain"], 
        "\n", \(\((\ \(Pochhammer[al, d1]\ Pochhammer[be, d2]\ Pochhammer[ga, 
                  d3]\)*\n\ \ Pochhammer[de, d4]\ Pochhammer[ep, 
                d5]\ )\)\ *\n\ 
          STLI[any, {{al + d1, m1}, \ {be + d2, m2}, \ {ga + d3, 
                m3}, \ {de + d4, m4}, \ {ep + d5, m5}}]\)}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TarasovT", "Subsection",
  CellTags->"T1.3.5.1"],

Cell["\<\
TarasovT[abrs__, qq_ /; Head[qq] =!= List] := 
  TarasovT[abrs, qq, {\"g\", \"g\", \"g\", \"g\", \"g\"}]\
\>", "Input"],

Cell[BoxData[
    \(\(TarasovT[r_, \ s_, \ 
          qq_, \ {alp1_, alp2_, \ alp3_, alp4_, alp5_}]\  := \n
        Block[{\ al1, al2, al3, al4, al5, alrul, new, Q1, Q11, Q12, Q2, Q22, 
            dum1, dum2}, \n\ \(If[alp1\  === \ 0, \ al1\  = \ 0]; \ 
          If[alp2\  === \ 0, \ al2\  = \ 0];\n
          \ \(If[alp3\  === \ 0, \ al3\  = \ 0];\)\n
          If[alp4\  === \ 0, \ al4\  = \ 0]; \ 
          If[alp5\  === \ 0, \ al5\  = \ 0];\n
          \ \(alrul\  = \ 
              Select[{al1 :> I\ ParD[1], \ al2 :> I\ ParD[2], \ 
                  al3 :> I\ ParD[3], \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ al4 :> 
                    I\ ParD[4], \ 
                  al5 :> I\ ParD[5]}, \ \(! MatchQ[#, \ 0 :> _]\) &];\)\n
          \ \(Q1\  = \ 
              al3\ al5\  + \ al4\ al5\  + \ al2\ al3\  + \ al3\ al4;\)\n
          \ \(Q2\  = \ 
              al4\ al5\  + \ al3\ al5\  + \ al1\ al4\  + \ al3\ al4;\)\n
          \ \(Q11\  = 1/\((\(-4\))\)\ \((\ al2\  + \ al4\  + \ al5\ )\);\)\n
          \ \(Q22\  = 1/\((\(-4\))\)\ \((\ al1\  + \ al3\  + \ al5\ )\);\)\n
          \ \(Q12\  = 1/\((\(-2\))\)\ al5;\)\n
          \t\tnew = \n\ 
            I^\((\(-r\) - s)\) \((\ 
                  D[\ Exp[\ 
                      I\ qq\ \((\n\ \ \ \ be1\ Q1\  + \ be2\ Q2\  + 
                            be1^2\ Q11\  + be2^2\ Q22\  + \ 
                            be1\ be2\ Q12\n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ )\)\ rho\ ], {be1, r}, {be2, 
                      s}\n\t\t\t\t]\ )\) /. \n\ \((\ 
                Join[alrul, \ {be1\  :> \ 0, be2\  :> \ 0, \ 
                    rho\  :> \ \(-Pi^2\)/
                          Pi^2\ DPlus\ }])\); \(\(Map[\((Select[#, \
\((FreeQ[#, ParD] && FreeQ[#, DPlus])\) &]\ TpD[qq, 
                      Select[#, \((\(! \((FreeQ[#, ParD] && 
                                  FreeQ[#, 
                                    DPlus])\)\))\) &]])\) &, \(\((Expand[new, 
                    ParD] + \ dum1\ dum2)\)\(\n\)\)\t\t]\)\(/.\)\({dum1 :> 0, 
              dum2 :> 0}\)\(\n\)\)\)\t\t];\)\)], "Input"],

Cell[BoxData[
    \(\(\(\n\)\(TarasovT[r_, \ s_, \ pp_, \ dp_ /; Head[dp] =!= List]\  := \ 
      TarasovT[r, s, pp, 
        dp, {"\<g\>", "\<g\>", "\<g\>", "\<g\>", "\<g\>"}]\)\)\)], "Input"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\((\[CapitalDelta]\ q\_1)\)\^a\)]],
  Cell[BoxData[
      \(TraditionalForm\`\((\[CapitalDelta]\ q\_2)\)\^b\)]],
  Cell[BoxData[
      \(TraditionalForm\`\((p\ q\_1)\)\^r\)]],
  Cell[BoxData[
      \(TraditionalForm\`\((p\ q\_2)\)\^s\)]]
}], "Text"],

Cell[BoxData[
    \(\(\(\n\)\(TarasovT[a_, b_, r_, s_, pp_, 
          dp_, {alp1_, alp2_, alp3_, alp4_, alp5_}] := 
        Block[{al1, al2, al3, al4, al5, alrul, new, Q1, Q11, Q12, Q2, Q22, 
            dum1, dum2}, If[alp1 === 0, al1 = 0]; If[alp2 === 0, al2 = 0]; 
          If[alp3 === 0, al3 = 0]; If[alp4 === 0, al4 = 0]; 
          If[alp5 === 0, al5 = 0]; 
          alrul = Select[{al1 \[RuleDelayed] I\ ParD[1], 
                al2 \[RuleDelayed] I\ ParD[2], al3 \[RuleDelayed] I\ ParD[3], 
                al4 \[RuleDelayed] I\ ParD[4], 
                al5 \[RuleDelayed] 
                  I\ ParD[5]}, \(\(\[InvisibleSpace]\)\(! \((MatchQ[#1, 
                      0 \[RuleDelayed] _])\)\)\) &]; 
          Q1 = al3\ al5 + al4\ al5 + al2\ al3 + al3\ al4; 
          Q2 = al4\ al5 + al3\ al5 + al1\ al4 + al3\ al4; 
          Q11 = \(-\(1\/4\)\)\ \((al2 + al4 + al5)\); 
          Q22 = \(-\(1\/4\)\)\ \((al1 + al3 + al5)\); Q12 = \(-\(al5\/2\)\); 
          new = I\^\(\(-r\) - s - a - b\)\ \[PartialD]\_\({be1, r}, {be2, s}, \
{ga1, a}, {ga2, b}\)Exp[
                    I\ \((\((be1\ pp + ga1\ dp)\)\ Q1 + \((be2\ pp + 
                                ga2\ dp)\)\ Q2 + 
                          be1\ \((be1\ pp + 2\ ga1\ dp)\)\ Q11 + 
                          be2\ \((be2\ pp + 
                                2\ ga2\ dp)\)\ Q22 + \((be1\ be2\ pp + \((be1\
\ ga2 + be2\ ga1)\)\ dp)\)\ Q12)\)\ rho] /. 
              Join[alrul, {be1 \[RuleDelayed] 0, be2 \[RuleDelayed] 0, 
                  ga1 :> 0, ga2 :> 0, 
                  rho \[RuleDelayed] \(-\(\(\[Pi]\^2\ \
DPlus\)\/\[Pi]\^2\)\)}]; \((Select[#1, 
                      FreeQ[#1, ParD] && FreeQ[#1, DPlus] &]\ TpD[pp, 
                      Select[#1, \(\(\[InvisibleSpace]\)\(! \((FreeQ[#1, 
                                  ParD] && 
                                FreeQ[#1, DPlus])\)\)\) &]] &)\) /@ \((Expand[
                    new] + dum1\ dum2)\) /. {dum1 \[RuleDelayed] 0, 
              dum2 \[RuleDelayed] 0}];\)\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ApplyTarasovT", "Subsection",
  CellTags->"T1.3.6.1"],

Cell[BoxData[
    \(ApplyTarasovT[tij_, \ exp_] := 
      Block[{dump}, \n\t\tdump = 
          Product[ParD[j]^dummy, {j, 5}]; \n\t\tExpand[
            tij\ exp] /. \n\((STLI[de_, pp_, pe__List]\ TpD[tpp_, 
                  DPlus^i_. \ t_])\) :> \n\t
            MassDerivative[
              STLI[\ de /. de :> \((de\  + \ 2\ i)\), pp, 
                pe], \n\t\t\t\t\t\t\t\(\(t\ dump\  /. Times -> List\) /. 
                  Power[_, n_] :> {0, n}\) /. dummy -> 0]]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Misc", "Subsection",
  CellTags->"T1.3.7.1"],

Cell[BoxData[
    \(Prefactor1 /: \t\tPrefactor1[a_]^n_ := Prefactor1[a^n]\)], "Input"],

Cell[CellGroupData[{

Cell["Colors", "Subsubsection",
  CellTags->"T1.3.7.1.1"],

Cell[TextData[{
  StyleBox["TFI",
    FontColor->RGBColor[1, 0.6, 0]],
  " ",
  StyleBox["TVI ",
    FontColor->RGBColor[0.2, 0.4, 0.8]],
  StyleBox["TFR ",
    FontColor->RGBColor[0, 0.6, 0]],
  StyleBox["TVR ",
    FontColor->RGBColor[0.2, 0.8, 1]],
  StyleBox["MakeFun ",
    FontColor->RGBColor[1, 0.6, 0.6]],
  StyleBox["Cayley ",
    FontColor->RGBColor[1, 0, 0.4]],
  StyleBox["CayleyD ",
    FontColor->RGBColor[1, 0.2, 1]],
  StyleBox["Cayleyu",
    FontColor->RGBColor[0.8, 0.8, 0.4]],
  StyleBox[" ",
    FontColor->RGBColor[1, 0.2, 1]],
  StyleBox["IFF ",
    FontColor->RGBColor[0.6, 0.4, 1]],
  StyleBox["ToArgs ",
    FontColor->RGBColor[0.2, 0.6, 1]],
  StyleBox["Block",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0.2, 0.2]]
}], "Text"],

Cell[BoxData[
    \(\(MakeBoxes[Block, StandardForm] := 
        StyleBox["\<Block\>", FontSize \[Rule] 16, 
          FontWeight \[Rule] "\<Bold\>", 
          FontColor \[Rule] RGBColor[1, 0.2, 0.2]];\)\)], "Input"],

Cell[BoxData[
    \(\(MakeBoxes[Cayley, StandardForm] := 
        StyleBox["\<Cayley\>", 
          FontColor \[Rule] RGBColor[1, 0, 0.4]];\)\)], "Input"],

Cell[BoxData[
    \(\(MakeBoxes[CayleyD, StandardForm] := 
        StyleBox["\<CayleyD\>", 
          FontColor \[Rule] RGBColor[1, 0.2, 1]];\)\)], "Input"],

Cell[BoxData[
    \(\(MakeBoxes[Cayleyu, StandardForm] := 
        StyleBox["\<Cayleyu\>", 
          FontColor \[Rule] RGBColor[0.8, 0.8, 0.4]];\)\)], "Input"],

Cell[BoxData[
    \(\(MakeBoxes[IFF, StandardForm] := 
        StyleBox["\<IFF\>", 
          FontColor \[Rule] RGBColor[0.6, 0.4, 1]];\)\)], "Input"],

Cell[BoxData[
    \(\(MakeBoxes[MakeFun, StandardForm] := 
        StyleBox["\<MakeFun\>", 
          FontColor \[Rule] RGBColor[1, 0.6, 0.6]];\)\)], "Input"],

Cell[BoxData[
    \(\(MakeBoxes[TFI, StandardForm] := 
        StyleBox["\<TFI\>", 
          FontColor \[Rule] RGBColor[1, 0.6, 0]];\)\)], "Input"],

Cell[BoxData[
    \(\(MakeBoxes[TFR, StandardForm] := 
        StyleBox["\<TFR\>", 
          FontColor \[Rule] RGBColor[0, 0.6, 0]];\)\)], "Input"],

Cell[BoxData[
    \(\(MakeBoxes[ToArgs, StandardForm] := 
        StyleBox["\<ToArgs\>", 
          FontColor \[Rule] RGBColor[0.2, 0.6, 1]];\)\)], "Input"],

Cell[BoxData[
    \(\(MakeBoxes[TVI, StandardForm] := 
        StyleBox["\<TVI\>", 
          FontColor \[Rule] RGBColor[0.2, 0.4, 0.8]];\)\)], "Input"],

Cell[BoxData[
    \(MakeBoxes[TVR, StandardForm] := 
      StyleBox["\<TVR\>", FontColor \[Rule] RGBColor[0.2, 0.8, 1]]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PQ", "Subsubsection",
  CellTags->"T1.3.7.2.1"],

Cell[BoxData[
    \(\(PQ[_Integer?Positive]\  := \ True;\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PNQ", "Subsubsection",
  CellTags->"T1.3.7.3.1"],

Cell[BoxData[
    \(\(PNQ[0] = True;\)\)], "Input"],

Cell[BoxData[
    \(\(PNQ[_Integer?Positive]\  := \ True;\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FactorC", "Subsubsection",
  CellTags->"T1.3.7.4.1"],

Cell[BoxData[
    \(FactorC[z_] := \(FactorC[z] = Factor[z]\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TFI", "Subsubsection",
  CellTags->"T1.3.7.5.1"],

Cell[BoxData[
    \(\(TFI[depp__, {a___, b_Integer, c___}] := 
        TFI[depp, {a, {b, 0}, c}];\)\)], "Input"],

Cell[BoxData[
    \(\(TFI[depp__, {a___, {0, m_ /; m =!= 0}, b___}] := 
        TFI[depp, {a, {0, 0}, b}];\)\)], "Input"],

Cell[BoxData[
    \(\(TFI[a__, {0, 0}, b__List] := TFI[a, b];\)\)], "Input"],

Cell[BoxData[
    \(\(TFI[d_, pp_, dp_, {0, 0}, {x1_, x2_, x3_, x4_, x5_}, list_List] := 
        TFI[d, pp, {x1, x2, x3, x4, x5}, list];\)\)], "Input"],

Cell[BoxData[
    \(\(TFI[d_, pp_, dp_, {a_, b_}, {0, 0, 0, 0, 0}, list_List] := 
        TFI[d, pp, dp, {a, b}, list];\)\)], "Input"],

Cell[BoxData[
    \(\(TFI[d_, pp_, dp_ /; Head[dp] =!= List, {0, 0, 0, 0, 0}, list_List] := 
        TFI[d, pp, list];\)\)], "Input"],

Cell[BoxData[
    \(\(TFI[d_, pp_, dp_ /; Head[dp] =!= List, list_List] := 
        TFI[d, pp, list];\)\)], "Input"],

Cell[BoxData[
    \(\(TFI[d_, pp_, dp_ /; Head[dp] =!= List, {x1_, x2_, x3_, x4_, x5_}, 
          list_List] := TFI[d, pp, {x1, x2, x3, x4, x5}, list];\)\)], "Input"],

Cell[BoxData[
    \(\(TFI[__, {{_, _}, {0, 0}, {_, _}, {0, 0}, {_, 0}}] := 0;\)\)], "Input"],

Cell[BoxData[
    \(\(TFI[__, {{0, 0}, {_, _}, {0, 0}, {_, _}, {_, 0}}] := 0;\)\)], "Input"],

Cell[BoxData[
    \(\(TFI[__, {{0, 0}, {_, _}, {_, 0}, {_, _}, {0, 0}}] := 0;\)\)], "Input"],

Cell[BoxData[
    \(\(TFI[__, {{_, 0}, {_, _}, {0, 0}, {_, _}, {0, 0}}] := 0;\)\)], "Input"],

Cell[BoxData[
    \(\(TFI[__, {{_, _}, {_, 0}, {_, _}, {0, 0}, {0, 0}}] := 0;\)\)], "Input"],

Cell[BoxData[
    \(\(TFI[__, {{_, _}, {0, 0}, {_, _}, {_, 0}, {0, 0}}] := 0;\)\)], "Input"],

Cell[BoxData[
    \(\(TFI[__, {{0, 0}, {0, 0}, {0, 0}, {_, 0}, {_, _}}] := 0;\)\)], "Input"],

Cell[BoxData[
    \(\(TFI[__, {{0, 0}, {0, 0}, {_, 0}, {0, 0}, {_, _}}] := 0;\)\)], "Input"],

Cell[BoxData[
    \(\(TFI[__, {{0, 0}, {_, 0}, {0, 0}, {0, 0}, {_, _}}] := 0;\)\)], "Input"],

Cell[BoxData[
    \(\(TFI[__, {{_, 0}, {0, 0}, {0, 0}, {0, 0}, {_, _}}] := 0;\)\)], "Input"],

Cell[BoxData[
    \(\(TFI[__, {{_, _}, {_, 0}, {0, 0}, {0, 0}, {0, 0}}] := 0;\)\)], "Input"],

Cell[BoxData[
    \(\(TFI[__, {{_, 0}, {_, _}, {0, 0}, {0, 0}, {0, 0}}] := 0;\)\)], "Input"],

Cell[BoxData[
    \(\(TFI[__, {{_, _}, {0, 0}, {0, 0}, {_, 0}, {0, 0}}] := 0;\)\)], "Input"],

Cell[BoxData[
    \(\(TFI[__, {{_, 0}, {0, 0}, {0, 0}, {_, _}, {0, 0}}] := 0;\)\)], "Input"],

Cell[BoxData[
    \(\(TFI[__, {{0, 0}, {_, 0}, {_, _}, {0, 0}, {0, 0}}] := 0;\)\)], "Input"],

Cell[BoxData[
    \(\(TFI[__, {{0, 0}, {_, _}, {_, 0}, {0, 0}, {0, 0}}] := 0;\)\)], "Input"],

Cell[BoxData[
    \(\(TFI[__, {{0, 0}, {0, 0}, {_, _}, {_, 0}, {0, 0}}] := 0;\)\)], "Input"],

Cell[BoxData[
    \(\(TFI[__, {{0, 0}, {0, 0}, {_, 0}, {_, _}, {0, 0}}] := 0;\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TJI", "Subsubsection",
  CellTags->"T1.3.7.6.1"],

Cell[BoxData[
    \(TJI[de_, 
        pp_, {{n1_Integer, m1_}, {n2_Integer, m2_}, {n3_Integer, 
            m3_}}] := \((TJI[de, pp, {{n1, m1}, {n2, m2}, {n3, m3}}] = 
            TJI[de, pp, 
              Reverse[Sort[{{n1, m1}, {n2, m2}, {n3, 
                      m3}}]]])\) /; \(\(\[InvisibleSpace]\)\(! \
\((OrderedQ[{{n3, m3}, {n2, m2}, {n1, m1}}])\)\)\)\)], "Input"],

Cell[BoxData[
    \(TJI[d, pp, {{1, m1}, {1, m2}, {1, m3}}]\)], "Input"],

Cell[BoxData[
    \(TJI[d_, 0, {{_, 0}, {_, 0}, {_, 0}}] := 0\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TBI", "Subsubsection",
  CellTags->"T1.3.7.7.1"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["TBI",
          FontColor->RGBColor[1, 0.6, 0]], "[", \(de_, 
        pp_, {{n1_Integer, m1_}, {n2_Integer, m2_}}\), "]"}], ":=", 
      RowBox[{
        RowBox[{"(", 
          RowBox[{\(TJI[de, pp, {{n1, m1}, {n2, m2}}]\), "=", 
            RowBox[{
              StyleBox["TBI",
                FontColor->RGBColor[1, 0.6, 0]], "[", \(de, pp, 
              Reverse@\(Sort@{{n1, m1}, {n2, m2}}\)\), "]"}]}], ")"}], "/;", 
        "\[InvisibleSpace]", \(! \((OrderedQ[{{n2, m2}, {n1, 
                  m1}}])\)\)}]}]], "Input"],

Cell[BoxData[
    \(TBI[d_, 0, {{_, 0}, {_, 0}}] := 0\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TAI", "Subsubsection",
  CellTags->"T1.3.7.8.1"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["TAI",
            FontColor->RGBColor[1, 0.6, 0]], "[", \(de_, 
          pp_, {{n1_Integer, 0}}\), "]"}], ":=", "0"}], ";"}]], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Definitions and notation", "Section",
  CellDingbat->"\[FilledSmallCircle]",
  CellTags->"T1.4.1"],

Cell[BoxData[
    RowBox[{
      RowBox[{"\[CapitalDelta]\[ScriptCapitalC]", "=", 
        RowBox[{\(-\(1\/2\)\), 
          RowBox[{"Det", "[", " ", 
            RowBox[{"(", GridBox[{
                  {"0", "1", "1", "1", "1"},
                  {"1", "0", \(\[Mu]\_6\), \(\[Mu]\_4\), \(\[Mu]\_3\)},
                  {"1", \(\[Mu]\_6\), "0", \(\[Mu]\_2\), \(\[Mu]\_1\)},
                  {"1", \(\[Mu]\_4\), \(\[Mu]\_2\), "0", \(\[Mu]\_5\)},
                  {"1", \(\[Mu]\_3\), \(\[Mu]\_1\), \(\[Mu]\_5\), "0"}
                  }], ")"}], "]"}]}]}], ";"}]], "Input"],

Cell[BoxData[
    \(\(checkli\  = \ {\n\t\t\[ScriptCapitalC] -> \[CapitalDelta]\
\[ScriptCapitalC], \n\[CapitalDelta]\_i_ :> \[PartialD]\_\(\[Mu]\_i\)\
\[CapitalDelta]\[ScriptCapitalC], \n\t\t\[Mu]\_6 :> PP, \[Mu]\_i_ :> 
            ToExpression["\<m\>" <> ToString[i]]^2, \n\t\tm\_1 :> \@m1\^2, 
          m\_2 :> \@m2\^2, m\_3 :> \@m3\^2, m\_4 :> \@m4\^2, 
          m\_5 :> \@m5\^2, \n\[CapitalDelta]\_\(i_, j_, k_\) :> \[Mu]\_i\%2 + \
\[Mu]\_j\%2 + \[Mu]\_k\%2 - 
              2 \((\(\[Mu]\_i\) \[Mu]\_j + \(\[Mu]\_j\) \[Mu]\_k + \(\[Mu]\_k\
\) \[Mu]\_i)\), \n
          u\_\(i_, j_, k_\) :> \[Mu]\_i - \[Mu]\_j - \[Mu]\_k, \n\
\[CapitalSigma]\_i_ :> 
            3\ d\  - 2\ \((\[Sum]\_\(j = 1\)\%i \[Nu]\_j)\) - 
              2, \n\t\[Nu]\_1 \[RuleDelayed] n1, \[Nu]\_2 \[RuleDelayed] 
            n2, \[Nu]\_3 \[RuleDelayed] n3, \[Nu]\_4 \[RuleDelayed] 
            n4, \[Nu]\_5 \[RuleDelayed] n5};\)\)], "Input"],

Cell[TextData[{
  "Define symmetry property for ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\_\(i, j, k\)\)]]
}], "Text"],

Cell[BoxData[
    \(\[CapitalDelta]\_\(i_, j_, k_\) := \[CapitalDelta]\_\(Sequence @@ \
Sort[{i, j, k}]\) /; \(! OrderedQ[{i, j, k}]\)\)], "Input"],

Cell[BoxData[
    \(\[CapitalDelta]\_\(3, 1, 2\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox["ToArgs",
      FontColor->RGBColor[0.2, 0.6, 1]]], "Subsection",
  CellTags->"T1.4.1.1"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["ToArgs",
            FontColor->RGBColor[0.2, 0.6, 1]], "[", "z_", "]"}], 
        ":=", \(Expand[z //. checkli]\)}], ";"}]], "Input"],

Cell[BoxData[
    \(ToArgs[\[CapitalSigma]\_4] // InputForm\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox["Cayley",
      FontColor->RGBColor[1, 0, 0.4]]], "Subsection",
  CellTags->"T1.4.2.1"],

Cell[TextData[{
  "This is (40).  ( p = ",
  Cell[BoxData[
      \(TraditionalForm\`\@p\^2\)]],
  ")"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"setd", "[", 
        RowBox[{
          RowBox[{"hCayley", "[", 
            RowBox[{
              RowBox[{
                InterpretationBox[\(m\_1\),
                  m1], ":", "_"}], ",", 
              RowBox[{
                InterpretationBox[\(m\_2\),
                  m2], ":", "_"}], ",", 
              RowBox[{
                InterpretationBox[\(m\_3\),
                  m3], ":", "_"}], ",", 
              RowBox[{
                InterpretationBox[\(m\_4\),
                  m4], ":", "_"}], ",", 
              RowBox[{
                InterpretationBox[\(m\_5\),
                  m5], ":", "_"}], ",", "p_"}], "]"}], ",", 
          RowBox[{"set", "[", 
            RowBox[{
              RowBox[{"hCayley", "[", 
                RowBox[{
                  InterpretationBox[\(m\_1\),
                    m1], ",", 
                  InterpretationBox[\(m\_2\),
                    m2], ",", 
                  InterpretationBox[\(m\_3\),
                    m3], ",", 
                  InterpretationBox[\(m\_4\),
                    m4], ",", 
                  InterpretationBox[\(m\_5\),
                    m5], ",", "p"}], "]"}], ",", 
              RowBox[{"factor", "[", 
                RowBox[{
                  RowBox[{
                    StyleBox["ToArgs",
                      FontColor->RGBColor[0.2, 0.6, 1]], "[", 
                    "\[ScriptCapitalC]", "]"}], "/.", 
                  RowBox[{
                    InterpretationBox[\(p\^2\),
                      PP], "\[Rule]", \(p\^2\)}]}], "]"}]}], "]"}]}], "]"}], "/.",
       
      RowBox[{"{", 
        RowBox[{
          RowBox[{"hCayley", "\[RuleDelayed]", 
            StyleBox["Cayley",
              FontColor->RGBColor[1, 0, 0.4]]}], 
          ",", \(setd \[RuleDelayed] SetDelayed\), 
          ",", \(set \[RuleDelayed] Set\), 
          ",", \(factor \[RuleDelayed] Factor\)}], "}"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Cayley",
          FontColor->RGBColor[1, 0, 0.4]], "[", "i", "]"}], 
      "=", \(\[CapitalDelta]\_i\)}]], "Subsection",
  CellTags->"T1.4.3.1"],

Cell[BoxData[
    RowBox[{"Do", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"setd", "[", 
            RowBox[{
              RowBox[{\(hCayley[i]\), "[", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                      InterpretationBox[\(m\_1\),
                        m1], ":", "_"}], ",", 
                    RowBox[{
                      InterpretationBox[\(m\_2\),
                        m2], ":", "_"}], ",", 
                    RowBox[{
                      InterpretationBox[\(m\_3\),
                        m3], ":", "_"}], ",", 
                    RowBox[{
                      InterpretationBox[\(m\_4\),
                        m4], ":", "_"}], ",", 
                    RowBox[{
                      InterpretationBox[\(m\_5\),
                        m5], ":", "_"}], ",", "p_"}], "}"}], "]"}], ",", 
              RowBox[{"set", "[", 
                RowBox[{
                  RowBox[{\(hCayley[i]\), "[", 
                    RowBox[{"{", 
                      RowBox[{
                        InterpretationBox[\(m\_1\),
                          m1], ",", 
                        InterpretationBox[\(m\_2\),
                          m2], ",", 
                        InterpretationBox[\(m\_3\),
                          m3], ",", 
                        InterpretationBox[\(m\_4\),
                          m4], ",", 
                        InterpretationBox[\(m\_5\),
                          m5], ",", "p"}], "}"}], "]"}], ",", 
                  RowBox[{"factor", "[", 
                    RowBox[{
                      RowBox[{
                        StyleBox["ToArgs",
                          FontColor->RGBColor[0.2, 0.6, 1]], 
                        "[", \(\[CapitalDelta]\_i\), "]"}], "/.", 
                      RowBox[{
                        InterpretationBox[\(p\^2\),
                          PP], "\[Rule]", \(p\^2\)}]}], "]"}]}], "]"}]}], 
            "]"}], "/.", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"hCayley", "\[RuleDelayed]", 
                StyleBox["Cayley",
                  FontColor->RGBColor[1, 0, 0.4]]}], 
              ",", \(setd \[RuleDelayed] SetDelayed\), 
              ",", \(set \[RuleDelayed] Set\), 
              ",", \(factor \[RuleDelayed] Factor\)}], "}"}]}], 
        ",", \({i, 6}\)}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["ToArgs",
        FontColor->RGBColor[0.2, 0.6, 1]], 
      "[", \(\[CapitalDelta]\_\(1, 2, 6\)\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          RowBox[{
            StyleBox["Cayley",
              FontColor->RGBColor[1, 0, 0.4]], "[", \(i_, j_, k_\), "]"}], 
          "[", "m_List", "]"}], ":=", 
        RowBox[{
          RowBox[{
            RowBox[{
              StyleBox["Cayley",
                FontColor->RGBColor[1, 0, 0.4]], "[", \(i, j, k\), "]"}], "[",
             "m", "]"}], 
          "=", \(Block[{mm = m}, \n\t\t\tWhile[Length[mm] < 7, 
              AppendTo[mm, Last[mm]]]; \n\t\t\tFactorC[
              mm\[LeftDoubleBracket]i\[RightDoubleBracket]\^4 - 
                2\ mm\[LeftDoubleBracket]j\[RightDoubleBracket]\^2\ mm\
\[LeftDoubleBracket]i\[RightDoubleBracket]\^2 - 
                2\ mm\[LeftDoubleBracket]k\[RightDoubleBracket]\^2\ mm\
\[LeftDoubleBracket]i\[RightDoubleBracket]\^2 + 
                mm\[LeftDoubleBracket]j\[RightDoubleBracket]\^4 + 
                mm\[LeftDoubleBracket]k\[RightDoubleBracket]\^4 - 
                2\ mm\[LeftDoubleBracket]j\[RightDoubleBracket]\^2\ mm\
\[LeftDoubleBracket]k\[RightDoubleBracket]\^2]]\)}]}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          RowBox[{
            StyleBox["Cayleyu",
              FontColor->RGBColor[0.8, 0.8, 0.4]], "[", \(i_, j_, k_\), "]"}],
           "[", "m_List", "]"}], ":=", 
        RowBox[{
          RowBox[{
            RowBox[{
              StyleBox["Cayleyu",
                FontColor->RGBColor[0.8, 0.8, 0.4]], "[", \(i, j, k\), "]"}], 
            "[", "mm", "]"}], 
          "=", \(Block[{mm = m}, \n\t\t\t\t\tWhile[Length[mm] < 7, 
              AppendTo[mm, Last[mm]]]; 
            FactorC[mm\[LeftDoubleBracket]i\[RightDoubleBracket]\^2 - 
                mm\[LeftDoubleBracket]j\[RightDoubleBracket]\^2 - 
                mm\[LeftDoubleBracket]k\[RightDoubleBracket]\^2]]\)}]}], 
      ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["CayleyD",
          FontColor->RGBColor[1, 0.2, 1]], "[", "i", "]"}], 
      "=", \(\[CapitalDelta]\_i\/\[CapitalDelta]\)}]], "Subsection",
  CellTags->"T1.4.4.1"],

Cell[BoxData[
    RowBox[{"Do", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"setd", "[", 
            RowBox[{
              RowBox[{\(hCayleyD[i]\), "[", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{
                      InterpretationBox[\(m\_1\),
                        m1], ":", "_"}], ",", 
                    RowBox[{
                      InterpretationBox[\(m\_2\),
                        m2], ":", "_"}], ",", 
                    RowBox[{
                      InterpretationBox[\(m\_3\),
                        m3], ":", "_"}], ",", 
                    RowBox[{
                      InterpretationBox[\(m\_4\),
                        m4], ":", "_"}], ",", 
                    RowBox[{
                      InterpretationBox[\(m\_5\),
                        m5], ":", "_"}], ",", "p_"}], "}"}], "]"}], ",", 
              RowBox[{"set", "[", 
                RowBox[{
                  RowBox[{\(hCayleyD[i]\), "[", 
                    RowBox[{"{", 
                      RowBox[{
                        InterpretationBox[\(m\_1\),
                          m1], ",", 
                        InterpretationBox[\(m\_2\),
                          m2], ",", 
                        InterpretationBox[\(m\_3\),
                          m3], ",", 
                        InterpretationBox[\(m\_4\),
                          m4], ",", 
                        InterpretationBox[\(m\_5\),
                          m5], ",", "p"}], "}"}], "]"}], ",", 
                  RowBox[{"factor", "[", 
                    FractionBox[
                      RowBox[{
                        RowBox[{
                          StyleBox["ToArgs",
                            FontColor->RGBColor[0.2, 0.6, 1]], 
                          "[", \(\[CapitalDelta]\_i\), "]"}], "/.", 
                        RowBox[{
                          InterpretationBox[\(p\^2\),
                            PP], "\[Rule]", \(p\^2\)}]}], 
                      RowBox[{"\[ScriptCapitalC]", "[", 
                        RowBox[{
                          InterpretationBox[\(m\_1\),
                            m1], ",", 
                          InterpretationBox[\(m\_2\),
                            m2], ",", 
                          InterpretationBox[\(m\_3\),
                            m3], ",", 
                          InterpretationBox[\(m\_4\),
                            m4], ",", 
                          InterpretationBox[\(m\_5\),
                            m5], ",", "p"}], "]"}]], "]"}]}], "]"}]}], "]"}], 
          "/.", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"hCayleyD", "\[RuleDelayed]", 
                StyleBox["CayleyD",
                  FontColor->RGBColor[1, 0.2, 1]]}], 
              ",", \(setd \[RuleDelayed] SetDelayed\), 
              ",", \(set \[RuleDelayed] Set\), 
              ",", \(factor \[RuleDelayed] Factor\), ",", 
              RowBox[{"\[ScriptCapitalC]", "\[RuleDelayed]", 
                StyleBox["Cayley",
                  FontColor->RGBColor[1, 0, 0.4]]}]}], "}"}]}], 
        ",", \({i, 6}\)}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"setd", "[", 
        RowBox[{
          RowBox[{\(hCayleyD[1, 2, 5]\), "[", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{
                  InterpretationBox[\(m\_1\),
                    m1], ":", "_"}], ",", 
                RowBox[{
                  InterpretationBox[\(m\_2\),
                    m2], ":", "_"}], ",", 
                RowBox[{
                  InterpretationBox[\(m\_3\),
                    m3], ":", "_"}], ",", 
                RowBox[{
                  InterpretationBox[\(m\_4\),
                    m4], ":", "_"}], ",", 
                RowBox[{
                  InterpretationBox[\(m\_5\),
                    m5], ":", "_"}], ",", "p_"}], "}"}], "]"}], ",", 
          RowBox[{"set", "[", 
            RowBox[{
              RowBox[{\(hCayleyD[1, 2, 5]\), "[", 
                RowBox[{"{", 
                  RowBox[{
                    InterpretationBox[\(m\_1\),
                      m1], ",", 
                    InterpretationBox[\(m\_2\),
                      m2], ",", 
                    InterpretationBox[\(m\_3\),
                      m3], ",", 
                    InterpretationBox[\(m\_4\),
                      m4], ",", 
                    InterpretationBox[\(m\_5\),
                      m5], ",", "p"}], "}"}], "]"}], ",", 
              RowBox[{"factor", "[", 
                FractionBox[
                  RowBox[{
                    RowBox[{
                      StyleBox["ToArgs",
                        FontColor->RGBColor[0.2, 0.6, 1]], 
                      "[", \(\[CapitalDelta]\_\(1, 2, 5\)\), "]"}], "/.", 
                    RowBox[{
                      InterpretationBox[\(p\^2\),
                        PP], "\[Rule]", \(p\^2\)}]}], 
                  RowBox[{"\[ScriptCapitalC]", "[", 
                    RowBox[{
                      InterpretationBox[\(m\_1\),
                        m1], ",", 
                      InterpretationBox[\(m\_2\),
                        m2], ",", 
                      InterpretationBox[\(m\_3\),
                        m3], ",", 
                      InterpretationBox[\(m\_4\),
                        m4], ",", 
                      InterpretationBox[\(m\_5\),
                        m5], ",", "p"}], "]"}]], "]"}]}], "]"}]}], "]"}], "/.",
       
      RowBox[{"{", 
        RowBox[{
          RowBox[{"hCayleyD", "\[RuleDelayed]", 
            StyleBox["CayleyD",
              FontColor->RGBColor[1, 0.2, 1]]}], 
          ",", \(setd \[RuleDelayed] SetDelayed\), 
          ",", \(set \[RuleDelayed] Set\), 
          ",", \(factor \[RuleDelayed] Factor\), ",", 
          RowBox[{"\[ScriptCapitalC]", "\[RuleDelayed]", 
            StyleBox["Cayley",
              FontColor->RGBColor[1, 0, 0.4]]}]}], "}"}]}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"setd", "[", 
        RowBox[{
          RowBox[{\(hCayleyD[1, 3, 6]\), "[", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{
                  InterpretationBox[\(m\_1\),
                    m1], ":", "_"}], ",", 
                RowBox[{
                  InterpretationBox[\(m\_2\),
                    m2], ":", "_"}], ",", 
                RowBox[{
                  InterpretationBox[\(m\_3\),
                    m3], ":", "_"}], ",", 
                RowBox[{
                  InterpretationBox[\(m\_4\),
                    m4], ":", "_"}], ",", 
                RowBox[{
                  InterpretationBox[\(m\_5\),
                    m5], ":", "_"}], ",", "p_"}], "}"}], "]"}], ",", 
          RowBox[{"set", "[", 
            RowBox[{
              RowBox[{\(hCayleyD[1, 3, 6]\), "[", 
                RowBox[{"{", 
                  RowBox[{
                    InterpretationBox[\(m\_1\),
                      m1], ",", 
                    InterpretationBox[\(m\_2\),
                      m2], ",", 
                    InterpretationBox[\(m\_3\),
                      m3], ",", 
                    InterpretationBox[\(m\_4\),
                      m4], ",", 
                    InterpretationBox[\(m\_5\),
                      m5], ",", "p"}], "}"}], "]"}], ",", 
              RowBox[{"factor", "[", 
                FractionBox[
                  RowBox[{
                    RowBox[{
                      StyleBox["ToArgs",
                        FontColor->RGBColor[0.2, 0.6, 1]], 
                      "[", \(\[CapitalDelta]\_\(1, 3, 6\)\), "]"}], "/.", 
                    RowBox[{
                      InterpretationBox[\(p\^2\),
                        PP], "\[Rule]", \(p\^2\)}]}], 
                  RowBox[{"\[ScriptCapitalC]", "[", 
                    RowBox[{
                      InterpretationBox[\(m\_1\),
                        m1], ",", 
                      InterpretationBox[\(m\_2\),
                        m2], ",", 
                      InterpretationBox[\(m\_3\),
                        m3], ",", 
                      InterpretationBox[\(m\_4\),
                        m4], ",", 
                      InterpretationBox[\(m\_5\),
                        m5], ",", "p"}], "]"}]], "]"}]}], "]"}]}], "]"}], "/.",
       
      RowBox[{"{", 
        RowBox[{
          RowBox[{"hCayleyD", "\[RuleDelayed]", 
            StyleBox["CayleyD",
              FontColor->RGBColor[1, 0.2, 1]]}], 
          ",", \(setd \[RuleDelayed] SetDelayed\), 
          ",", \(set \[RuleDelayed] Set\), 
          ",", \(factor \[RuleDelayed] Factor\), ",", 
          RowBox[{"\[ScriptCapitalC]", "\[RuleDelayed]", 
            StyleBox["Cayley",
              FontColor->RGBColor[1, 0, 0.4]]}]}], "}"}]}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"setd", "[", 
        RowBox[{
          RowBox[{\(hCayleyD[3, 4, 5]\), "[", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{
                  InterpretationBox[\(m\_1\),
                    m1], ":", "_"}], ",", 
                RowBox[{
                  InterpretationBox[\(m\_2\),
                    m2], ":", "_"}], ",", 
                RowBox[{
                  InterpretationBox[\(m\_3\),
                    m3], ":", "_"}], ",", 
                RowBox[{
                  InterpretationBox[\(m\_4\),
                    m4], ":", "_"}], ",", 
                RowBox[{
                  InterpretationBox[\(m\_5\),
                    m5], ":", "_"}], ",", "p_"}], "}"}], "]"}], ",", 
          RowBox[{"set", "[", 
            RowBox[{
              RowBox[{\(hCayleyD[3, 4, 5]\), "[", 
                RowBox[{"{", 
                  RowBox[{
                    InterpretationBox[\(m\_1\),
                      m1], ",", 
                    InterpretationBox[\(m\_2\),
                      m2], ",", 
                    InterpretationBox[\(m\_3\),
                      m3], ",", 
                    InterpretationBox[\(m\_4\),
                      m4], ",", 
                    InterpretationBox[\(m\_5\),
                      m5], ",", "p"}], "}"}], "]"}], ",", 
              RowBox[{"factor", "[", 
                FractionBox[
                  RowBox[{
                    RowBox[{
                      StyleBox["ToArgs",
                        FontColor->RGBColor[0.2, 0.6, 1]], 
                      "[", \(\[CapitalDelta]\_\(3, 4, 5\)\), "]"}], "/.", 
                    RowBox[{
                      InterpretationBox[\(p\^2\),
                        PP], "\[Rule]", \(p\^2\)}]}], 
                  RowBox[{"\[ScriptCapitalC]", "[", 
                    RowBox[{
                      InterpretationBox[\(m\_1\),
                        m1], ",", 
                      InterpretationBox[\(m\_2\),
                        m2], ",", 
                      InterpretationBox[\(m\_3\),
                        m3], ",", 
                      InterpretationBox[\(m\_4\),
                        m4], ",", 
                      InterpretationBox[\(m\_5\),
                        m5], ",", "p"}], "]"}]], "]"}]}], "]"}]}], "]"}], "/.",
       
      RowBox[{"{", 
        RowBox[{
          RowBox[{"hCayleyD", "\[RuleDelayed]", 
            StyleBox["CayleyD",
              FontColor->RGBColor[1, 0.2, 1]]}], 
          ",", \(setd \[RuleDelayed] SetDelayed\), 
          ",", \(set \[RuleDelayed] Set\), 
          ",", \(factor \[RuleDelayed] Factor\), ",", 
          RowBox[{"\[ScriptCapitalC]", "\[RuleDelayed]", 
            StyleBox["Cayley",
              FontColor->RGBColor[1, 0, 0.4]]}]}], "}"}]}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["ToArgs",
        FontColor->RGBColor[0.2, 0.6, 1]], 
      "[", \(\[CapitalDelta]\_\(i, j, k\)\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["ToArgs",
        FontColor->RGBColor[0.2, 0.6, 1]], 
      "[", \(\[CapitalDelta]\_\(1, 2, 6\)\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["ToArgs",
        FontColor->RGBColor[0.2, 0.6, 1]], "[", \(u\_\(i, j, k\)\), 
      "]"}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Utility Functions", "Section",
  CellDingbat->"\[FilledSmallCircle]",
  CellTags->"T1.5.1"],

Cell[CellGroupData[{

Cell["MakeFun and friends", "Subsection",
  CellTags->"T1.5.1.1"],

Cell["\<\
This function generates the recursion function definitions for 
TARCER starting from the entered relations.\
\>", "Text"],

Cell["The idea is to recurse TFR into TFI's step by step.", "Text"],

Cell[TextData[{
  "Define: S cD[ijk__] := ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[ScriptCapitalC]\^\(-1\)\) \
\[CapitalDelta]\_ijk\)]]
}], "Text"],

Cell[BoxData[
    \(\(nutonand\[CapitalDelta]u[w_, 
          5] := \(w /. {\[Nu]\_1 \[RuleDelayed] n1, \[Nu]\_2 \[RuleDelayed] 
                n2, \[Nu]\_3 \[RuleDelayed] n3, \[Nu]\_4 \[RuleDelayed] 
                n4, \[Nu]\_5 \[RuleDelayed] 
                n5, \[CapitalDelta]\_ijk__ \[RuleDelayed] \[ScriptCapitalC]\ \
cD[ijk], u\_ijk__ \[RuleDelayed] cu[ijk], \n\t\tD\_ijk__ :> 
                TA[D, ijk], \[Rho]\_ijk__ :> 
                TA[\[Rho], ijk], \[Phi]\_\(\(ijk__\)\(\ \)\) :> 
                TA[\[Phi], ijk], \n\t\t\t\[Sigma]\_\(i_, j_, k_\) :> 
                TA[\[Sigma], d, i, j, k, \[Nu]\_i, \[Nu]\_j, \[Nu]\_k], 
              h\_\(i_, j_, k_\) :> 
                TA[h, d, i, j, k, \[Nu]\_i, \[Nu]\_j, \[Nu]\_k], 
              S\_\(i_, j_, k_\) :> 
                TA[S, d, i, j, 
                  k, \[Nu]\_i, \[Nu]\_j, \[Nu]\_k], \n\t\t\t\(\(\
\[CapitalSigma]\_i_\)\(:>\)\(ToArgs[\[CapitalSigma]\_i]\)\(\n\)\)\t\t}\) /. {\
\t\[Nu]\_1 \[RuleDelayed] n1, \[Nu]\_2 \[RuleDelayed] 
              n2, \[Nu]\_3 \[RuleDelayed] n3, \[Nu]\_4 \[RuleDelayed] 
              n4, \[Nu]\_5 \[RuleDelayed] n5, m\_1 :> m1, m\_2 :> m2, 
            m\_3 :> m3, m\_4 :> m4, m\_5 :> m5};\)\)], "Input"],

Cell[BoxData[
    \(\(nutonand\[CapitalDelta]u[
          w_] := \(w /. {\[Nu]\_1 \[RuleDelayed] n1, \[Nu]\_2 \[RuleDelayed] 
                n2, \[Nu]\_3 \[RuleDelayed] n3, \[Nu]\_4 \[RuleDelayed] 
                n4, \[Nu]\_5 \[RuleDelayed] 
                n5, \[CapitalDelta]\_ijk__ \[RuleDelayed] cD[ijk], 
              u\_ijk__ \[RuleDelayed] cu[ijk], 
              D\_ijk__ \[RuleDelayed] 
                TA[D, ijk], \[Rho]\_ijk__ \[RuleDelayed] 
                TA[\[Rho], ijk], \[Phi]\_ijk__ \[RuleDelayed] 
                TA[\[Phi], ijk], \[Sigma]\_\(i_, j_, k_\) \[RuleDelayed] 
                TA[\[Sigma], d, i, j, k, \[Nu]\_i, \[Nu]\_j, \[Nu]\_k], 
              h\_\(i_, j_, k_\) \[RuleDelayed] 
                TA[h, d, i, j, k, \[Nu]\_i, \[Nu]\_j, \[Nu]\_k], 
              S\_\(i_, j_, k_\) \[RuleDelayed] 
                TA[S, d, i, j, 
                  k, \[Nu]\_i, \[Nu]\_j, \[Nu]\_k], \[CapitalSigma]\_i_ \
\[RuleDelayed] ToArgs[\[CapitalSigma]\_i]}\) /. {\[Nu]\_1 \[RuleDelayed] 
              n1, \[Nu]\_2 \[RuleDelayed] n2, \[Nu]\_3 \[RuleDelayed] 
              n3, \[Nu]\_4 \[RuleDelayed] n4, \[Nu]\_5 \[RuleDelayed] n5, 
            m\_1 \[RuleDelayed] m1, m\_2 \[RuleDelayed] m2, 
            m\_3 \[RuleDelayed] m3, m\_4 \[RuleDelayed] m4, 
            m\_5 \[RuleDelayed] m5};\)\)], "Input"],

Cell[BoxData[
    \(\(addPeP[TFR[d_, pp_, li1_, rest_]] := 
        TFR[d, pp, li1, rest];\)\)], "Input"],

Cell[BoxData[
    \(\(addPeP[TFI[d_, pp_, li1_List]] := TFI[d, pp, li1];\)\)], "Input"],

Cell[BoxData[
    \(\(addPeP[TFR[d_, pp_, dp_Symbol, li1_, rest_]] := 
        TFR[d, pp, dp, li1, rest];\)\)], "Input"],

Cell[BoxData[
    \(\(addPeP[TFI[d_, pp_, dp_Symbol, li1_List]] := 
        TFI[d, pp, dp, li1];\)\)], "Input"],

Cell[BoxData[
    \(\(addPeP[TVI[d_, pp_, li1_List]] := TVI[d, pp, li1];\)\)], "Input"],

Cell[BoxData[
    \(nnnnnaddPeP[any_[d_, pp_, li1_List, rest__List]] := 
      any[d, pp, li1, rest] /; any =!= List\)], "Input"],

Cell[BoxData[
    \(\(addPeP[z_List] := Append[z, \@PP];\)\)], "Input"],

Cell["addPeP[TFI[d_, z_List]] := TFI[d, PP, z]; ", "Input"],

Cell[BoxData[
    \(\(addPeP[TVI[d_, z_List]] := TVI[d, PP, z];\)\)], "Input"],

Cell[BoxData[
    \(\(addPeP[TJI[d_, z_List]] := TJI[d, PP, z];\)\)], "Input"],

Cell[BoxData[
    \(\(addPeP[TFR[d_, z_List]] := TFR[d, PP_, z];\)\)], "Input"],

Cell[BoxData[
    \(\(addPeP[TFR[d_, pl_List, z_List]] := TFR[d, PP_, pl, z];\)\)], "Input"],

Cell[BoxData[
    \(\(addPeP[TVR[d_, z__List]] := TVR[d, PP_, z];\)\)], "Input"],

Cell[BoxData[
    \(\(addPeP[TJR[d_, z__List]] := TJR[d, PP_, z];\)\)], "Input"],

Cell[BoxData[
    \(\(nutomass[
          w_] := \(\(w /. {\[Nu]\_1 + i1_.  \[RuleDelayed] {n1 + i1, 
                    m1}, \[Nu]\_2 + i2_.  \[RuleDelayed] {n2 + i2, 
                    m2}, \[Nu]\_3 + i3_.  \[RuleDelayed] {n3 + i3, 
                    m3}, \[Nu]\_4 + i4_.  \[RuleDelayed] {n4 + i4, 
                    m4}, \[Nu]\_5 + i5_.  \[RuleDelayed] {n5 + i5, 
                    m5}}\) /. {in1_Integer, in2_Integer, in3_Integer, 
                in4_Integer} \[RuleDelayed] {{in1, m1}, {in2, m2}, {in3, 
                  m3}, {in4, m4}}\) /. {in1_Integer, in2_Integer, 
              in3_Integer} \[RuleDelayed] {{in1, m1}, {in2, m2}, {in3, 
                m3}};\)\)], "Input"],

Cell[BoxData[
    \(\(Clear[maybeF];\)\)], "Input"],

Cell[BoxData[
    \(\(maybeF[z_Times] := 
        FactorC[z] /; 
          FreeQ[z, TFI] && FreeQ[z, TVI] && FreeQ[z, TJI] && 
            Length[Cases[z, cD[__], \(-1\)]] > 1;\)\)], "Input"],

Cell[BoxData[
    \(maybeF[z_] := z; SetAttributes[top, Listable];\)], "Input"],

Cell["This is the function for the information of side conditions.", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"SetAttributes", "[", 
        RowBox[{
          StyleBox["IFF",
            FontColor->RGBColor[0.6, 0.4, 1]], ",", "HoldAll"}], "]"}], 
      ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Clear", "[", 
        StyleBox["MakeFun",
          FontColor->RGBColor[1, 0.6, 0.6]], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["MakeFun",
            FontColor->RGBColor[1, 0.6, 0.6]], "[", 
          RowBox[{
            RowBox[{
              RowBox[{"c_.", " ", 
                RowBox[{
                  StyleBox["TFI",
                    FontColor->RGBColor[1, 0.6, 0]], "[", "t__", "]"}]}], "==",
               "rhs_"}], ",", "eqn_String", ",", 
            RowBox[{
              StyleBox["IFF",
                FontColor->RGBColor[0.6, 0.4, 1]], "[", "conds_", "]"}], 
            ",", \(mrel_ : {}\)}], "]"}], ":=", 
        RowBox[{
          StyleBox["Block",
            CellFrame->True,
            FontSize->16,
            FontWeight->"Bold",
            FontColor->RGBColor[1, 0.2, 0.2]], "[", 
          RowBox[{\({nm}\), ",", 
            
            RowBox[{\(nmrel = Select[Flatten[{mrel}], FreeQ[#1, Factor] &]\), 
              ";", 
              RowBox[{
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        RowBox[{
                          RowBox[{
                            RowBox[{
                              RowBox[{
                                RowBox[{
                                  RowBox[{
                                    RowBox[{"HoldForm", "@@", 
                                      RowBox[{"{", 
                                        RowBox[{
                                        RowBox[{
                                        RowBox[{
                                        RowBox[{
                                        RowBox[{"setdel", "[", 
                                        RowBox[{
                                        RowBox[{
                                        RowBox[{"addPeP", "[", 
                                        RowBox[{
                                        StyleBox["TFR",
                                        FontColor->RGBColor[0, 0.6, 0]], 
                                        "@@", \(top /@ nutomass[{t}]\)}], 
                                        "]"}], "/.", "nmrel"}], ",", 
                                        RowBox[{\(Hold[Condition]\), "[", 
                                        RowBox[{
                                        
                                        RowBox[{\(Hold[CompoundExpression]\), 
                                        "[", "\t", 
                                        
                                        RowBox[{\(\(Hold[TComment]\)[
                                        eqn, \(\(\(addPeP[nutomass[TFR[t]]] /. 
                                        TFR -> TFIC\) /. {Pattern :> pat, 
                                        Blank :> blank}\) /. pat[PP, 
                                        blank[]] :> PP\) /. nmrel]\), ",", 
                                        RowBox[{
                                        RowBox[{"Collect", "[", 
                                        RowBox[{
                                        RowBox[{"TT", "=", 
                                        RowBox[{"Expand3", "[", 
                                        RowBox[{
                                        "nutonand\[CapitalDelta]u", "[", 
                                        RowBox[{
                                        RowBox[{\(1\/c\), 
                                        RowBox[{"(", 
                                        RowBox[{"rhs", "/.", 
                                        RowBox[{
                                        RowBox[{
                                        StyleBox["TFI",
                                        FontColor->RGBColor[1, 0.6, 0]], "[", 
                                        "te__", "]"}], "\[RuleDelayed]", 
                                        RowBox[{"addPeP", "[", 
                                        RowBox[{"nutomass", "[", 
                                        RowBox[{
                                        StyleBox["TFI",
                                        FontColor->RGBColor[1, 0.6, 0]], "[", 
                                        "te", "]"}], "]"}], "]"}]}]}], 
                                        ")"}]}], ",", "5"}], "]"}], "]"}]}], 
                                        ",", 
                                        RowBox[{
                                        StyleBox["TFI",
                                        FontColor->RGBColor[1, 0.6, 0]], "[", 
                                        "__", "]"}], 
                                        ",", \(maybeF[\((Collect[
                                        Numerator[#1], cD[__], 
                                        Factor]/Collect[Denominator[#1], 
                                        cD[__], Factor] &)\) /@ 
                                        Factor[#1]] &\)}], "]"}], "/.", 
                                        "nmrel"}]}], "]"}], ",", 
                                        RowBox[{
                                        "nutonand\[CapitalDelta]u", "[", 
                                        RowBox[{
                                        RowBox[{
                                        StyleBox["IFF",
                                        FontColor->RGBColor[0.6, 0.4, 1]], 
                                        "[", "conds", "]"}], ",", "5"}], 
                                        "]"}]}], "]"}]}], "]"}], 
                                        "/.", \(top[i_Integer] \[Rule] i\)}], 
                                        "/.", \(top \[RuleDelayed] \
\((patternTest[pattern[#1, blank[]], PQ] &)\)\)}], "/.", 
                                        RowBox[{
                                        RowBox[{"patternTest", "[", 
                                        RowBox[{
                                        RowBox[{"pattern", "[", 
                                        RowBox[{
                                        RowBox[{"dm_", "/;", 
                                        RowBox[{"MemberQ", "[", 
                                        RowBox[{
                                        RowBox[{"{", 
                                        RowBox[{"d", ",", 
                                        InterpretationBox[\(p\^2\),
                                        PP], ",", "DP", ",", 
                                        InterpretationBox[\(m\_1\),
                                        m1], ",", 
                                        InterpretationBox[\(m\_2\),
                                        m2], ",", 
                                        InterpretationBox[\(m\_3\),
                                        m3], ",", 
                                        InterpretationBox[\(m\_4\),
                                        m4], ",", 
                                        InterpretationBox[\(m\_5\),
                                        m5]}], "}"}], ",", "dm"}], "]"}]}], 
                                        ",", \(blank[]\)}], "]"}], ",", "_"}],
                                         "]"}], 
                                        "\[RuleDelayed]", \(pattern[dm, 
                                        blank[]]\)}]}], "/.", "\n", 
                                        "\t\t\t\t\t", \({blank \[RuleDelayed] 
                                        Blank, 
                                        pattern \[RuleDelayed] Pattern, 
                                        patternTest \[RuleDelayed] 
                                        PatternTest}\)}], "}"}]}], "/.", 
                                    RowBox[{\(cD[ijk__]\), "\[Rule]", 
                                      RowBox[{
                                        RowBox[{"Hold", "[", 
                                        RowBox[{
                                        StyleBox["CayleyD",
                                        FontColor->RGBColor[1, 0.2, 1]], "[", 
                                        "ijk", "]"}], "]"}], 
                                        "[", \(addPeP[
                                        BLA = \(nutomass[Last[{t}]] /. 
                                        nmrel\) /. {nuu_, ma_} \[RuleDelayed] 
                                        ma]\), "]"}]}]}], 
                                  "/.", \(addPeP -> Identity\)}], 
                                "/.", \(Hold[CompoundExpression] \[Rule] 
                                  CompoundExpression\)}], "/.", 
                              RowBox[{
                                RowBox[{\(Hold[Condition]\), "[", 
                                  RowBox[{"a_", ",", 
                                    RowBox[{
                                      StyleBox["IFF",
                                        FontColor->RGBColor[0.6, 0.4, 1]], 
                                      "[", "b_", "]"}]}], "]"}], 
                                "\[Rule]", \(a /; b\)}]}], 
                            "/.", \(Hold[Set] \[Rule] Set\)}], 
                          "/.", \(Hold[TComment] -> TComment\)}], "/.", 
                        RowBox[{
                          RowBox[{"Hold", "[", 
                            RowBox[{
                              StyleBox["CayleyD",
                                FontColor->RGBColor[1, 0.2, 1]], "[", "ijk__",
                               "]"}], "]"}], "\[Rule]", 
                          RowBox[{
                            StyleBox["CayleyD",
                              FontColor->RGBColor[1, 0.2, 1]], "[", "ijk", 
                            "]"}]}]}], 
                      "/.", \({setdel \[RuleDelayed] SetDelayed}\)}], ")"}], 
                  "/.", \(Identity -> identit\)}], 
                "/.", \(identit[a_] -> a\)}]}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["MakeFun",
            FontColor->RGBColor[1, 0.6, 0.6]], "[", 
          RowBox[{
            RowBox[{
              RowBox[{"c_.", " ", 
                RowBox[{
                  StyleBox["TFI",
                    FontColor->RGBColor[1, 0.6, 0]], "[", "t__", "]"}]}], "==",
               "rhs_"}], ",", "eqn_String", ",", \(mrel_ : {}\)}], "]"}], ":=",
         
        RowBox[{
          RowBox[{
            StyleBox["Block",
              CellFrame->True,
              FontSize->16,
              FontWeight->"Bold",
              FontColor->RGBColor[1, 0.2, 0.2]], "[", 
            RowBox[{\({nm}\), ",", 
              
              RowBox[{\(nmrel = 
                  Select[Flatten[{mrel}], FreeQ[#1, Factor] &]\), ";", 
                RowBox[{
                  RowBox[{
                    RowBox[{
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            RowBox[{
                              RowBox[{
                                RowBox[{
                                  RowBox[{
                                    RowBox[{
                                      RowBox[{"HoldForm", "@@", 
                                        RowBox[{"{", 
                                        RowBox[{
                                        RowBox[{
                                        RowBox[{
                                        RowBox[{
                                        RowBox[{"setdel", "[", 
                                        RowBox[{
                                        RowBox[{
                                        RowBox[{"addPeP", "[", 
                                        RowBox[{
                                        StyleBox["TFR",
                                        FontColor->RGBColor[0, 0.6, 0]], 
                                        "@@", \(top /@ nutomass[{t}]\)}], 
                                        "]"}], "/.", "nmrel"}], ",", 
                                        
                                        RowBox[{\(Hold[CompoundExpression]\), 
                                        "[", 
                                        
                                        RowBox[{\(\(Hold[TComment]\)[
                                        eqn, \(\(\(addPeP[nutomass[TFR[t]]] /. 
                                        TFR -> TFIC\) /. {Pattern :> pat, 
                                        Blank :> blank}\) /. pat[PP, 
                                        blank[]] :> PP\) /. nmrel]\), ",", 
                                        RowBox[{
                                        RowBox[{"Collect", "[", 
                                        RowBox[{
                                        RowBox[{"TT", "=", 
                                        RowBox[{"Expand3", "[", 
                                        RowBox[{
                                        "nutonand\[CapitalDelta]u", "[", 
                                        RowBox[{\(1\/c\), 
                                        RowBox[{"(", 
                                        RowBox[{"rhs", "/.", 
                                        RowBox[{
                                        RowBox[{
                                        StyleBox["TFI",
                                        FontColor->RGBColor[1, 0.6, 0]], "[", 
                                        "te__", "]"}], "\[RuleDelayed]", 
                                        RowBox[{"addPeP", "[", 
                                        RowBox[{"nutomass", "[", 
                                        RowBox[{
                                        StyleBox["TFI",
                                        FontColor->RGBColor[1, 0.6, 0]], "[", 
                                        "te", "]"}], "]"}], "]"}]}]}], 
                                        ")"}]}], "]"}], "]"}]}], ",", 
                                        RowBox[{
                                        StyleBox["TFI",
                                        FontColor->RGBColor[1, 0.6, 0]], "[", 
                                        "__", "]"}], 
                                        ",", \(maybeF[\((Collect[
                                        Numerator[#1], cD[__], 
                                        Factor]/Collect[Denominator[#1], 
                                        cD[__], Factor] &)\) /@ 
                                        Factor[#1]] &\)}], "]"}], "/.", 
                                        "nmrel"}]}], "]"}]}], "]"}], 
                                        "/.", \(top[i_Integer] \[Rule] i\)}], 
                                        "/.", \(top \[RuleDelayed] \
\((patternTest[pattern[#1, blank[]], PQ] &)\)\)}], "/.", 
                                        RowBox[{
                                        RowBox[{"patternTest", "[", 
                                        RowBox[{
                                        RowBox[{"pattern", "[", 
                                        RowBox[{
                                        RowBox[{"dm_", "/;", 
                                        RowBox[{"MemberQ", "[", 
                                        RowBox[{
                                        RowBox[{"{", 
                                        RowBox[{"d", ",", 
                                        InterpretationBox[\(p\^2\),
                                        PP], ",", "DP", ",", 
                                        InterpretationBox[\(m\_1\),
                                        m1], ",", 
                                        InterpretationBox[\(m\_2\),
                                        m2], ",", 
                                        InterpretationBox[\(m\_3\),
                                        m3], ",", 
                                        InterpretationBox[\(m\_4\),
                                        m4], ",", 
                                        InterpretationBox[\(m\_5\),
                                        m5]}], "}"}], ",", "dm"}], "]"}]}], 
                                        ",", \(blank[]\)}], "]"}], ",", "_"}],
                                         "]"}], "\[RuleDelayed]", \(pattern[
                                        dm, blank[]]\)}]}], "/.", 
                                        "\t", \({blank \[RuleDelayed] Blank, 
                                        pattern \[RuleDelayed] Pattern, 
                                        patternTest \[RuleDelayed] 
                                        PatternTest}\)}], "}"}]}], "/.", 
                                      RowBox[{\(cD[ijk__]\), "\[Rule]", 
                                        RowBox[{
                                        RowBox[{"Hold", "[", 
                                        RowBox[{
                                        StyleBox["CayleyD",
                                        FontColor->RGBColor[1, 0.2, 1]], "[", 
                                        "ijk", "]"}], "]"}], 
                                        "[", \(addPeP[\(\(nutomass[
                                        Last[{t}]] /. addPeP -> Identity\) /. 
                                        nmrel\) /. {nuu_, ma_} \[RuleDelayed] 
                                        ma]\), "]"}]}]}], 
                                    "/.", \(Hold[CompoundExpression] \[Rule] 
                                      CompoundExpression\)}], "/.", 
                                  RowBox[{
                                    RowBox[{\(Hold[Condition]\), "[", 
                                      RowBox[{"a_", ",", 
                                        RowBox[{
                                        StyleBox["IFF",
                                        FontColor->RGBColor[0.6, 0.4, 1]], 
                                        "[", "b_", "]"}]}], "]"}], 
                                    "\[Rule]", \(a /; b\)}]}], 
                                "/.", \(Hold[Set] \[Rule] Set\)}], 
                              "/.", \(Hold[TComment] -> TComment\)}], "/.", 
                            RowBox[{
                              RowBox[{"Hold", "[", 
                                RowBox[{
                                  StyleBox["CayleyD",
                                    FontColor->RGBColor[1, 0.2, 1]], "[", 
                                  "ijk__", "]"}], "]"}], "\[Rule]", 
                              RowBox[{
                                StyleBox["CayleyD",
                                  FontColor->RGBColor[1, 0.2, 1]], "[", "ijk",
                                 "]"}]}]}], 
                          "/.", \({setdel \[RuleDelayed] SetDelayed}\)}], 
                        ")"}], "/.", \(addPeP -> Identity\)}], 
                    "/.", \(Identity -> identit\)}], 
                  "/.", \(identit[a_] -> a\)}]}]}], "]"}], "/;", 
          RowBox[{\(Head[mrel]\), "=!=", 
            StyleBox["IFF",
              FontColor->RGBColor[0.6, 0.4, 1]]}]}]}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["MakeFun",
            FontColor->RGBColor[1, 0.6, 0.6]], "[", 
          RowBox[{
            RowBox[{
              RowBox[{"c_.", " ", 
                RowBox[{
                  StyleBox["TVI",
                    FontColor->RGBColor[0.2, 0.4, 0.8]], "[", "t__", "]"}]}], 
              "==", "rhs_"}], ",", "eqn_String", ",", 
            RowBox[{
              StyleBox["IFF",
                FontColor->RGBColor[0.6, 0.4, 1]], "[", "conds_", "]"}], 
            ",", \(mrel_ : {}\)}], "]"}], ":=", 
        RowBox[{
          StyleBox["Block",
            FontSize->16,
            FontWeight->"Bold",
            FontColor->RGBColor[1, 0.2, 0.2]], "[", 
          RowBox[{\({nm}\), ",", 
            
            RowBox[{\(nmrel = Select[Flatten[{mrel}], FreeQ[#1, Factor] &]\), 
              ";", 
              RowBox[{"nmrel", "=", 
                RowBox[{"Join", "[", 
                  RowBox[{"nmrel", ",", 
                    RowBox[{"{", 
                      RowBox[{
                        RowBox[{\(m\_1\), "\[RuleDelayed]", 
                          InterpretationBox[\(m\_1\),
                            m1]}], ",", 
                        RowBox[{\(m\_2\), "\[RuleDelayed]", 
                          InterpretationBox[\(m\_2\),
                            m2]}], ",", 
                        RowBox[{\(m\_3\), "\[RuleDelayed]", 
                          InterpretationBox[\(m\_3\),
                            m3]}], ",", 
                        RowBox[{\(m\_4\), "\[RuleDelayed]", 
                          InterpretationBox[\(m\_4\),
                            m4]}], 
                        ",", \(\[CapitalSigma]\_i_ :> 
                          ToArgs[\[CapitalSigma]\_i]\)}], "}"}]}], "]"}]}], 
              ";", 
              RowBox[{
                RowBox[{
                  RowBox[{
                    RowBox[{
                      RowBox[{
                        RowBox[{
                          RowBox[{
                            RowBox[{
                              RowBox[{
                                RowBox[{
                                  RowBox[{
                                    RowBox[{
                                      RowBox[{
                                        RowBox[{
                                        RowBox[{"HoldForm", "@@", 
                                        RowBox[{"{", 
                                        RowBox[{
                                        RowBox[{
                                        RowBox[{
                                        RowBox[{
                                        RowBox[{"setdel", "[", 
                                        RowBox[{
                                        RowBox[{
                                        RowBox[{"addPeP", "[", 
                                        RowBox[{
                                        StyleBox["TVR",
                                        FontColor->RGBColor[0.2, 0.8, 1]], 
                                        "@@", \(top /@ nutomass[{t}]\)}], 
                                        "]"}], "/.", "nmrel"}], ",", 
                                        RowBox[{\(Hold[Condition]\), "[", 
                                        RowBox[{
                                        
                                        RowBox[{\(Hold[CompoundExpression]\), 
                                        "[", 
                                        
                                        RowBox[{\(\(Hold[TComment]\)[
                                        eqn, \(\(\(addPeP[nutomass[TVR[t]]] /. 
                                        TVR -> TVIC\) /. {Pattern :> pat, 
                                        Blank :> blank}\) /. pat[PP, 
                                        blank[]] :> PP\) /. nmrel]\), ",", 
                                        RowBox[{
                                        RowBox[{
                                        RowBox[{"Collect", "[", 
                                        RowBox[{
                                        RowBox[{"TT", "=", 
                                        RowBox[{"Expand3", "[", 
                                        RowBox[{"nutonand\[CapitalDelta]u", 
                                        "[", 
                                        RowBox[{\(1\/c\), 
                                        RowBox[{"(", 
                                        RowBox[{"rhs", "/.", 
                                        RowBox[{
                                        RowBox[{
                                        StyleBox["TVI",
                                        FontColor->RGBColor[0.2, 0.4, 0.8]], 
                                        "[", "te__", "]"}], "\[RuleDelayed]", 
                                        
                                        RowBox[{"addPeP", "[", 
                                        RowBox[{"nutomass", "[", 
                                        RowBox[{
                                        StyleBox["TVI",
                                        FontColor->RGBColor[0.2, 0.4, 0.8]], 
                                        "[", "te", "]"}], "]"}], "]"}]}]}], 
                                        ")"}]}], "]"}], "]"}]}], ",", 
                                        RowBox[{
                                        StyleBox["TVI",
                                        FontColor->RGBColor[0.2, 0.4, 0.8]], 
                                        "[", "__", "]"}], 
                                        ",", \(maybeF[\((Collect[
                                        Numerator[#1], cu[__], 
                                        Factor]/Collect[Denominator[#1], 
                                        cu[__], Factor] &)\) /@ 
                                        Factor[#1]] &\)}], "]"}], 
                                        "/.", \(\[ScriptCapitalC] -> 1\)}], "/.",
                                         "nmrel"}]}], "]"}], ",", 
                                        RowBox[{
                                        "nutonand\[CapitalDelta]u", "[", 
                                        RowBox[{
                                        StyleBox["IFF",
                                        FontColor->RGBColor[0.6, 0.4, 1]], 
                                        "[", "conds", "]"}], "]"}]}], "]"}]}],
                                         "]"}], "/.", \(top[
                                        i_Integer] \[Rule] i\)}], 
                                        "/.", \(top \[RuleDelayed] \
\((patternTest[pattern[#1, blank[]], PQ] &)\)\)}], "/.", 
                                        RowBox[{
                                        RowBox[{"patternTest", "[", 
                                        RowBox[{
                                        RowBox[{"pattern", "[", 
                                        RowBox[{
                                        RowBox[{"dm_", "/;", 
                                        RowBox[{"MemberQ", "[", 
                                        RowBox[{
                                        RowBox[{"{", 
                                        RowBox[{"d", ",", 
                                        InterpretationBox[\(p\^2\),
                                        PP], ",", 
                                        InterpretationBox[\(m\_1\),
                                        m1], ",", 
                                        InterpretationBox[\(m\_2\),
                                        m2], ",", 
                                        InterpretationBox[\(m\_3\),
                                        m3], ",", 
                                        InterpretationBox[\(m\_4\),
                                        m4]}], "}"}], ",", "dm"}], "]"}]}], 
                                        ",", \(blank[]\)}], "]"}], ",", "_"}],
                                         "]"}], "\[RuleDelayed]", \(pattern[
                                        dm, blank[]]\)}]}], "/.", 
                                        "\t", \({blank \[RuleDelayed] Blank, 
                                        pattern \[RuleDelayed] Pattern, 
                                        patternTest \[RuleDelayed] 
                                        PatternTest}\)}], "}"}]}], "/.", "\n",
                                         "\t\t\t", \(HoldPattern[
                                        TA[aijk__]] \[Rule] \(Hold[
                                        TA[aijk]]\)[
                                        addPeP[\(nutomass[Last[{t}]] /. 
                                        nmrel\) /. {nuu_, ma_} \[RuleDelayed] 
                                        ma]]\)}], "/.", "\n", 
                                        "\t\t\t", \(cD[
                                        ijk__] \[Rule] \(Hold[Cayley[ijk]]\)[
                                        addPeP[\(nutomass[Last[{t}]] /. 
                                        nmrel\) /. {nuu_, ma_} \[RuleDelayed] 
                                        ma]]\)}], "/.", 
                                      RowBox[{\(cu[ijk__]\), "\[Rule]", 
                                        RowBox[{
                                        RowBox[{"Hold", "[", 
                                        RowBox[{
                                        StyleBox["Cayleyu",
                                        FontColor->RGBColor[0.8, 0.8, 0.4]], 
                                        "[", "ijk", "]"}], "]"}], 
                                        "[", \(addPeP[\(\(nutomass[
                                        Last[{t}]] /. addPeP -> Identity\) /. 
                                        nmrel\) /. {nuu_, ma_} \[RuleDelayed] 
                                        ma]\), "]"}]}]}], 
                                    "/.", \(Hold[CompoundExpression] \[Rule] 
                                      CompoundExpression\)}], "/.", 
                                  RowBox[{
                                    RowBox[{\(Hold[Condition]\), "[", 
                                      RowBox[{"a_", ",", 
                                        RowBox[{
                                        StyleBox["IFF",
                                        FontColor->RGBColor[0.6, 0.4, 1]], 
                                        "[", "b_", "]"}]}], "]"}], 
                                    "\[Rule]", \(a /; b\)}]}], 
                                "/.", \(Hold[Set] \[Rule] Set\)}], 
                              "/.", \(Hold[TComment] -> TComment\)}], 
                            "/.", \(addPeP -> Identity\)}], "/.", 
                          RowBox[{
                            RowBox[{"Hold", "[", 
                              RowBox[{
                                StyleBox["Cayleyu",
                                  FontColor->RGBColor[0.8, 0.8, 0.4]], "[", 
                                "ijk__", "]"}], "]"}], "\[Rule]", 
                            RowBox[{
                              StyleBox["Cayleyu",
                                FontColor->RGBColor[0.8, 0.8, 0.4]], "[", 
                              "ijk", "]"}]}]}], "/.", 
                        RowBox[{
                          RowBox[{"Hold", "[", 
                            RowBox[{
                              StyleBox["Cayley",
                                FontColor->RGBColor[1, 0.2, 1]], "[", "ijk__",
                               "]"}], "]"}], "\[Rule]", 
                          RowBox[{
                            StyleBox["Cayley",
                              FontColor->RGBColor[1, 0.2, 1]], "[", "ijk", 
                            "]"}]}]}], "/.", "\n", 
                      "\t\t\t", \(Hold[TA] -> TA\)}], 
                    "/.", \({setdel \[RuleDelayed] SetDelayed}\)}], 
                  "/.", \(Identity -> identit\)}], 
                "/.", \(identit[a_] -> a\)}]}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["MakeFun",
            FontColor->RGBColor[1, 0.6, 0.6]], "[", 
          RowBox[{
            RowBox[{
              RowBox[{"c_.", " ", 
                RowBox[{
                  StyleBox["TVI",
                    FontColor->RGBColor[0.2, 0.4, 0.8]], "[", "t__", "]"}]}], 
              "==", "rhs_"}], ",", "eqn_String", ",", \(mrel_ : {}\)}], "]"}],
         ":=", 
        RowBox[{
          RowBox[{
            StyleBox["Block",
              FontSize->16,
              FontWeight->"Bold",
              FontColor->RGBColor[1, 0.2, 0.2]], "[", 
            RowBox[{\({nm}\), ",", 
              
              RowBox[{\(nmrel = 
                  Select[Flatten[{mrel}], FreeQ[#1, Factor] &]\), ";", 
                RowBox[{"nmrel", "=", 
                  RowBox[{"Join", "[", 
                    RowBox[{"nmrel", ",", 
                      RowBox[{"{", 
                        RowBox[{
                          RowBox[{\(m\_1\), "\[RuleDelayed]", 
                            InterpretationBox[\(m\_1\),
                              m1]}], ",", 
                          RowBox[{\(m\_2\), "\[RuleDelayed]", 
                            InterpretationBox[\(m\_2\),
                              m2]}], ",", 
                          RowBox[{\(m\_3\), "\[RuleDelayed]", 
                            InterpretationBox[\(m\_3\),
                              m3]}], ",", 
                          RowBox[{\(m\_4\), "\[RuleDelayed]", 
                            InterpretationBox[\(m\_4\),
                              m4]}], ",", 
                          RowBox[{\(\[CapitalSigma]\_i_\), "\[RuleDelayed]", 
                            RowBox[{
                              StyleBox["ToArgs",
                                FontColor->RGBColor[0.2, 0.6, 1]], 
                              "[", \(\[CapitalSigma]\_i\), "]"}]}]}], "}"}]}],
                     "]"}]}], ";", 
                RowBox[{
                  RowBox[{
                    RowBox[{
                      RowBox[{
                        RowBox[{
                          RowBox[{
                            RowBox[{
                              RowBox[{
                                RowBox[{
                                  RowBox[{
                                    RowBox[{
                                      RowBox[{"HoldForm", "@@", 
                                        RowBox[{"{", 
                                        RowBox[{
                                        RowBox[{
                                        RowBox[{
                                        RowBox[{
                                        RowBox[{"setdel", "[", 
                                        RowBox[{
                                        RowBox[{
                                        RowBox[{"addPeP", "[", 
                                        RowBox[{
                                        StyleBox["TVR",
                                        FontColor->RGBColor[0.2, 0.8, 1]], 
                                        "@@", \(top /@ nutomass[{t}]\)}], 
                                        "]"}], "/.", "nmrel"}], ",", 
                                        
                                        RowBox[{\(Hold[CompoundExpression]\), 
                                        "[", 
                                        
                                        RowBox[{\(\(Hold[TComment]\)[
                                        eqn, \(\(\(addPeP[nutomass[TVR[t]]] /. 
                                        TVR -> TVIC\) /. {Pattern :> pat, 
                                        Blank :> blank}\) /. pat[PP, 
                                        blank[]] :> PP\) /. nmrel]\), "\n", 
                                        "\t\t\t\t\t\t", ",", 
                                        RowBox[{
                                        RowBox[{
                                        RowBox[{"Collect", "[", 
                                        RowBox[{
                                        RowBox[{"TT", "=", 
                                        RowBox[{"Expand3", "[", 
                                        RowBox[{
                                        "nutonand\[CapitalDelta]u", "[", 
                                        RowBox[{\(1\/c\), 
                                        RowBox[{"(", 
                                        RowBox[{"rhs", "/.", 
                                        RowBox[{
                                        RowBox[{
                                        StyleBox["TVI",
                                        FontColor->RGBColor[0.2, 0.4, 0.8]], 
                                        "[", "te__", "]"}], "\[RuleDelayed]", 
                                        
                                        RowBox[{"addPeP", "[", 
                                        RowBox[{"nutomass", "[", 
                                        RowBox[{
                                        StyleBox["TVI",
                                        FontColor->RGBColor[0.2, 0.4, 0.8]], 
                                        "[", "te", "]"}], "]"}], "]"}]}]}], 
                                        ")"}]}], "]"}], "]"}]}], ",", 
                                        RowBox[{
                                        StyleBox["TVI",
                                        FontColor->RGBColor[0.2, 0.4, 0.8]], 
                                        "[", "__", "]"}], 
                                        ",", \(maybeF[\((Collect[
                                        Numerator[#1], cu[__], 
                                        Factor]/Collect[Denominator[#1], 
                                        cu[__], Factor] &)\) /@ 
                                        Factor[#1]] &\)}], "]"}], "/.", 
                                        "nmrel"}], 
                                        "/.", \(\[ScriptCapitalC] \[Rule] 
                                        1\)}]}], "]"}]}], "]"}], 
                                        "/.", \(top[i_Integer] \[Rule] i\)}], 
                                        "/.", \(top \[RuleDelayed] \
\((patternTest[pattern[#1, blank[]], PQ] &)\)\)}], "/.", 
                                        RowBox[{
                                        RowBox[{"patternTest", "[", 
                                        RowBox[{
                                        RowBox[{"pattern", "[", 
                                        RowBox[{
                                        RowBox[{"dm_", "/;", 
                                        RowBox[{"MemberQ", "[", 
                                        RowBox[{
                                        RowBox[{"{", 
                                        RowBox[{"d", ",", 
                                        InterpretationBox[\(p\^2\),
                                        PP], ",", 
                                        InterpretationBox[\(m\_1\),
                                        m1], ",", 
                                        InterpretationBox[\(m\_2\),
                                        m2], ",", 
                                        InterpretationBox[\(m\_3\),
                                        m3], ",", 
                                        InterpretationBox[\(m\_4\),
                                        m4]}], "}"}], ",", "dm"}], "]"}]}], 
                                        ",", \(blank[]\)}], "]"}], ",", "_"}],
                                         "]"}], "\[RuleDelayed]", \(pattern[
                                        dm, blank[]]\)}]}], 
                                        "/.", \({blank \[RuleDelayed] Blank, 
                                        pattern \[RuleDelayed] Pattern, 
                                        patternTest \[RuleDelayed] 
                                        PatternTest}\)}], "}"}]}], "/.", 
                                      RowBox[{\(cD[ijk__]\), "\[Rule]", 
                                        RowBox[{
                                        RowBox[{"Hold", "[", 
                                        RowBox[{
                                        StyleBox["Cayley",
                                        FontColor->RGBColor[1, 0, 0.4]], "[", 
                                        "ijk", "]"}], "]"}], 
                                        "[", \(addPeP[\(nutomass[Last[{t}]] /. 
                                        nmrel\) /. {nuu_, 
                                        ma_Symbol} \[RuleDelayed] ma]\), 
                                        "]"}]}]}], "/.", 
                                    RowBox[{\(cu[ijk__]\), "\[Rule]", 
                                      RowBox[{
                                        RowBox[{"Hold", "[", 
                                        RowBox[{
                                        StyleBox["Cayleyu",
                                        FontColor->RGBColor[0.8, 0.8, 0.4]], 
                                        "[", "ijk", "]"}], "]"}], 
                                        "[", \(addPeP[\(nutomass[Last[{t}]] /. 
                                        nmrel\) /. {nuu_, 
                                        ma_Symbol} \[RuleDelayed] ma]\), 
                                        "]"}]}]}], 
                                  "/.", \(Hold[CompoundExpression] \[Rule] 
                                    CompoundExpression\)}], 
                                "/.", \(Hold[Set] \[Rule] Set\)}], 
                              "/.", \(Hold[TComment] -> TComment\)}], 
                            "/.", \(addPeP -> Identity\)}], "/.", 
                          RowBox[{
                            RowBox[{"Hold", "[", 
                              RowBox[{
                                StyleBox["Cayleyu",
                                  FontColor->RGBColor[0.8, 0.8, 0.4]], "[", 
                                "ijk__", "]"}], "]"}], "\[Rule]", 
                            RowBox[{
                              StyleBox["Cayleyu",
                                FontColor->RGBColor[0.8, 0.8, 0.4]], "[", 
                              "ijk", "]"}]}]}], "/.", 
                        RowBox[{
                          RowBox[{"Hold", "[", 
                            RowBox[{
                              StyleBox["Cayley",
                                FontColor->RGBColor[1, 0, 0.4]], "[", "ijk__",
                               "]"}], "]"}], "\[Rule]", 
                          RowBox[{
                            StyleBox["Cayley",
                              FontColor->RGBColor[1, 0, 0.4]], "[", "ijk", 
                            "]"}]}]}], 
                      "/.", \({setdel \[RuleDelayed] SetDelayed}\)}], 
                    "/.", \(Identity -> identit\)}], 
                  "/.", \(identit[a_] -> a\)}]}]}], "]"}], "/;", 
          RowBox[{\(Head[mrel]\), "=!=", 
            StyleBox["IFF",
              FontColor->RGBColor[0.6, 0.4, 1]]}]}]}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["MakeFun",
            FontColor->RGBColor[1, 0.6, 0.6]], "[", 
          RowBox[{\(c_. \ TJI[t__] == rhs_\), ",", "eqn_String", ",", 
            RowBox[{
              StyleBox["IFF",
                FontColor->RGBColor[0.6, 0.4, 1]], "[", "conds_", "]"}], 
            ",", \(mrel_ : {}\)}], "]"}], ":=", 
        RowBox[{
          StyleBox["Block",
            FontSize->16,
            FontWeight->"Bold",
            FontColor->RGBColor[1, 0.2, 0.2]], "[", 
          RowBox[{\({nm, nmrel, \ result}\), ",", 
            
            RowBox[{\(\[ScriptCapitalC] = 1\), 
              ";", \(nmrel = Select[Flatten[{mrel}], FreeQ[#1, Factor] &]\), 
              ";", 
              RowBox[{"nmrel", "=", 
                RowBox[{"Join", "[", 
                  RowBox[{"nmrel", ",", 
                    RowBox[{"{", 
                      RowBox[{
                        RowBox[{\(m\_1\), "\[RuleDelayed]", 
                          InterpretationBox[\(m\_1\),
                            m1]}], ",", 
                        RowBox[{\(m\_2\), "\[RuleDelayed]", 
                          InterpretationBox[\(m\_2\),
                            m2]}], ",", 
                        RowBox[{\(m\_3\), "\[RuleDelayed]", 
                          InterpretationBox[\(m\_3\),
                            m3]}], ",", 
                        RowBox[{\(m\_4\), "\[RuleDelayed]", 
                          InterpretationBox[\(m\_4\),
                            m4]}], ",", 
                        RowBox[{\(\[CapitalSigma]\_i_\), "\[RuleDelayed]", 
                          RowBox[{
                            StyleBox["ToArgs",
                              FontColor->RGBColor[0.2, 0.6, 1]], 
                            "[", \(\[CapitalSigma]\_i\), "]"}]}]}], "}"}]}], 
                  "]"}]}], ";", "\n", "\t\t", 
              RowBox[{"result", " ", "=", " ", 
                RowBox[{
                  RowBox[{
                    RowBox[{
                      RowBox[{
                        RowBox[{
                          RowBox[{
                            RowBox[{
                              RowBox[{
                                RowBox[{
                                  RowBox[{
                                    RowBox[{
                                      RowBox[{"HoldForm", "@@", 
                                        RowBox[{"{", 
                                        RowBox[{
                                        RowBox[{
                                        RowBox[{
                                        RowBox[{
                                        RowBox[{"setdel", "[", 
                                        
                                        RowBox[{\(addPeP[TJR @@ \(top /@ 
                                        nutomass[{tT = t}]\)] /. nmrel\), ",",
                                         
                                        RowBox[{\(Hold[Condition]\), "[", 
                                        
                                        RowBox[{\(\(Hold[
                                        CompoundExpression]\)[\(Hold[
                                        TComment]\)[eqn, \(\(\(addPeP[
                                        nutomass[TJR[t]]] /. TJR -> 
                                        TJIC\) /. {Pattern :> pat, Blank :> 
                                        blank}\) /. pat[PP, blank[]] :> PP\) /. 
                                        nmrel]\t, TJ = \(Collect[TT = Expand3[
                                        nutonand\[CapitalDelta]u[\(1\/c\) \
\((rhs /. TJI[te__] \[RuleDelayed] addPeP[nutomass[TJI[te]]])\)]], TJI[__], 
                                        maybeF[\((Collect[Numerator[#1], 
                                        cu[__], 
                                        Factor]/Collect[Denominator[#1], 
                                        cu[__], Factor] &)\) /@ 
                                        Factor[#1]] &] /. \[ScriptCapitalC] \
\[Rule] 1\) /. nmrel]\), ",", 
                                        RowBox[{
                                        "nutonand\[CapitalDelta]u", "[", 
                                        RowBox[{
                                        StyleBox["IFF",
                                        FontColor->RGBColor[0.6, 0.4, 1]], 
                                        "[", "conds", "]"}], "]"}]}], "]"}]}],
                                         "]"}], "/.", \(top[
                                        i_Integer] \[Rule] i\)}], 
                                        "/.", \(top \[RuleDelayed] \
\((patternTest[pattern[#1, blank[]], PQ] &)\)\)}], "/.", 
                                        RowBox[{
                                        RowBox[{"patternTest", "[", 
                                        RowBox[{
                                        RowBox[{"pattern", "[", 
                                        RowBox[{
                                        RowBox[{"dm_", "/;", 
                                        RowBox[{"MemberQ", "[", 
                                        RowBox[{
                                        RowBox[{"{", 
                                        RowBox[{"d", ",", 
                                        InterpretationBox[\(p\^2\),
                                        PP], ",", 
                                        InterpretationBox[\(m\_1\),
                                        m1], ",", 
                                        InterpretationBox[\(m\_2\),
                                        m2], ",", 
                                        InterpretationBox[\(m\_3\),
                                        m3], ",", 
                                        InterpretationBox[\(m\_4\),
                                        m4]}], "}"}], ",", "dm"}], "]"}]}], 
                                        ",", \(blank[]\)}], "]"}], ",", "_"}],
                                         "]"}], "\[RuleDelayed]", \(pattern[
                                        dm, blank[]]\)}]}], 
                                        "/.", \({blank \[RuleDelayed] Blank, 
                                        pattern \[RuleDelayed] Pattern, 
                                        patternTest \[RuleDelayed] 
                                        PatternTest}\)}], "}"}]}], 
                                      "/.", \(HoldPattern[
                                        TA[aijk__]] \[Rule] \(\(Hold[TA]\)[
                                        aijk]\)[
                                        addPeP[\(nutomass[Last[{t}]] /. 
                                        nmrel\) /. {nuu_, ma_} \[RuleDelayed] 
                                        ma]]\)}], "/.", 
                                    RowBox[{\(cD[ijk__]\), "\[Rule]", 
                                      RowBox[{
                                        RowBox[{"Hold", "[", 
                                        RowBox[{
                                        StyleBox["Cayley",
                                        FontColor->RGBColor[1, 0, 0.4]], "[", 
                                        "ijk", "]"}], "]"}], 
                                        "[", \(addPeP[\(nutomass[Last[{t}]] /. 
                                        nmrel\) /. {nuu_, 
                                        ma_Symbol} \[RuleDelayed] ma]\), 
                                        "]"}]}]}], "/.", 
                                  RowBox[{\(cu[ijk__]\), "\[Rule]", 
                                    RowBox[{
                                      RowBox[{"Hold", "[", 
                                        RowBox[{
                                        StyleBox["Cayleyu",
                                        FontColor->RGBColor[0.8, 0.8, 0.4]], 
                                        "[", "ijk", "]"}], "]"}], 
                                      "[", \(addPeP[\(nutomass[Last[{t}]] /. 
                                        nmrel\) /. {nuu_, 
                                        ma_Symbol} \[RuleDelayed] ma]\), 
                                      "]"}]}]}], 
                                "/.", \(Hold[CompoundExpression] \[Rule] 
                                  CompoundExpression\)}], "/.", 
                              RowBox[{
                                RowBox[{\(Hold[Condition]\), "[", 
                                  RowBox[{"a_", ",", 
                                    RowBox[{
                                      StyleBox["IFF",
                                        FontColor->RGBColor[0.6, 0.4, 1]], 
                                      "[", "b_", "]"}]}], "]"}], 
                                "\[Rule]", \(a /; b\)}]}], 
                            "/.", \(Hold[Set] \[Rule] Set\)}], 
                          "/.", \(Hold[TComment] -> TComment\)}], "/.", 
                        RowBox[{
                          RowBox[{"Hold", "[", 
                            RowBox[{
                              StyleBox["Cayleyu",
                                FontColor->RGBColor[0.8, 0.8, 0.4]], "[", 
                              "ijk__", "]"}], "]"}], "\[Rule]", 
                          RowBox[{
                            StyleBox["Cayleyu",
                              FontColor->RGBColor[0.8, 0.8, 0.4]], "[", "ijk",
                             "]"}]}]}], "/.", 
                      RowBox[{
                        RowBox[{"Hold", "[", 
                          RowBox[{
                            StyleBox["Cayley",
                              FontColor->RGBColor[1, 0, 0.4]], "[", "ijk__", 
                            "]"}], "]"}], "\[Rule]", 
                        RowBox[{
                          StyleBox["Cayley",
                            FontColor->RGBColor[1, 0, 0.4]], "[", "ijk", 
                          "]"}]}]}], "/.", \(Hold[TA] \[Rule] TA\)}], 
                  "/.", \({setdel \[RuleDelayed] SetDelayed}\)}]}], 
              ";", \(\[ScriptCapitalC] =  . \), ";", " ", "result"}]}], 
          "]"}]}], ";"}]], "Input"],

Cell[BoxData[
    \(\(SetAttributes[paTT, HoldFirst];\)\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["MakeFun",
          FontColor->RGBColor[1, 0.6, 0.6]], "[", 
        RowBox[{
          RowBox[{
            RowBox[{"c_.", " ", 
              RowBox[{
                StyleBox["TKI",
                  FontColor->RGBColor[0.2, 0.4, 0.8]], "[", "t__", "]"}]}], "==",
             "rhs_"}], ",", "eqn_String", ",", 
          RowBox[{
            StyleBox["IFF",
              FontColor->RGBColor[0.6, 0.4, 1]], "[", "conds_", "]"}], 
          ",", \(mrel_ : {}\)}], "]"}], ":=", 
      " ", \(\(\(\(MakeFun[c\ TJI[t] == rhs /. TKI -> TJI, eqn, IFF[conds], 
                mrel] /. {PP :> 0, Sqrt[PP] :> 0, Pattern :> paTT}\) /. 
            paTT[0, _] -> 0\) /. paTT -> Pattern\) /. 
        TJIC[d_, li_List] :> TJIC[d, 0, li]\)}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["MakeFun",
            FontColor->RGBColor[1, 0.6, 0.6]], "[", 
          RowBox[{
            RowBox[{
              RowBox[{"c_.", " ", 
                RowBox[{
                  StyleBox["TBI",
                    FontColor->RGBColor[0.2, 0.4, 0.8]], "[", "t__", "]"}]}], 
              "==", "rhs_"}], ",", "eqn_String", ",", 
            RowBox[{
              StyleBox["IFF",
                FontColor->RGBColor[0.6, 0.4, 1]], "[", "conds_", "]"}], 
            ",", \(mrel_ : {}\)}], "]"}], ":=", 
        " ", \(MakeFun[c\ TJI[t] == rhs /. TBI -> TJI, eqn, IFF[conds], 
            mrel] /. {\n\t\t\tTJI :> TBI, TJR :> TBR, TJIC :> TBIC}\)}], 
      ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["MakeFun",
            FontColor->RGBColor[1, 0.6, 0.6]], "[", 
          RowBox[{
            RowBox[{
              RowBox[{"c_.", " ", 
                RowBox[{
                  StyleBox["TAI",
                    FontColor->RGBColor[0.2, 0.4, 0.8]], "[", "t__", "]"}]}], 
              "==", "rhs_"}], ",", "eqn_String", ",", 
            RowBox[{
              StyleBox["IFF",
                FontColor->RGBColor[0.6, 0.4, 1]], "[", "conds_", "]"}], 
            ",", \(mrel_ : {}\)}], "]"}], ":=", 
        " ", \(MakeFun[c\ TJI[t] == rhs /. TAI -> TJI, eqn, IFF[conds], 
            mrel] /. {\n\t\t\tTJI :> TAI, TJR :> TAR, TJIC :> TAIC}\)}], 
      ";"}]], "Input"],

Cell[CellGroupData[{

Cell["Interchange", "Subsubsection",
  CellTags->"T1.5.1.1.1"],

Cell[BoxData[
    RowBox[{\(Interchange[z_, i_ \[LeftRightArrow] j_]\), ":=", 
      RowBox[{\(\[Nu]explicit[
            z] /. {\[Nu]\_i :> \[Nu]\_j, \[Nu]\_j :> \[Nu]\_i, m\_i :> m\_j, 
            m\_j :> m\_i, \[CapitalDelta]\_ij__ :> \((\[CapitalDelta]\_ij /. \
{i :> j, j :> i})\), 
            u\_ij__ :> \((u\_ij /. {i :> j, 
                    j :> i})\), \n\t\th\_ij__ :> \((h\_ij /. {i :> j, 
                    j :> i})\), \[Phi]\_ij__ :> \((\[Phi]\_ij /. {i :> j, 
                    j :> i})\), \[Rho]\_ij__ :> \((\[Rho]\_ij /. {i :> j, 
                    j :> i})\), \[Sigma]\_ij__ :> \((\[Sigma]\_ij /. {i :> j, 
                    j :> i})\), D\_ij__ :> \((D\_ij /. {i :> j, j :> i})\)}\),
         "/.", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox["TFI",
                  FontColor->RGBColor[1, 0.6, 0]], "[", \(depp__, args_List\),
                 "]"}], ":>", 
              RowBox[{
                RowBox[{
                  StyleBox["TFI",
                    FontColor->RGBColor[1, 0.6, 0]], "[", \(depp, 
                  Sort[args]\), "]"}], "/;", 
                "\[InvisibleSpace]", \(! \((OrderedQ[args])\)\)}]}], ",", 
            "\n", "\t", 
            RowBox[{
              RowBox[{
                StyleBox["TVI",
                  FontColor->RGBColor[1, 0.6, 0]], "[", \(depp__, args_List\),
                 "]"}], ":>", 
              RowBox[{
                RowBox[{
                  StyleBox["TVI",
                    FontColor->RGBColor[1, 0.6, 0]], "[", \(depp, 
                  Sort[args]\), "]"}], "/;", 
                "\[InvisibleSpace]", \(! \((OrderedQ[args])\)\)}]}], ",", 
            "\n", "\t", 
            RowBox[{
              RowBox[{
                StyleBox["TJI",
                  FontColor->RGBColor[1, 0.6, 0]], "[", \(depp__, args_List\),
                 "]"}], ":>", 
              RowBox[{
                RowBox[{
                  StyleBox["TJI",
                    FontColor->RGBColor[1, 0.6, 0]], "[", \(depp, 
                  Sort[args]\), "]"}], "/;", 
                "\[InvisibleSpace]", \(! \((OrderedQ[args])\)\)}]}], ",", 
            "\n", "\t\t\t", 
            RowBox[{
              RowBox[{
                StyleBox["TBI",
                  FontColor->RGBColor[1, 0.6, 0]], "[", \(depp__, args_List\),
                 "]"}], ":>", 
              RowBox[{
                RowBox[{
                  StyleBox["TBI",
                    FontColor->RGBColor[1, 0.6, 0]], "[", \(depp, 
                  Sort[args]\), "]"}], "/;", 
                "\[InvisibleSpace]", \(! \((OrderedQ[args])\)\)}]}]}], 
          "}"}]}]}]], "Input"],

Cell[BoxData[
    \(\(Interchange[z_, i_ \[LeftRightArrow] j_, vw__] := 
        Interchange[Interchange[z, i \[LeftRightArrow] j], vw];\)\)], "Input"],

Cell[BoxData[
    \(\(Interchange[z_, {i_ \[LeftRightArrow] j_}] := 
        Interchange[Interchange[z, i \[LeftRightArrow] j]];\)\)], "Input"],

Cell[BoxData[
    \(\(Interchange[z_, {i_ \[LeftRightArrow] j_, vw__}] := 
        Interchange[Interchange[z, i \[LeftRightArrow] j], vw];\)\)], "Input"],

Cell[BoxData[
    \(Interchange[
      test[\[CapitalDelta]\_\(x, b, y\), \[Nu]\_x, \[Nu]\_y, \[Nu]\_a, \
\[Nu]\_b, m\_x], \ x \[LeftRightArrow] y, a \[LeftRightArrow] b]\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\[Nu]explicit", "Subsection",
  CellTags->"T1.5.2.1"],

Cell[BoxData[
    \(\[Nu]explicit[
        z_] := \(z /. \[CapitalSigma]\_i_ :> \((Expand[
                3\ d\  - 2\  - 
                  2\ \(\[Sum]\_\(j = 1\)\%i \[Nu]\_j\)])\)\) /. \n\t{\t\
\[Sigma]\_\(i_, j_, k_\) :> \(-\(1\/4\)\) \((d - \[Nu]\_i - 
                    2  \[Nu]\_j)\) \[Phi]\_\(i, j, k\) - \(1\/4\) \((d - 
                    2  \[Nu]\_i - \[Nu]\_j)\) \[Phi]\_\(j, i, k\) - \n\t\t\t\t\
\t\(1\/4\) \((2  d - 2  \[Nu]\_i - 2  \[Nu]\_j - \[Nu]\_k - 
                    1)\) \[Phi]\_\(k, i, j\), \n\t\t\t\
h\_\(\(i_\)\(,\)\(j_\)\(,\)\(k_\)\(\ \)\) :> \n\t\t\t\t\(-\(1\/2\)\) \((d - 
                    2  \[Nu]\_j - \[Nu]\_k)\) \(m\_k\^2\) \[Phi]\_\(i, j, k\) \
- \(1\/2\) \((2  d - \[Nu]\_i - 2  \[Nu]\_j - 2  \[Nu]\_k - 
                    1)\) \(m\_i\^2\) \[Phi]\_\(k, i, j\) + \n\t\t\t\t\t\((d - \
\[Nu]\_j - 2\ \[Nu]\_k)\) \[Rho]\_\(i, j, k\), \n
          S\_\(\(i_\)\(,\)\(j_\)\(,\)\(k_\)\(\ \)\) :> \n\t\t\t\t\(-\((d - 
                      2  \[Nu]\_j - \[Nu]\_k)\)\) \(m\_k\^2\) \[Phi]\_\(j, i, \
k\)\  - \((d - \[Nu]\_j - 
                    2  \[Nu]\_k)\) \(m\_j\^2\) \[Phi]\_\(k, i, j\) + \n\t\t\t\
\t\t2 \((2  d - \[Nu]\_i - 2  \[Nu]\_j - 2  \[Nu]\_k - 
                    1)\) \[Rho]\_\(i, j, k\)}\)], "Input"],

Cell[CellGroupData[{

Cell["TA", "Subsubsection",
  CellTags->"T1.5.2.1.1"],

Cell[BoxData[
    \(MakeBoxes[\(TA[a_, d___Symbol, ijk___Integer]\)[__], fmt_] := 
      SubscriptBox[a, RowBox[{ijk}]]\)], "Input"],

Cell[BoxData[
    \(MakeBoxes[\(TA[a_, d___Symbol, ijk___Integer, ___Symbol]\)[__], fmt_] := 
      SubscriptBox[a, RowBox[{ijk}]]\)], "Input"],

Cell[BoxData[
    \(\(\(TA[args__]\)[
          mar_List] := \((\(TA[args]\)[mar] = \(ta[args]\)[
              mar])\);\)\)], "Input"],

Cell[TextData[{
  "Assume that the last argument of {em__} is always p =",
  Cell[BoxData[
      FormBox[
        SqrtBox[
          RowBox[{" ", 
            FormBox[\(p\^2\),
              "TraditionalForm"]}]], TraditionalForm]]],
  "."
}], "Text"],

Cell["(72)", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(\(ta[D, i_Integer, j_Integer, k_Integer]\)[{em__}]\), ":=", 
        RowBox[{"With", "[", 
          
          RowBox[{\({q = Last[{em}], 
              mi = {em}\[LeftDoubleBracket]i\[RightDoubleBracket], 
              mj = {em}\[LeftDoubleBracket]j\[RightDoubleBracket], 
              mk = {em}\[LeftDoubleBracket]k\[RightDoubleBracket]}\), ",", 
            RowBox[{"Factor", "[", 
              
              RowBox[{\(q\^8\), "-", \(4\ q\^6\ \((mi\^2 + mj\^2 + mk\^2)\)\),
                 "+", \(q\^4\ \((6\ \((mi\^4 + mj\^4 + mk\^4)\) + 
                      4\ \((mi\^2\ mj\^2 + mk\^2\ mi\^2 + 
                            mk\^2\ mj\^2)\))\)\), 
                "-", \(4\ q\^2\ \((mi\^6 + mj\^6 + mk\^6 - 
                      mi\^2\ \((mj\^4 + mk\^4)\) - 
                      mj\^2\ \((mi\^4 + mk\^4)\) - 
                      mk\^2\ \((mi\^4 + mj\^4)\) + 
                      10\ mi\^2\ mj\^2\ mk\^2)\)\), "+", 
                SuperscriptBox[
                  RowBox[{
                    RowBox[{
                      StyleBox["Cayley",
                        FontColor->RGBColor[1, 0, 0.4]], "[", \(i, j, k\), 
                      "]"}], "[", \({em}\), "]"}], "2"]}], "]"}]}], "]"}]}], 
      ";"}]], "Input"],

Cell["(73)", "Text"],

Cell[BoxData[
    \(\(\(ta[\[Rho], i_Integer, j_Integer, k_Integer]\)[{em__}] := 
        With[{q = Last[{em}], 
            mi = {em}\[LeftDoubleBracket]i\[RightDoubleBracket], 
            mj = {em}\[LeftDoubleBracket]j\[RightDoubleBracket], 
            mk = {em}\[LeftDoubleBracket]k\[RightDoubleBracket]}, 
          Factor[\(-q\^6\) + 3\ q\^4\ \((mi\^2 + mj\^2 + mk\^2)\) - 
              q\^2\ \((3\ \((mi\^4 + mj\^4 + mk\^4)\) + 
                    2\ \((mi\^2\ mj\^2 + mk\^2\ mi\^2 + 
                          mk\^2\ mj\^2)\))\) + \ \((mi\^6 + mj\^6 + mk\^6 - 
                  mi\^2\ \((mj\^4 + mk\^4)\) - mj\^2\ \((mi\^4 + mk\^4)\) - 
                  mk\^2\ \((mi\^4 + mj\^4)\) + 
                  10\ mi\^2\ mj\^2\ mk\^2)\)]];\)\)], "Input"],

Cell["(74)", "Text"],

Cell[BoxData[
    \(\(\(ta[\[Phi], i_Integer, j_Integer, k_Integer]\)[{em__}] := 
        With[{q = Last[{em}], 
            mi = {em}\[LeftDoubleBracket]i\[RightDoubleBracket], 
            mj = {em}\[LeftDoubleBracket]j\[RightDoubleBracket], 
            mk = {em}\[LeftDoubleBracket]k\[RightDoubleBracket]}, 
          4  Factor[
              q\^4\  + 
                2 \( q\^2\) \((mi\^2 - mj\^2 - 
                      mk\^2)\) + \((mj\^2 - mk\^2)\)\^2 + \(mi\^2\) \((2 
                         mj\^2 + 2  mk\^2 - 3  mi\^2)\)]];\)\)], "Input"],

Cell["(75)", "Text"],

Cell[BoxData[
    \(\(\(ta[\[Sigma], d_, i_Integer, j_Integer, 
            k_Integer, \[Nu]i_Integer, \[Nu]j_Integer, \
\[Nu]k_Integer]\)[{em__}] := 
        Factor[\(\(-\(1\/4\)\) \((d - \[Nu]i - 2  \[Nu]j)\) \(TA[\[Phi], i, 
                    j, k]\)[{em}]\)\ \(-\(\(1\/4\) \((d - 
                      2  \[Nu]i - \[Nu]j)\) \(TA[\[Phi], j, i, 
                      k]\)[{em}]\)\) - \(\(1\/4\) \((2  d - 2  \[Nu]i - 
                  2  \[Nu]j - \[Nu]k - 1)\) \(\(TA[\[Phi], k, i, 
                  j]\)[{em}]\)\(\ \)\)\ \ ];\)\)], "Input"],

Cell["(76)", "Text"],

Cell[BoxData[
    \(\(\(ta[h, d_, i_Integer, j_Integer, 
            k_Integer, \[Nu]i_Integer, \[Nu]j_Integer, \
\[Nu]k_Integer]\)[{em__}] := \n\t
        With[{q = Last[{em}], 
            mi = {em}\[LeftDoubleBracket]i\[RightDoubleBracket], 
            mj = {em}\[LeftDoubleBracket]j\[RightDoubleBracket], 
            mk = {em}\[LeftDoubleBracket]k\[RightDoubleBracket]}, 
          Factor[\(-\(1\/2\)\) \((d - 
                    2  \[Nu]j - \[Nu]k)\) \(mk\^2\) \(TA[\[Phi], i, j, 
                    k]\)[{em}] - \(1\/2\) \((2  d - \[Nu]i - 2  \[Nu]j - 
                    2  \[Nu]k - 1)\) \(mi\^2\) \(TA[\[Phi], k, i, 
                    j]\)[{em}] + \(\((d - \[Nu]j - 
                    2\ \[Nu]k)\) \(\(TA[\[Rho], i, j, 
                    k]\)[{em}]\)\(\ \)\)\ \ ]];\)\)], "Input"],

Cell["(79)", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(\(ta[S, d_, i_Integer, j_Integer, 
            k_Integer, \[Nu]i_Integer, \[Nu]j_Integer, \
\[Nu]k_Integer]\)[{em__}]\), ":=", "\n", "\t\t", 
        RowBox[{"With", "[", 
          
          RowBox[{\({q = Last[{em}], 
              mi = {em}\[LeftDoubleBracket]i\[RightDoubleBracket], 
              mj = {em}\[LeftDoubleBracket]j\[RightDoubleBracket], 
              mk = {em}\[LeftDoubleBracket]k\[RightDoubleBracket]}\), ",", 
            RowBox[{"Factor", "[", 
              
              RowBox[{\(\(-\((d - 
                        2  \[Nu]j - \[Nu]k)\)\) \(mk\^2\) \(TA[\[Phi], j, i, 
                      k]\)[{em}]\), " ", "-", 
                
                RowBox[{\((d - \[Nu]j - 
                      2  \[Nu]k)\), \(mj\^2\), \(\(TA[\[Phi], k, i, 
                      j]\)[{em}]\), "test", "\n", 
                  FormBox["test",
                    "TraditionalForm"], 
                  "2", \((2  d - \[Nu]i - 2  \[Nu]j - 2  \[Nu]k - 
                      1)\), \(\(TA[\[Rho], i, j, k]\)[{em}]\)}]}], "   ", 
              "]"}]}], "]"}]}], ";"}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["CheckRecursion", "Subsection",
  CellTags->"T1.5.3.1"],

Cell["\<\
The following functions check the recurrence relations for J and V \
(using the final form as generated by MakeFun) via their Mellin-Integral \
Kernels.\
\>", "Text"],

Cell["\<\
This test is applicable in the general case  and if some of the 
masses vanish, but not for other special cases !!!\
\>", "Text"],

Cell[CellGroupData[{

Cell["CheckTVIRecursion", "Subsubsection",
  CellTags->"T1.5.3.1.1"],

Cell[BoxData[
    \(\(TVIKernel[d_, PP, \ 
          lis_] := \n\(\((\(-PP\))\)\^\(d - n1 - n2 - n3 - 
                n4\)\) \(\((m1\^2\/\(-PP\))\)\^s1\) \
\(\((m2\^2\/\(-PP\))\)\^s2\) \(\((m3\^2\/\(-PP\))\)\^s3\) \
\((m4\^2\/\(-PP\))\)\^s4*
          TVIpsi\ [
            d, \ \((lis /. {m1 -> s1, m2 -> s2, m3 -> s3, 
                  m4 -> s4})\)];\)\)], "Input"],

Cell[BoxData[
    \(\(TVIPsi[
          d_, \n\t{{n1_, \ s1_}, \ {n2_, s2_}, {n3_, s3_}, {n4_, 
              s4_}}] := \(\((\(-1\))\)\^\(n1 + n2 + n3 + n4 + 
                1\)\) \(\(gamma[\(-s1\)] gamma[d/2 - n1 - s1]\)\/gamma[
                n1]\) \(\(gamma[\(-s2\)] gamma[d/2 - n2 - s2]\)\/gamma[
                n2]\) \(\(gamma[\(-s3\)] gamma[d/2 - n3 - s3]\)\/gamma[
                n3]\) \(\(gamma[\(-s4\)] gamma[n4 + s4]\)\/gamma[n4]\) 
          gamma[n1 + n2 + n3 + n4 + s1 + s2 + s3 + s4 - d]/
            gamma[3  d/2 - n1 - n2 - n3 - n4 - s1 - s2 - s3 - s4] \(gamma[
                n1 + n3 + s1 + s3 - d/2]\/gamma[
                n1 + n3 + n4 + s1 + s3 + s4 - d/2]\) 
          gamma[d - n1 - n3 - n4 - s1 - s3 - s4]\/gamma[d - n1 - n3 - s1 - \
s3];\)\)], "Input"],

Cell[BoxData[
    \(CheckTVIRecursion[expr_] := \ 
      If[\ $CheckRecursion === True, \n\t
        Block[{rel, kern, \ nkern}, \n
          rel = \((\((Extract[
                    expr /. TVIC -> TVIkernel, {1, 2, 1, 1, 2}])\) - 
                Extract[expr /. TVI -> TVIkernel, {1, 2, 1, 2}])\); \n
          If[\ {TVIkernel} === 
              Union[Head /@ 
                  Cases[rel, ff_[__] /; Context[ff] =!= "\<System`\>", 
                    4]], \t\n
            rel = Collect[Numerator[Together[rel]], \ TVI[__], Factor]; \n
            kern = rel /. TVIkernel -> TVIKernel; \n
            kern = kern /. {PP -> \(-1\), m1 -> Sqrt[z1], m2 -> Sqrt[z2], 
                  m3 -> Sqrt[z3], m4 -> Sqrt[z4]}; \n
            kern = PowerExpand[kern]; \nkern = Expand[kern]; \n
            kern = kern /. {\(z1\^\(s1 + w1_. \)\) \(z2\^\(s2 + 
                            w2_. \)\) \(z3\^\(s3 + w3_. \)\) \(z4\^\(s4 + 
                            w4_. \)\) 
                      fac_ :> \((fac /. {s1 -> s1 - w1, s2 -> s2 - w2, 
                          s3 -> s3 - w3, s4 -> s4 - w4})\)}\ ; \n
            kern = \(\(kern /. 
                    TVIpsi -> TVIPsi\) /. {gamma[zz_] :> 
                      gamma[Expand[zz]]}\) /. {gamma[zz_ + nn_Integer] :> 
                    gamma[zz] Pochhammer[zz, nn]}; \n\t\t\t\tKERN = kern; \n
            kern = kern /. {gamma[zz_] :> 1}; \n
            kern = \(kern /. {\((\(-1\))\)\^\(nn_ + ww_Integer\) :> \
\((\(-1\))\)\^ww}\) /. {\((\(-1\))\)\^nn_ :> 1}; \n
            nkern = Table[\n\t\t\tkern /. 
                  Thread[{d, \ n1, \ n2, \ n3, n4, s1, s2, \ s3, s4} -> 
                      Table[Random[], {9}]], {3}]; \n
            nkern\ \ , \n\t\tPrint["\<Matching Error\>"]\ ]\ ], \n\t\t\
If[$Notebooks, Print["\<Off\>"]]]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CheckTJIRecursion", "Subsubsection",
  CellTags->"T1.5.3.2.1"],

Cell[BoxData[
    \(\(TJIKernel[d_, PP, \ 
          lis_] := \n\(\((\(-PP\))\)\^\(d - n1 - n2 - 
                n3\)\) \(\((m1\^2\/\(-PP\))\)\^s1\) \
\(\((m2\^2\/\(-PP\))\)\^s2\) \((m3\^2\/\(-PP\))\)\^s3*
          TJIpsi\ [
            d, \ \((lis /. {m1 -> s1, m2 -> s2, m3 -> s3})\)];\)\)], "Input"],

Cell[BoxData[
    \(TJIPsi\ [d_, {{n1_, \ s1_}, \ {n2_, s2_}, {n3_, s3_}}] := 
      Evaluate[TVIPsi[d, \n\t{{n1, \ s1}, \ {n2, s2}, {n3, s3}, {0, 0}}]/
          gamma[0]]\)], "Input"],

Cell[BoxData[
    \(\(Clear[CheckTJIRecursion];\)\)], "Input"],

Cell[BoxData[
    \(CheckTJIRecursion[expr_] := \ 
      If[\ $CheckRecursion === True, \n\t
        Block[{rel, kern, nkern}, \n
          rel = \((\((Extract[
                    expr /. TJIC -> TJIkernel, {1, 2, 1, 1, 2}])\) - 
                Extract[
                  expr /. TJI -> TJIkernel, {1, 2, 1, 2}])\); \n\t\t\tREL = 
            rel; \t\t\t\n
          If[{TJIkernel} === 
              Union[Head /@ 
                  Cases[rel, ff_[__] /; Context[ff] =!= "\<System`\>", 
                    4]]\ , \t\t\t\n
            rel = Collect[Numerator[Together[rel]], \ TJI[__], Factor]; \n
            kern = rel /. TJIkernel -> TJIKernel; \n
            kern = kern /. {PP -> \(-1\), m1 -> Sqrt[z1], m2 -> Sqrt[z2], 
                  m3 -> Sqrt[z3]}; \nkern = PowerExpand[kern]; \n
            kern = Expand[kern]; \n
            kern = kern /. {\(z1\^\(s1 + w1_. \)\) \(z2\^\(s2 + 
                            w2_. \)\) \(z3\^\(s3 + w3_. \)\) 
                      fac_ :> \((fac /. {s1 -> s1 - w1, s2 -> s2 - w2, 
                          s3 -> s3 - w3})\)}; \ \n
            kern = \(\(kern /. 
                    TJIpsi -> TJIPsi\) /. {gamma[zz_] :> 
                      gamma[Expand[zz]]}\) /. {gamma[zz_ + nn_Integer] :> 
                    gamma[zz] Pochhammer[zz, nn]}; \n\ \ \ \ \ \ KERN = 
              kern; \nkern = kern /. {gamma[zz_] :> 1}; \n
            kern = \(kern /. {\((\(-1\))\)\^\(nn_ + ww_Integer\) :> \
\((\(-1\))\)\^ww}\) /. {\((\(-1\))\)\^nn_ :> 1}; \n
            nkern = Table[\n\t\t\tkern /. 
                  Thread[{d, \ n1, \ n2, \ n3, s1, s2, \ s3} -> 
                      Table[Random[], {7}]], {3}]; \n
            nkern\ \ , \n\t\tPrint["\<Matching Error\>"]\ ]\ ], \n\t\t\
If[$Notebooks, Print["\<Off\>"]]]\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Recurrence Relations Input and Recursion Function Generation", "Section",
  CellDingbat->"\[FilledSmallCircle]",
  CellTags->"T1.6.1"],

Cell[TextData[{
  "Most ",
  Cell[BoxData[
      \(TraditionalForm\`e\_\(\(...\)\(\ \)\)\)]],
  "equations below were entered by the palettes which show up when \
$PutPalettes is set to True.\nExamples of alternative (hand) input are  (50) \
, (201) -- (205)."
}], "Text"],

Cell[CellGroupData[{

Cell["Input (35)", "Subsection",
  CellTags->"T1.6.1.1"],

Cell[TextData[{
  "general ",
  Cell[BoxData[
      \(m\_i\%2\)]]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(e\_35\), "=", "\n", 
        RowBox[{
          RowBox[{"2", \(\[Nu]\_1\), "\[ScriptCapitalC]", " ", 
            InterpretationBox[
              StyleBox[\(1\^+\),
                FontWeight->"Bold"],
              Schiebe[ 1, "+"],
              Editable->True], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["F",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_4\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_5\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TFI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3], 
                Subscript[ \[Nu], 4], 
                Subscript[ \[Nu], 5]}],
              Editable->True]}], "\[Equal]", " ", 
          RowBox[{
            RowBox[{"(", 
              
              RowBox[{\(\((d - 
                      2  \[Nu]\_1 - \[Nu]\_3 - \[Nu]\_5)\) \[CapitalDelta]\_1\
\), "+", 
                RowBox[{\(\[CapitalDelta]\_\(3, 4, 5\)\), 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{\(\[Nu]\_5\), 
                        InterpretationBox[
                          StyleBox[\(5\^+\),
                            FontWeight->"Bold"],
                          Schiebe[ 5, "+"],
                          Editable->True], 
                        RowBox[{"(", 
                          RowBox[{
                            InterpretationBox[
                              StyleBox[\(2\^-\),
                                FontWeight->"Bold"],
                              Schiebe[ 2, "-"],
                              Editable->True], "-", 
                            InterpretationBox[
                              StyleBox[\(1\^-\),
                                FontWeight->"Bold"],
                              Schiebe[ 1, "-"],
                              Editable->True]}], ")"}]}], "-", 
                      RowBox[{\(\[Nu]\_3\), 
                        InterpretationBox[
                          StyleBox[\(3\^+\),
                            FontWeight->"Bold"],
                          Schiebe[ 3, "+"],
                          Editable->True], 
                        InterpretationBox[
                          StyleBox[\(1\^-\),
                            FontWeight->"Bold"],
                          Schiebe[ 1, "-"],
                          Editable->True]}]}], ")"}]}], "+", 
                RowBox[{\(\[CapitalDelta]\_2\), 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{\(\[Nu]\_1\), 
                        InterpretationBox[
                          StyleBox[\(1\^+\),
                            FontWeight->"Bold"],
                          Schiebe[ 1, "+"],
                          Editable->True], 
                        RowBox[{"(", 
                          RowBox[{
                            InterpretationBox[
                              StyleBox[\(5\^-\),
                                FontWeight->"Bold"],
                              Schiebe[ 5, "-"],
                              Editable->True], "-", 
                            InterpretationBox[
                              StyleBox[\(2\^-\),
                                FontWeight->"Bold"],
                              Schiebe[ 2, "-"],
                              Editable->True]}], ")"}]}], "+", 
                      RowBox[{\(\[Nu]\_3\), 
                        InterpretationBox[
                          StyleBox[\(3\^+\),
                            FontWeight->"Bold"],
                          Schiebe[ 3, "+"],
                          Editable->True], 
                        RowBox[{"(", 
                          RowBox[{
                            InterpretationBox[
                              StyleBox[\(5\^-\),
                                FontWeight->"Bold"],
                              Schiebe[ 5, "-"]], "-", 
                            InterpretationBox[
                              StyleBox[\(4\^-\),
                                FontWeight->"Bold"],
                              Schiebe[ 4, "-"],
                              Editable->True]}], ")"}]}], "+", \(\[Nu]\_5\), 
                      "-", \(\[Nu]\_1\)}], ")"}]}], "+", "\n", "\t\t\t\t", 
                RowBox[{\(\[CapitalDelta]\_6\), 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{\(\[Nu]\_1\), 
                        InterpretationBox[
                          StyleBox[\(1\^+\),
                            FontWeight->"Bold"],
                          Schiebe[ 1, "+"],
                          Editable->True], 
                        InterpretationBox[
                          StyleBox[\(3\^-\),
                            FontWeight->"Bold"],
                          Schiebe[ 3, "-"],
                          Editable->True]}], "+", 
                      RowBox[{\(\[Nu]\_5\), 
                        InterpretationBox[
                          StyleBox[\(5\^+\),
                            FontWeight->"Bold"],
                          Schiebe[ 5, "+"],
                          Editable->True], 
                        RowBox[{"(", 
                          RowBox[{
                            InterpretationBox[
                              StyleBox[\(3\^-\),
                                FontWeight->"Bold"],
                              Schiebe[ 3, "-"],
                              Editable->True], "-", 
                            InterpretationBox[
                              StyleBox[\(4\^-\),
                                FontWeight->"Bold"],
                              Schiebe[ 4, "-"],
                              Editable->True]}], ")"}]}], "+", \(\[Nu]\_3\), 
                      "-", \(\[Nu]\_1\)}], ")"}]}]}], ")"}], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["F",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_4\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_5\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TFI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3], 
                Subscript[ \[Nu], 4], 
                Subscript[ \[Nu], 5]}],
              Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
    \(s\_35 = OperatorApplyF[e\_35]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (35)", "Subsection",
  CellTags->"T1.6.2.1"],

Cell[BoxData[
    \(h\_351 = s\_35 /. \[Nu]\_1 -> \((\[Nu]\_1 - 1)\)\)], "Input"],

Cell[CellGroupData[{

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`1\^\(\(+\)\(\ \)\)\)]],
  " (35_1)"
}], "Subsubsection",
  CellTags->"T1.6.2.1.1"],

Cell[BoxData[
    RowBox[{\(f\_351\), "=", 
      RowBox[{
        StyleBox["MakeFun",
          FontColor->RGBColor[1, 0.6, 0.6]], "[", 
        RowBox[{\(h\_351\), ",", "\"\<(35_1)\>\"", ",", 
          RowBox[{
            StyleBox["IFF",
              FontColor->RGBColor[0.6, 0.4, 1]], "[", 
            RowBox[{\(\[Nu]\_1 > 1\), "&&", 
              RowBox[{
                RowBox[{
                  StyleBox["Cayley",
                    FontColor->RGBColor[1, 0, 0.4]], "[", 
                  RowBox[{
                    InterpretationBox[\(m\_1\),
                      m1], ",", 
                    InterpretationBox[\(m\_2\),
                      m2], ",", 
                    InterpretationBox[\(m\_3\),
                      m3], ",", 
                    InterpretationBox[\(m\_4\),
                      m4], ",", 
                    InterpretationBox[\(m\_5\),
                      m5], ",", 
                    SqrtBox[
                      InterpretationBox[\(p\^2\),
                        PP]]}], "]"}], "=!=", "0"}]}], "]"}]}], 
        "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`2\^\(\(+\)\(\ \)\)\)]],
  " (35_2)"
}], "Subsubsection",
  CellTags->"T1.6.2.2.1"],

Cell[BoxData[
    RowBox[{\(f\_352\), "=", 
      RowBox[{
        StyleBox["MakeFun",
          FontColor->RGBColor[1, 0.6, 0.6]], "[", 
        RowBox[{\(Interchange[h\_351, 1 \[LeftRightArrow] 2, 
            3 \[LeftRightArrow] 4]\), ",", "\"\<(35_2)\>\"", ",", 
          RowBox[{
            StyleBox["IFF",
              FontColor->RGBColor[0.6, 0.4, 1]], "[", 
            RowBox[{\(\[Nu]\_2 > 1\), "&&", 
              RowBox[{
                RowBox[{
                  StyleBox["Cayley",
                    FontColor->RGBColor[1, 0, 0.4]], "[", 
                  RowBox[{
                    InterpretationBox[\(m\_1\),
                      m1], ",", 
                    InterpretationBox[\(m\_2\),
                      m2], ",", 
                    InterpretationBox[\(m\_3\),
                      m3], ",", 
                    InterpretationBox[\(m\_4\),
                      m4], ",", 
                    InterpretationBox[\(m\_5\),
                      m5], ",", 
                    SqrtBox[
                      InterpretationBox[\(p\^2\),
                        PP]]}], "]"}], "=!=", "0"}]}], "]"}]}], 
        "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`3\^\(\(+\)\(\ \)\)\)]],
  " (35_3)"
}], "Subsubsection",
  CellTags->"T1.6.2.3.1"],

Cell[BoxData[
    RowBox[{\(f\_353\), "=", 
      RowBox[{
        StyleBox["MakeFun",
          FontColor->RGBColor[1, 0.6, 0.6]], "[", 
        RowBox[{\(Interchange[h\_351, 1 \[LeftRightArrow] 3, 
            2 \[LeftRightArrow] 4]\), ",", "\"\<(35_3)\>\"", ",", 
          RowBox[{
            StyleBox["IFF",
              FontColor->RGBColor[0.6, 0.4, 1]], "[", 
            RowBox[{\(\[Nu]\_3 > 1\), "&&", 
              RowBox[{
                RowBox[{
                  StyleBox["Cayley",
                    FontColor->RGBColor[1, 0, 0.4]], "[", 
                  RowBox[{
                    InterpretationBox[\(m\_1\),
                      m1], ",", 
                    InterpretationBox[\(m\_2\),
                      m2], ",", 
                    InterpretationBox[\(m\_3\),
                      m3], ",", 
                    InterpretationBox[\(m\_4\),
                      m4], ",", 
                    InterpretationBox[\(m\_5\),
                      m5], ",", 
                    SqrtBox[
                      InterpretationBox[\(p\^2\),
                        PP]]}], "]"}], "=!=", "0"}]}], "]"}]}], 
        "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`4\^\(\(+\)\(\ \)\)\)]],
  " (35_4)"
}], "Subsubsection",
  CellTags->"T1.6.2.4.1"],

Cell[BoxData[
    RowBox[{\(f\_354\), "=", 
      RowBox[{
        StyleBox["MakeFun",
          FontColor->RGBColor[1, 0.6, 0.6]], "[", 
        RowBox[{\(Interchange[h\_351, 1 \[LeftRightArrow] 4, 
            2 \[LeftRightArrow] 3]\), ",", "\"\<(35_4)\>\"", ",", 
          RowBox[{
            StyleBox["IFF",
              FontColor->RGBColor[0.6, 0.4, 1]], "[", 
            RowBox[{\(\[Nu]\_4 > 1\), "&&", 
              RowBox[{
                RowBox[{
                  StyleBox["Cayley",
                    FontColor->RGBColor[1, 0, 0.4]], "[", 
                  RowBox[{
                    InterpretationBox[\(m\_1\),
                      m1], ",", 
                    InterpretationBox[\(m\_2\),
                      m2], ",", 
                    InterpretationBox[\(m\_3\),
                      m3], ",", 
                    InterpretationBox[\(m\_4\),
                      m4], ",", 
                    InterpretationBox[\(m\_5\),
                      m5], ",", 
                    SqrtBox[
                      InterpretationBox[\(p\^2\),
                        PP]]}], "]"}], "=!=", "0"}]}], "]"}]}], 
        "]"}]}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (3501)", "Subsection",
  CellTags->"T1.6.3.1"],

Cell[BoxData[
    \(Cayley[m1, m5, m5, m4, m5, m5] // Factor\)], "Input"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`m\_1 = 0\ \ ; \ \ m\_2 = \(m\_3 = m\_5\); \ \ \ 
    p\^2 = m\_5\%2\)]]], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(e\_3501\), "=", 
        RowBox[{
          RowBox[{\((d - 2  \[Nu]\_1 - \[Nu]\_3 - \[Nu]\_5)\), 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["F",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_4\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_5\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TFI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3], 
                Subscript[ \[Nu], 4], 
                Subscript[ \[Nu], 5]}],
              Editable->True]}], "==", 
          RowBox[{
            RowBox[{"(", " ", 
              RowBox[{
                RowBox[{\(\[Nu]\_5\), 
                  RowBox[{"(", 
                    RowBox[{
                      InterpretationBox[
                        StyleBox[\(1\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 1, "-"],
                        Editable->True], "-", 
                      InterpretationBox[
                        StyleBox[\(2\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 2, "-"],
                        Editable->True]}], ")"}], 
                  InterpretationBox[
                    StyleBox[\(5\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 5, "+"],
                    Editable->True]}], "+", 
                RowBox[{\(\[Nu]\_3\), 
                  InterpretationBox[
                    StyleBox[\(1\^-\),
                      FontWeight->"Bold"],
                    Schiebe[ 1, "-"],
                    Editable->True], 
                  InterpretationBox[
                    RowBox[{
                      StyleBox[\(3\^+\),
                        FontWeight->"Bold"], " "}],
                    Schiebe[ 3, "+"],
                    Editable->True]}]}], ")"}], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["F",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_4\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_5\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TFI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3], 
                Subscript[ \[Nu], 4], 
                Subscript[ \[Nu], 5]}],
              Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
    \(s\_3501 = OperatorApplyF[e\_3501]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "MakeFun (3501) \[CapitalDelta]=0 ",
  Cell[BoxData[
      \(TraditionalForm\`\((p\^2 = m\^2)\)\)]]
}], "Subsection",
  CellTags->"T1.6.4.1"],

Cell[BoxData[
    \(h\_3501 = s\_3501\)], "Input"],

Cell[BoxData[
    RowBox[{\(f\_3501\), "=", 
      RowBox[{
        StyleBox["MakeFun",
          FontColor->RGBColor[1, 0.6, 0.6]], "[", 
        RowBox[{\(s\_3501\), ",", "\"\<(3501)\>\"", ",", 
          RowBox[{
            StyleBox["IFF",
              FontColor->RGBColor[0.6, 0.4, 1]], "[", \(PP === m5^2\), "]"}], 
          ",", \({m1 :> 0, m2 :> m5, m3 :> m5}\)}], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (3502)", "Subsection",
  CellTags->"T1.6.5.1"],

Cell[BoxData[
    \(Cayley[m1, m5, m5, m4, m5, m5] // Factor\)], "Input"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`m\_4 = 0\ \ ; \ \ m\_2 = \(m\_3 = m\_5\); \ \ \ 
    p\^2 = m\_5\%2\)]]], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(e\_3502\), "=", 
        RowBox[{
          RowBox[{\((d - 2  \[Nu]\_1 - \[Nu]\_3 - \[Nu]\_5)\), 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["F",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_4\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_5\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TFI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3], 
                Subscript[ \[Nu], 4], 
                Subscript[ \[Nu], 5]}],
              Editable->True]}], "==", 
          RowBox[{
            RowBox[{"(", " ", 
              RowBox[{
                RowBox[{\(\[Nu]\_5\), 
                  RowBox[{"(", 
                    RowBox[{
                      InterpretationBox[
                        StyleBox[\(1\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 1, "-"],
                        Editable->True], "-", 
                      InterpretationBox[
                        StyleBox[\(2\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 2, "-"],
                        Editable->True]}], ")"}], 
                  InterpretationBox[
                    StyleBox[\(5\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 5, "+"],
                    Editable->True]}], "+", 
                RowBox[{\(\[Nu]\_3\), 
                  InterpretationBox[
                    StyleBox[\(1\^-\),
                      FontWeight->"Bold"],
                    Schiebe[ 1, "-"],
                    Editable->True], 
                  InterpretationBox[
                    RowBox[{
                      StyleBox[\(3\^+\),
                        FontWeight->"Bold"], " "}],
                    Schiebe[ 3, "+"],
                    Editable->True]}]}], ")"}], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["F",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_4\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_5\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TFI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3], 
                Subscript[ \[Nu], 4], 
                Subscript[ \[Nu], 5]}],
              Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
    \(s\_3502 = OperatorApplyF[e\_3502]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "MakeFun (3502) \[CapitalDelta]=0 ",
  Cell[BoxData[
      \(TraditionalForm\`\((p\^2 = m\^2)\)\)]]
}], "Subsection",
  CellTags->"T1.6.6.1"],

Cell[BoxData[
    \(h\_3502 = s\_3502\)], "Input"],

Cell[BoxData[
    RowBox[{\(f\_3502\), "=", 
      RowBox[{
        StyleBox["MakeFun",
          FontColor->RGBColor[1, 0.6, 0.6]], "[", 
        RowBox[{\(h\_3502\), ",", "\"\<(3502)\>\"", ",", 
          RowBox[{
            StyleBox["IFF",
              FontColor->RGBColor[0.6, 0.4, 1]], "[", \(PP === m5^2\), "]"}], 
          ",", \({m4 :> 0, m2 :> m5, m3 :> m5}\)}], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "MakeFun (3503) \[CapitalDelta]=0 ",
  Cell[BoxData[
      \(TraditionalForm\`\((p\^2 = m\^2)\)\)]]
}], "Subsection",
  CellTags->"T1.6.7.1"],

Cell[BoxData[
    \(Cayley[m5, 0, m3, m5, m5, m5]\)], "Input"],

Cell[BoxData[
    \(h\_3503 = 
      Interchange[s\_3502, 1 \[LeftRightArrow] 2, \ 
        3 \[LeftRightArrow] 4]\)], "Input"],

Cell[BoxData[
    RowBox[{\(f\_3503\), "=", 
      RowBox[{
        StyleBox["MakeFun",
          FontColor->RGBColor[1, 0.6, 0.6]], "[", 
        RowBox[{\(h\_3503\), ",", "\"\<(3503)\>\"", ",", 
          RowBox[{
            StyleBox["IFF",
              FontColor->RGBColor[0.6, 0.4, 1]], "[", \(PP === m5^2\), "]"}], 
          ",", \({m2 :> 0, m1 :> m5, m4 :> m5}\)}], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "MakeFun (3504) \[CapitalDelta]=0 ",
  Cell[BoxData[
      \(TraditionalForm\`\((p\^2 = m\^2)\)\)]]
}], "Subsection",
  CellTags->"T1.6.8.1"],

Cell[BoxData[
    \(Cayley[m5, m2, 0, m5, m5, m5]\)], "Input"],

Cell[BoxData[
    \(h\_3504 = 
      Interchange[s\_3502, 1 \[LeftRightArrow] 3, \ 
        2 \[LeftRightArrow] 4]\)], "Input"],

Cell[BoxData[
    RowBox[{\(f\_3504\), "=", 
      RowBox[{
        StyleBox["MakeFun",
          FontColor->RGBColor[1, 0.6, 0.6]], "[", 
        RowBox[{\(h\_3504\), ",", "\"\<(3504)\>\"", ",", 
          RowBox[{
            StyleBox["IFF",
              FontColor->RGBColor[0.6, 0.4, 1]], "[", \(PP === m5^2\), "]"}], 
          ",", \({m3 :> 0, m1 :> m5, m4 :> m5}\)}], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (41)", "Subsection",
  CellTags->"T1.6.9.1"],

Cell[TextData[{
  "general ",
  Cell[BoxData[
      \(m\_i\%2\)]]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(e\_41\), "=", "\n", 
        RowBox[{
          RowBox[{"2", \(\[Nu]\_5\), " ", "\[ScriptCapitalC]", " ", 
            InterpretationBox[
              StyleBox[\(5\^+\),
                FontWeight->"Bold"],
              Schiebe[ 5, "+"]], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["F",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_4\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_5\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TFI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3], 
                Subscript[ \[Nu], 4], 
                Subscript[ \[Nu], 5]}]]}], " ", "\[Equal]", " ", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{\(\[CapitalDelta]\_\(1, 3, 6\)\), 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{\(\[Nu]\_3\), 
                        InterpretationBox[
                          StyleBox[\(3\^+\),
                            FontWeight->"Bold"],
                          Schiebe[ 3, "+"]], 
                        RowBox[{"(", 
                          RowBox[{
                            InterpretationBox[
                              StyleBox[\(4\^-\),
                                FontWeight->"Bold"],
                              Schiebe[ 4, "-"]], "-", 
                            InterpretationBox[
                              StyleBox[\(5\^-\),
                                FontWeight->"Bold"],
                              Schiebe[ 5, "-"]]}], ")"}]}], "+", 
                      RowBox[{\(\[Nu]\_1\), 
                        InterpretationBox[
                          StyleBox[\(1\^+\),
                            FontWeight->"Bold"],
                          Schiebe[ 1, "+"]], 
                        RowBox[{"(", 
                          RowBox[{
                            InterpretationBox[
                              StyleBox[\(2\^-\),
                                FontWeight->"Bold"],
                              Schiebe[ 2, "-"]], "-", 
                            InterpretationBox[
                              StyleBox[\(5\^-\),
                                FontWeight->"Bold"],
                              Schiebe[ 5, "-"]]}], ")"}]}]}], ")"}]}], 
                "+", \(\((d - \[Nu]\_1 - \[Nu]\_3 - 
                      2  \[Nu]\_5)\) \[CapitalDelta]\_5\), "+", 
                RowBox[{\(\[CapitalDelta]\_2\), 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{\(\[Nu]\_5\), 
                        InterpretationBox[
                          StyleBox[\(5\^+\),
                            FontWeight->"Bold"],
                          Schiebe[ 5, "+"]], 
                        RowBox[{"(", 
                          RowBox[{
                            InterpretationBox[
                              StyleBox[\(1\^-\),
                                FontWeight->"Bold"],
                              Schiebe[ 1, "-"]], "-", 
                            InterpretationBox[
                              StyleBox[\(2\^-\),
                                FontWeight->"Bold"],
                              Schiebe[ 2, "-"]]}], ")"}]}], "+", 
                      RowBox[{\(\[Nu]\_3\), 
                        InterpretationBox[
                          StyleBox[\(3\^+\),
                            FontWeight->"Bold"],
                          Schiebe[ 3, "+"]], 
                        InterpretationBox[
                          StyleBox[\(1\^-\),
                            FontWeight->"Bold"],
                          Schiebe[ 1, "-"]]}], "+", \(\[Nu]\_1\), 
                      "-", \(\[Nu]\_5\)}], ")"}]}], "+", 
                RowBox[{\(\[CapitalDelta]\_4\), 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{\(\[Nu]\_1\), 
                        InterpretationBox[
                          StyleBox[\(1\^+\),
                            FontWeight->"Bold"],
                          Schiebe[ 1, "+"]], 
                        InterpretationBox[
                          StyleBox[\(3\^-\),
                            FontWeight->"Bold"],
                          Schiebe[ 3, "-"]]}], "+", 
                      RowBox[{\(\[Nu]\_5\), 
                        InterpretationBox[
                          StyleBox[\(5\^+\),
                            FontWeight->"Bold"],
                          Schiebe[ 5, "+"]], 
                        RowBox[{"(", 
                          RowBox[{
                            InterpretationBox[
                              StyleBox[\(3\^-\),
                                FontWeight->"Bold"],
                              Schiebe[ 3, "-"]], "-", 
                            InterpretationBox[
                              StyleBox[\(4\^-\),
                                FontWeight->"Bold"],
                              Schiebe[ 4, "-"]]}], ")"}]}], "+", \(\[Nu]\_3\),
                       "-", \(\[Nu]\_5\)}], ")"}]}]}], ")"}], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["F",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_4\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_5\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TFI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3], 
                Subscript[ \[Nu], 4], 
                Subscript[ \[Nu], 5]}]]}]}]}], ";"}]], "Input"],

Cell[BoxData[
    \(s\_41 = OperatorApplyF[e\_41]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (41)", "Subsection",
  CellTags->"T1.6.10.1"],

Cell[BoxData[
    \(h\_41 = s\_41 /. \[Nu]\_5 \[Rule] \[Nu]\_5 - 1\)], "Input"],

Cell[BoxData[
    RowBox[{\(f\_41\), "=", 
      RowBox[{
        StyleBox["MakeFun",
          FontColor->RGBColor[1, 0.6, 0.6]], "[", 
        RowBox[{\(h\_41\), ",", "\"\<(41)\>\"", ",", 
          RowBox[{
            StyleBox["IFF",
              FontColor->RGBColor[0.6, 0.4, 1]], "[", 
            RowBox[{\(\[Nu]\_5 > 1\), "&&", 
              RowBox[{
                RowBox[{
                  StyleBox["Cayley",
                    FontColor->RGBColor[1, 0, 0.4]], "[", 
                  RowBox[{
                    InterpretationBox[\(m\_1\),
                      m1], ",", 
                    InterpretationBox[\(m\_2\),
                      m2], ",", 
                    InterpretationBox[\(m\_3\),
                      m3], ",", 
                    InterpretationBox[\(m\_4\),
                      m4], ",", 
                    InterpretationBox[\(m\_5\),
                      m5], ",", 
                    SqrtBox[
                      InterpretationBox[\(p\^2\),
                        PP]]}], "]"}], "=!=", "0"}]}], "]"}]}], 
        "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (43)", "Subsection",
  CellTags->"T1.6.11.1"],

Cell[TextData[{
  "general ",
  Cell[BoxData[
      \(p\^2\)]],
  " and ( ",
  Cell[BoxData[
      \(TraditionalForm\`m\_5\%2 == 0\)]],
  "  &&  ",
  Cell[BoxData[
      \(TraditionalForm\`m\_1\%2\)]],
  "==",
  Cell[BoxData[
      \(TraditionalForm\`m\_2\%2\)]],
  " && ",
  Cell[BoxData[
      \(TraditionalForm\`m\_3\%2\)]],
  "== ",
  Cell[BoxData[
      \(TraditionalForm\`m\_4\%2\)]],
  " ) \[DoubleLongRightArrow] \[CapitalDelta] == 0"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(e\_43\), "=", 
        RowBox[{
          RowBox[{\((d - \[Nu]\_1 - \[Nu]\_3 - 2  \[Nu]\_5)\), 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["F",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_4\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_5\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TFI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3], 
                Subscript[ \[Nu], 4], 
                Subscript[ \[Nu], 5]}],
              Editable->True]}], "\[Equal]", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{\(\[Nu]\_1\), 
                  InterpretationBox[
                    StyleBox[\(1\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 1, "+"],
                    Editable->True], 
                  RowBox[{"(", 
                    RowBox[{
                      InterpretationBox[
                        StyleBox[\(5\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 5, "-"],
                        Editable->True], "-", 
                      InterpretationBox[
                        StyleBox[\(2\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 2, "-"],
                        Editable->True]}], ")"}]}], "+", 
                RowBox[{\(\[Nu]\_3\), 
                  InterpretationBox[
                    StyleBox[\(3\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 3, "+"],
                    Editable->True], 
                  RowBox[{"(", 
                    RowBox[{
                      InterpretationBox[
                        StyleBox[\(5\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 5, "-"],
                        Editable->True], "-", 
                      InterpretationBox[
                        StyleBox[\(4\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 4, "-"],
                        Editable->True]}], ")"}]}]}], ")"}], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["F",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_4\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_5\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TFI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3], 
                Subscript[ \[Nu], 4], 
                Subscript[ \[Nu], 5]}],
              Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
    \(s\_43 = OperatorApplyF[e\_43]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (44)", "Subsection",
  CellTags->"T1.6.12.1"],

Cell[TextData[{
  "general ",
  Cell[BoxData[
      \(p\^2\)]],
  " and ( ",
  Cell[BoxData[
      \(TraditionalForm\`m\_5\%2 == 0\)]],
  "  &&  ",
  Cell[BoxData[
      \(TraditionalForm\`m\_1\%2\)]],
  "==",
  Cell[BoxData[
      \(TraditionalForm\`m\_2\%2\)]],
  " && ",
  Cell[BoxData[
      \(TraditionalForm\`m\_3\%2\)]],
  "== ",
  Cell[BoxData[
      \(TraditionalForm\`m\_4\%2\)]],
  " ) \[DoubleLongRightArrow] \[CapitalDelta] == 0"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(e\_44\), "=", 
        RowBox[{
          RowBox[{\((d - \[Nu]\_2 - \[Nu]\_4 - 2  \[Nu]\_5)\), 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["F",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_4\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_5\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TFI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3], 
                Subscript[ \[Nu], 4], 
                Subscript[ \[Nu], 5]}],
              Editable->True]}], "\[Equal]", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{\(\[Nu]\_2\), 
                  InterpretationBox[
                    StyleBox[\(2\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 2, "+"],
                    Editable->True], 
                  RowBox[{"(", 
                    RowBox[{
                      InterpretationBox[
                        StyleBox[\(5\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 5, "-"],
                        Editable->True], "-", 
                      InterpretationBox[
                        StyleBox[\(1\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 1, "-"],
                        Editable->True]}], ")"}]}], "+", 
                RowBox[{\(\[Nu]\_4\), 
                  InterpretationBox[
                    StyleBox[\(4\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 4, "+"],
                    Editable->True], 
                  RowBox[{"(", 
                    RowBox[{
                      InterpretationBox[
                        StyleBox[\(5\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 5, "-"],
                        Editable->True], "-", 
                      InterpretationBox[
                        StyleBox[\(3\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 3, "-"],
                        Editable->True]}], ")"}]}]}], ")"}], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["F",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_4\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_5\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TFI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3], 
                Subscript[ \[Nu], 4], 
                Subscript[ \[Nu], 5]}],
              Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
    \(s\_44 = OperatorApplyF[e\_44]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (45)", "Subsection",
  CellTags->"T1.6.13.1"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(e\_45\), "=", " ", 
        RowBox[{
          RowBox[{\(\[CapitalDelta]\_\(1, 3, 6\)\), 
            InterpretationBox[
              StyleBox[\(1\^+\),
                FontWeight->"Bold"],
              Schiebe[ 1, "+"],
              Editable->True], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["F",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_4\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_5\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TFI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3], 
                Subscript[ \[Nu], 4], 
                Subscript[ \[Nu], 5]}],
              Editable->True]}], "\[Equal]", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{\(u\_\(6, 1, 3\)\), 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{\(\[Nu]\_1\), 
                        InterpretationBox[
                          StyleBox[\(1\^+\),
                            FontWeight->"Bold"],
                          Schiebe[ 1, "+"],
                          Editable->True], 
                        InterpretationBox[
                          StyleBox[\(3\^-\),
                            FontWeight->"Bold"],
                          Schiebe[ 3, "-"],
                          Editable->True]}], "+", 
                      RowBox[{\(\[Nu]\_5\), 
                        InterpretationBox[
                          StyleBox[\(5\^+\),
                            FontWeight->"Bold"],
                          Schiebe[ 5, "+"],
                          Editable->True], 
                        RowBox[{"(", 
                          RowBox[{
                            InterpretationBox[
                              StyleBox[\(3\^-\),
                                FontWeight->"Bold"],
                              Schiebe[ 3, "-"],
                              Editable->True], "-", 
                            InterpretationBox[
                              StyleBox[\(4\^-\),
                                FontWeight->"Bold"],
                              Schiebe[ 4, "-"],
                              Editable->True]}], ")"}]}]}], ")"}]}], "-", 
                RowBox[{"2", \(u\_\(1, 3, 6\)\), 
                  RowBox[{"(", " ", 
                    RowBox[{
                      RowBox[{\(\[Nu]\_2\), 
                        InterpretationBox[
                          StyleBox[\(2\^+\),
                            FontWeight->"Bold"],
                          Schiebe[ 2, "+"],
                          Editable->True], 
                        RowBox[{"(", 
                          RowBox[{
                            InterpretationBox[
                              StyleBox[\(5\^-\),
                                FontWeight->"Bold"],
                              Schiebe[ 5, "-"],
                              Editable->True], "-", 
                            InterpretationBox[
                              StyleBox[\(1\^-\),
                                FontWeight->"Bold"],
                              Schiebe[ 1, "-"],
                              Editable->True]}], ")"}]}], "+", " ", 
                      RowBox[{\(\[Nu]\_4\), 
                        InterpretationBox[
                          StyleBox[\(4\^+\),
                            FontWeight->"Bold"],
                          Schiebe[ 4, "+"],
                          Editable->True], 
                        RowBox[{"(", 
                          RowBox[{
                            InterpretationBox[
                              StyleBox[\(5\^-\),
                                FontWeight->"Bold"],
                              Schiebe[ 5, "-"],
                              Editable->True], "-", 
                            InterpretationBox[
                              StyleBox[\(3\^-\),
                                FontWeight->"Bold"],
                              Schiebe[ 3, "-"],
                              Editable->True]}], ")"}]}], 
                      "+", \(-\[CapitalSigma]\_5\), "-", \(\[Nu]\_1\), 
                      "+", \(3  \[Nu]\_3\)}], ")"}]}], "+", 
                RowBox[{"2", \(m\_3\%2\), 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{\(\[Nu]\_5\), 
                        InterpretationBox[
                          StyleBox[\(5\^+\),
                            FontWeight->"Bold"],
                          Schiebe[ 5, "+"],
                          Editable->True], 
                        RowBox[{"(", 
                          RowBox[{
                            InterpretationBox[
                              StyleBox[\(1\^-\),
                                FontWeight->"Bold"],
                              Schiebe[ 1, "-"],
                              Editable->True], "-", 
                            InterpretationBox[
                              StyleBox[\(2\^-\),
                                FontWeight->"Bold"],
                              Schiebe[ 2, "-"],
                              Editable->True]}], ")"}]}], "+", 
                      RowBox[{\(\[Nu]\_3\), 
                        InterpretationBox[
                          StyleBox[\(3\^+\),
                            FontWeight->"Bold"],
                          Schiebe[ 3, "+"],
                          Editable->True], 
                        InterpretationBox[
                          StyleBox[\(1\^-\),
                            FontWeight->"Bold"],
                          Schiebe[ 1, "-"],
                          Editable->True]}], "+", \(\[Nu]\_1\), 
                      "-", \(\[Nu]\_3\)}], ")"}]}]}], ")"}], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["F",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_4\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_5\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TFI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3], 
                Subscript[ \[Nu], 4], 
                Subscript[ \[Nu], 5]}],
              Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
    \(s\_45 = OperatorApplyF[e\_45]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (43) and (44)", "Subsection",
  CellTags->"T1.6.14.1"],

Cell[BoxData[
    \(f\_43 = 
      MakeFun[s\_43, "\<(43)\>", 
        IFF[\[Nu]\_1 + \[Nu]\_3 + 2  \[Nu]\_5 - \((d /. dd_Symbol :> 4)\) =!= 
            0], {m5 :> 0, m4 :> m3, m2 :> m1}]\)], "Input"],

Cell[BoxData[
    \(f\_44 = 
      MakeFun[s\_44, "\<(44)\>", {m5 :> 0, m4 :> m3, m2 :> m1}]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (50)", "Subsection",
  CellTags->"T1.6.15.1"],

Cell["\<\
Subscript[f, 50] = 
   HoldForm[TFR[d_, PP_, 
      {{(n1_)?PQ, m1_}, {(n2_)?PQ, m2_}, {(n3_)?PQ, m3_}, 
       {(n4_)?PQ, m4_}, {(n5_)?PQ, m5_}}] := 
     (TComment[\"(50)\", TFIC[d, PP, 
          {{n1, m1}, {n2, m2}, {n3, m3}, {n4, m4}, 
           {n5, m5}}]]; 
        Block[{r1 = 3 - d, r2 = 4 - d, 
          r3 = 
           -(m1^2*m2^2*m3^2) + m2^4*m3^2 + m2^2*m3^4 + 
            m1^4*m4^2 - m1^2*m2^2*m4^2 - 
            m1^2*m3^2*m4^2 - m2^2*m3^2*m4^2 + 
            m1^2*m4^4 + m1^2*m2^2*m5^2 - 
            m2^2*m3^2*m5^2 - m1^2*m4^2*m5^2 + 
            m3^2*m4^2*m5^2 + m1^2*m3^2*PP - 
            m2^2*m3^2*PP - m1^2*m4^2*PP + m2^2*m4^2*PP - 
            m1^2*m5^2*PP - m2^2*m5^2*PP - m3^2*m5^2*PP - 
            m4^2*m5^2*PP + m5^4*PP + m5^2*PP^2, 
          r4 = -4 + d, r5 = -3 + d, r6 = -7 + 2*d, 
          r7 = -(m2^2*r4) + m3^2*r5 - m5^2*r5 + m4^2*r6, 
          r8 = -10 + 3*d, r9 = -m3^2 + m4^2, 
          r10 = -11 + 3*d, 
          r11 = -(m4^2*r10) - 3*m5^2*r5 + m3^2*r6, 
          r12 = 
           m2^2*r11 + m5^4*r5 + m2^4*r8 + m4^2*r4*r9 + 
            m5^2*r5*r9, r13 = -6 + d, 
          r14 = -(m4^2*r13) + m5^2*r5, 
          r15 = -3*m3^2 - m4^2*r10 + m5^2*r5, 
          r16 = 
           m3^2*r14 + m2^2*r15 + m2^4*r4 - 2*m3^4*r5 - 
            3*m4^2*m5^2*r5 + m5^4*r5 + m4^4*r8, 
          r17 = m3^2 + 2*m4^2, r18 = -1 + d, 
          r19 = -(m3^2*r13) - 2*m4^2*r18 + 2*m5^2*r5, 
          r20 = 
           2*m2^4 - 3*m3^4 + d*m3^4 - 3*m3^2*m4^2 + 
            2*m4^4 + m2^2*r19 - 2*m5^4*r5 + m5^2*r17*r5, 
          r21 = 2 + d, r22 = 
           2*m5^2 - m4^2*r21 + m2^2*r4 - m3^2*r4, 
          r23 = -7 + d, r24 = 6*m4^2 - 4*m5^2, 
          r25 = 3*m3^2 + m4^2*r18 + m5^2*r23, 
          r26 = 
           -6*m4^4 - 2*m4^2*m5^2*r23 + m3^2*r24 + 
            2*m2^2*r25 - 2*m2^4*r4 - m3^4*r4, 
          r27 = m3^4 + m3^2*m4^2 - 2*m4^4, 
          r28 = m3^2 + m4^2*r23, 
          r29 = -2*m4^2*r18 + m3^2*r21 + 2*m5^2*r23, 
          r30 = -6*m2^4 + 2*m5^2*r28 - m2^2*r29 + r27*r4, 
          r31 = m1^4*r22 + m1^2*r26 + m3^2*r30 + m1^6*r4, 
          r32 = m3 - m4, r33 = m3 + m4, 
          r34 = 2*m3^2 + m4^2, r35 = -17 + 3*d, 
          r36 = m3^2*r23 + m4^2*r35, r37 = -9 + d, 
          r38 = 17 - 3*d, 
          r39 = 5*m3^2 + m4^2*r37 + m5^2*r38, 
          r40 = 1 + d, r41 = 
           5*m4^2 - m5^2*r23 + m2^2*r4 - m3^2*r40, 
          r42 = 
           m5^4*r35 - m5^2*r36 + m2^2*r39 - 2*m1^4*r4 + 
            m2^4*r4 - r32*r33*r34*r4 + m1^2*r41, 
          r43 = m1^2 - m2^2 + m3^2 - m4^2, 
          r44 = 2*m5^2*r13 + r4*r43, 
          r45 = 
           m3^4*r12 + m1^4*r16 + m1^2*m3^2*r20 + 
            PP*r31 + PP^2*r42 + PP^3*r44 + m1^6*r7, 
          r46 = m2^2 + m4^2, r47 = 13 - 3*d, 
          r48 = m4^2*r47 - m5^2*r5 + m3^2*r6, 
          r49 = m5^4*r5 + m5^2*r32*r33*r5 + m4^2*r4*r9, 
          r50 = -18 + 4*d, r51 = -(m4^2*r13) - 3*m5^2*r5, 
          r52 = 
           2*m3^4*r5 + m4^2*m5^2*r5 + m5^4*r5 + 
            m4^4*r50 + m3^2*r51, 
          r53 = -3*m4^2 + 2*m5^2*r5, 
          r54 = 
           m4^4*r47 + 2*m3^4*r5 + m4^2*m5^2*r5 - 
            2*m5^4*r5 + m3^2*r53, 
          r55 = m4^2*r13 + 6*m3^2*r5 - 2*m5^2*r5, 
          r56 = 3*m4^2 + m3^2*r5 - m5^2*r5, 
          r57 = 7 - 2*d, 
          r58 = m3^2*r5 + 3*m5^2*r5 + m4^2*r57, 
          r59 = 
           m2^6*r4 + m2^2*m4^2*r55 + m2^4*r56 + m4^4*r58, 
          r60 = m4^2 - m3^2*r5, r61 = 10 - 3*d, 
          r62 = 2*m5^2 + 3*m4^2*r4 + m3^2*r61, 
          r63 = m4^2 + m5^2*r5, 
          r64 = 
           -4*m4^2*m5^2 + 3*m4^4*r4 - 2*m3^4*r5 + 
            2*m3^2*r63, r65 = m4^2 + m3^2*r5 - m5^2*r5, 
          r66 = 2*m3^2*r5 + 2*m5^2*r5 + m4^2*r61, 
          r67 = 3*m2^4*r4 + 2*m2^2*r65 + m4^2*r66, 
          r68 = 
           -3*m2^6*r4 - 2*m1^4*m4^2*r5 + 
            2*m4^2*m5^2*r60 + m2^4*r62 + m2^2*r64 + 
            m1^2*r67 - 3*m4^4*r4*r9, r69 = -13 + 3*d, 
          r70 = m3^2*r5 + m4^2*r69, 
          r71 = m4^2 - 3*m2^2*r4 - m3^2*r5 + m5^2*r5, 
          r72 = -5 + d, r73 = m3^2 + m5^2*r69 + m4^2*r72, 
          r74 = 
           3*m2^4*r4 - m5^4*r5 + m5^2*r70 + m1^2*r71 + 
            m2^2*r73 + 3*m4^2*r4*r9, 
          r75 = m1^2 - m2^2 + m3^2 - m4^2 - 2*m5^2, 
          r76 = 
           m2^8*r4 + m2^6*r48 + m4^4*r49 + 
            2*m1^4*m4^2*r46*r5 + m2^4*r52 + 
            m2^2*m4^2*r54 - m1^2*r59 + PP*r68 + 
            PP^2*r74 + PP^3*r4*r75, 
          r77 = m3^2 - m4^2 + m5^2, 
          r78 = -2*m2^2 + m4^2 + m5^2, 
          r79 = -2*m1^2 - m3^2 - m4^2 + m5^2, 
          r80 = 
           m1^4 + PP^2 - m1^2*r77 + m3^2*r78 + PP*r79, 
          r81 = m3^2 + m4^2, r82 = m3^2 + m4^2 + m5^2, 
          r83 = m1^2 + m3^2 - m5^2, 
          r84 = 
           m1^4 + 2*m3^2*m4^2 - m4^4 + PP^2 - m2^2*r77 + 
            m5^2*r81 - m1^2*r82 - 2*PP*r83, 
          r85 = m1 - m3, r86 = -PP + r85^2, 
          r87 = m1 + m3, r88 = -PP + r87^2, 
          r89 = m2 - m4, r90 = m2 + m4, 
          r91 = -m1^2 - m2^2 - m3^2 - m4^2 + 2*m5^2, 
          r92 = PP^2 + r85*r87*r89*r90 + PP*r91, 
          r93 = m2^2 - 3*m4^2, r94 = m4 - m5, 
          r95 = m4 + m5, r96 = 2*m3^2 - m4^2 + m5^2, 
          r97 = -m1^2 - m2^2 - 2*m3^2 + 3*m5^2, 
          r98 = 
           PP^2 + m1^2*r93 + m2^2*r94*r95 + m4^2*r96 + 
            PP*r97, r99 = -2 + d, r100 = -m1^2 + m2^2, 
          r101 = m2^2 + m1^2*r72, 
          r102 = m3^2*r101 - 2*m3^4*r4 + m2^2*r100*r4, 
          r103 = 9 - 2*d, r104 = m2^2*r23 + m3^2*r72, 
          r105 = 
           2*m1^4 + m2^4*r103 + m1^2*r104 + m2^2*m3^2*r5, 
          r106 = -9 + 2*d, r107 = m1 - m2, 
          r108 = m1 + m2, 
          r109 = -(r106*r107*r108) + m3^2*r4, 
          r110 = 
           m2^2*r102 + m4^2*r105 + m4^4*r109 - m4^6*r4, 
          r111 = m1^2 + m2^2, 
          r112 = m2^2*r4 - 2*m1^2*r72, r113 = -19 + 5*d, 
          r114 = m3^2*r112 + m3^4*r113 + m2^2*r111*r4, 
          r115 = m3^2*r5 + m2^2*r6, 
          r116 = 
           2*m1^4 + 2*m1^2*r115 + m2^4*r13 + m3^4*r72 - 
            2*m2^2*m3^2*r99, 
          r117 = m2^2*r106 + m3^2*r4 - m1^2*r99, 
          r118 = 
           m2^2*r114 - m4^2*r116 + m4^4*r117 - m4^6*r6, 
          r119 = -(m2^2*r5) + 2*m3^2*r57 + m1^2*r72, 
          r120 = m1^2*r18 + 2*m3^2*r4 - m2^2*r5, 
          r121 = m2^2*r119 + m4^2*r120 + 2*m4^4*r5, 
          r122 = m3^2*r5 + m4^2*r72, 
          r123 = -2*m2^2*r4 - m4^2*r69 + m3^2*r72, 
          r124 = 
           m2^2*r122 + m1^2*r123 + 2*m2^4*r4 + 
            2*m4^2*r32*r33*r4, 
          r125 = -3*m4^2 + m2^2*r4 - m3^2*r72, 
          r126 = m3^2 - m4^2*r72, 
          r127 = 
           -2*m3^2*m4^2 - 2*m1^2*r125 - 2*m2^2*r126 + 
            m4^4*r18 - 4*m2^4*r4 + m3^4*r72, 
          r128 = 
           -(m2^2*r18) + 2*m4^2*r5 + m1^2*r72 + 
            2*m3^2*r72, 
          r129 = 
           m5^2*r127 - m5^4*r128 - r124*r32*r33 + 
            m5^6*r72, r130 = -m1^2 + m2^2 + m3^2 - m4^2, 
          r131 = -14 + 3*d, 
          r132 = 
           -(m3^2*r13) + m4^2*r131 + m1^2*r4 + 5*m2^2*r4, 
          r133 = -2*m5^4 + m5^2*r132 + r130*r32*r33*r4, 
          r134 = 
           m5^2*r118 + m5^4*r121 + PP*r129 + PP^2*r133 + 
            r110*r32*r33 - 2*m5^2*PP^3*r4 + 
            m5^6*r5*r89*r90, r135 = m3 - m4 - m5, 
          r136 = m3 + m4 - m5, r137 = m3 - m4 + m5, 
          r138 = m3 + m4 + m5, r139 = -10 + d, 
          r140 = 13 - 2*d, r141 = d*m4^2 + 2*m3^2*r5, 
          r142 = -8 + d, 
          r143 = m4^2*r142 - m3^2*r99 + m5^2*r99, 
          r144 = 
           m3^2*m4^2*r139 + m4^4*r140 - m5^2*r141 + 
            m2^2*r143 + m3^4*r5 + m5^4*r5, 
          r145 = 3*m3^4 - 12*m3^2*m4^2 + 7*m4^4, 
          r146 = 3*m3^2 + 4*m4^2, r147 = m3^2 - 11*m4^2, 
          r148 = 
           7*m3^4 + 10*m3^2*m4^2 - 17*m4^4 - 5*m5^4 - 
            2*m5^2*r147, r149 = m2^2 + 2*m3^2 + m4^2, 
          r150 = 
           -m2^4 + m2^2*m3^2 + m3^4 + 3*m2^2*m4^2 + 
            m3^2*m4^2 - m4^4 + m5^4 - m5^2*r149, 
          r151 = 
           3*m3^6 + 6*m3^4*m4^2 - 17*m3^2*m4^4 + 
            8*m4^6 + 3*m5^6 - m5^2*r145 - m5^4*r146 + 
            m2^2*r148 - d*r150*r77 + 6*m2^4*r94*r95, 
          r152 = -(m3^2*m4) + m4^3, r153 = 11 - 2*d, 
          r154 = -(d*m3^2*m4^2) + m4^4*r153 + m3^4*r5, 
          r155 = m4^2 + m3^2*r5, 
          r156 = r142*r32*r33 + m5^2*r99, 
          r157 = 11 - 3*d, r158 = -8 + 3*d, 
          r159 = m5^2*r158 + m4^2*r21, 
          r160 = 
           -3*m3^4 + 2*m4^2*m5^2*r106 + m5^4*r157 + 
            m3^2*r159 - m4^4*r18, 
          r161 = 
           -2*m2^6 + m5^2*r154 - 2*m5^4*r155 + 
            m2^4*r156 + m2^2*r160 + r152^2*r4 + m5^6*r5, 
          r162 = m4^2*r23 - 3*m3^2*r72, 
          r163 = -4*m2^2 + m4^2*r18 + m3^2*r23, 
          r164 = -m3^4 + m4^4, 
          r165 = 
           -(m2^4*r13) + m2^2*r162 + m1^2*r163 + 
            r164*r4 + m1^4*r99, r166 = -19 + 4*d, 
          r167 = m4^2 + m3^2*r72, r168 = m3^2 + m4^2*r69, 
          r169 = -2*r168 + 4*m2^2*r4, 
          r170 = 
           -m3^4 + m2^4*r13 - m4^4*r166 + 2*m2^2*r167 + 
            m1^2*r169 + 2*m3^2*m4^2*r72 + m1^4*r99, 
          r171 = m1^2 - m2^2 + 4*m4^2, 
          r172 = 
           -(m5^2*r170) + r165*r32*r33 + m5^6*r72 - 
            m5^4*r171*r72, r173 = m2^2 + m3^2, 
          r174 = -(m4^2*r13) + r131*r173 + m1^2*r8, 
          r175 = m5^2*r174 - 2*m5^4*r4 + r130*r32*r33*r4, 
          r176 = 
           2*m1^6*m4^2 + m1^4*r144 + m1^2*r151 + 
            m3^2*r161 + PP*r172 + PP^2*r175 - 
            2*m5^2*PP^3*r4, r177 = m3^2 + m4^2 - m5^2, 
          r178 = -2*m1^2 + m3^2 - m4^2 + m5^2, 
          r179 = -m3^2 + m4^2 + m5^2, 
          r180 = m2^2*r177 + m4^2*r178 + PP*r179, 
          r181 = -2*m2^2 - m3^2 + m4^2 + m5^2, 
          r182 = m1^2*r177 + m3^2*r181 + PP*r77, 
          r183 = -(m2^2*r13) - 2*m3^2*r5, 
          r184 = 
           m1^2*r183 - 2*m3^4*r4 + m2^4*r57 + m1^4*r72 - 
            m2^2*m3^2*r99, r185 = 3*m2^2*r4 + m3^2*r72, 
          r186 = 
           m2^4*r106 + 2*m1^2*r185 + m1^4*r40 - 
            2*m2^2*m3^2*r6, r187 = r111*r13 - m3^2*r4, 
          r188 = 
           m2^2*r184 + m4^2*r186 - m4^4*r187 + m4^6*r4, 
          r189 = 2*m1^2 + m3^2*r10 + 2*m2^2*r5, 
          r190 = m2^2*r5 + m3^2*r72 + 2*m1^2*r99, 
          r191 = m2^2*r189 - m4^2*r190 - m4^4*r5, 
          r192 = -(m3^2*r5) - m4^2*r72, 
          r193 = 2*m2^2*r4 + m4^2*r69 - m3^2*r72, 
          r194 = 
           m2^2*r192 + m1^2*r193 - 2*m2^4*r4 + 
            2*m4^2*r4*r9, r195 = m2^2 + m4^2 + m3^2*r72, 
          r196 = -(m3^2*r6) - m4^2*r72, 
          r197 = 
           m2^4*r157 + 2*m1^2*r195 + 2*m2^2*r196 + 
            2*m4^2*r17*r4 + m1^4*r72, 
          r198 = 
           m4^2*r10 - 2*m2^2*r5 + 2*m1^2*r72 + m3^2*r72, 
          r199 = 
           r107*r108*r194 + m5^2*r197 - m5^4*r198 + 
            m5^6*r72, r200 = m1^2 - m2^2 - m3^2 + m4^2, 
          r201 = m1^2 + m2^2 + m3^2 + 5*m4^2, 
          r202 = 2*m5^4 - r107*r108*r200 - m5^2*r201, 
          r203 = 
           r107*r108*r110 - m5^2*r188 - m5^4*r191 + 
            PP*r199 + 2*m5^2*PP^3*r4 + PP^2*r202*r4 + 
            m5^6*r5*r89*r90, r204 = m4^2 + m5^2, 
          r205 = -2*m5^2*r5 + m4^2*r99, r206 = 18 - 5*d, 
          r207 = m4^2*r206 + m5^2*r8 - 2*m3^2*r99, 
          r208 = 
           m2^2*r207 + 2*m2^4*r4 - m3^4*r5 - 
            m3^2*r204*r5 + r205*r94*r95, 
          r209 = 2*m3^2*m4^2 + m4^4*r142 + 2*m3^4*r5, 
          r210 = -(m4^2*r18) + m3^2*r5, r211 = 3 - 2*d, 
          r212 = m5^2 + m4^2*r157 + m3^2*r211, 
          r213 = m4^2*r106 + m3^2*r4, 
          r214 = 
           -(d*m3^4) + 10*m3^2*m4^2 - 2*d*m3^2*m4^2 - 
            2*m4^4 + d*m4^4 + 2*m5^2*r213 - 2*m5^4*r4, 
          r215 = 
           d*m3^2*m4^4 - 2*m4^6 - m5^2*r209 + 
            m5^4*r210 + m2^4*r212 + m2^2*r214 + 
            m2^6*r4 + m5^6*r5 - m3^4*m4^2*r99, 
          r216 = m4^2*r13 + m3^2*r99, 
          r217 = m3^2*r5 - m4^2*r72, r218 = 13 - 4*d, 
          r219 = 3*m3^2 + m5^2*r218 + m4^2*r23, 
          r220 = m4^2*r142 + m5^2*r61, 
          r221 = 
           2*m3^4 + 2*m4^2*m5^2 - m4^4*r13 + m3^2*r220 + 
            2*m5^4*r6, r222 = 
           m4^2*m5^2*r216 + m5^4*r217 + m2^4*r219 + 
            m2^2*r221 - m5^6*r5 + m2^6*r99, 
          r223 = -(m3^2*r10) + m4^2*r5, 
          r224 = 
           4*m3^2*m4^2 + m1^2*r122 + m4^4*r13 + 
            m2^2*r223 + m1^4*r4 - m2^4*r4 - m3^4*r99, 
          r225 = -m3^2 + m2^2*r72 - m4^2*r72, 
          r226 = -2*m4^2*r106 + 2*m3^2*r69, 
          r227 = 
           m1^4*r106 + m2^4*r106 - m4^4*r13 - 
            2*m1^2*r225 + m2^2*r226 - 4*m3^2*m4^2*r4 - 
            m3^4*r99, r228 = m3^2 + 3*m4^2, 
          r229 = 
           r107*r108*r224 - m5^2*r227 + m5^6*r72 - 
            m5^4*r228*r72, 
          r230 = m4^2*r131 + m1^2*r4 + m2^2*r4 + m3^2*r8, 
          r231 = 
           2*m5^4*r106 - m5^2*r230 - r107*r108*r200*r4, 
          r232 = 
           m1^4*r208 - m1^2*r215 - m3^2*r222 + PP*r229 + 
            PP^2*r231 + 2*m5^2*PP^3*r4 + m1^6*r7, 
          r233 = -2*m3^2 + m4^2, 
          r234 = -m2^2 + m4^2 - 2*m5^2, 
          r235 = -m1^2 + m2^2 + m5^2, 
          r236 = 
           m1^4 + m5^4 + m2^2*r233 + m1^2*r234 + 
            PP*r235 - m5^2*r46, r237 = -m2^2 + m5^2, 
          r238 = m2^2 + m3^2 - 2*m4^2 + m5^2, 
          r239 = -m1^2 + m2^2 - m5^2, 
          r240 = m1^4 + m3^2*r237 - m1^2*r238 + PP*r239, 
          r241 = m3^2 + 3*m4^2 - m5^2, 
          r242 = -3*m3^2 - m4^2 + m5^2, 
          r243 = 
           m5^4 - m5^2*r228 + m1^2*r241 + m2^2*r242 + 
            2*PP*r32*r33 + 2*m4^2*r9, 
          r244 = 2*m1^2 + m2^2 + m4^2, 
          r245 = -2*m1^2 - m3^2 - m4^2 + 3*m5^2, 
          r246 = 
           m1^4 - 3*m2^2*m3^2 + m5^4 + PP^2 + 
            m4^2*r173 - m5^2*r244 + PP*r245, 
          r247 = -2*m3^2 + m4^2 + m5^2, 
          r248 = 
           -m2^4 - m4^2*m5^2 + PP*r235 + m2^2*r247 + 
            m1^2*r46, r249 = m2^2*r153 + m1^2*r5, 
          r250 = 2*m1^2 + m2^2*r4, 
          r251 = m2^2*r13 + m1^2*r139, 
          r252 = r107*r108*r250 + m3^2*r251 - m3^4*r4, 
          r253 = m1^2*r140 + 2*m3^2*r4 + m2^2*r72, 
          r254 = 
           m3^4*r249 + m4^2*r252 + m4^4*r253 - m4^6*r4 + 
            m2^2*m3^2*r100*r99, r255 = 2*m3^2 + m4^2*r13, 
          r256 = -2*m3^2*r5 + m2^2*r99 - m4^2*r99, 
          r257 = -11 + 2*d, 
          r258 = 
           -(m4^4*r106) + 2*m3^2*m4^2*r23 - m3^4*r257, 
          r259 = 4*m4^2 + m3^2*r13, 
          r260 = 
           -2*m2^4 + 6*m3^2*m4^2 + 2*m2^2*r259 + 
            m4^4*r37 + m3^4*r5, 
          r261 = 
           -5*m3^4*m4^2 + m2^4*r255 + m1^4*r256 + 
            m2^2*r258 + m1^2*r260 - m2^6*r4 + m3^6*r5 + 
            m4^6*r6 - 3*m3^2*m4^4*r72, 
          r262 = m3^4 + m3^2*m4^2 + m4^4, 
          r263 = 
           m1^4 + m2^4 - 2*r262 + m1^2*r81 + m2^2*r81, 
          r264 = m1^2 + m2^2 - m3^2 - m4^2, 
          r265 = -(r13*r32*r33) + m2^2*r99, 
          r266 = 
           -2*m1^2*r265 - r32^2*r33^2*r4 + 
            2*m2^2*r13*r9 + m1^4*r99 + m2^4*r99, 
          r267 = m3^2*r13 + m4^2*r4, r268 = -16 + 3*d, 
          r269 = m3^2*r13 - m4^2*r268 + m2^2*r4, 
          r270 = 
           2*m2^2*r267 + 2*m1^2*r269 + 
            r13*r228*r32*r33 + m2^4*r61 + m1^4*r99, 
          r271 = 2*m2^2 + m4^2*r23 - m3^2*r72, 
          r272 = 
           -(m5^2*r270) - 2*m5^4*r271 + r266*r32*r33, 
          r273 = 2*m3^2 - 2*m4^2 - m5^2, 
          r274 = m1^2*r5 - m2^2*r5 + r273*r72, 
          r275 = 
           r200*r254 + m5^2*r261 + PP*r272 + 
            2*m5^2*PP^2*r274 + m5^4*r263*r5 - 
            m5^6*r264*r5, 
          r276 = 
           -2*m2^2*m3^2 - 2*m3^4 + 3*m3^2*m4^2 - m4^4 + 
            3*m3^2*m5^2 + 2*m4^2*m5^2 - m5^4 + 
            m1^2*r177 + PP*r77, 
          r277 = -(m4^2*r106) + m2^2*r4 - m3^2*r5, 
          r278 = 
           -2*m3^4 - m3^2*m4^2*r13 + m2^2*r196 + 
            m2^4*r4 + m4^4*r4, 
          r279 = m4^2*r131 + m3^2*r8, 
          r280 = 
           m2^2*r279 - 2*m2^4*r4 + m4^2*r32*r33*r99, 
          r281 = m1^4*r277 + m2^2*r278 + m1^2*r280, 
          r282 = 11*m3^2 - 3*d*m3^2 + 9*m4^2 - 2*d*m4^2, 
          r283 = 15 - 4*d, 
          r284 = m4^2*r106 + m2^2*r283 + m3^2*r5, 
          r285 = m4^4*r13 + 4*m3^2*m4^2*r5 - m3^4*r99, 
          r286 = -m4^2 + m3^2*r5, 
          r287 = -(m4^2*r5) + m3^2*r6, 
          r288 = 2*m2^2*r287 + m2^4*r72 - 2*r286*r81, 
          r289 = 
           -2*m3^2*m4^4 + m2^4*r282 + m1^4*r284 + 
            m2^2*r285 + m1^2*r288 - m4^6*r4 + m1^6*r5 + 
            m2^6*r6 + m3^4*m4^2*r99, 
          r290 = 2*m2^2 - m3^2 - m4^2, 
          r291 = 
           2*m1^4 + 2*m2^4 - m3^4 - m4^4 + m1^2*r290 - 
            m2^2*r81, r292 = m2^2 - m3^2 + m4^2, 
          r293 = 
           m1^4*r4 + m2^4*r4 - 2*m1^2*r292*r4 + 
            2*m2^2*r4*r9 - r32^2*r33^2*r99, 
          r294 = m3^2*r13 - m4^2*r131, 
          r295 = m2^2*r13 - r4*r81, 
          r296 = 
           m1^4*r131 + 2*m2^2*r294 - 2*m1^2*r295 - 
            2*m3^2*m4^2*r4 + m4^4*r8 - m2^4*r99 - 
            m3^4*r99, r297 = 2*m4^2 - m2^2*r5 + m1^2*r72, 
          r298 = 
           r107*r108*r293 - m5^2*r296 + 2*m5^4*r297, 
          r299 = -2*m5^2*r32*r33*r5 + 2*m5^4*r72, 
          r300 = 
           r130*r281 - m5^2*r289 + PP*r298 + PP^2*r299 - 
            m5^6*r264*r5 + m5^4*r291*r5, 
          r301 = 
           -2*m2^2*m3^2 - m3^2*m4^2 + m4^4 + m5^4 - 
            m5^2*r17 + m1^2*r177 + PP*r77, 
          r302 = m2^2 + 2*m3^2 - 3*m4^2, 
          r303 = -m1^2 + m2^2 - 3*m5^2, 
          r304 = 
           m1^4 - m2^2*m4^2 - m5^4 + m5^2*r149 - 
            m1^2*r302 + PP*r303, 
          r305 = 
           -((r45*TBI[d, PP, {{1, m4}, {1, m2}}]*
                 TBI[d, PP, {{2, m1}, {1, m3}}])/(4*r3)) 
+ (r76*TBI[d, PP, {{1, m3}, {1, m1}}]*
               TBI[d, PP, {{2, m2}, {1, m4}}])/(4*r3) - 
            (r80*TBI[d, PP, {{2, m1}, {1, m3}}]*
               TBI[d, PP, {{2, m2}, {1, m4}}])/2 - 
            (r45*TBI[d, PP, {{1, m4}, {1, m2}}]*
               TBI[d, PP, {{2, m3}, {1, m1}}])/(4*r3) - 
            (r84*TBI[d, PP, {{2, m2}, {1, m4}}]*
               TBI[d, PP, {{2, m3}, {1, m1}}])/2 - 
            r86*r88*TBI[d, PP, {{1, m4}, {1, m2}}]*
             TBI[d, PP, {{2, m3}, {2, m1}}] + 
            (r76*TBI[d, PP, {{1, m3}, {1, m1}}]*
               TBI[d, PP, {{2, m4}, {1, m2}}])/(4*r3) - 
            (r92*TBI[d, PP, {{2, m1}, {1, m3}}]*
               TBI[d, PP, {{2, m4}, {1, m2}}])/2 - 
            (r98*TBI[d, PP, {{2, m3}, {1, m1}}]*
               TBI[d, PP, {{2, m4}, {1, m2}}])/2 - 
            r86*r88*TBI[d, PP, {{1, m4}, {1, m2}}]*
             TBI[d, PP, {{3, m1}, {1, m3}}] - 
            r86*r88*TBI[d, PP, {{1, m4}, {1, m2}}]*
             TBI[d, PP, {{3, m3}, {1, m1}}] - 
            r3*TFI[r99, PP, 
              {{1, m1}, {1, m2}, {1, m3}, {1, m4}, 
               {1, m5}}] - 
            (r134*TVI[d, PP, 
                {{1, m5}, {1, m1}, {2, m4}, {1, m3}}])/
             (4*r3) - (r135*r136*r137*r138*
               TVI[d, PP, 
                {{1, m5}, {1, m1}, {2, m4}, {2, m3}}])/2 
- (r176*TVI[d, PP, {{1, m5}, {1, m2}, {2, m3}, 
                 {1, m4}}])/(4*r3) + 
            (r180*TVI[d, PP, 
                {{1, m5}, {1, m2}, {2, m3}, {2, m4}}])/2 
- r182*TVI[d, PP, {{1, m5}, {1, m2}, {3, m3}, 
               {1, m4}}] + 
            (r203*TVI[d, PP, 
                {{1, m5}, {1, m3}, {2, m2}, {1, m1}}])/
             (4*r3) + (r232*
               TVI[d, PP, 
                {{1, m5}, {1, m4}, {2, m1}, {1, m2}}])/
             (4*r3) + (r236*
               TVI[d, PP, 
                {{1, m5}, {1, m4}, {2, m1}, {2, m2}}])/2 
+ r240*TVI[d, PP, {{1, m5}, {1, m4}, {3, m1}, 
               {1, m2}}] + 
            (r45*TVI[d, PP, 
                {{1, m5}, {2, m1}, {1, m4}, {1, m3}}])/
             (4*r3) + (r86*r88*
               TVI[d, PP, 
                {{1, m5}, {2, m1}, {1, m4}, {2, m3}}])/2 
+ (r92*TVI[d, PP, {{1, m5}, {2, m1}, {2, m4}, 
                 {1, m3}}])/2 - 
            (r76*TVI[d, PP, 
                {{1, m5}, {2, m2}, {1, m3}, {1, m4}}])/
             (4*r3) - (r243*
               TVI[d, PP, 
                {{1, m5}, {2, m2}, {2, m3}, {1, m4}}])/2 
+ (r45*TVI[d, PP, {{1, m5}, {2, m3}, {1, m2}, 
                 {1, m1}}])/(4*r3) + 
            (r86*r88*TVI[d, PP, 
                {{1, m5}, {2, m3}, {1, m2}, {2, m1}}])/2 
+ (r246*TVI[d, PP, {{1, m5}, {2, m3}, {2, m2}, 
                 {1, m1}}])/2 - 
            (r76*TVI[d, PP, 
                {{1, m5}, {2, m4}, {1, m1}, {1, m2}}])/
             (4*r3) + (r248*
               TVI[d, PP, 
                {{1, m5}, {2, m4}, {2, m1}, {1, m2}}])/2 
+ r86*r88*TVI[d, PP, {{1, m5}, {3, m1}, {1, m4}, 
               {1, m3}}] + 
            r86*r88*TVI[d, PP, 
              {{1, m5}, {3, m3}, {1, m2}, {1, m1}}] + 
            (r275*TVI[d, PP, 
                {{2, m5}, {1, m1}, {1, m4}, {1, m3}}])/
             (4*r3) + (r276*
               TVI[d, PP, 
                {{2, m5}, {1, m1}, {1, m4}, {2, m3}}])/2 
- (r180*TVI[d, PP, {{2, m5}, {1, m1}, {2, m4}, 
                 {1, m3}}])/2 - 
            (r275*TVI[d, PP, 
                {{2, m5}, {1, m2}, {1, m3}, {1, m4}}])/
             (4*r3) + (r180*
               TVI[d, PP, 
                {{2, m5}, {1, m2}, {1, m3}, {2, m4}}])/2 
- (r276*TVI[d, PP, {{2, m5}, {1, m2}, {2, m3}, 
                 {1, m4}}])/2 - 
            (r300*TVI[d, PP, 
                {{2, m5}, {1, m3}, {1, m2}, {1, m1}}])/
             (4*r3) - (r240*
               TVI[d, PP, 
                {{2, m5}, {1, m3}, {1, m2}, {2, m1}}])/2 
- (r236*TVI[d, PP, {{2, m5}, {1, m3}, {2, m2}, 
                 {1, m1}}])/2 + 
            (r300*TVI[d, PP, 
                {{2, m5}, {1, m4}, {1, m1}, {1, m2}}])/
             (4*r3) + (r236*
               TVI[d, PP, 
                {{2, m5}, {1, m4}, {1, m1}, {2, m2}}])/2 
+ (r240*TVI[d, PP, {{2, m5}, {1, m4}, {2, m1}, 
                 {1, m2}}])/2 + 
            (r182*TVI[d, PP, 
                {{2, m5}, {2, m1}, {1, m4}, {1, m3}}])/2 
- (r301*TVI[d, PP, {{2, m5}, {2, m2}, {1, m3}, 
                 {1, m4}}])/2 - 
            (r304*TVI[d, PP, 
                {{2, m5}, {2, m3}, {1, m2}, {1, m1}}])/2 
+ (r248*TVI[d, PP, {{2, m5}, {2, m4}, {1, m1}, 
                 {1, m2}}])/2, r306}, 
         r306 = Factor /@ r305/(PP*r1*r2); r306]) /; 
         n1 === 1 && n2 === 1 && n3 === 1 && n4 === 1 && n5 === 1 &&  
       MatchQ[d, _Symbol + _Integer?Positive] && PP =!= 0 &&
       Cayley[m1, m2, m3, m4, m5, Sqrt[PP]] =!= 0]; \
\>", "Input",
  Editable->False]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (51)", "Subsection",
  CellTags->"T1.6.16.1"],

Cell[TextData[{
  "general ",
  Cell[BoxData[
      \(m\_i\%2\)]]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(e\_51\), "=", 
        RowBox[{
          RowBox[{\(\[CapitalDelta]\_\(1, 3, 4\)\), \(\[Nu]\_1\), 
            InterpretationBox[
              StyleBox[\(1\^+\),
                FontWeight->"Bold"],
              Schiebe[ 1, "+"],
              Editable->True], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["V",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_4\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TVI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3], 
                Subscript[ \[Nu], 4]}],
              Editable->True]}], "==", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"2", \(m\_3\%2\), \(\[Nu]\_3\), 
                  InterpretationBox[
                    StyleBox[\(3\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 3, "+"],
                    Editable->True], 
                  RowBox[{"(", 
                    RowBox[{
                      InterpretationBox[
                        StyleBox[\(1\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 1, "-"],
                        Editable->True], "-", 
                      InterpretationBox[
                        StyleBox[\(4\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 4, "-"],
                        Editable->True]}], ")"}]}], "+", 
                RowBox[{\(u\_\(4, 1, 3\)\), \(\[Nu]\_1\), 
                  InterpretationBox[
                    StyleBox[\(1\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 1, "+"],
                    Editable->True], 
                  RowBox[{"(", 
                    RowBox[{
                      InterpretationBox[
                        StyleBox[\(3\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 3, "-"],
                        Editable->True], "-", 
                      InterpretationBox[
                        StyleBox[\(4\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 4, "-"],
                        Editable->True]}], ")"}]}], 
                "+", \(\(u\_\(1, 3, 4\)\) \((d - \[Nu]\_1 - 2  \[Nu]\_3)\)\), 
                "+", \(2 \( m\_3\%2\) \((\[Nu]\_1 - \[Nu]\_3)\)\)}], ")"}], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["V",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_4\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TVI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3], 
                Subscript[ \[Nu], 4]}],
              Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
    \(s\_51 = OperatorApplyV[e\_51]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (51)", "Subsection",
  CellTags->"T1.6.17.1"],

Cell[BoxData[
    \(s\_51\)], "Input"],

Cell[BoxData[
    \(h\_51 = s\_51 /. \[Nu]\_1 \[Rule] \[Nu]\_1 - 1\)], "Input"],

Cell[BoxData[
    RowBox[{\(f\_51\), "=", 
      RowBox[{
        StyleBox["MakeFun",
          FontColor->RGBColor[1, 0.6, 0.6]], "[", 
        RowBox[{\(h\_51\), ",", "\"\<(51)\>\"", ",", 
          RowBox[{
            StyleBox["IFF",
              FontColor->RGBColor[0.6, 0.4, 1]], 
            "[", \(\[Nu]\_1 > 1 && \[CapitalDelta]\_\(1, 3, 4\) =!= 0\), 
            "]"}]}], "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CheckTVIRecursion[f\_51]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`"Off"\)], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (52)", "Subsection",
  CellTags->"T1.6.18.1"],

Cell[TextData[{
  "general ",
  Cell[BoxData[
      \(m\_i\%2\)]]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(e\_52\), "=", 
        RowBox[{
          RowBox[{\(\[CapitalDelta]\_\(2, 4, 6\)\), \(\[Nu]\_2\), 
            InterpretationBox[
              StyleBox[\(2\^+\),
                FontWeight->"Bold"],
              Schiebe[ 2, "+"],
              Editable->True], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["V",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_4\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TVI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3], 
                Subscript[ \[Nu], 4]}],
              Editable->True]}], "==", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"2", \(m\_1\%2\), \(\[Nu]\_1\), 
                  InterpretationBox[
                    StyleBox[\(1\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 1, "+"],
                    Editable->True], 
                  RowBox[{"(", 
                    RowBox[{
                      InterpretationBox[
                        StyleBox[\(4\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 4, "-"],
                        Editable->True], "-", 
                      InterpretationBox[
                        StyleBox[\(2\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 2, "-"],
                        Editable->True]}], ")"}]}], "+", 
                RowBox[{"2", \(m\_3\%2\), \(\[Nu]\_3\), 
                  InterpretationBox[
                    StyleBox[\(3\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 3, "+"],
                    Editable->True], 
                  RowBox[{"(", 
                    RowBox[{
                      InterpretationBox[
                        StyleBox[\(4\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 4, "-"],
                        Editable->True], "-", 
                      InterpretationBox[
                        StyleBox[\(2\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 2, "-"],
                        Editable->True]}], ")"}]}], "-", 
                RowBox[{"2", \(m\_4\%2\), \(\[Nu]\_4\), 
                  InterpretationBox[
                    StyleBox[\(4\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 4, "+"],
                    Editable->True], 
                  InterpretationBox[
                    StyleBox[\(2\^-\),
                      FontWeight->"Bold"],
                    Schiebe[ 2, "-"],
                    Editable->True]}], "+", 
                RowBox[{\((2  m\_2\%2 - u\_\(4, 2, 6\))\), \(\[Nu]\_2\), 
                  InterpretationBox[
                    StyleBox[\(2\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 2, "+"],
                    Editable->True], 
                  InterpretationBox[
                    StyleBox[\(4\^-\),
                      FontWeight->"Bold"],
                    Schiebe[ 4, "-"],
                    Editable->True]}], "-", 
                RowBox[{\((\[CapitalSigma]\_4 + 2)\), 
                  RowBox[{"(", 
                    RowBox[{
                      InterpretationBox[
                        StyleBox[\(4\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 4, "-"],
                        Editable->True], "-", 
                      InterpretationBox[
                        StyleBox[\(2\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 2, "-"],
                        Editable->True]}], ")"}]}], 
                "+", \(\(u\_\(2, 4, 6\)\) \((d - 3  \[Nu]\_2)\)\), 
                "+", \(2 \( m\_4\%2\) \((\[Nu]\_4 - \[Nu]\_2)\)\)}], ")"}], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["V",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_4\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TVI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3], 
                Subscript[ \[Nu], 4]}],
              Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
    \(s\_52 = OperatorApplyV[e\_52]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (52)", "Subsection",
  CellTags->"T1.6.19.1"],

Cell[BoxData[
    \(h\_52 = \[Nu]explicit[
          s\_52] /. \[Nu]\_2 \[Rule] \[Nu]\_2 - 1\)], "Input"],

Cell[BoxData[
    RowBox[{\(f\_52\), "=", 
      RowBox[{
        StyleBox["MakeFun",
          FontColor->RGBColor[1, 0.6, 0.6]], "[", 
        RowBox[{\(h\_52\), ",", "\"\<(52)\>\"", ",", 
          RowBox[{
            StyleBox["IFF",
              FontColor->RGBColor[0.6, 0.4, 1]], 
            "[", \(\[Nu]\_2 > 1 && \[CapitalDelta]\_\(2, 4, 6\) =!= 0\), 
            "]"}]}], "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CheckTVIRecursion[f\_52]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`"Off"\)], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (53)", "Subsection",
  CellTags->"T1.6.20.1"],

Cell[BoxData[
    \(h\_53 = 
      Interchange[s\_51, 
          1 \[LeftRightArrow] 3] /. \[Nu]\_3 \[Rule] \[Nu]\_3 - 1\)], "Input"],

Cell[BoxData[
    RowBox[{\(f\_53\), "=", 
      RowBox[{
        StyleBox["MakeFun",
          FontColor->RGBColor[1, 0.6, 0.6]], "[", 
        RowBox[{\(h\_53\), ",", "\"\<(53)\>\"", ",", 
          RowBox[{
            StyleBox["IFF",
              FontColor->RGBColor[0.6, 0.4, 1]], 
            "[", \(\[Nu]\_3 > 1 && \[CapitalDelta]\_\(3, 1, 4\) =!= 0\), 
            "]"}]}], "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CheckTVIRecursion[f\_53]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`"Off"\)], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (54)", "Subsection",
  CellTags->"T1.6.21.1"],

Cell[TextData[{
  "general ",
  Cell[BoxData[
      \(m\_i\%2\)]]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(e\_54\), "=", 
        RowBox[{
          RowBox[{"2", \(m\_3\%2\), \(\[Nu]\_3\), 
            InterpretationBox[
              StyleBox[\(3\^+\),
                FontWeight->"Bold"],
              Schiebe[ 3, "+"],
              Editable->True], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["V",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_4\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TVI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3], 
                Subscript[ \[Nu], 4]}],
              Editable->True]}], "==", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{\(u\_\(4, 1, 3\)\), \(\[Nu]\_1\), 
                  InterpretationBox[
                    StyleBox[\(1\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 1, "+"],
                    Editable->True]}], "+", 
                RowBox[{\(\[Nu]\_1\), 
                  InterpretationBox[
                    StyleBox[\(1\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 1, "+"],
                    Editable->True], 
                  RowBox[{"(", 
                    RowBox[{
                      InterpretationBox[
                        StyleBox[\(4\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 4, "-"],
                        Editable->True], "-", 
                      InterpretationBox[
                        StyleBox[\(3\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 3, "-"],
                        Editable->True]}], ")"}]}], "+", "\n", 
                "\t\t\t\t", \((d - \[Nu]\_1 - 2  \[Nu]\_3)\)}], ")"}], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["V",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_4\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TVI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3], 
                Subscript[ \[Nu], 4]}],
              Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
    \(s\_54 = OperatorApplyV[e\_54]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (54)", "Subsection",
  CellTags->"T1.6.22.1"],

Cell[BoxData[
    \(h\_54 = s\_54 /. \[Nu]\_3 \[Rule] \[Nu]\_3 - 1\)], "Input"],

Cell[BoxData[
    RowBox[{\(f\_54\), "=", 
      RowBox[{
        StyleBox["MakeFun",
          FontColor->RGBColor[1, 0.6, 0.6]], "[", 
        RowBox[{\(h\_54\), ",", "\"\<(54)\>\"", ",", 
          RowBox[{
            StyleBox["IFF",
              FontColor->RGBColor[0.6, 0.4, 1]], "[", 
            " ", \(\[Nu]\_3 > 1 && \ m3 =!= 0\), "]"}]}], "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CheckTVIRecursion[f\_54]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`"Off"\)], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (55)", "Subsection",
  CellTags->"T1.6.23.1"],

Cell[TextData[{
  "general ",
  Cell[BoxData[
      \(m\_i\%2\)]]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(e\_55\), "=", 
        RowBox[{
          RowBox[{"2", " ", \(m\_4\%2\), \(\[Nu]\_4\), 
            InterpretationBox[
              StyleBox[\(4\^+\),
                FontWeight->"Bold"],
              Schiebe[ 4, "+"],
              Editable->True], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["V",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_4\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TVI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3], 
                Subscript[ \[Nu], 4]}],
              Editable->True]}], "==", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{\(u\_\(3, 1, 4\)\), \(\[Nu]\_1\), 
                  InterpretationBox[
                    StyleBox[\(1\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 1, "+"],
                    Editable->True]}], "+", 
                RowBox[{\(u\_\(6, 2, 4\)\), \(\[Nu]\_2\), 
                  InterpretationBox[
                    StyleBox[\(2\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 2, "+"],
                    Editable->True]}], "+", "\n", "\t\t\t\t", 
                RowBox[{\(\[Nu]\_1\), 
                  InterpretationBox[
                    StyleBox[\(1\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 1, "+"],
                    Editable->True], 
                  RowBox[{"(", 
                    RowBox[{
                      InterpretationBox[
                        StyleBox[\(3\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 3, "-"],
                        Editable->True], "-", 
                      InterpretationBox[
                        StyleBox[\(4\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 4, "-"],
                        Editable->True]}], ")"}]}], "-", 
                RowBox[{\(\[Nu]\_2\), 
                  InterpretationBox[
                    StyleBox[\(2\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 2, "+"],
                    Editable->True], 
                  InterpretationBox[
                    StyleBox[\(4\^-\),
                      FontWeight->"Bold"],
                    Schiebe[ 4, "-"],
                    Editable->True]}], 
                "+", \((d - \[Nu]\_1 - \[Nu]\_2 - 2  \[Nu]\_4)\)}], ")"}], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["V",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_4\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TVI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3], 
                Subscript[ \[Nu], 4]}],
              Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
    \(s\_55 = OperatorApplyV[e\_55]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (55)", "Subsection",
  CellTags->"T1.6.24.1"],

Cell[BoxData[
    \(h\_55 = s\_55 /. \[Nu]\_4 \[Rule] \[Nu]\_4 - 1\)], "Input"],

Cell[BoxData[
    RowBox[{\(f\_55\), "=", 
      RowBox[{
        StyleBox["MakeFun",
          FontColor->RGBColor[1, 0.6, 0.6]], "[", 
        RowBox[{\(h\_55\), ",", "\"\<(55)\>\"", ",", 
          RowBox[{
            StyleBox["IFF",
              FontColor->RGBColor[0.6, 0.4, 1]], 
            "[", \(\[Nu]\_4 > 1 && \ m4 =!= 0\  && \ \[Nu]\_3 > 1\), "]"}]}], 
        "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CheckTVIRecursion[f\_55]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`"Off"\)], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (56)", "Subsection",
  CellTags->"T1.6.25.1"],

Cell[TextData[{
  "general ",
  Cell[BoxData[
      \(m\_i\%2\)]]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(e\_56\), "=", 
        RowBox[{
          RowBox[{"2", " ", \(m\_4\%2\), \(\[Nu]\_4\), 
            InterpretationBox[
              StyleBox[\(4\^+\),
                FontWeight->"Bold"],
              Schiebe[ 4, "+"],
              Editable->True], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["V",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_4\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TVI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3], 
                Subscript[ \[Nu], 4]}],
              Editable->True]}], "==", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{\(-2\), \(m\_1\%2\), \(\[Nu]\_1\), 
                  InterpretationBox[
                    StyleBox[\(1\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 1, "+"],
                    Editable->True]}], "+", 
                RowBox[{\(u\_\(6, 2, 4\)\), \(\[Nu]\_2\), 
                  InterpretationBox[
                    StyleBox[\(2\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 2, "+"],
                    Editable->True]}], "-", 
                RowBox[{"2", \(m\_3\%2\), \(\[Nu]\_3\), 
                  InterpretationBox[
                    StyleBox[\(3\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 3, "+"],
                    Editable->True]}], "-", "\n", "\t\t\t\t", 
                RowBox[{\(\[Nu]\_2\), 
                  InterpretationBox[
                    StyleBox[\(2\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 2, "+"],
                    Editable->True], 
                  InterpretationBox[
                    StyleBox[\(4\^-\),
                      FontWeight->"Bold"],
                    Schiebe[ 4, "-"],
                    Editable->True]}], 
                "+", \((2  d - 2  \[Nu]\_1 - \[Nu]\_2 - 2  \[Nu]\_3 - 
                    2  \[Nu]\_4)\)}], ")"}], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["V",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_4\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TVI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3], 
                Subscript[ \[Nu], 4]}],
              Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
    \(s\_56 = OperatorApplyV[e\_56]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (56)", "Subsection",
  CellTags->"T1.6.26.1"],

Cell[BoxData[
    \(h\_56 = s\_56 /. \[Nu]\_4 \[Rule] \[Nu]\_4 - 1\)], "Input"],

Cell[BoxData[
    RowBox[{\(f\_56\), "=", 
      RowBox[{
        StyleBox["MakeFun",
          FontColor->RGBColor[1, 0.6, 0.6]], "[", 
        RowBox[{\(h\_56\), ",", "\"\<(56)\>\"", ",", 
          RowBox[{
            StyleBox["IFF",
              FontColor->RGBColor[0.6, 0.4, 1]], 
            "[", \(\[Nu]\_4 > 1 && \ m4 =!= 0\  && \ \[Nu]\_3 === 1\), 
            "]"}]}], "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CheckTVIRecursion[f\_56]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`"Off"\)], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (59)", "Subsection",
  CellTags->"T1.6.27.1"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\_\(1, 3, 4\)\)]],
  "== 0 but all  ",
  Cell[BoxData[
      \(m\_i\%2\)]],
  " != 0"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(e\_59\), "=", 
        RowBox[{
          
          RowBox[{\((2 \( m\_1\%2\) \(u\_\(1, 3, 4\)\) \((d - \[Nu]\_1 - 
                      2  \[Nu]\_3)\) + \((\[Nu]\_3 - 1)\) 
                  u\_\(4, 1, 3\)\%2 + \n\t
                4 \( m\_1\%2\) \(m\_3\%2\) \((\[Nu]\_1 - \[Nu]\_3)\))\), 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["V",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_4\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TVI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3], 
                Subscript[ \[Nu], 4]}],
              Editable->True]}], "==", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{\(u\_\(4, 1, 3\)\), \(\[Nu]\_3\), 
                  InterpretationBox[
                    StyleBox[\(3\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 3, "+"],
                    Editable->True], 
                  InterpretationBox[
                    StyleBox[\(4\^-\),
                      FontWeight->"Bold"],
                    Schiebe[ 4, "-"],
                    Editable->True], 
                  RowBox[{"(", 
                    RowBox[{
                      InterpretationBox[
                        StyleBox[\(4\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 4, "-"],
                        Editable->True], "-", 
                      InterpretationBox[
                        StyleBox[\(1\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 1, "-"],
                        Editable->True]}], ")"}]}], "-", "\n", "\t", 
                RowBox[{"4", \(m\_1\%2\), \(m\_3\%2\), \(\[Nu]\_3\), 
                  InterpretationBox[
                    StyleBox[\(3\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 3, "+"],
                    Editable->True], 
                  InterpretationBox[
                    StyleBox[\(1\^-\),
                      FontWeight->"Bold"],
                    Schiebe[ 1, "-"],
                    Editable->True]}], "+", 
                
                RowBox[{\((4 \( m\_1\%2\) m\_3\%2 + 
                      u\_\(4, 1, 3\)\%2)\), \(\[Nu]\_3\), 
                  InterpretationBox[
                    StyleBox[\(3\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 3, "+"],
                    Editable->True], 
                  InterpretationBox[
                    StyleBox[\(4\^-\),
                      FontWeight->"Bold"],
                    Schiebe[ 4, "-"],
                    Editable->True]}], "+", 
                RowBox[{\(u\_\(4, 1, 3\)\), \((\[Nu]\_3 - 1)\), 
                  InterpretationBox[
                    StyleBox[\(1\^-\),
                      FontWeight->"Bold"],
                    Schiebe[ 1, "-"],
                    Editable->True]}], "-", "\n", "\t\t", 
                
                RowBox[{\((d - 2  \[Nu]\_1 - \[Nu]\_3 + 1)\), \(u\_\(4, 1, 
                      3\)\), 
                  InterpretationBox[
                    StyleBox[\(3\^-\),
                      FontWeight->"Bold"],
                    Schiebe[ 3, "-"],
                    Editable->True]}], "+", 
                
                RowBox[{\((d - 2  \[Nu]\_1 - 2  \[Nu]\_3 + 1)\), \(u\_\(4, 1, 
                      3\)\), 
                  InterpretationBox[
                    StyleBox[\(4\^-\),
                      FontWeight->"Bold"],
                    Schiebe[ 4, "-"],
                    Editable->True]}]}], ")"}], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["V",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_4\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TVI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3], 
                Subscript[ \[Nu], 4]}],
              Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
    \(s\_59 = OperatorApplyV[e\_59]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (59)", "Subsection",
  CellTags->"T1.6.28.1"],

Cell[BoxData[
    \(h\_59 = s\_59\)], "Input"],

Cell[BoxData[
    RowBox[{\(f\_59\), "=", 
      RowBox[{
        StyleBox["MakeFun",
          FontColor->RGBColor[1, 0.6, 0.6]], "[", 
        RowBox[{\(h\_59\), ",", "\"\<(59)\>\"", ",", 
          RowBox[{
            StyleBox["IFF",
              FontColor->RGBColor[0.6, 0.4, 1]], 
            "[", \(\[CapitalDelta]\_\(1, 3, 4\) == 
                0 && \((4\ m\_3\%2\ m\_1\%2 - 4\ m\_3\%2\ \[Nu]\_3\ m\_1\%2 + 
                    2\ d\ u\_\(1, 3, 4\)\ m\_1\%2 - 
                    4\ \[Nu]\_3\ u\_\(1, 3, 4\)\ m\_1\%2 - 
                    2\ u\_\(1, 3, 4\)\ m\_1\%2 + \[Nu]\_3\ u\_\(4, 1, 3\)\%2 \
- u\_\(4, 1, 3\)\%2)\)\ \  =!= 0 && n1\  === \ 1 && \ n2\  === \ 1 && \ 
              n4\  === \ 1 && MatchQ[d, _Integer]\), "]"}]}], 
        "]"}]}]], "Input"],

Cell["CheckTVIRecursion not applicable .", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (60) ", "Subsection",
  CellTags->"T1.6.29.1"],

Cell[TextData[{
  "general ",
  Cell[BoxData[
      \(m\_i\%2\)]]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(e\_60\), "=", 
        RowBox[{
          RowBox[{"2", \(m\_1\%2\), \(\[Nu]\_1\), 
            InterpretationBox[
              StyleBox[\(1\^+\),
                FontWeight->"Bold"],
              Schiebe[ 1, "+"],
              Editable->True], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["V",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_4\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TVI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3], 
                Subscript[ \[Nu], 4]}],
              Editable->True]}], "==", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{\(u\_\(4, 1, 3\)\), \(\[Nu]\_3\), 
                  InterpretationBox[
                    StyleBox[\(3\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 3, "+"],
                    Editable->True]}], "+", 
                RowBox[{\(\[Nu]\_3\), 
                  InterpretationBox[
                    StyleBox[\(3\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 3, "+"],
                    Editable->True], 
                  RowBox[{"(", 
                    RowBox[{
                      InterpretationBox[
                        StyleBox[\(4\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 4, "-"],
                        Editable->True], "-", 
                      InterpretationBox[
                        StyleBox[\(1\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 1, "-"],
                        Editable->True]}], ")"}]}], "+", "\n", 
                "\t\t\t\t", \((d - \[Nu]\_3 - 2  \[Nu]\_1)\)}], ")"}], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["V",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_4\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TVI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3], 
                Subscript[ \[Nu], 4]}],
              Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
    \(s\_60 = OperatorApplyV[e\_60]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (60)", "Subsection",
  CellTags->"T1.6.30.1"],

Cell[BoxData[
    \(h\_60 = s\_60 /. \[Nu]\_1 \[Rule] \[Nu]\_1 - 1\)], "Input"],

Cell[BoxData[
    RowBox[{\(notnecessaryf\_60\), "=", 
      RowBox[{
        StyleBox["MakeFun",
          FontColor->RGBColor[1, 0.6, 0.6]], "[", 
        RowBox[{\(h\_60\), ",", "\"\<(60)\>\"", ",", 
          RowBox[{
            StyleBox["IFF",
              FontColor->RGBColor[0.6, 0.4, 1]], 
            "[", \(\[Nu]\_1 > 1 && \ m1 =!= 0\), "]"}]}], "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CheckTVIRecursion[notnecessaryf\_60]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`"Off"\)], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (61) ", "Subsection",
  CellTags->"T1.6.31.1"],

Cell[TextData[{
  " ( ",
  Cell[BoxData[
      \(m\_1\%2\)]],
  "== 0 && ",
  Cell[BoxData[
      \(m\_4\%2\)]],
  "== ",
  Cell[BoxData[
      \(m\_3\%2\)]],
  " )  \[DoubleLongRightArrow] ( ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\_\(1, 3, 4\)\)]],
  "== 0 )"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(e\_61\), "=", 
        RowBox[{
          RowBox[{\((d - 2  \[Nu]\_1 - \[Nu]\_3)\), 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["V",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_4\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TVI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3], 
                Subscript[ \[Nu], 4]}],
              Editable->True]}], "==", 
          RowBox[{\(\[Nu]\_3\), 
            InterpretationBox[
              StyleBox[\(3\^+\),
                FontWeight->"Bold"],
              Schiebe[ 3, "+"],
              Editable->True], 
            RowBox[{"(", 
              RowBox[{
                InterpretationBox[
                  StyleBox[\(1\^-\),
                    FontWeight->"Bold"],
                  Schiebe[ 1, "-"],
                  Editable->True], "-", 
                InterpretationBox[
                  StyleBox[\(4\^-\),
                    FontWeight->"Bold"],
                  Schiebe[ 4, "-"],
                  Editable->True]}], ")"}], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["V",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_4\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TVI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3], 
                Subscript[ \[Nu], 4]}],
              Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
    \(s\_61 = OperatorApplyV[e\_61]\)], "Input"],

Cell[TextData[{
  "For  ( ",
  Cell[BoxData[
      \(m\_3\%2\)]],
  "== 0 && ",
  Cell[BoxData[
      \(m\_4\%2\)]],
  "== ",
  Cell[BoxData[
      \(m\_1\%2\)]],
  " )  \[DoubleLongRightArrow] ( ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\_\(1, 3, 4\)\)]],
  "== 0 )\nuse ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              InterpretationBox[
                SubsuperscriptBox[
                  StyleBox["V",
                    SingleLetterItalics->False,
                    FontWeight->"Bold"], 
                  RowBox[{
                    FormBox[\(\[Nu]\_1\),
                      "TraditionalForm"], 
                    FormBox[\(\[Nu]\_2\),
                      "TraditionalForm"], 
                    FormBox[\(\[Nu]\_3\),
                      "TraditionalForm"], 
                    FormBox[\(\[Nu]\_4\),
                      "TraditionalForm"]}], 
                  RowBox[{"(", 
                    FormBox["d",
                      "TraditionalForm"], ")"}]],
                TVI[ d, {
                  Subscript[ \[Nu], 1], 
                  Subscript[ \[Nu], 2], 
                  Subscript[ \[Nu], 3], 
                  Subscript[ \[Nu], 4]}],
                Editable->True], "==", 
              InterpretationBox[
                SubsuperscriptBox[
                  StyleBox["V",
                    SingleLetterItalics->False,
                    FontWeight->"Bold"], 
                  RowBox[{
                    FormBox[\(\[Nu]\_3\),
                      "TraditionalForm"], 
                    FormBox[\(\[Nu]\_2\),
                      "TraditionalForm"], 
                    FormBox[\(\[Nu]\_1\),
                      "TraditionalForm"], 
                    FormBox[\(\[Nu]\_4\),
                      "TraditionalForm"]}], 
                  RowBox[{"(", 
                    FormBox["d",
                      "TraditionalForm"], ")"}]],
                TVI[ d, {
                  Subscript[ \[Nu], 1], 
                  Subscript[ \[Nu], 2], 
                  Subscript[ \[Nu], 3], 
                  Subscript[ \[Nu], 4]}],
                Editable->True]}], ")"}], " "}], TextForm]]],
  " and switch the masses accordingly."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (61)", "Subsection",
  CellTags->"T1.6.32.1"],

Cell[TextData[{
  "( ",
  Cell[BoxData[
      \(m\_1\%2\)]],
  "== 0 && ",
  Cell[BoxData[
      \(m\_4\%2\)]],
  "== ",
  Cell[BoxData[
      \(m\_3\%2\)]],
  " )  \[DoubleLongRightArrow] ( ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\_\(1, 3, 4\)\)]],
  "== 0 )"
}], "Text"],

Cell[BoxData[
    \(h\_61 = s\_61\)], "Input"],

Cell[BoxData[
    RowBox[{\(f\_61\), "=", 
      RowBox[{
        StyleBox["MakeFun",
          FontColor->RGBColor[1, 0.6, 0.6]], "[", 
        RowBox[{\(h\_61\), ",", "\"\<(61)\>\"", ",", 
          RowBox[{
            StyleBox["IFF",
              FontColor->RGBColor[0.6, 0.4, 1]], "[", 
            RowBox[{
              RowBox[{
                InterpretationBox[\(m\_1\),
                  m1], "===", "0"}], "&&", 
              RowBox[{
                InterpretationBox[\(m\_3\),
                  m3], "===", 
                InterpretationBox[\(m\_4\),
                  m4]}]}], "]"}], ",", \({n1 :> 1, n4 :> 1}\)}], 
        "]"}]}]], "Input"],

Cell["CheckTVIRecursion not applicable .", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (6153)", "Subsection",
  CellTags->"T1.6.33.1"],

Cell[TextData[{
  " ( ",
  Cell[BoxData[
      \(m\_3\%2\)]],
  "== 0 && ",
  Cell[BoxData[
      \(m\_4\%2\)]],
  "== ",
  Cell[BoxData[
      \(m\_1\%2\)]],
  ")  \[DoubleLongRightArrow] ( ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\_\(1, 3, 4\)\)]],
  "== 0 )"
}], "Text"],

Cell[BoxData[
    \(h\_6153 = Interchange[s\_61, 1 \[LeftRightArrow] 3]\)], "Input"],

Cell[BoxData[
    RowBox[{\(f\_6153\), "=", 
      RowBox[{
        StyleBox["MakeFun",
          FontColor->RGBColor[1, 0.6, 0.6]], "[", 
        RowBox[{\(h\_6153\), ",", "\"\<(6153)\>\"", ",", 
          RowBox[{
            StyleBox["IFF",
              FontColor->RGBColor[0.6, 0.4, 1]], "[", 
            RowBox[{
              RowBox[{
                InterpretationBox[\(m\_3\),
                  m3], "===", "0"}], "&&", 
              RowBox[{
                InterpretationBox[\(m\_1\),
                  m1], "===", 
                InterpretationBox[\(m\_4\),
                  m4]}]}], "]"}], ",", \({n3 :> 1, n4 :> 1}\)}], 
        "]"}]}]], "Input"],

Cell["CheckTVIRecursion not applicable .", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (62) ", "Subsection",
  CellTags->"T1.6.34.1"],

Cell[TextData[{
  "( ",
  Cell[BoxData[
      \(m\_4\%2\)]],
  "== 0 && ",
  Cell[BoxData[
      \(m\_1\%2\)]],
  "== ",
  Cell[BoxData[
      \(m\_3\%2\)]],
  " ) \[DoubleLongRightArrow] (",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\[CapitalDelta]\_\(1, 3, 4\)\)\)\)]],
  "== 0 )\nlower ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu]\_2\)]],
  " via (52) to one first"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(e\_62\), "=", 
        RowBox[{
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                InterpretationBox[\(p\^2\),
                  PP], "-", \(m\_2\%2\)}], 
              ")"}], \((\[Nu]\_1 - 2  \[Nu]\_2 + 2  \[Nu]\_4 + 2)\), 
            InterpretationBox[
              StyleBox[\(4\^+\),
                FontWeight->"Bold"],
              Schiebe[ 4, "+"],
              Editable->True], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["V",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_4\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TVI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3], 
                Subscript[ \[Nu], 4]}],
              Editable->True]}], "==", "\n", "\t\t", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{\((m\_1\%2 - u\_\(6, 1, 2\))\), \(\[Nu]\_1\), 
                  InterpretationBox[
                    StyleBox[\(1\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 1, "+"],
                    Editable->True]}], "+", 
                RowBox[{"4", \(m\_2\%2\), \(\[Nu]\_2\), 
                  InterpretationBox[
                    StyleBox[\(2\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 2, "+"],
                    Editable->True]}], "+", 
                RowBox[{"2", \(m\_1\%2\), \(\[Nu]\_3\), 
                  InterpretationBox[
                    StyleBox[\(3\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 3, "+"],
                    Editable->True]}], "+", "\n", "\t\t\t\t", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{\(\[CapitalSigma]\_4\), "-", 
                      RowBox[{"2", \(m\_1\%2\), \(\[Nu]\_1\), 
                        InterpretationBox[
                          StyleBox[\(1\^+\),
                            FontWeight->"Bold"],
                          Schiebe[ 1, "+"],
                          Editable->True]}], "-", 
                      RowBox[{"2", \(m\_1\%2\), \(\[Nu]\_3\), 
                        InterpretationBox[
                          StyleBox[\(3\^+\),
                            FontWeight->"Bold"],
                          Schiebe[ 3, "+"],
                          Editable->True]}]}], ")"}], 
                  InterpretationBox[
                    StyleBox[\(2\^-\),
                      FontWeight->"Bold"],
                    Schiebe[ 2, "-"],
                    Editable->True], 
                  InterpretationBox[
                    StyleBox[\(4\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 4, "+"],
                    Editable->True]}], "+", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      InterpretationBox[\(p\^2\),
                        PP], "-", \(m\_2\%2\)}], ")"}], \(\[Nu]\_1\), 
                  InterpretationBox[
                    StyleBox[\(1\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 1, "+"],
                    Editable->True], 
                  InterpretationBox[
                    StyleBox[\(4\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 4, "+"],
                    Editable->True], 
                  InterpretationBox[
                    StyleBox[\(3\^-\),
                      FontWeight->"Bold"],
                    Schiebe[ 3, "-"],
                    Editable->True]}], "-", "\n", 
                "\t\t\t\t", \(\[CapitalSigma]\_4\)}], ")"}], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["V",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_4\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TVI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3], 
                Subscript[ \[Nu], 4]}],
              Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
    \(s\_62 = OperatorApplyV[e\_62]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (62)", "Subsection",
  CellTags->"T1.6.35.1"],

Cell[BoxData[
    \(h\_62 = \[Nu]explicit[
          s\_62] /. \[Nu]\_4 \[Rule] \[Nu]\_4 - 1\)], "Input"],

Cell[BoxData[
    RowBox[{\(f\_62\), "=", 
      RowBox[{
        StyleBox["MakeFun",
          FontColor->RGBColor[1, 0.6, 0.6]], "[", 
        RowBox[{\(h\_62\), ",", "\"\<(62)\>\"", ",", 
          RowBox[{
            StyleBox["IFF",
              FontColor->RGBColor[0.6, 0.4, 1]], "[", 
            RowBox[{
              RowBox[{
                InterpretationBox[\(p\^2\),
                  PP], "=!=", 
                InterpretationBox[\(m\_2\%2\),
                  Power[ m2, 2]]}], 
              "&&", \(\[Nu]\_1 - 2\ \[Nu]\_2 + 2\ \[Nu]\_4 =!= 0\)}], "]"}], 
          ",", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{
                InterpretationBox[\(m\_4\),
                  m4], "\[RuleDelayed]", "0"}], ",", 
              RowBox[{
                InterpretationBox[\(m\_3\),
                  m3], "\[RuleDelayed]", 
                InterpretationBox[\(m\_1\),
                  m1]}], ",", \(n2 \[RuleDelayed] 1\)}], "}"}]}], 
        "]"}]}]], "Input"],

Cell["CheckTVIRecursion not applicable .", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (63) ", "Subsection",
  CellTags->"T1.6.36.1"],

Cell[TextData[{
  Cell[BoxData[
      \(m\_4\%2\)]],
  "== 0  && ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\[CapitalDelta]\_\(1, 3, 4\)\)\)\)]],
  " != 0\nreplace (55) by the following"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(e\_63\), "=", 
        RowBox[{
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                InterpretationBox[\(p\^2\),
                  PP], "-", \(m\_2\%2\)}], 
              ")"}], \((\((m\_3\%2 - m\_1\%2)\) \((d - 2  \[Nu]\_2 - 
                      2  \[Nu]\_3 + 2  \[Nu]\_4)\) + 
                2 \( m\_3\%2\) \((\[Nu]\_3 - \[Nu]\_1)\))\), 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["V",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_4\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TVI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3], 
                Subscript[ \[Nu], 4]}],
              Editable->True]}], "==", "\n", "\t\t", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{\((m\_1\%2 - m\_3\%2)\), 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{"2", \(m\_1\%2\), \(\[Nu]\_1\), 
                              InterpretationBox[
                                StyleBox[\(1\^+\),
                                  FontWeight->"Bold"],
                                Schiebe[ 1, "+"],
                                Editable->True]}], "+", 
                            RowBox[{"2", \(m\_3\%2\), \(\[Nu]\_3\), 
                              InterpretationBox[
                                StyleBox[\(3\^+\),
                                  FontWeight->"Bold"],
                                Schiebe[ 3, "+"],
                                Editable->True]}], 
                            "-", \(\[CapitalSigma]\_4\), "-", "2"}], ")"}], 
                        RowBox[{"(", 
                          RowBox[{
                            InterpretationBox[
                              StyleBox[\(2\^-\),
                                FontWeight->"Bold"],
                              Schiebe[ 2, "-"],
                              Editable->True], "-", 
                            InterpretationBox[
                              StyleBox[\(4\^-\),
                                FontWeight->"Bold"],
                              Schiebe[ 4, "-"],
                              Editable->True]}], ")"}]}], "-", 
                      RowBox[{"4", \(m\_2\%2\), \(\[Nu]\_2\), 
                        InterpretationBox[
                          StyleBox[\(2\^+\),
                            FontWeight->"Bold"],
                          Schiebe[ 2, "+"],
                          Editable->True], 
                        InterpretationBox[
                          StyleBox[\(4\^-\),
                            FontWeight->"Bold"],
                          Schiebe[ 4, "-"],
                          Editable->True]}]}], ")"}]}], "+", "\n", "\t\t\t\t",
                 
                RowBox[{"2", 
                  RowBox[{"(", 
                    RowBox[{
                      InterpretationBox[\(p\^2\),
                        PP], "-", \(m\_2\%2\)}], ")"}], 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{\(m\_3\%2\), \(\[Nu]\_3\), 
                        InterpretationBox[
                          StyleBox[\(3\^+\),
                            FontWeight->"Bold"],
                          Schiebe[ 3, "+"],
                          Editable->True], 
                        RowBox[{"(", 
                          RowBox[{
                            InterpretationBox[
                              StyleBox[\(1\^-\),
                                FontWeight->"Bold"],
                              Schiebe[ 1, "-"],
                              Editable->True], "-", 
                            InterpretationBox[
                              StyleBox[\(4\^-\),
                                FontWeight->"Bold"],
                              Schiebe[ 4, "-"],
                              Editable->True]}], ")"}]}], "+", 
                      RowBox[{\(m\_1\%2\), \(\[Nu]\_1\), 
                        InterpretationBox[
                          StyleBox[\(1\^+\),
                            FontWeight->"Bold"],
                          Schiebe[ 1, "+"],
                          Editable->True], 
                        RowBox[{"(", 
                          RowBox[{
                            InterpretationBox[
                              StyleBox[\(4\^-\),
                                FontWeight->"Bold"],
                              Schiebe[ 4, "-"],
                              Editable->True], "-", 
                            InterpretationBox[
                              StyleBox[\(3\^-\),
                                FontWeight->"Bold"],
                              Schiebe[ 3, "-"],
                              Editable->True]}], ")"}]}]}], ")"}]}]}], ")"}], 
            
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["V",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_4\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TVI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3], 
                Subscript[ \[Nu], 4]}],
              Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
    \(s\_63 = OperatorApplyV[e\_63]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (63)", "Subsection",
  CellTags->"T1.6.37.1"],

Cell[TextData[{
  Cell[BoxData[
      \(m\_4\%2\)]],
  "== 0  && ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\[CapitalDelta]\_\(1, 3, 4\)\)\)\)]],
  " != 0"
}], "Text"],

Cell[BoxData[
    \(h\_63 = \[Nu]explicit[s\_63]\)], "Input"],

Cell[BoxData[
    RowBox[{\(f\_63\), "=", 
      RowBox[{
        StyleBox["MakeFun",
          FontColor->RGBColor[1, 0.6, 0.6]], "[", 
        RowBox[{\(h\_63\), ",", "\"\<(63)\>\"", ",", 
          RowBox[{
            StyleBox["IFF",
              FontColor->RGBColor[0.6, 0.4, 1]], 
            "[", \(PP\  =!= \ m2^2 && \(Cayley[1, 3, 4]\)[{m1, m2, m3, m4}] =!= 
                0\), "]"}], ",", 
          RowBox[{"{", 
            RowBox[{
              InterpretationBox[\(m\_4\),
                m4], "\[RuleDelayed]", "0"}], "}"}]}], "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CheckTVIRecursion[f\_63]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`"Off"\)], "Print"]
}, Open  ]],

Cell[BoxData[
    RowBox[{\(f\_63\), "=", 
      RowBox[{
        StyleBox["MakeFun",
          FontColor->RGBColor[1, 0.6, 0.6]], "[", 
        RowBox[{\(h\_63\), ",", "\"\<(63)\>\"", ",", 
          RowBox[{
            StyleBox["IFF",
              FontColor->RGBColor[0.6, 0.4, 1]], 
            "[", \(PP\  =!= \ m2^2 && \(Cayley[1, 3, 4]\)[{m1, m2, m3, m4}] =!= 
                0\), "]"}], ",", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{
                InterpretationBox[\(m\_4\),
                  m4], "\[RuleDelayed]", "0"}], ",", \(n1 :> 1\), 
              ",", \(n3 :> 1\)}], "}"}]}], "]"}]}]], "Input"],

Cell["\<\

CheckTVIRecursion not applicable for special indices since A's and 
B's appear .
\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (6552)", "Subsection",
  CellTags->"T1.6.38.1"],

Cell[BoxData[
    \(r\_6552 = \[Nu]explicit[e\_52] /. \[CapitalDelta]\_\(2, 4, 6\) -> 
          0\)], "Input"],

Cell[BoxData[
    RowBox[{"formal", "=", 
      RowBox[{
        RowBox[{
          RowBox[{"Solve", "[", 
            RowBox[{\(e\_55 /. TVI[__] -> 1\), ",", 
              InterpretationBox[
                StyleBox[\(4\^+\),
                  FontWeight->"Bold"],
                Schiebe[ 4, "+"],
                Editable->True]}], "]"}], "[", \([1, 1]\), "]"}], 
        "/.", \(\[Nu]\_2 -> \[Nu]\_2 - 1\)}]}]], "Input"],

Cell[BoxData[
    \(r\_6552 /. formal\)], "Input"],

Cell[BoxData[
    \(n\_6552 = OperatorApplyV[r\_6552 /. formal]\)], "Input"],

Cell[BoxData[
    \(n\_6552[\([2, 4]\)]\)], "Input"],

Cell[BoxData[
    \(s\_6552 = \(-n\_6552[\([2, 4]\)]\) == \((n\_6552[\([2]\)] - 
            n\_6552[\([2, 4]\)])\)\)], "Input"],

Cell[BoxData[
    RowBox[{\(f\_6552\), "=", 
      RowBox[{
        StyleBox["MakeFun",
          FontColor->RGBColor[1, 0.6, 0.6]], "[", 
        RowBox[{\(s\_6552\), ",", "\"\<(6552)\>\"", ",", 
          RowBox[{
            StyleBox["IFF",
              FontColor->RGBColor[0.6, 0.4, 1]], "[", 
            RowBox[{\(\[CapitalDelta]\_\(2, 4, 6\) === 0\), "&&", 
              RowBox[{
                RowBox[{"Expand", "[", 
                  RowBox[{
                    RowBox[{"2", " ", \((\[Nu]\_2 - \[Nu]\_4)\), " ", 
                      InterpretationBox[\(m\_4\%2\),
                        Power[ m4, 2]]}], 
                    "+", \(\((3\ \[Nu]\_2 - d)\)\ u\_\(2, 4, 6\)\), 
                    "+", \(\[Nu]\_2\ u\_\(6, 2, 4\)\)}], "]"}], "=!=", 
                "0"}]}], "]"}]}], "]"}]}]], "Input"],

Cell["CheckTVIRecursion not applicable .", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (6552)", "Subsection",
  CellTags->"T1.6.39.1"],

Cell[BoxData[
    \(r\_6552 = \[Nu]explicit[e\_52] /. \[CapitalDelta]\_\(2, 4, 6\) -> 
          0\)], "Input"],

Cell[BoxData[
    \(n\_6552 = OperatorApplyV[r\_6552]\)], "Input"],

Cell[BoxData[
    \(n\_6552[\([2, 5]\)]\)], "Input"],

Cell[BoxData[
    \(s\_6552 = \(-n\_6552[\([2, 5]\)]\) == \((n\_6552[\([2]\)] - 
            n\_6552[\([2, 5]\)])\)\)], "Input"],

Cell[BoxData[
    RowBox[{\(f\_6552\), "=", 
      RowBox[{
        StyleBox["MakeFun",
          FontColor->RGBColor[1, 0.6, 0.6]], "[", 
        RowBox[{\(s\_6552\), ",", "\"\<(6552)\>\"", ",", 
          RowBox[{
            StyleBox["IFF",
              FontColor->RGBColor[0.6, 0.4, 1]], 
            "[", \(\[CapitalDelta]\_\(2, 4, 6\) === 0 && 
              Expand[\((\(-2\)\ \[Nu]\_2\ m\_4\%2 + 2\ \[Nu]\_4\ m\_4\%2 + 
                      d\ u\_\(2, 4, 6\) - 3\ \[Nu]\_2\ u\_\(2, 4, 6\))\)] =!= 
                0\), "]"}]}], "]"}]}]], "Input"],

Cell["CheckTVIRecursion not applicable .", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (6553)", "Subsection",
  CellTags->"T1.6.40.1"],

Cell[BoxData[
    \(r\_6553 = \(\(\[Nu]explicit[s\_55] /. u\_\(3, 1, 4\) -> 0\) /. 
          u\_\(6, 2, 4\) -> 0\) /. m\_4 -> 0\)], "Input"],

Cell[BoxData[
    \(h\_6553 = \(-r\_6553[\([2, 1]\)]\) == \((r\_6553[\([2]\)] - 
            r\_6553[\([2, 1]\)])\)\)], "Input"],

Cell[BoxData[
    RowBox[{\(f\_6553\), "=", 
      RowBox[{
        StyleBox["MakeFun",
          FontColor->RGBColor[1, 0.6, 0.6]], "[", 
        RowBox[{\(h\_6553\), ",", "\"\<(6553)\>\"", ",", 
          RowBox[{
            StyleBox["IFF",
              FontColor->RGBColor[0.6, 0.4, 1]], 
            "[", \(u\_\(6, 2, 4\) === 0 && u\_\(1, 3, 4\) === 0\), "]"}], 
          ",", \(m4 :> 0\)}], "]"}]}]], "Input"],

Cell["CheckTVIRecursion not applicable .", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (66) ", "Subsection",
  CellTags->"T1.6.41.1"],

Cell[TextData[{
  "general ",
  Cell[BoxData[
      \(m\_i\%2\)]]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(e\_66\), "=", 
        RowBox[{
          RowBox[{"4", 
            InterpretationBox[\(p\^2\),
              PP], \(\[Nu]\_1\), 
            InterpretationBox[
              StyleBox[\(1\^+\),
                FontWeight->"Bold"],
              Schiebe[ 1, "+"],
              Editable->True], \(\[Nu]\_2\), 
            InterpretationBox[
              StyleBox[\(2\^+\),
                FontWeight->"Bold"],
              Schiebe[ 2, "+"],
              Editable->True], \(\[Nu]\_3\), 
            InterpretationBox[
              StyleBox[\(3\^+\),
                FontWeight->"Bold"],
              Schiebe[ 3, "+"],
              Editable->True], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["V",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_4\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox[\(d + 2\),
                    "TraditionalForm"], ")"}]],
              TVI[ 
                Plus[ 2, d], {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3], 
                Subscript[ \[Nu], 4]}],
              Editable->True]}], "==", 
          RowBox[{
            RowBox[{"-", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"(", 
                    
                    RowBox[{\(6  d\), "-", \(6  \[Nu]\_1\), 
                      "-", \(5  \[Nu]\_2\), "-", \(6  \[Nu]\_3\), 
                      "-", \(4  \[Nu]\_4\), "-", 
                      RowBox[{"6", \(m\_1\%2\), \(\[Nu]\_1\), 
                        InterpretationBox[
                          StyleBox[\(1\^+\),
                            FontWeight->"Bold"],
                          Schiebe[ 1, "+"],
                          Editable->True]}]}], ")"}], "+", 
                  RowBox[{\((u\_\(6, 2, 4\) - 4  m\_2\%2)\), \(\[Nu]\_2\), 
                    InterpretationBox[
                      StyleBox[\(2\^+\),
                        FontWeight->"Bold"],
                      Schiebe[ 2, "+"],
                      Editable->True]}], "-", 
                  RowBox[{"6", \(m\_3\%2\), \(\[Nu]\_3\), 
                    InterpretationBox[
                      StyleBox[\(3\^+\),
                        FontWeight->"Bold"],
                      Schiebe[ 3, "+"],
                      Editable->True]}], "+", 
                  RowBox[{"2", \((u\_\(6, 2, 4\) - m\_4\%2)\), \(\[Nu]\_4\), 
                    InterpretationBox[
                      StyleBox[\(4\^+\),
                        FontWeight->"Bold"],
                      Schiebe[ 4, "+"],
                      Editable->True]}], "-", 
                  RowBox[{\(\[Nu]\_2\), 
                    InterpretationBox[
                      StyleBox[\(2\^+\),
                        FontWeight->"Bold"],
                      Schiebe[ 2, "+"],
                      Editable->True], 
                    InterpretationBox[
                      StyleBox[\(4\^-\),
                        FontWeight->"Bold"],
                      Schiebe[ 4, "-"],
                      Editable->True]}], "-", 
                  RowBox[{"2", \(\[Nu]\_4\), 
                    InterpretationBox[
                      StyleBox[\(4\^+\),
                        FontWeight->"Bold"],
                      Schiebe[ 4, "+"],
                      Editable->True], 
                    InterpretationBox[
                      StyleBox[\(2\^-\),
                        FontWeight->"Bold"],
                      Schiebe[ 2, "-"],
                      Editable->True]}]}], ")"}]}], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["V",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_4\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TVI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3], 
                Subscript[ \[Nu], 4]}],
              Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
    \(s\_66 = OperatorApplyV[e\_66]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (66)", "Subsection",
  CellTags->"T1.6.42.1"],

Cell[BoxData[
    \(h\_66 = 
      s\_66 /. {\[Nu]\_1 :> \[Nu]\_1 - 1, \[Nu]\_2 :> \[Nu]\_2 - 
              1, \[Nu]\_3 :> \[Nu]\_3 - 1, d :> d - 2}\)], "Input"],

Cell[BoxData[
    RowBox[{\(f\_66\), "=", 
      RowBox[{
        StyleBox["MakeFun",
          FontColor->RGBColor[1, 0.6, 0.6]], "[", 
        RowBox[{\(h\_66\), ",", "\"\<(66)\>\"", ",", 
          RowBox[{
            StyleBox["IFF",
              FontColor->RGBColor[0.6, 0.4, 1]], 
            "[", \(PP =!= 0 && \[Nu]\_1 > 1 && \[Nu]\_2 > 1 && \[Nu]\_3 > 1 && 
              MatchQ[d, _Symbol + _Integer?Positive]\), "]"}]}], 
        "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CheckTVIRecursion[f\_66]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`"Off"\)], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (alternative67)", "Subsection",
  CellTags->"T1.6.43.1"],

Cell["\<\
we dereived an alternative formula for Tarasov's (67), but do not \
save it by default.\
\>", "Text"],

Cell[TextData[{
  "general ",
  Cell[BoxData[
      \(m\_i\%2\)]]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(e\_67\), "=", 
        RowBox[{
          RowBox[{"4", 
            InterpretationBox[\(p\^2\),
              PP], \(\[Nu]\_1\), \((\[Nu]\_1 + 1)\), 
            InterpretationBox[
              StyleBox[\(1\^+\),
                FontWeight->"Bold"],
              Schiebe[ 1, "+"],
              Editable->True], 
            InterpretationBox[
              StyleBox[\(1\^+\),
                FontWeight->"Bold"],
              Schiebe[ 1, "+"],
              Editable->True], \(\[Nu]\_2\), 
            InterpretationBox[
              StyleBox[\(2\^+\),
                FontWeight->"Bold"],
              Schiebe[ 2, "+"],
              Editable->True], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["V",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_4\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox[\(d + 2\),
                    "TraditionalForm"], ")"}]],
              TVI[ 
                Plus[ 2, d], {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3], 
                Subscript[ \[Nu], 4]}],
              Editable->True]}], " ", "==", 
          RowBox[{
            RowBox[{"(", 
              
              RowBox[{\((6  d - 6  \[Nu]\_1 - 5  \[Nu]\_2 - 6  \[Nu]\_3 - 
                    4  \[Nu]\_4)\), "-", 
                RowBox[{
                "2", \((u\_\(2, 4, 6\) + 3  m\_1\%2)\), \(\[Nu]\_1\), 
                  InterpretationBox[
                    StyleBox[\(1\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 1, "+"],
                    Editable->True]}], "+", 
                RowBox[{\((u\_\(6, 2, 4\) - 4  m\_2\%2)\), \(\[Nu]\_2\), 
                  InterpretationBox[
                    StyleBox[\(2\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 2, "+"],
                    Editable->True]}], "-", 
                RowBox[{"6", \(m\_3\%2\), \(\[Nu]\_3\), 
                  InterpretationBox[
                    StyleBox[\(3\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 3, "+"],
                    Editable->True]}], "+", 
                RowBox[{"2", \((u\_\(6, 2, 4\) - m\_4\%2)\), \(\[Nu]\_4\), 
                  InterpretationBox[
                    StyleBox[\(4\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 4, "+"],
                    Editable->True]}], "+", 
                RowBox[{"2", \(\[Nu]\_1\), 
                  InterpretationBox[
                    StyleBox[\(1\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 1, "+"],
                    Editable->True], 
                  RowBox[{"(", 
                    RowBox[{
                      InterpretationBox[
                        StyleBox[\(4\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 4, "-"],
                        Editable->True], "-", 
                      InterpretationBox[
                        StyleBox[\(2\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 2, "-"],
                        Editable->True]}], ")"}]}], "-", 
                RowBox[{\(\[Nu]\_2\), 
                  InterpretationBox[
                    StyleBox[\(2\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 2, "+"],
                    Editable->True], 
                  InterpretationBox[
                    StyleBox[\(4\^-\),
                      FontWeight->"Bold"],
                    Schiebe[ 4, "-"],
                    Editable->True]}], "-", 
                RowBox[{"2", \(\[Nu]\_4\), 
                  InterpretationBox[
                    StyleBox[\(4\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 4, "+"],
                    Editable->True], 
                  InterpretationBox[
                    StyleBox[\(2\^-\),
                      FontWeight->"Bold"],
                    Schiebe[ 2, "-"],
                    Editable->True]}]}], ")"}], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["V",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_4\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TVI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3], 
                Subscript[ \[Nu], 4]}],
              Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
    \(s\_67 = OperatorApplyV[e\_67]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (67)", "Subsection",
  CellTags->"T1.6.44.1"],

Cell[TextData[{
  "general ",
  Cell[BoxData[
      \(m\_i\%2\)]]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(e\_67\), "=", 
        RowBox[{
          RowBox[{"4", 
            InterpretationBox[\(p\^2\),
              PP], \(\[Nu]\_1\), \((\[Nu]\_1 + 1)\), 
            InterpretationBox[
              StyleBox[\(1\^+\),
                FontWeight->"Bold"],
              Schiebe[ 1, "+"],
              Editable->True], 
            InterpretationBox[
              StyleBox[\(1\^+\),
                FontWeight->"Bold"],
              Schiebe[ 1, "+"],
              Editable->True], \(\[Nu]\_2\), 
            InterpretationBox[
              StyleBox[\(2\^+\),
                FontWeight->"Bold"],
              Schiebe[ 2, "+"],
              Editable->True], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["V",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_4\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox[\(d + 2\),
                    "TraditionalForm"], ")"}]],
              TVI[ 
                Plus[ 2, d], {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3], 
                Subscript[ \[Nu], 4]}],
              Editable->True]}], " ", "==", 
          RowBox[{
            RowBox[{"(", 
              
              RowBox[{\(2 \((2  d - 2  \[Nu]\_1 - 2  \[Nu]\_2 - 
                      2  \[Nu]\_3 - \[Nu]\_4)\)\), "-", 
                RowBox[{
                "2", \((u\_\(2, 4, 6\) + 2  m\_1\%2)\), \(\[Nu]\_1\), 
                  InterpretationBox[
                    StyleBox[\(1\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 1, "+"],
                    Editable->True]}], "+", 
                RowBox[{\(-4\), \(m\_2\%2\), \(\[Nu]\_2\), 
                  InterpretationBox[
                    StyleBox[\(2\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 2, "+"],
                    Editable->True]}], "-", 
                RowBox[{"4", \(m\_3\%2\), \(\[Nu]\_3\), 
                  InterpretationBox[
                    StyleBox[\(3\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 3, "+"],
                    Editable->True]}], "+", 
                RowBox[{"2", \(u\_\(6, 2, 4\)\), \(\[Nu]\_4\), 
                  InterpretationBox[
                    StyleBox[\(4\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 4, "+"],
                    Editable->True]}], "+", 
                RowBox[{"2", \(\[Nu]\_1\), 
                  InterpretationBox[
                    StyleBox[\(1\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 1, "+"],
                    Editable->True], 
                  RowBox[{"(", 
                    RowBox[{
                      InterpretationBox[
                        StyleBox[\(4\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 4, "-"],
                        Editable->True], "-", 
                      InterpretationBox[
                        StyleBox[\(2\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 2, "-"],
                        Editable->True]}], ")"}]}], "-", 
                RowBox[{"2", \(\[Nu]\_4\), 
                  InterpretationBox[
                    StyleBox[\(4\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 4, "+"],
                    Editable->True], 
                  InterpretationBox[
                    StyleBox[\(2\^-\),
                      FontWeight->"Bold"],
                    Schiebe[ 2, "-"],
                    Editable->True]}]}], ")"}], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["V",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_4\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TVI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3], 
                Subscript[ \[Nu], 4]}],
              Editable->True]}]}]}], ";"}]], "Input"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(-4\), " ", \(\[Nu]\_2\), " ", 
          InterpretationBox[
            SubsuperscriptBox[
              StyleBox["V",
                SingleLetterItalics->False,
                FontWeight->"Bold"], 
              RowBox[{
                FormBox[\(\[Nu]\_1\),
                  "TraditionalForm"], 
                StyleBox[
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"],
                  FontColor->RGBColor[0, 0, 1]], 
                FormBox[\(\[Nu]\_3\),
                  "TraditionalForm"], 
                FormBox[\(\[Nu]\_4\),
                  "TraditionalForm"]}], 
              RowBox[{"(", 
                FormBox["d",
                  "TraditionalForm"], ")"}]],
            TVI[ d, {
              Subscript[ \[Nu], 1], 
              Plus[ 1, 
                Subscript[ \[Nu], 2]], 
              Subscript[ \[Nu], 3], 
              Subscript[ \[Nu], 4]}],
            Editable->True], " ", \(m\_2\%2\)}], "-", 
        RowBox[{"2", " ", \(\[Nu]\_4\), " ", 
          InterpretationBox[
            SubsuperscriptBox[
              StyleBox["V",
                SingleLetterItalics->False,
                FontWeight->"Bold"], 
              RowBox[{
                FormBox[\(\[Nu]\_1\),
                  "TraditionalForm"], 
                StyleBox[
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"],
                  FontColor->RGBColor[1, 0, 0]], 
                FormBox[\(\[Nu]\_3\),
                  "TraditionalForm"], 
                StyleBox[
                  FormBox[\(\[Nu]\_4\),
                    "TraditionalForm"],
                  FontColor->RGBColor[0, 0, 1]]}], 
              RowBox[{"(", 
                FormBox["d",
                  "TraditionalForm"], ")"}]],
            TVI[ d, {
              Subscript[ \[Nu], 1], 
              Plus[ -1, 
                Subscript[ \[Nu], 2]], 
              Subscript[ \[Nu], 3], 
              Plus[ 1, 
                Subscript[ \[Nu], 4]]}],
            Editable->True]}], "+", 
        RowBox[{
        "2", " ", \((2\ d - 2\ \[Nu]\_1 - 2\ \[Nu]\_2 - 
              2\ \[Nu]\_3 - \[Nu]\_4)\), " ", 
          InterpretationBox[
            SubsuperscriptBox[
              StyleBox["V",
                SingleLetterItalics->False,
                FontWeight->"Bold"], 
              RowBox[{
                FormBox[\(\[Nu]\_1\),
                  "TraditionalForm"], 
                FormBox[\(\[Nu]\_2\),
                  "TraditionalForm"], 
                FormBox[\(\[Nu]\_3\),
                  "TraditionalForm"], 
                FormBox[\(\[Nu]\_4\),
                  "TraditionalForm"]}], 
              RowBox[{"(", 
                FormBox["d",
                  "TraditionalForm"], ")"}]],
            TVI[ d, {
              Subscript[ \[Nu], 1], 
              Subscript[ \[Nu], 2], 
              Subscript[ \[Nu], 3], 
              Subscript[ \[Nu], 4]}],
            Editable->True]}], "-", 
        RowBox[{
        "2", " ", \((m\_2\%2 + m\_4\%2 - p\^2)\), " ", \(\[Nu]\_4\), " ", 
          InterpretationBox[
            SubsuperscriptBox[
              StyleBox["V",
                SingleLetterItalics->False,
                FontWeight->"Bold"], 
              RowBox[{
                FormBox[\(\[Nu]\_1\),
                  "TraditionalForm"], 
                FormBox[\(\[Nu]\_2\),
                  "TraditionalForm"], 
                FormBox[\(\[Nu]\_3\),
                  "TraditionalForm"], 
                StyleBox[
                  FormBox[\(\[Nu]\_4\),
                    "TraditionalForm"],
                  FontColor->RGBColor[0, 0, 1]]}], 
              RowBox[{"(", 
                FormBox["d",
                  "TraditionalForm"], ")"}]],
            TVI[ d, {
              Subscript[ \[Nu], 1], 
              Subscript[ \[Nu], 2], 
              Subscript[ \[Nu], 3], 
              Plus[ 1, 
                Subscript[ \[Nu], 4]]}],
            Editable->True]}], "-", 
        RowBox[{"4", " ", \(m\_3\%2\), " ", \(\[Nu]\_3\), " ", 
          InterpretationBox[
            SubsuperscriptBox[
              StyleBox["V",
                SingleLetterItalics->False,
                FontWeight->"Bold"], 
              RowBox[{
                FormBox[\(\[Nu]\_1\),
                  "TraditionalForm"], 
                FormBox[\(\[Nu]\_2\),
                  "TraditionalForm"], 
                StyleBox[
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"],
                  FontColor->RGBColor[0, 0, 1]], 
                FormBox[\(\[Nu]\_4\),
                  "TraditionalForm"]}], 
              RowBox[{"(", 
                FormBox["d",
                  "TraditionalForm"], ")"}]],
            TVI[ d, {
              Subscript[ \[Nu], 1], 
              Subscript[ \[Nu], 2], 
              Plus[ 1, 
                Subscript[ \[Nu], 3]], 
              Subscript[ \[Nu], 4]}],
            Editable->True]}], "-", 
        RowBox[{"2", " ", \(\[Nu]\_1\), " ", 
          InterpretationBox[
            SubsuperscriptBox[
              StyleBox["V",
                SingleLetterItalics->False,
                FontWeight->"Bold"], 
              RowBox[{
                StyleBox[
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"],
                  FontColor->RGBColor[0, 0, 1]], 
                StyleBox[
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"],
                  FontColor->RGBColor[1, 0, 0]], 
                FormBox[\(\[Nu]\_3\),
                  "TraditionalForm"], 
                FormBox[\(\[Nu]\_4\),
                  "TraditionalForm"]}], 
              RowBox[{"(", 
                FormBox["d",
                  "TraditionalForm"], ")"}]],
            TVI[ d, {
              Plus[ 1, 
                Subscript[ \[Nu], 1]], 
              Plus[ -1, 
                Subscript[ \[Nu], 2]], 
              Subscript[ \[Nu], 3], 
              Subscript[ \[Nu], 4]}],
            Editable->True]}], "+", 
        RowBox[{"2", " ", \(\[Nu]\_1\), " ", 
          InterpretationBox[
            SubsuperscriptBox[
              StyleBox["V",
                SingleLetterItalics->False,
                FontWeight->"Bold"], 
              RowBox[{
                StyleBox[
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"],
                  FontColor->RGBColor[0, 0, 1]], 
                FormBox[\(\[Nu]\_2\),
                  "TraditionalForm"], 
                FormBox[\(\[Nu]\_3\),
                  "TraditionalForm"], 
                StyleBox[
                  FormBox[\(\[Nu]\_4\),
                    "TraditionalForm"],
                  FontColor->RGBColor[1, 0, 0]]}], 
              RowBox[{"(", 
                FormBox["d",
                  "TraditionalForm"], ")"}]],
            TVI[ d, {
              Plus[ 1, 
                Subscript[ \[Nu], 1]], 
              Subscript[ \[Nu], 2], 
              Subscript[ \[Nu], 3], 
              Plus[ -1, 
                Subscript[ \[Nu], 4]]}],
            Editable->True]}], "-", 
        RowBox[{
        "2", " ", \((2\ m\_1\%2 + m\_2\%2 - m\_4\%2 - p\^2)\), 
          " ", \(\[Nu]\_1\), " ", 
          InterpretationBox[
            SubsuperscriptBox[
              StyleBox["V",
                SingleLetterItalics->False,
                FontWeight->"Bold"], 
              RowBox[{
                StyleBox[
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"],
                  FontColor->RGBColor[0, 0, 1]], 
                FormBox[\(\[Nu]\_2\),
                  "TraditionalForm"], 
                FormBox[\(\[Nu]\_3\),
                  "TraditionalForm"], 
                FormBox[\(\[Nu]\_4\),
                  "TraditionalForm"]}], 
              RowBox[{"(", 
                FormBox["d",
                  "TraditionalForm"], ")"}]],
            TVI[ d, {
              Plus[ 1, 
                Subscript[ \[Nu], 1]], 
              Subscript[ \[Nu], 2], 
              Subscript[ \[Nu], 3], 
              Subscript[ \[Nu], 4]}],
            Editable->True]}], "-", 
        RowBox[{
        "4", " ", \(p\^2\), " ", \(\[Nu]\_1\), " ", \((\[Nu]\_1 + 1)\), 
          " ", \(\[Nu]\_2\), " ", 
          InterpretationBox[
            SubsuperscriptBox[
              StyleBox["V",
                SingleLetterItalics->False,
                FontWeight->"Bold"], 
              RowBox[{
                StyleBox[
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"],
                  FontWeight->"Bold",
                  FontColor->RGBColor[0, 0, 1]], 
                StyleBox[
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"],
                  FontColor->RGBColor[0, 0, 1]], 
                FormBox[\(\[Nu]\_3\),
                  "TraditionalForm"], 
                FormBox[\(\[Nu]\_4\),
                  "TraditionalForm"]}], 
              RowBox[{"(", 
                FormBox[\(d + 2\),
                  "TraditionalForm"], ")"}]],
            TVI[ 
              Plus[ 2, d], {
              Plus[ 2, 
                Subscript[ \[Nu], 1]], 
              Plus[ 1, 
                Subscript[ \[Nu], 2]], 
              Subscript[ \[Nu], 3], 
              Subscript[ \[Nu], 4]}],
            Editable->True]}]}], TraditionalForm]]]], "Text"],

Cell[BoxData[
    \(s\_67 = OperatorApplyV[e\_67]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (67)", "Subsection",
  CellTags->"T1.6.45.1"],

Cell[BoxData[
    \(h\_67 = 
      s\_67 /. {\[Nu]\_1 :> \[Nu]\_1 - 2, \[Nu]\_2 :> \[Nu]\_2 - 1, 
          d :> d - 2}\)], "Input"],

Cell[BoxData[
    RowBox[{\(f\_67\), "=", 
      RowBox[{
        StyleBox["MakeFun",
          FontColor->RGBColor[1, 0.6, 0.6]], "[", 
        RowBox[{\(h\_67\), ",", "\"\<(67)\>\"", ",", 
          RowBox[{
            StyleBox["IFF",
              FontColor->RGBColor[0.6, 0.4, 1]], 
            "[", \(PP =!= 0 && \[Nu]\_1 > 2 && \[Nu]\_2 > 1 && 
              MatchQ[d, _Symbol + _Integer?Positive]\), "]"}]}], 
        "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CheckTVIRecursion[f\_67]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`"Off"\)], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (6713)", "Subsection",
  CellTags->"T1.6.46.1"],

Cell[BoxData[
    \(h\_6713 = 
      Interchange[s\_67, 
          1 \[LeftRightArrow] 
            3] /. {\[Nu]\_3 :> \[Nu]\_3 - 2, \[Nu]\_2 :> \[Nu]\_2 - 1, 
          d :> d - 2}\)], "Input"],

Cell[BoxData[
    RowBox[{\(f\_6713\), "=", 
      RowBox[{
        StyleBox["MakeFun",
          FontColor->RGBColor[1, 0.6, 0.6]], "[", 
        RowBox[{\(h\_6713\), ",", "\"\<(6713)\>\"", ",", 
          RowBox[{
            StyleBox["IFF",
              FontColor->RGBColor[0.6, 0.4, 1]], 
            "[", \(PP =!= 0 && \[Nu]\_3 > 2 && \[Nu]\_2 > 1 && 
              MatchQ[d, _Symbol + _Integer?Positive]\), "]"}]}], 
        "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CheckTVIRecursion[f\_6713]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`"Off"\)], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (68)", "Subsection",
  CellTags->"T1.6.47.1"],

Cell[TextData[{
  "general ",
  Cell[BoxData[
      \(m\_i\%2\)]]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(e\_68\), "=", 
        RowBox[{
          RowBox[{"4", 
            InterpretationBox[\(p\^2\),
              PP], \(m\_4\%2\), \(\[Nu]\_1\), 
            InterpretationBox[
              StyleBox[\(1\^+\),
                FontWeight->"Bold"],
              Schiebe[ 1, "+"],
              Editable->True], \(\[Nu]\_2\), \((\[Nu]\_2 + 1)\), 
            InterpretationBox[
              StyleBox[\(2\^+\),
                FontWeight->"Bold"],
              Schiebe[ 2, "+"],
              Editable->True], 
            InterpretationBox[
              StyleBox[\(2\^+\),
                FontWeight->"Bold"],
              Schiebe[ 2, "+"],
              Editable->True], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["V",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_4\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox[\(d + 2\),
                    "TraditionalForm"], ")"}]],
              TVI[ 
                Plus[ 2, d], {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3], 
                Subscript[ \[Nu], 4]}],
              Editable->True]}], "==", 
          RowBox[{
            RowBox[{"-", 
              RowBox[{"(", 
                
                RowBox[{\((\((m\_1\%2 - m\_3\%2)\) \((2  d - 
                            2  \[Nu]\_1 - \[Nu]\_2 - 2  \[Nu]\_3 - 
                            2  \[Nu]\_4)\) + \(m\_4\%2\) \((2  \[Nu]\_1 + \
\[Nu]\_2 - 2  \[Nu]\_3)\))\), "-", 
                  RowBox[{\(u\_\(1, 3, 4\)\), 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{"2", \(m\_1\%2\), \(\[Nu]\_1\), 
                          InterpretationBox[
                            StyleBox[\(1\^+\),
                              FontWeight->"Bold"],
                            Schiebe[ 1, "+"],
                            Editable->True]}], "+", 
                        RowBox[{\(u\_\(2, 4, 6\)\), \(\[Nu]\_2\), 
                          InterpretationBox[
                            StyleBox[\(2\^+\),
                              FontWeight->"Bold"],
                            Schiebe[ 2, "+"],
                            Editable->True]}]}], ")"}]}], "+", 
                  RowBox[{\(u\_\(3, 1, 4\)\), 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{"2", \(m\_3\%2\), \(\[Nu]\_3\), 
                          InterpretationBox[
                            StyleBox[\(3\^+\),
                              FontWeight->"Bold"],
                            Schiebe[ 3, "+"],
                            Editable->True]}], "+", 
                        RowBox[{\(\[Nu]\_2\), 
                          InterpretationBox[
                            StyleBox[\(2\^+\),
                              FontWeight->"Bold"],
                            Schiebe[ 2, "+"],
                            Editable->True], 
                          InterpretationBox[
                            StyleBox[\(4\^-\),
                              FontWeight->"Bold"],
                            Schiebe[ 4, "-"],
                            Editable->True]}]}], ")"}]}], "-", 
                  RowBox[{"2", \(m\_4\%2\), 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{\(\[Nu]\_2\), 
                          InterpretationBox[
                            StyleBox[\(2\^+\),
                              FontWeight->"Bold"],
                            Schiebe[ 2, "+"],
                            Editable->True]}], "+", 
                        RowBox[{\(\[Nu]\_4\), 
                          InterpretationBox[
                            StyleBox[\(4\^+\),
                              FontWeight->"Bold"],
                            Schiebe[ 4, "+"],
                            Editable->True]}]}], ")"}], 
                    RowBox[{"(", 
                      RowBox[{
                        InterpretationBox[
                          StyleBox[\(3\^-\),
                            FontWeight->"Bold"],
                          Schiebe[ 3, "-"],
                          Editable->True], "-", 
                        InterpretationBox[
                          StyleBox[\(1\^-\),
                            FontWeight->"Bold"],
                          Schiebe[ 1, "-"],
                          Editable->True]}], ")"}]}]}], ")"}]}], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["V",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_4\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TVI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3], 
                Subscript[ \[Nu], 4]}],
              Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
    \(s\_68 = OperatorApplyV[e\_68]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (68)", "Subsection",
  CellTags->"T1.6.48.1"],

Cell[BoxData[
    \(h\_68 = 
      s\_68 /. {\[Nu]\_1 :> \[Nu]\_1 - 1, \[Nu]\_2 :> \[Nu]\_2 - 2, 
          d :> d - 2}\)], "Input"],

Cell[BoxData[
    RowBox[{\(f\_68\), "=", 
      RowBox[{
        StyleBox["MakeFun",
          FontColor->RGBColor[1, 0.6, 0.6]], "[", 
        RowBox[{\(h\_68\), ",", "\"\<(68)\>\"", ",", 
          RowBox[{
            StyleBox["IFF",
              FontColor->RGBColor[0.6, 0.4, 1]], 
            "[", \(PP =!= 0 && m4 =!= 0 && \[Nu]\_1 > 1 && \[Nu]\_2 > 2 && 
              MatchQ[d, _Symbol + _Integer?Positive]\), "]"}]}], 
        "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CheckTVIRecursion[f\_68]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`"Off"\)], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (6813)", "Subsection",
  CellTags->"T1.6.49.1"],

Cell[BoxData[
    \(h\_6813 = 
      Interchange[s\_68, 
          1 \[LeftRightArrow] 
            3] /. {\[Nu]\_2 :> \[Nu]\_2 - 2, \[Nu]\_3 :> \[Nu]\_3 - 1, 
          d :> d - 2}\)], "Input"],

Cell[BoxData[
    RowBox[{\(f\_6813\), "=", 
      RowBox[{
        StyleBox["MakeFun",
          FontColor->RGBColor[1, 0.6, 0.6]], "[", 
        RowBox[{\(h\_6813\), ",", "\"\<(6813)\>\"", ",", 
          RowBox[{
            StyleBox["IFF",
              FontColor->RGBColor[0.6, 0.4, 1]], 
            "[", \(\(PP =!= 0 && m4 =!= 0\) && \[Nu]\_2 > 2 && \[Nu]\_3 > 1 && 
              MatchQ[d, _Symbol + _Integer?Positive]\), "]"}]}], 
        "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CheckTVIRecursion[f\_6813]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`"Off"\)], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (70)", "Subsection",
  CellTags->"T1.6.50.1"],

Cell[TextData[{
  "general ",
  Cell[BoxData[
      \(m\_i\%2\)]]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(e\_70\), "=", 
        RowBox[{
          RowBox[{\((3  d - 10)\), \(\((d - 3)\)\^2\), \(m\_4\%2\), 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["V",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox["1",
                    "TraditionalForm"], 
                  FormBox["1",
                    "TraditionalForm"], 
                  FormBox["1",
                    "TraditionalForm"], 
                  FormBox["1",
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TVI[ d, {1, 1, 1, 1}],
              Editable->True]}], "==", 
          RowBox[{
            RowBox[{
              FractionBox["1", 
                RowBox[{"4", 
                  InterpretationBox[\(p\^2\),
                    PP]}]], 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\((3  d - 10)\), \(\[CapitalDelta]\_\(1, 3, 4\)\), 
                    RowBox[{"(", 
                      RowBox[{\(\[CapitalDelta]\_\(2, 4, 6\)\), "+", 
                        RowBox[{\(u\_\(2, 4, 6\)\), 
                          RowBox[{"(", 
                            RowBox[{
                              InterpretationBox[
                                StyleBox[\(2\^-\),
                                  FontWeight->"Bold"],
                                Schiebe[ 2, "-"],
                                Editable->True], "-", 
                              InterpretationBox[
                                StyleBox[\(4\^-\),
                                  FontWeight->"Bold"],
                                Schiebe[ 4, "-"],
                                Editable->True]}], ")"}]}]}], ")"}]}], "-", 
                  RowBox[{"8", \(\((d - 4)\)\^2\), 
                    InterpretationBox[\(p\^2\),
                      PP], \(m\_3\%2\), \(m\_4\%2\), 
                    InterpretationBox[
                      StyleBox[\(4\^-\),
                        FontWeight->"Bold"],
                      Schiebe[ 4, "-"],
                      Editable->True]}]}], ")"}], 
              InterpretationBox[
                SubsuperscriptBox[
                  StyleBox["V",
                    SingleLetterItalics->False,
                    FontWeight->"Bold"], 
                  RowBox[{
                    FormBox["1",
                      "TraditionalForm"], 
                    FormBox["1",
                      "TraditionalForm"], 
                    FormBox["1",
                      "TraditionalForm"], 
                    FormBox["1",
                      "TraditionalForm"]}], 
                  RowBox[{"(", 
                    FormBox[\(d - 2\),
                      "TraditionalForm"], ")"}]],
                TVI[ 
                  Plus[ -2, d], {1, 1, 1, 1}],
                Editable->True]}], "+", "\n", "\t\t\t", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\((d - 3)\), \(m\_4\%2\), 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{"4", \(m\_1\%2\), \((d - 4)\), 
                          InterpretationBox[
                            StyleBox[\(1\^+\),
                              FontWeight->"Bold"],
                            Schiebe[ 1, "+"],
                            Editable->True], 
                          InterpretationBox[
                            StyleBox[\(1\^+\),
                              FontWeight->"Bold"],
                            Schiebe[ 1, "+"],
                            Editable->True]}], "-", 
                        RowBox[{"8", \((d - 3)\), \(m\_2\%2\), 
                          InterpretationBox[
                            StyleBox[\(2\^+\),
                              FontWeight->"Bold"],
                            Schiebe[ 2, "+"],
                            Editable->True], 
                          InterpretationBox[
                            StyleBox[\(2\^+\),
                              FontWeight->"Bold"],
                            Schiebe[ 2, "+"],
                            Editable->True]}], "+", 
                        RowBox[{\((3  d - 10)\), \((d - 3)\), 
                          InterpretationBox[
                            StyleBox[\(2\^+\),
                              FontWeight->"Bold"],
                            Schiebe[ 2, "+"],
                            Editable->True]}]}], ")"}]}], "+", 
                  RowBox[{\(u\_\(6, 2, 4\)\), 
                    RowBox[{"(", 
                      RowBox[{
                        
                        RowBox[{\(1\/2\), \((3  d - 10)\), \(u\_\(1, 3, 4\)\),
                           
                          RowBox[{"(", 
                            RowBox[{
                              InterpretationBox[
                                StyleBox[\(1\^+\),
                                  FontWeight->"Bold"],
                                Schiebe[ 1, "+"],
                                Editable->True], "-", 
                              InterpretationBox[
                                StyleBox[\(3\^+\),
                                  FontWeight->"Bold"],
                                Schiebe[ 3, "+"],
                                Editable->True]}], ")"}]}], "+", 
                        RowBox[{\((d - 2)\), \((d - 3)\), \(m\_4\%2\), 
                          InterpretationBox[
                            StyleBox[\(1\^+\),
                              FontWeight->"Bold"],
                            Schiebe[ 1, "+"],
                            Editable->True]}]}], ")"}], 
                    InterpretationBox[
                      StyleBox[\(2\^+\),
                        FontWeight->"Bold"],
                      Schiebe[ 2, "+"],
                      Editable->True]}], "-", 
                  RowBox[{\(m\_4\%2\), 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{\(\((d - 4)\)\^2\), \(u\_\(1, 3, 4\)\), 
                          InterpretationBox[
                            StyleBox[\(2\^+\),
                              FontWeight->"Bold"],
                            Schiebe[ 2, "+"],
                            Editable->True]}], "+", 
                        RowBox[{\((3  d - 10)\), \(u\_\(4, 1, 3\)\), 
                          InterpretationBox[
                            StyleBox[\(3\^+\),
                              FontWeight->"Bold"],
                            Schiebe[ 3, "+"],
                            Editable->True]}]}], ")"}], 
                    InterpretationBox[
                      StyleBox[\(1\^+\),
                        FontWeight->"Bold"],
                      Schiebe[ 1, "+"],
                      Editable->True]}]}], ")"}], 
              InterpretationBox[
                StyleBox[\(4\^-\),
                  FontWeight->"Bold"],
                Schiebe[ 4, "-"],
                Editable->True], 
              InterpretationBox[
                SubsuperscriptBox[
                  StyleBox["V",
                    SingleLetterItalics->False,
                    FontWeight->"Bold"], 
                  RowBox[{
                    FormBox["1",
                      "TraditionalForm"], 
                    FormBox["1",
                      "TraditionalForm"], 
                    FormBox["1",
                      "TraditionalForm"], 
                    FormBox["1",
                      "TraditionalForm"]}], 
                  RowBox[{"(", 
                    FormBox["d",
                      "TraditionalForm"], ")"}]],
                TVI[ d, {1, 1, 1, 1}],
                Editable->True]}], "-", 
            RowBox[{\((d - 3)\), \(m\_4\%2\), 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"4", \((d - 4)\), \(m\_1\%2\), 
                    InterpretationBox[
                      StyleBox[\(1\^+\),
                        FontWeight->"Bold"],
                      Schiebe[ 1, "+"],
                      Editable->True]}], "+", 
                  RowBox[{\((d - 2)\), 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{\(u\_\(6, 2, 4\)\), 
                          InterpretationBox[
                            StyleBox[\(2\^+\),
                              FontWeight->"Bold"],
                            Schiebe[ 2, "+"],
                            Editable->True]}], "-", 
                        RowBox[{"2", \(m\_4\%2\), 
                          InterpretationBox[
                            StyleBox[\(4\^+\),
                              FontWeight->"Bold"],
                            Schiebe[ 4, "+"],
                            Editable->True]}]}], ")"}]}]}], ")"}], 
              InterpretationBox[
                StyleBox[\(1\^+\),
                  FontWeight->"Bold"],
                Schiebe[ 1, "+"],
                Editable->True], 
              InterpretationBox[
                StyleBox[\(3\^-\),
                  FontWeight->"Bold"],
                Schiebe[ 3, "-"],
                Editable->True], 
              InterpretationBox[
                SubsuperscriptBox[
                  StyleBox["V",
                    SingleLetterItalics->False,
                    FontWeight->"Bold"], 
                  RowBox[{
                    FormBox["1",
                      "TraditionalForm"], 
                    FormBox["1",
                      "TraditionalForm"], 
                    FormBox["1",
                      "TraditionalForm"], 
                    FormBox["1",
                      "TraditionalForm"]}], 
                  RowBox[{"(", 
                    FormBox["d",
                      "TraditionalForm"], ")"}]],
                TVI[ d, {1, 1, 1, 1}],
                Editable->True]}], "+", 
            RowBox[{\(1\/2\), \((3  d - 10)\), \(u\_\(1, 3, 4\)\), 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(u\_\(6, 2, 4\)\), 
                    InterpretationBox[
                      StyleBox[\(2\^+\),
                        FontWeight->"Bold"],
                      Schiebe[ 2, "+"],
                      Editable->True]}], "-", 
                  RowBox[{"2", \(m\_4\%2\), 
                    InterpretationBox[
                      StyleBox[\(4\^+\),
                        FontWeight->"Bold"],
                      Schiebe[ 4, "+"],
                      Editable->True]}]}], ")"}], 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    InterpretationBox[
                      StyleBox[\(3\^+\),
                        FontWeight->"Bold"],
                      Schiebe[ 3, "+"],
                      Editable->True], 
                    InterpretationBox[
                      StyleBox[\(1\^-\),
                        FontWeight->"Bold"],
                      Schiebe[ 1, "-"],
                      Editable->True]}], "-", 
                  RowBox[{
                    InterpretationBox[
                      StyleBox[\(1\^+\),
                        FontWeight->"Bold"],
                      Schiebe[ 1, "+"],
                      Editable->True], 
                    InterpretationBox[
                      StyleBox[\(3\^-\),
                        FontWeight->"Bold"],
                      Schiebe[ 3, "-"],
                      Editable->True]}]}], ")"}], 
              InterpretationBox[
                SubsuperscriptBox[
                  StyleBox["V",
                    SingleLetterItalics->False,
                    FontWeight->"Bold"], 
                  RowBox[{
                    FormBox["1",
                      "TraditionalForm"], 
                    FormBox["1",
                      "TraditionalForm"], 
                    FormBox["1",
                      "TraditionalForm"], 
                    FormBox["1",
                      "TraditionalForm"]}], 
                  RowBox[{"(", 
                    FormBox["d",
                      "TraditionalForm"], ")"}]],
                TVI[ d, {1, 1, 1, 1}],
                Editable->True]}]}]}]}], ";"}]], "Input"],

Cell[BoxData[
    \(s\_70 = OperatorApplyV[e\_70]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (70)", "Subsection",
  CellTags->"T1.6.51.1"],

Cell[BoxData[
    \(h\_70 = s\_70\)], "Input"],

Cell[BoxData[
    RowBox[{\(f\_70\), "=", 
      RowBox[{
        StyleBox["MakeFun",
          FontColor->RGBColor[1, 0.6, 0.6]], "[", 
        RowBox[{\(h\_70\), ",", "\"\<(70)\>\"", ",", 
          RowBox[{
            StyleBox["IFF",
              FontColor->RGBColor[0.6, 0.4, 1]], 
            "[", \(\(m4 =!= 0\  && \ PP =!= 0\) && 
              MatchQ[d, _Symbol + _Integer?Positive]\), "]"}]}], 
        "]"}]}]], "Input"],

Cell["\<\
CheckTVIRecursion not applicable for special indices since A's and 
B's appear .\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (71)", "Subsection",
  CellTags->"T1.6.52.1"],

Cell[TextData[{
  "general ",
  Cell[BoxData[
      \(m\_i\%2\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu]\_1, \[Nu]\_2 > 0\)]]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(e\_71\), "=", 
        RowBox[{
          RowBox[{"2", \(D\_\(1, 2, 3\)\), \(\[Nu]\_1\), 
            InterpretationBox[
              StyleBox[\(1\^+\),
                FontWeight->"Bold"],
              Schiebe[ 1, "+"],
              Editable->True], \(\[Nu]\_2\), 
            InterpretationBox[
              StyleBox[\(2\^+\),
                FontWeight->"Bold"],
              Schiebe[ 2, "+"],
              Editable->True], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["J",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TJI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3]}],
              Editable->True]}], "==", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"2", \(h\_\(1, 2, 3\)\), \(\[Nu]\_1\), 
                  InterpretationBox[
                    StyleBox[\(1\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 1, "+"],
                    Editable->True]}], "+", 
                RowBox[{"2", \(h\_\(2, 1, 3\)\), \(\[Nu]\_2\), 
                  InterpretationBox[
                    StyleBox[\(2\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 2, "+"],
                    Editable->True]}], "+", 
                RowBox[{
                "4", \(m\_3\%2\), \(\[Sigma]\_\(1, 2, 3\)\), \(\[Nu]\_3\), 
                  InterpretationBox[
                    StyleBox[\(3\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 3, "+"],
                    Editable->True]}], "+", 
                RowBox[{\(m\_3\%2\), \(\[Phi]\_\(2, 1, 3\)\), \(\[Nu]\_2\), 
                  InterpretationBox[
                    StyleBox[\(2\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 2, "+"],
                    Editable->True], \(\[Nu]\_3\), 
                  InterpretationBox[
                    StyleBox[\(3\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 3, "+"],
                    Editable->True], 
                  InterpretationBox[
                    StyleBox[\(1\^-\),
                      FontWeight->"Bold"],
                    Schiebe[ 1, "-"],
                    Editable->True]}], "+", 
                RowBox[{\(m\_3\%2\), \(\[Phi]\_\(1, 2, 3\)\), \(\[Nu]\_1\), 
                  InterpretationBox[
                    StyleBox[\(1\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 1, "+"],
                    Editable->True], \(\[Nu]\_3\), 
                  InterpretationBox[
                    StyleBox[\(3\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 3, "+"],
                    Editable->True], 
                  InterpretationBox[
                    StyleBox[\(2\^-\),
                      FontWeight->"Bold"],
                    Schiebe[ 2, "-"],
                    Editable->True]}], "-", 
                RowBox[{"2", \(\[Rho]\_\(1, 2, 3\)\), \(\[Nu]\_1\), 
                  InterpretationBox[
                    StyleBox[\(1\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 1, "+"],
                    Editable->True], \(\[Nu]\_2\), 
                  InterpretationBox[
                    StyleBox[\(2\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 2, "+"],
                    Editable->True], 
                  InterpretationBox[
                    StyleBox[\(3\^-\),
                      FontWeight->"Bold"],
                    Schiebe[ 3, "-"],
                    Editable->True]}], 
                "+", \(\(1\/2\) \(\[CapitalSigma]\_3\) \((d - \[Nu]\_1 - \
\[Nu]\_2 - \[Nu]\_3)\) \[Phi]\_\(3, 2, 1\)\)}], ")"}], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["J",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TJI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3]}],
              Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
    \(s\_71 = OperatorApplyJ[e\_71]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (71)", "Subsection",
  CellTags->"T1.6.53.1"],

Cell[BoxData[
    \(h\_71 = \(\[Nu]explicit[
            s\_71] /. \[Nu]\_1 -> \[Nu]\_1 - 1\) /. \[Nu]\_2 -> \[Nu]\_2 - 
            1\)], "Input"],

Cell[BoxData[
    \(f\_71 = 
      MakeFun[h\_71, "\<(71)\>", 
        IFF[\[Nu]\_1 > 1 && \[Nu]\_2 > 1 && D\_\(1, 2, 3\) =!= 0]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CheckTJIRecursion[f\_71]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`"Off"\)], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (7123)", "Subsection",
  CellTags->"T1.6.54.1"],

Cell[BoxData[
    \(h\_7123 = \(Interchange[s\_71, 
            2 \[LeftRightArrow] 3] /. \[Nu]\_1 -> \[Nu]\_1 - 
              1\) /. \[Nu]\_3 -> \[Nu]\_3 - 1\)], "Input"],

Cell[BoxData[
    \(f\_7123 = 
      MakeFun[h\_7123, "\<(7123)\>", 
        IFF[\[Nu]\_1 > 1 && \[Nu]\_3 > 1 && D\_\(1, 3, 2\) =!= 0]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CheckTJIRecursion[f\_7123]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`"Off"\)], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (7113)", "Subsection",
  CellTags->"T1.6.55.1"],

Cell[BoxData[
    \(h\_7113 = \(Interchange[s\_71, 
            1 \[LeftRightArrow] 3] /. \[Nu]\_2 -> \[Nu]\_2 - 
              1\) /. \[Nu]\_3 -> \[Nu]\_3 - 1\)], "Input"],

Cell[BoxData[
    \(f\_7113 = 
      MakeFun[h\_7113, "\<(7113)\>", 
        IFF[\[Nu]\_2 > 1 && \[Nu]\_3 > 1 && D\_\(3, 2, 1\) =!= 0]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CheckTJIRecursion[f\_7113]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`"Off"\)], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (78)", "Subsection",
  CellTags->"T1.6.56.1"],

Cell[TextData[{
  "general ",
  Cell[BoxData[
      \(m\_i\%2\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu]\_1 > 0\)]]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(e\_78\), "=", 
        RowBox[{
          RowBox[{
          "2", \(m\_1\%2\), 
            " ", \(D\_\(1, 2, 3\)\), \(\[Nu]\_1\), \((\[Nu]\_1 + 1)\), 
            InterpretationBox[
              StyleBox[\(1\^+\),
                FontWeight->"Bold"],
              Schiebe[ 1, "+"],
              Editable->True], 
            InterpretationBox[
              StyleBox[\(1\^+\),
                FontWeight->"Bold"],
              Schiebe[ 1, "+"],
              Editable->True], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["J",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TJI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3]}],
              Editable->True]}], "==", 
          RowBox[{
            RowBox[{"(", 
              
              RowBox[{\(\(-\[CapitalSigma]\_3\) \((d - \[Nu]\_1 - \[Nu]\_2 - \
\[Nu]\_3)\) \[Rho]\_\(1, 2, 3\)\), "+", 
                
                RowBox[{\(m\_2\%2\), \(m\_3\%2\), \(\[Phi]\_\(1, 2, 
                      3\)\), \(\[Nu]\_2\), 
                  InterpretationBox[
                    StyleBox[\(2\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 2, "+"],
                    Editable->True], \(\[Nu]\_3\), 
                  InterpretationBox[
                    StyleBox[\(3\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 3, "+"],
                    Editable->True], 
                  InterpretationBox[
                    StyleBox[\(1\^-\),
                      FontWeight->"Bold"],
                    Schiebe[ 1, "-"],
                    Editable->True]}], "+", 
                
                RowBox[{\(m\_1\%2\), \(m\_3\%2\), \(\[Phi]\_\(2, 1, 
                      3\)\), \(\[Nu]\_1\), 
                  InterpretationBox[
                    StyleBox[\(1\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 1, "+"],
                    Editable->True], \(\[Nu]\_3\), 
                  InterpretationBox[
                    StyleBox[\(3\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 3, "+"],
                    Editable->True], 
                  InterpretationBox[
                    StyleBox[\(2\^-\),
                      FontWeight->"Bold"],
                    Schiebe[ 2, "-"],
                    Editable->True]}], "+", 
                
                RowBox[{\(m\_1\%2\), \(m\_2\%2\), \(\[Phi]\_\(3, 1, 
                      2\)\), \(\[Nu]\_1\), 
                  InterpretationBox[
                    StyleBox[\(1\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 1, "+"],
                    Editable->True], \(\[Nu]\_2\), 
                  InterpretationBox[
                    StyleBox[\(2\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 2, "+"],
                    Editable->True], 
                  InterpretationBox[
                    StyleBox[\(3\^-\),
                      FontWeight->"Bold"],
                    Schiebe[ 3, "-"],
                    Editable->True]}], "+", 
                
                RowBox[{\((d - 2 - 2  \[Nu]\_1)\), \(D\_\(1, 2, 
                      3\)\), \(\[Nu]\_1\), 
                  InterpretationBox[
                    StyleBox[\(1\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 1, "+"],
                    Editable->True]}], "+", 
                RowBox[{\(m\_1\%2\), \(S\_\(1, 2, 3\)\), \(\[Nu]\_1\), 
                  InterpretationBox[
                    StyleBox[\(1\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 1, "+"],
                    Editable->True]}], "+", 
                RowBox[{\(m\_2\%2\), \(S\_\(2, 1, 3\)\), \(\[Nu]\_2\), 
                  InterpretationBox[
                    StyleBox[\(2\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 2, "+"],
                    Editable->True]}], "+", 
                RowBox[{\(m\_3\%2\), \(S\_\(3, 1, 2\)\), \(\[Nu]\_3\), 
                  InterpretationBox[
                    StyleBox[\(3\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 3, "+"],
                    Editable->True]}]}], ")"}], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["J",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TJI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3]}],
              Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
    \(s\_78 = OperatorApplyJ[e\_78]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (78)", "Subsection",
  CellTags->"T1.6.57.1"],

Cell[BoxData[
    \(h\_78 = \[Nu]explicit[s\_78] /. \[Nu]\_1 -> \[Nu]\_1 - 2\)], "Input"],

Cell[BoxData[
    \(f\_78 = 
      MakeFun[h\_78, "\<(78)\>", 
        IFF[\(\[Nu]\_1 > 2 && m1 =!= 0\) && D\_\(1, 2, 3\) =!= 0]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CheckTJIRecursion[f\_78]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`"Off"\)], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (80)", "Subsection",
  CellTags->"T1.6.58.1"],

Cell[TextData[{
  Cell[BoxData[
      \(m\_1\%2 == 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu]\_1 > 0\)]]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(e\_80\), "=", 
        RowBox[{
          
          RowBox[{\(\[Nu]\_1\), 
            " ", \((d - 2\ \[Nu]\_1 - 2)\), \(\[CapitalDelta]\_\(2, 3, 6\)\), 
            
            InterpretationBox[
              StyleBox[\(1\^+\),
                FontWeight->"Bold"],
              Schiebe[ 1, "+"],
              Editable->True], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["J",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TJI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3]}],
              Editable->True]}], "==", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{\(-4\), \(m\_2\%2\), \(m\_3\%2\), \(\[Nu]\_2\), 
                  InterpretationBox[
                    StyleBox[\(2\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 2, "+"],
                    Editable->True], \(\[Nu]\_3\), 
                  InterpretationBox[
                    StyleBox[\(3\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 3, "+"],
                    Editable->True], 
                  InterpretationBox[
                    StyleBox[\(1\^-\),
                      FontWeight->"Bold"],
                    Schiebe[ 1, "-"],
                    Editable->True]}], "+", "\n", "\t\t\t\t", 
                RowBox[{"2", \(m\_2\%2\), 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        RowBox[{"(", 
                          RowBox[{
                            InterpretationBox[\(p\^2\),
                              PP], "-", \(m\_2\%2\)}], 
                          ")"}], \((2  d - 2  \[Nu]\_1 - \[Nu]\_2 - 
                            2  \[Nu]\_3 - 1)\)}], 
                      "-", \(\(m\_3\%2\) \((2  \[Nu]\_1 - \[Nu]\_2 - 1)\)\)}],
                     ")"}], \(\[Nu]\_2\), 
                  InterpretationBox[
                    StyleBox[\(2\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 2, "+"],
                    Editable->True]}], "+", "\n", "\t\t\t  ", 
                RowBox[{"2", " ", \(m\_3\%2\), 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        RowBox[{"(", 
                          RowBox[{
                            InterpretationBox[\(p\^2\),
                              PP], "-", \(m\_3\%2\)}], 
                          ")"}], \((2  d - 2  \[Nu]\_1 - 
                            2  \[Nu]\_2 - \[Nu]\_3 - 1)\)}], 
                      "-", \(\(m\_2\%2\) \((2  \[Nu]\_1 - \[Nu]\_3 - 1)\)\)}],
                     ")"}], \(\[Nu]\_3\), 
                  InterpretationBox[
                    StyleBox[\(3\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 3, "+"],
                    Editable->True]}], "-", "\n", 
                "\t\t\t\t", \(\(\[CapitalSigma]\_3\) \((d - \[Nu]\_1 - \
\[Nu]\_2 - \[Nu]\_3)\) u\_\(6, 2, 3\)\)}], ")"}], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["J",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TJI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3]}],
              Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
    \(s\_80 = OperatorApplyJ[e\_80]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (80)", "Subsection",
  CellTags->"T1.6.59.1"],

Cell[BoxData[
    \(h\_80 = \[Nu]explicit[
          s\_80] /. \[Nu]\_1 \[Rule] \[Nu]\_1 - 1\)], "Input"],

Cell[BoxData[
    \(f\_80 = 
      MakeFun[h\_80, "\<(80)\>", 
        IFF[\[Nu]\_1 > 1 && \[CapitalDelta]\_\(2, 3, 6\) =!= 0], 
        m1 :> 0]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CheckTJIRecursion[f\_80]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`"Off"\)], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (81)", "Subsection",
  CellTags->"T1.6.60.1"],

Cell[TextData[{
  "general ",
  Cell[BoxData[
      \(m\_i\%2\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu]\_1, \[Nu]\_2 > 0\)]]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(e\_81\), "=", 
        RowBox[{
          RowBox[{
            InterpretationBox[\(p\^2\),
              PP], \((\[CapitalSigma]\_3 + 2)\), \(\[Nu]\_1\), 
            InterpretationBox[
              StyleBox[\(1\^+\),
                FontWeight->"Bold"],
              Schiebe[ 1, "+"],
              Editable->True], \(\[Nu]\_2\), 
            InterpretationBox[
              StyleBox[\(2\^+\),
                FontWeight->"Bold"],
              Schiebe[ 2, "+"],
              Editable->True], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["J",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox[\(d + 2\),
                    "TraditionalForm"], ")"}]],
              TJI[ 
                Plus[ 2, d], {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3]}],
              Editable->True]}], "==", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  InterpretationBox[\(p\^2\),
                    PP], \((d - 2  \[Nu]\_3)\)}], 
                "+", \(\(m\_1\%2\) \((d - \[Nu]\_1 - 2  \[Nu]\_2)\)\), 
                "+", \(\(m\_2\%2\) \((d - 2  \[Nu]\_1 - \[Nu]\_2)\)\), 
                "-", \(2 \( 
                      m\_3\%2\) \((d - \[Nu]\_1 - \[Nu]\_2 - \[Nu]\_3)\)\), 
                "-", 
                RowBox[{"2", \(m\_3\%2\), 
                  RowBox[{"(", 
                    RowBox[{
                      InterpretationBox[\(p\^2\),
                        PP], "-", \(m\_3\%2\)}], ")"}], \(\[Nu]\_3\), 
                  InterpretationBox[
                    StyleBox[\(3\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 3, "+"],
                    Editable->True]}], "+", 
                RowBox[{\(m\_1\%2\), 
                  RowBox[{"(", 
                    RowBox[{
                      InterpretationBox[\(p\^2\),
                        PP], "-", \(m\_1\%2\), "-", \(3  m\_2\%2\), 
                      "+", \(3  m\_3\%2\), "-", 
                      InterpretationBox[
                        StyleBox[\(2\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 2, "-"],
                        Editable->True], "+", 
                      InterpretationBox[
                        StyleBox[\(3\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 3, "-"],
                        Editable->True]}], ")"}], \(\[Nu]\_1\), 
                  InterpretationBox[
                    StyleBox[\(1\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 1, "+"],
                    Editable->True]}], "+", 
                RowBox[{\(m\_2\%2\), 
                  RowBox[{"(", 
                    RowBox[{
                      InterpretationBox[\(p\^2\),
                        PP], "-", \(3  m\_1\%2\), "-", \(m\_2\%2\), 
                      "+", \(3  m\_3\%2\), "-", 
                      InterpretationBox[
                        StyleBox[\(1\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 1, "-"],
                        Editable->True], "+", 
                      InterpretationBox[
                        StyleBox[\(3\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 3, "-"],
                        Editable->True]}], ")"}], \(\[Nu]\_2\), 
                  InterpretationBox[
                    StyleBox[\(2\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 2, "+"],
                    Editable->True]}]}], ")"}], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["J",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TJI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3]}],
              Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
    \(s\_81 = OperatorApplyJ[e\_81]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (81)", "Subsection",
  CellTags->"T1.6.61.1"],

Cell[BoxData[
    \(h\_81 = \(\(\[Nu]explicit[
              s\_81] /. \[Nu]\_1 -> \[Nu]\_1 - 1\) /. \[Nu]\_2 -> \[Nu]\_2 - 
              1\) /. d -> d - 2\)], "Input"],

Cell[BoxData[
    \(f\_81 = 
      MakeFun[h\_81, "\<(81)\>", 
        IFF[PP =!= 0 && \[Nu]\_1 > 1 && \[Nu]\_2 > 1 && 
            MatchQ[d, _Symbol + _Integer?Positive]]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CheckTJIRecursion[f\_81]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`"Off"\)], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (8123)", "Subsection",
  CellTags->"T1.6.62.1"],

Cell[BoxData[
    \(h\_8123 = \(\(Interchange[s\_81, 
              2 \[LeftRightArrow] 3] /. \[Nu]\_1 -> \[Nu]\_1 - 
                1\) /. \[Nu]\_3 -> \[Nu]\_3 - 1\) /. d -> d - 2\)], "Input"],

Cell[BoxData[
    \(f\_8123 = 
      MakeFun[h\_8123, "\<(8123)\>", 
        IFF[PP =!= 0 && \[Nu]\_1 > 1 && \[Nu]\_3 > 1 && 
            MatchQ[d, _Symbol + _Integer?Positive]]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CheckTJIRecursion[f\_8123]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`"Off"\)], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (8113)", "Subsection",
  CellTags->"T1.6.63.1"],

Cell[BoxData[
    \(h\_8113 = \(\(Interchange[s\_81, 
              1 \[LeftRightArrow] 3] /. \[Nu]\_2 \[Rule] \[Nu]\_2 - 
                1\) /. \[Nu]\_3 \[Rule] \[Nu]\_3 - 1\) /. 
        d \[Rule] d - 2\)], "Input"],

Cell[BoxData[
    \(f\_8113 = 
      MakeFun[h\_8113, "\<(8113)\>", 
        IFF[PP =!= 0 && \[Nu]\_2 > 1 && \[Nu]\_3 > 1 && 
            MatchQ[d, _Symbol + _Integer?Positive]]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CheckTJIRecursion[f\_8113]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`"Off"\)], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (82)", "Subsection",
  CellTags->"T1.6.64.1"],

Cell[TextData[{
  "general ",
  Cell[BoxData[
      \(m\_i\%2\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu]\_1 > 0\)]]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(e\_82\), "=", 
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                InterpretationBox[\(p\^2\),
                  PP]}], \(m\_1\%2\), \((\[CapitalSigma]\_3 + 
                  2)\), \(\[Nu]\_1\), \((\[Nu]\_1 + 1)\), 
              InterpretationBox[
                StyleBox[\(1\^+\),
                  FontWeight->"Bold"],
                Schiebe[ 1, "+"],
                Editable->True], 
              InterpretationBox[
                StyleBox[\(1\^+\),
                  FontWeight->"Bold"],
                Schiebe[ 1, "+"],
                Editable->True], 
              InterpretationBox[
                SubsuperscriptBox[
                  StyleBox["J",
                    SingleLetterItalics->False,
                    FontWeight->"Bold"], 
                  RowBox[{
                    FormBox[\(\[Nu]\_1\),
                      "TraditionalForm"], 
                    FormBox[\(\[Nu]\_2\),
                      "TraditionalForm"], 
                    FormBox[\(\[Nu]\_3\),
                      "TraditionalForm"]}], 
                  RowBox[{"(", 
                    FormBox[\(d + 2\),
                      "TraditionalForm"], ")"}]],
                TJI[ 
                  Plus[ 2, d], {
                  Subscript[ \[Nu], 1], 
                  Subscript[ \[Nu], 2], 
                  Subscript[ \[Nu], 3]}],
                Editable->True]}], "+", 
            RowBox[{\(1\/2\), 
              InterpretationBox[\(p\^2\),
                
                PP], \((\[CapitalSigma]\_3 + 2)\), \((\[CapitalSigma]\_3 + 
                  4)\), \(\[Nu]\_1\), 
              InterpretationBox[
                StyleBox[\(1\^+\),
                  FontWeight->"Bold"],
                Schiebe[ 1, "+"],
                Editable->True], 
              InterpretationBox[
                SubsuperscriptBox[
                  StyleBox["J",
                    SingleLetterItalics->False,
                    FontWeight->"Bold"], 
                  RowBox[{
                    FormBox[\(\[Nu]\_1\),
                      "TraditionalForm"], 
                    FormBox[\(\[Nu]\_2\),
                      "TraditionalForm"], 
                    FormBox[\(\[Nu]\_3\),
                      "TraditionalForm"]}], 
                  RowBox[{"(", 
                    FormBox[\(d + 2\),
                      "TraditionalForm"], ")"}]],
                TJI[ 
                  Plus[ 2, d], {
                  Subscript[ \[Nu], 1], 
                  Subscript[ \[Nu], 2], 
                  Subscript[ \[Nu], 3]}],
                Editable->True]}]}], "==", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{\(-\(1\/2\)\), 
                  SuperscriptBox[
                    RowBox[{"(", 
                      InterpretationBox[\(p\^2\),
                        PP], ")"}], 
                    "2"], \((d + 2  \[Nu]\_1 - 2  \[Nu]\_2 - 2  \[Nu]\_3)\)}],
                 "+", 
                RowBox[{\(1\/2\), 
                  InterpretationBox[\(p\^2\),
                    
                    PP], \((\(m\_1\%2\) \((6  \[Nu]\_1 + 6  \[Nu]\_2 + 
                            6  \[Nu]\_3 - 7  d)\) + \(m\_2\%2\) \((7  d - 
                            2  \[Nu]\_1 - 4  \[Nu]\_2 - 
                            10  \[Nu]\_3)\) + \(m\_3\%2\) \((7  d - 
                            2  \[Nu]\_1 - 10  \[Nu]\_2 - 4  \[Nu]\_3)\))\)}], 
                "+", \(\(\((m\_2\%2)\)\^2\) \((d - 
                      2  \[Nu]\_1 - \[Nu]\_2)\)\), 
                "+", \(\(\((m\_3\%2)\)\^2\) \((d - 
                      2  \[Nu]\_1 - \[Nu]\_3)\)\), 
                "+", \(\(m\_1\%2\) \(m\_2\%2\) \((d - \[Nu]\_1 - 
                      2  \[Nu]\_2)\)\), 
                "+", \(\(m\_1\%2\) \(m\_3\%2\) \((d - \[Nu]\_1 - 
                      2  \[Nu]\_3)\)\), 
                "-", \(4 \( 
                      m\_2\%2\) \(m\_3\%2\) \((d - \[Nu]\_1 - \[Nu]\_2 - \
\[Nu]\_3)\)\), "-", 
                RowBox[{\(m\_1\%2\), 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"2", 
                        SuperscriptBox[
                          RowBox[{"(", 
                            InterpretationBox[\(p\^2\),
                              PP], ")"}], "2"]}], "-", 
                      RowBox[{
                        InterpretationBox[\(p\^2\),
                          PP], \((2  m\_1\%2 + m\_2\%2 + m\_3\%2)\)}], 
                      "+", \(\(m\_1\%2\) \((m\_2\%2 + m\_3\%2)\)\), 
                      "+", \(3 \((m\_2\%2 - m\_3\%2)\)\^2\)}], 
                    ")"}], \(\[Nu]\_1\), 
                  InterpretationBox[
                    StyleBox[\(1\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 1, "+"],
                    Editable->True]}], "+", 
                RowBox[{\(m\_2\%2\), 
                  RowBox[{"(", 
                    RowBox[{
                      SuperscriptBox[
                        RowBox[{"(", 
                          InterpretationBox[\(p\^2\),
                            PP], ")"}], "2"], "+", 
                      RowBox[{
                        RowBox[{"(", 
                          RowBox[{
                            InterpretationBox[\(p\^2\),
                              PP], "-", \(m\_2\%2\)}], ")"}], 
                        RowBox[{"(", 
                          RowBox[{\(3  m\_1\%2\), "-", \(5  m\_3\%2\), "+", 
                            InterpretationBox[
                              StyleBox[\(1\^-\),
                                FontWeight->"Bold"],
                              Schiebe[ 1, "-"],
                              Editable->True], "-", 
                            InterpretationBox[
                              StyleBox[\(3\^-\),
                                FontWeight->"Bold"],
                              Schiebe[ 3, "-"],
                              Editable->True]}], ")"}]}], 
                      "-", \(\((m\_2\%2)\)\^2\)}], ")"}], \(\[Nu]\_2\), 
                  InterpretationBox[
                    StyleBox[\(2\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 2, "+"],
                    Editable->True]}], "+", 
                RowBox[{\(m\_3\%2\), 
                  RowBox[{"(", 
                    RowBox[{
                      SuperscriptBox[
                        RowBox[{"(", 
                          InterpretationBox[\(p\^2\),
                            PP], ")"}], "2"], "+", 
                      RowBox[{
                        RowBox[{"(", 
                          RowBox[{
                            InterpretationBox[\(p\^2\),
                              PP], "-", \(m\_3\%2\)}], ")"}], 
                        RowBox[{"(", 
                          RowBox[{\(3  m\_1\%2\), "-", \(5  m\_2\%2\), "+", 
                            InterpretationBox[
                              StyleBox[\(1\^-\),
                                FontWeight->"Bold"],
                              Schiebe[ 1, "-"],
                              Editable->True], "-", 
                            InterpretationBox[
                              StyleBox[\(2\^-\),
                                FontWeight->"Bold"],
                              Schiebe[ 2, "-"],
                              Editable->True]}], ")"}]}], 
                      "-", \(\((m\_3\%2)\)\^2\)}], ")"}], \(\[Nu]\_3\), 
                  InterpretationBox[
                    StyleBox[\(3\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 3, "+"],
                    Editable->True]}], "-", 
                RowBox[{\(1\/2\), 
                  InterpretationBox[\(p\^2\),
                    PP], \((\[CapitalSigma]\_3 + 2)\), 
                  RowBox[{"(", 
                    RowBox[{
                      InterpretationBox[
                        StyleBox[\(1\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 1, "-"],
                        Editable->True], "-", 
                      InterpretationBox[
                        StyleBox[\(2\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 2, "-"],
                        Editable->True], "-", 
                      InterpretationBox[
                        StyleBox[\(3\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 3, "-"],
                        Editable->True]}], ")"}]}], "-", 
                RowBox[{\(m\_1\%2\), \((m\_2\%2 - m\_3\%2)\), \(\[Nu]\_1\), 
                  InterpretationBox[
                    StyleBox[\(1\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 1, "+"],
                    Editable->True], 
                  RowBox[{"(", 
                    RowBox[{
                      InterpretationBox[
                        StyleBox[\(2\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 2, "-"],
                        Editable->True], "-", 
                      InterpretationBox[
                        StyleBox[\(3\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 3, "-"],
                        Editable->True]}], ")"}]}]}], ")"}], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["J",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TJI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3]}],
              Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
    \(r\_82 = OperatorApplyJ[e\_82]\)], "Input"],

Cell[BoxData[
    \(r\_82[\([1, 1]\)]\)], "Input"],

Cell[BoxData[
    \(\(s\_82 = \((r\_82[\([1, 2]\)] == \(-r\_82[\([1, 1]\)]\) + 
              r\_82[\([2]\)])\);\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (82)", "Subsection",
  CellTags->"T1.6.65.1"],

Cell[BoxData[
    \(h\_82 = \(\[Nu]explicit[s\_82] /. \[Nu]\_1 -> \[Nu]\_1 - 2\) /. 
        d -> d - 2\)], "Input"],

Cell[BoxData[
    \(f\_82 = 
      MakeFun[h\_82, "\<(82)\>", 
        IFF[\(PP =!= 0 && \[Nu]\_1 > 2 && m1 =!= 0\) && 
            MatchQ[d, _Symbol + _Integer?Positive]]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CheckTJIRecursion[f\_82]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`"Off"\)], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (8213)", "Subsection",
  CellTags->"T1.6.66.1"],

Cell[BoxData[
    \(h\_8213 = \(Interchange[s\_82, 
            1 \[LeftRightArrow] 3] /. \[Nu]\_3 -> \[Nu]\_3 - 2\) /. 
        d -> d - 2\)], "Input"],

Cell[BoxData[
    \(f\_8213 = 
      MakeFun[h\_8213, "\<(8213)\>", 
        IFF[\(PP =!= 0 && m3 =!= 0\) && \[Nu]\_3 > 2 && 
            MatchQ[d, _Symbol + _Integer?Positive]]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CheckTJIRecursion[f\_8213]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`"Off"\)], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (8212)", "Subsection",
  CellTags->"T1.6.67.1"],

Cell[BoxData[
    \(h\_8212 = \(Interchange[s\_82, 
            1 \[LeftRightArrow] 2] /. \[Nu]\_2 -> \[Nu]\_2 - 2\) /. 
        d -> d - 2\)], "Input"],

Cell[BoxData[
    \(f\_8212 = 
      MakeFun[h\_8212, "\<(8212)\>", 
        IFF[\(PP =!= 0 && \[Nu]\_2 > 2 && m2 =!= 0\) && 
            MatchQ[d, _Symbol + _Integer?Positive]]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CheckTJIRecursion[f\_8212]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`"Off"\)], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (83)", "Subsection",
  CellTags->"T1.6.68.1"],

Cell[TextData[{
  Cell[BoxData[
      \(m\_1\%2 == 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu]\_1 > 0\)]]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(e\_83\), "=", 
        RowBox[{
          RowBox[{
            InterpretationBox[\(p\^2\),
              
              PP], \((\[CapitalSigma]\_3 + 2)\), \((\[CapitalSigma]\_3 + 
                4)\), \(\[Nu]\_1\), 
            InterpretationBox[
              StyleBox[\(1\^+\),
                FontWeight->"Bold"],
              Schiebe[ 1, "+"],
              Editable->True], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["J",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox[\(d + 2\),
                    "TraditionalForm"], ")"}]],
              TJI[ 
                Plus[ 2, d], {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3]}],
              Editable->True]}], "==", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"-", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        InterpretationBox[\(p\^2\),
                          PP], ")"}], "2"]}], \((d + 2  \[Nu]\_1 - 
                      2  \[Nu]\_2 - 2  \[Nu]\_3)\)}], "+", 
                RowBox[{
                  InterpretationBox[\(p\^2\),
                    
                    PP], \((\(m\_2\%2\) \((7  d - 2  \[Nu]\_1 - 4  \[Nu]\_2 - 
                            10  \[Nu]\_3)\) + \(m\_3\%2\) \((7  d - 
                            2  \[Nu]\_1 - 10  \[Nu]\_2 - 4  \[Nu]\_3)\))\)}], 
                "+", \(2 \(\((m\_2\%2)\)\^2\) \((d - 
                      2  \[Nu]\_1 - \[Nu]\_2)\)\), 
                "+", \(2 \(\((m\_3\%2)\)\^2\) \((d - 
                      2  \[Nu]\_1 - \[Nu]\_3)\)\), 
                "-", \(8 \( 
                      m\_2\%2\) \(m\_3\%2\) \((d - \[Nu]\_1 - \[Nu]\_2 - \
\[Nu]\_3)\)\), "+", 
                RowBox[{"2", \(m\_2\%2\), 
                  RowBox[{"(", 
                    RowBox[{
                      SuperscriptBox[
                        RowBox[{"(", 
                          InterpretationBox[\(p\^2\),
                            PP], ")"}], "2"], "-", 
                      RowBox[{
                        RowBox[{"(", 
                          RowBox[{
                            InterpretationBox[\(p\^2\),
                              PP], "-", \(m\_2\%2\)}], ")"}], 
                        RowBox[{"(", 
                          RowBox[{\(5  m\_3\%2\), "-", 
                            InterpretationBox[
                              StyleBox[\(1\^-\),
                                FontWeight->"Bold"],
                              Schiebe[ 1, "-"],
                              Editable->True], "+", 
                            InterpretationBox[
                              StyleBox[\(3\^-\),
                                FontWeight->"Bold"],
                              Schiebe[ 3, "-"],
                              Editable->True]}], ")"}]}], 
                      "-", \(\((m\_2\%2)\)\^2\)}], ")"}], \(\[Nu]\_2\), 
                  InterpretationBox[
                    StyleBox[\(2\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 2, "+"],
                    Editable->True]}], "+", 
                RowBox[{"2", \(m\_3\%2\), 
                  RowBox[{"(", 
                    RowBox[{
                      SuperscriptBox[
                        RowBox[{"(", 
                          InterpretationBox[\(p\^2\),
                            PP], ")"}], "2"], "-", 
                      RowBox[{
                        RowBox[{"(", 
                          RowBox[{
                            InterpretationBox[\(p\^2\),
                              PP], "-", \(m\_3\%2\)}], ")"}], 
                        RowBox[{"(", 
                          RowBox[{\(5  m\_2\%2\), "-", 
                            InterpretationBox[
                              StyleBox[\(1\^-\),
                                FontWeight->"Bold"],
                              Schiebe[ 1, "-"],
                              Editable->True], "+", 
                            InterpretationBox[
                              StyleBox[\(2\^-\),
                                FontWeight->"Bold"],
                              Schiebe[ 2, "-"],
                              Editable->True]}], ")"}]}], 
                      "-", \(\((m\_3\%2)\)\^2\)}], ")"}], \(\[Nu]\_3\), 
                  InterpretationBox[
                    StyleBox[\(3\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 3, "+"],
                    Editable->True]}], "-", 
                RowBox[{
                  InterpretationBox[\(p\^2\),
                    PP], \((\[CapitalSigma]\_3 + 2)\), 
                  RowBox[{"(", 
                    RowBox[{
                      InterpretationBox[
                        StyleBox[\(1\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 1, "-"],
                        Editable->True], "-", 
                      InterpretationBox[
                        StyleBox[\(2\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 2, "-"],
                        Editable->True], "-", 
                      InterpretationBox[
                        StyleBox[\(3\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 3, "-"],
                        Editable->True]}], ")"}]}]}], ")"}], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["J",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TJI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3]}],
              Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
    \(s\_83 = OperatorApplyJ[e\_83]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (83)", "Subsection",
  CellTags->"T1.6.69.1"],

Cell[BoxData[
    \(h\_83 = \(\[Nu]explicit[s\_83] /. \[Nu]\_1 -> \[Nu]\_1 - 1\) /. 
        d -> d - 2\)], "Input"],

Cell[BoxData[
    \(f\_83 = 
      MakeFun[h\_83, "\<(83)\>", 
        IFF[PP =!= 0 && \[Nu]\_1 > 1 && 
            MatchQ[d, _Symbol + _Integer?Positive]], m1 :> 0]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CheckTJIRecursion[f\_83]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`"Off"\)], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (87)", "Subsection",
  CellTags->"T1.6.70.1"],

Cell[CellGroupData[{

Cell["(88)", "Subsubsection",
  CellTags->"T1.6.70.1.1"],

Cell[BoxData[
    \(\(t\_1 = m\_1\%2 + m\_2\%2 + m\_3\%2;\)\)], "Input"],

Cell[BoxData[
    \(\(t\_2 = 
        3 \((m\_1\%4 + m\_2\%4 + m\_3\%4)\) + 
          2 \((\(m\_1\%2\) m\_2\%2 + \(m\_1\%2\) m\_3\%2 + \(m\_2\%2\) 
                  m\_3\%2)\);\)\)], "Input"],

Cell[BoxData[
    \(\(t\_3 = \(m\_1\%2\) \((m\_1\%4 - m\_2\%4 - 
                m\_3\%4)\) + \(m\_2\%2\) \((m\_2\%4 - m\_1\%4 - 
                m\_3\%4)\) + \(m\_3\%2\) \((m\_3\%4 - m\_1\%4 - m\_2\%4)\) + 
          10 \( m\_1\%2\) \(m\_2\%2\) m\_3\%2;\)\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(f[\[Mu]1_, \[Mu]2_, \ \[Mu]3_]\), ":=", 
        RowBox[{"\[Mu]1", 
          RowBox[{"(", 
            RowBox[{
              InterpretationBox[\(p\^2\),
                PP], "-", "\[Mu]1"}], ")"}], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{\(-2\), \((d - 4)\), 
                SuperscriptBox[
                  RowBox[{"(", 
                    InterpretationBox[\(p\^2\),
                      PP], ")"}], "2"]}], "+", 
              RowBox[{
                InterpretationBox[\(p\^2\),
                  
                  PP], \((4 \( t\_1\) \((5  d - 18)\) - 
                    24  \[Mu]1 \((2  d - 7)\))\)}], 
              "-", \(2 \((4  d - 13)\) t\_1\^2\), 
              "+", \(2 \((9  d - 31)\) t\_2\), 
              "-", \(24  \[Mu]2\ \[Mu]3 \((4  d - 13)\)\), 
              "-", \(24\ \(\[Mu]1\^2\) \((2  d - 7)\)\)}], ")"}]}]}], 
      ";"}]], "Input"],

Cell[BoxData[
    \(\(f\_\(1, 2, 3\) = f[m\_1\%2, m\_2\%2, m\_3\%2];\)\)], "Input"],

Cell[BoxData[
    \(\(f\_\(2, 1, 3\) = f[m\_2\%2, m\_1\%2, m\_3\%2];\)\)], "Input"],

Cell[BoxData[
    \(\(f\_\(3, 2, 1\) = f[m\_3\%2, m\_2\%2, m\_1\%2];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["(89)", "Subsubsection",
  CellTags->"T1.6.70.2.1"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(g[\[Mu]1_, \[Mu]2_, \ \[Mu]3_]\), ":=", 
        RowBox[{\(\(\[Mu]1\ \[Mu]2\)\/\(d - 4\)\), 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"4", \((d - 4)\), 
                SuperscriptBox[
                  RowBox[{"(", 
                    InterpretationBox[\(p\^2\),
                      PP], ")"}], "2"]}], "-", 
              RowBox[{"4", \((7  d - 24)\), 
                InterpretationBox[\(p\^2\),
                  PP], \((3  \[Mu]3 - 2  t\_1)\)}], 
              "-", \(\(t\_1\^2\) \((23  d - 80)\)\), 
              "+", \(\(t\_2\) \((9  d - 32)\)\), 
              "-", \(12 \( \[Mu]3\^2\) \((d - 4)\)\), 
              "+", \(12  \[Mu]1\ \[Mu]2\ \((7  d - 24)\)\)}], ")"}]}]}], 
      ";"}]], "Input"],

Cell[BoxData[
    \(\(g\_\(1, 2, 3\) = g[m\_1\%2, m\_2\%2, m\_3\%2];\)\)], "Input"],

Cell[BoxData[
    \(\(g\_\(1, 3, 2\) = g[m\_1\%2, m\_3\%2, m\_2\%2];\)\)], "Input"],

Cell[BoxData[
    \(\(g\_\(2, 3, 1\) = g[m\_2\%2, m\_3\%2, m\_1\%2];\)\)], "Input"],

Cell[BoxData[
    \(g\_\(1, 2, 3\)\)], "Input"],

Cell[TextData[{
  "general  ",
  Cell[BoxData[
      \(m\_i\%2\)]],
  " "
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(e\_87\), "=", 
        RowBox[{
          RowBox[{"3", 
            InterpretationBox[\(p\^2\),
              PP], \((d - 3)\), \((d - 4)\), \((3  d - 8)\), \((3  d - 10)\), 
            
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["J",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox["1",
                    "TraditionalForm"], 
                  FormBox["1",
                    "TraditionalForm"], 
                  FormBox["1",
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TJI[ d, {1, 1, 1}],
              Editable->True]}], "==", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{\(\((d - 4)\)\^2\), 
                  SuperscriptBox[
                    RowBox[{"(", 
                      InterpretationBox[\(p\^2\),
                        PP], ")"}], "3"]}], "-", 
                RowBox[{"2", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      InterpretationBox[\(p\^2\),
                        PP], ")"}], 
                    "2"], \(t\_1\), \((d - 4)\), \((6  d - 23)\)}], "+", 
                RowBox[{
                  InterpretationBox[\(p\^2\),
                    
                    PP], \((5 \( t\_1\^2\) \((15  d\^2 - 117  d + 
                            224)\) - \(t\_2\) \((42  d\^2 - 331  d + 
                            640)\))\)}], 
                "-", \(\(1\/4\) \((d - 
                      5)\) \((\(t\_3\) \((27  d - 
                            90)\) - \(t\_1\) \(t\_2\) \((3  d - 2)\) - 
                      2 \( t\_1\^3\) \((5  d - 26)\))\)\), "+", 
                RowBox[{\(f\_\(1, 2, 3\)\), 
                  InterpretationBox[
                    StyleBox[\(1\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 1, "+"],
                    Editable->True]}], "+", 
                RowBox[{\(f\_\(2, 1, 3\)\), 
                  InterpretationBox[
                    StyleBox[\(2\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 2, "+"],
                    Editable->True]}], "+", 
                RowBox[{\(f\_\(3, 2, 1\)\), 
                  InterpretationBox[
                    StyleBox[\(3\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 3, "+"],
                    Editable->True]}], "+", 
                RowBox[{\(g\_\(1, 2, 3\)\), 
                  InterpretationBox[
                    StyleBox[\(1\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 1, "+"],
                    Editable->True], 
                  InterpretationBox[
                    StyleBox[\(2\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 2, "+"],
                    Editable->True], 
                  InterpretationBox[
                    StyleBox[\(3\^-\),
                      FontWeight->"Bold"],
                    Schiebe[ 3, "-"],
                    Editable->True]}], "+", 
                RowBox[{\(g\_\(1, 3, 2\)\), 
                  InterpretationBox[
                    StyleBox[\(1\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 1, "+"],
                    Editable->True], 
                  InterpretationBox[
                    StyleBox[\(2\^-\),
                      FontWeight->"Bold"],
                    Schiebe[ 2, "-"],
                    Editable->True], 
                  InterpretationBox[
                    StyleBox[\(3\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 3, "+"],
                    Editable->True]}], "+", 
                RowBox[{\(g\_\(2, 3, 1\)\), 
                  InterpretationBox[
                    StyleBox[\(1\^-\),
                      FontWeight->"Bold"],
                    Schiebe[ 1, "-"],
                    Editable->True], 
                  InterpretationBox[
                    StyleBox[\(2\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 2, "+"],
                    Editable->True], 
                  InterpretationBox[
                    StyleBox[\(3\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 3, "+"],
                    Editable->True]}]}], ")"}], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["J",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox["1",
                    "TraditionalForm"], 
                  FormBox["1",
                    "TraditionalForm"], 
                  FormBox["1",
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox[\(d - 2\),
                    "TraditionalForm"], ")"}]],
              TJI[ 
                Plus[ -2, d], {1, 1, 1}],
              Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
    \(s\_87 = OperatorApplyJ[e\_87]\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (87)", "Subsection",
  CellTags->"T1.6.71.1"],

Cell[BoxData[
    \(h\_87 = s\_87\)], "Input"],

Cell[BoxData[
    \(\(f\_87 = 
        MakeFun[h\_87, "\<(87)\>", 
          IFF[PP =!= 0 && 
              MatchQ[d, _Symbol + _Integer?Positive]]];\)\)], "Input"],

Cell["CheckTJIRecursion not applicable.", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (90)", "Subsection",
  CellTags->"T1.6.72.1"],

Cell[TextData[{
  "general  ",
  Cell[BoxData[
      \(m\_i\%2\)]],
  " "
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(e\_90\), "=", 
        RowBox[{
          RowBox[{"3", 
            InterpretationBox[\(p\^2\),
              PP], \((d - 3)\), \((d - 4)\), \((3  d - 10)\), 
            InterpretationBox[
              StyleBox[\(1\^+\),
                FontWeight->"Bold"],
              Schiebe[ 1, "+"],
              Editable->True], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["J",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox["1",
                    "TraditionalForm"], 
                  FormBox["1",
                    "TraditionalForm"], 
                  FormBox["1",
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TJI[ d, {1, 1, 1}],
              Editable->True]}], "==", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{\(-m\_1\%2\), 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          RowBox[{"(", 
                            InterpretationBox[\(p\^2\),
                              PP], ")"}], "2"], \((7  d - 24)\)}], "-", 
                      RowBox[{"2", 
                        InterpretationBox[\(p\^2\),
                          
                          PP], \((\((4  d - 15)\) t\_1 - \((d - 5)\) 
                              m\_1\%2)\)}], 
                      "+", \(\(3\/2\) \((d - 5)\) t\_1\^2\), 
                      "+", \(\(5\/2\) \((d - 3)\) t\_2\), 
                      "-", \(2 \((5  d - 17)\) \((m\_1\%2)\)\^2\), 
                      "-", \(2 \((13  d - 45)\) \(m\_2\%2\) m\_3\%2\)}], 
                    ")"}], 
                  InterpretationBox[
                    StyleBox[\(1\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 1, "+"],
                    Editable->True]}], "+", "\n", "\t\t\t\t", 
                RowBox[{"2", \(m\_2\%2\), 
                  RowBox[{"(", 
                    RowBox[{
                      InterpretationBox[\(p\^2\),
                        PP], "-", \(m\_2\%2\)}], ")"}], 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{\((d - 3)\), 
                        RowBox[{"(", 
                          RowBox[{
                            InterpretationBox[\(p\^2\),
                              PP], "+", \(m\_2\%2\), "-", \(5  m\_3\%2\)}], 
                          ")"}]}], "+", \(\((7  d - 25)\) m\_1\%2\)}], ")"}], 
                  
                  InterpretationBox[
                    StyleBox[\(2\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 2, "+"],
                    Editable->True]}], "+", "\n", "\t\t\t\t", 
                RowBox[{"2", \(m\_3\%2\), 
                  RowBox[{"(", 
                    RowBox[{
                      InterpretationBox[\(p\^2\),
                        PP], "-", \(m\_3\%2\)}], ")"}], 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{\((d - 3)\), 
                        RowBox[{"(", 
                          RowBox[{
                            InterpretationBox[\(p\^2\),
                              PP], "-", \(5  m\_2\%2\), "+", \(m\_3\%2\)}], 
                          ")"}]}], "+", \(\((7  d - 25)\) m\_1\%2\)}], ")"}], 
                  
                  InterpretationBox[
                    StyleBox[\(3\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 3, "+"],
                    Editable->True]}], "-", "\n", "\t\t\t\t", 
                RowBox[{\((d - 3)\), \((d - 4)\), 
                  SuperscriptBox[
                    RowBox[{"(", 
                      InterpretationBox[\(p\^2\),
                        PP], ")"}], "2"]}], "+", 
                RowBox[{
                  InterpretationBox[\(p\^2\),
                    
                    PP], \((\((7  d - 30)\) \((d - 3)\) 
                        t\_1 - \((7  d - 31)\) \((3  d - 10)\) m\_1\%2)\)}], 
                "+", \(\(1\/4\) \((d - 
                      5)\) \((\((17  d - 66)\) t\_1\^2 - \((3  d - 14)\) 
                        t\_2 - 
                      4 \((3  d - 10)\) \((\((m\_1\%2)\)\^2 + 
                            5 \( m\_2\%2\) m\_3\%2)\))\)\), "+", "\t", 
                RowBox[{\(2\/\(d - 4\)\), 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              RowBox[{"(", 
                                RowBox[{
                                  InterpretationBox[\(p\^2\),
                                    PP], "+", \(m\_2\%2\)}], 
                                ")"}], \((7  d - 24)\)}], 
                            "+", \(\((d - 4)\) m\_1\%2\), 
                            "-", \(\((5  d - 18)\) m\_3\%2\)}], 
                          ")"}], \(m\_1\%2\), \(m\_2\%2\), 
                        InterpretationBox[
                          StyleBox[\(1\^+\),
                            FontWeight->"Bold"],
                          Schiebe[ 1, "+"],
                          Editable->True], 
                        InterpretationBox[
                          StyleBox[\(2\^+\),
                            FontWeight->"Bold"],
                          Schiebe[ 2, "+"],
                          Editable->True], 
                        InterpretationBox[
                          StyleBox[\(3\^-\),
                            FontWeight->"Bold"],
                          Schiebe[ 3, "-"],
                          Editable->True]}], "+", "\n", "\t\t\t\t\t\t", 
                      RowBox[{
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              RowBox[{"(", 
                                RowBox[{
                                  InterpretationBox[\(p\^2\),
                                    PP], "+", \(m\_3\%2\)}], 
                                ")"}], \((7  d - 24)\)}], 
                            "+", \(\((d - 4)\) m\_1\%2\), 
                            "-", \(\((5  d - 18)\) m\_2\%2\)}], 
                          ")"}], \(m\_1\%2\), \(m\_3\%2\), 
                        InterpretationBox[
                          StyleBox[\(1\^+\),
                            FontWeight->"Bold"],
                          Schiebe[ 1, "+"],
                          Editable->True], 
                        InterpretationBox[
                          StyleBox[\(2\^-\),
                            FontWeight->"Bold"],
                          Schiebe[ 2, "-"],
                          Editable->True], 
                        InterpretationBox[
                          StyleBox[\(3\^+\),
                            FontWeight->"Bold"],
                          Schiebe[ 3, "+"],
                          Editable->True]}], "-", "\n", "\t\t\t\t\t\t", 
                      RowBox[{"2", 
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              RowBox[{"(", 
                                RowBox[{
                                  InterpretationBox[\(p\^2\),
                                    PP], "+", \(m\_2\%2\), "+", \(m\_3\%2\)}],
                                 ")"}], \((d - 3)\)}], 
                            "+", \(\((d - 4)\) m\_1\%2\)}], 
                          ")"}], \(m\_2\%2\), \(m\_3\%2\), 
                        InterpretationBox[
                          StyleBox[\(1\^-\),
                            FontWeight->"Bold"],
                          Schiebe[ 1, "-"],
                          Editable->True], 
                        InterpretationBox[
                          StyleBox[\(2\^+\),
                            FontWeight->"Bold"],
                          Schiebe[ 2, "+"],
                          Editable->True], 
                        InterpretationBox[
                          StyleBox[\(3\^+\),
                            FontWeight->"Bold"],
                          Schiebe[ 3, "+"],
                          Editable->True]}]}], ")"}]}]}], ")"}], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["J",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox["1",
                    "TraditionalForm"], 
                  FormBox["1",
                    "TraditionalForm"], 
                  FormBox["1",
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox[\(d - 2\),
                    "TraditionalForm"], ")"}]],
              TJI[ 
                Plus[ -2, d], {1, 1, 1}],
              Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
    \(s\_90 = OperatorApplyJ[e\_90]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (90)", "Subsection",
  CellTags->"T1.6.73.1"],

Cell[BoxData[
    \(\(h\_90 = s\_90;\)\)], "Input"],

Cell[BoxData[
    \(f\_90 = 
      MakeFun[h\_90, "\<(90)\>", 
        IFF[PP =!= 0 && MatchQ[d, _Symbol + _Integer?Positive]]]\)], "Input"],

Cell["CheckTJIRecursion not applicable.", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (91)", "Subsection",
  CellTags->"T1.6.74.1"],

Cell[TextData[{
  "general ",
  Cell[BoxData[
      \(m\_i\%2\)]]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(e\_91.1\), "=", " ", 
        RowBox[{
          RowBox[{\((d - 2)\), \(\[Nu]\_1\), 
            InterpretationBox[
              StyleBox[\(1\^+\),
                FontWeight->"Bold"],
              Schiebe[ 1, "+"],
              Editable->True], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["K",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TKI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3]}],
              Editable->True]}], "==", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{\(-u\_\(1, 2, 3\)\), "-", 
                InterpretationBox[
                  StyleBox[\(1\^-\),
                    FontWeight->"Bold"],
                  Schiebe[ 1, "-"],
                  Editable->True], "+", 
                InterpretationBox[
                  StyleBox[\(2\^-\),
                    FontWeight->"Bold"],
                  Schiebe[ 2, "-"],
                  Editable->True], "+", 
                InterpretationBox[
                  StyleBox[\(3\^-\),
                    FontWeight->"Bold"],
                  Schiebe[ 3, "-"],
                  Editable->True]}], ")"}], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["K",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox[\(d - 2\),
                    "TraditionalForm"], ")"}]],
              TKI[ 
                Plus[ -2, d], {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3]}],
              Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
    \(s\_91.1 = OperatorApplyK[e\_91.1]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(e\_91.2\), "=", 
        RowBox[{
          RowBox[{\((d - 2)\), \(\[Nu]\_2\), 
            InterpretationBox[
              StyleBox[\(2\^+\),
                FontWeight->"Bold"],
              Schiebe[ 2, "+"],
              Editable->True], \(\[Nu]\_3\), 
            InterpretationBox[
              StyleBox[\(3\^+\),
                FontWeight->"Bold"],
              Schiebe[ 3, "+"],
              Editable->True], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["K",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TKI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3]}],
              Editable->True]}], "==", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{\(-2\), \(m\_1\%2\), \(\[Nu]\_1\), 
                  InterpretationBox[
                    StyleBox[\(1\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 1, "+"],
                    Editable->True]}], "+", \((d - 2 - 2  \[Nu]\_1)\)}], 
              ")"}], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["K",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox[\(d - 2\),
                    "TraditionalForm"], ")"}]],
              TKI[ 
                Plus[ -2, d], {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3]}],
              Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
    \(s\_91.2 = OperatorApplyK[e\_91.2]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(e\_91.3\), "=", 
        RowBox[{
          RowBox[{\((d - 2)\), \((d - \[Nu]\_1 - \[Nu]\_2 - \[Nu]\_3)\), 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["K",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TKI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3]}],
              Editable->True]}], "==", 
          RowBox[{
            RowBox[{"-", 
              RowBox[{"(", 
                RowBox[{\(\[CapitalDelta]\_\(1, 2, 3\)\), "+", 
                  RowBox[{\(u\_\(1, 2, 3\)\), 
                    InterpretationBox[
                      StyleBox[\(1\^-\),
                        FontWeight->"Bold"],
                      Schiebe[ 1, "-"],
                      Editable->True]}], "+", 
                  RowBox[{\(u\_\(2, 1, 3\)\), 
                    InterpretationBox[
                      StyleBox[\(2\^-\),
                        FontWeight->"Bold"],
                      Schiebe[ 2, "-"],
                      Editable->True]}], "+", 
                  RowBox[{\(u\_\(3, 1, 2\)\), 
                    InterpretationBox[
                      StyleBox[\(3\^-\),
                        FontWeight->"Bold"],
                      Schiebe[ 3, "-"],
                      Editable->True]}]}], ")"}]}], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["K",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox[\(d - 2\),
                    "TraditionalForm"], ")"}]],
              TKI[ 
                Plus[ -2, d], {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3]}],
              Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
    \(s\_91.3 = OperatorApplyK[e\_91.3]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(e\_91.4\), "=", 
        RowBox[{
          RowBox[{\(\[CapitalDelta]\_\(1, 2, 3\)\), \(\[Nu]\_1\), 
            InterpretationBox[
              StyleBox[\(1\^+\),
                FontWeight->"Bold"],
              Schiebe[ 1, "+"],
              Editable->True], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["K",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TKI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3]}],
              Editable->True]}], "==", 
          RowBox[{
            RowBox[{"(", 
              
              RowBox[{\(\(u\_\(1, 2, 3\)\) \((d - \[Nu]\_1 - 2  \[Nu]\_2)\)\),
                 "+", \(2 \( m\_2\%2\) \((\[Nu]\_1 - \[Nu]\_2)\)\), "+", 
                RowBox[{\(u\_\(3, 1, 2\)\), \(\[Nu]\_1\), 
                  InterpretationBox[
                    StyleBox[\(1\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 1, "+"],
                    Editable->True], 
                  RowBox[{"(", 
                    RowBox[{
                      InterpretationBox[
                        StyleBox[\(2\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 2, "-"],
                        Editable->True], "-", 
                      InterpretationBox[
                        StyleBox[\(3\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 3, "-"],
                        Editable->True]}], ")"}]}], "+", 
                RowBox[{"2", \(m\_2\%2\), \(\[Nu]\_2\), 
                  InterpretationBox[
                    StyleBox[\(2\^+\),
                      FontWeight->"Bold"],
                    Schiebe[ 2, "+"],
                    Editable->True], 
                  RowBox[{"(", 
                    RowBox[{
                      InterpretationBox[
                        StyleBox[\(1\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 1, "-"],
                        Editable->True], "-", 
                      InterpretationBox[
                        StyleBox[\(3\^-\),
                          FontWeight->"Bold"],
                        Schiebe[ 3, "-"],
                        Editable->True]}], ")"}]}]}], ")"}], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["K",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TKI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3]}],
              Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
    \(s\_91.4 = OperatorApplyK[e\_91.4]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (911)", "Subsection",
  CellTags->"T1.6.75.1"],

Cell[BoxData[
    \(h\_911 = s\_91.1 /. \[Nu]\_1 -> \[Nu]\_1 - 1\)], "Input"],

Cell[BoxData[
    \(f\_911 = 
      MakeFun[h\_911, "\<(911)\>", 
        IFF[\[Nu]\_1 > 1 && 
            MatchQ[d, _Symbol + _Integer?Positive]]]\)], "Input"],

Cell["CheckTJIRecursion not applicable.", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (912)", "Subsection",
  CellTags->"T1.6.76.1"],

Cell[BoxData[
    \(h\_912 = \(s\_91.2 /. \[Nu]\_2 -> \[Nu]\_2 - 
              1\) /. \[Nu]\_3 -> \[Nu]\_3 - 1\)], "Input"],

Cell[BoxData[
    \(f\_912 = 
      MakeFun[h\_912, "\<(912)\>", 
        IFF[\[Nu]\_2 > 1 && \[Nu]\_3 > 1 && 
            MatchQ[d, _Symbol + _Integer?Positive]]]\)], "Input"],

Cell["CheckTJIRecursion not applicable.", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (913)", "Subsection",
  CellTags->"T1.6.77.1"],

Cell[BoxData[
    \(h\_913 = s\_91.3\)], "Input"],

Cell[BoxData[
    \(f\_913 = 
      MakeFun[h\_913, "\<(913)\>", 
        IFF[\((n2 === 1\  || \ n3 === 1)\) && 
            MatchQ[d, _Symbol + _Integer?Positive]], n1 :> 1]\)], "Input"],

Cell["CheckTJIRecursion not applicable.", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (914)", "Subsection",
  CellTags->"T1.6.78.1"],

Cell[BoxData[
    \(h\_914 = s\_91.4 /. \[Nu]\_1 -> \[Nu]\_1 - 1\)], "Input"],

Cell[BoxData[
    \(f\_914 = 
      MakeFun[h\_914, "\<(914)\>", 
        IFF[\[CapitalDelta]\_\(1, 2, 3\) =!= 0 && \((\[Nu]\_1\  > \ 1\ )\) && 
            MatchQ[d, _Symbol]]]\)], "Input"],

Cell["CheckTJIRecursion not applicable.", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (92)", "Subsection",
  CellTags->"T1.6.79.1"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\_\(1, 2, 3\)\)]],
  " = Cayley[1,2,3][{m1,m2,m3}]"
}], "Text"],

Cell[BoxData[
    \(\(Cayley[1, 2, 3]\)[{m1, m2, m3}]\)], "Input"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\((\ 
        m\_1\%2 == \((m\_2 + m\_3)\)\^2\ )\)\ \[DoubleLongRightArrow]\ \((\ \
\[CapitalDelta]\_\(1, 2, 3\) == 0\ )\)\)]]], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(e\_92\), "=", 
        RowBox[{
          RowBox[{
          "2", \(m\_2\), \(m\_3\), \((m\_2 + m\_3)\), \((d - 2  \[Nu]\_1 - 
                2  \[Nu]\_2 - 2  \[Nu]\_3 - 1)\), 
            InterpretationBox[
              StyleBox[\(1\^+\),
                FontWeight->"Bold"],
              Schiebe[ 1, "+"],
              Editable->True], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["K",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TKI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3]}],
              Editable->True]}], "==", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{\(m\_2\), 
                  RowBox[{"(", 
                    RowBox[{
                      
                      RowBox[{\((d - \[Nu]\_1 - \[Nu]\_2 - 2  \[Nu]\_3 - 1)\),
                         
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              InterpretationBox[
                                StyleBox[\(1\^+\),
                                  FontWeight->"Bold"],
                                Schiebe[ 1, "+"],
                                Editable->True], 
                              InterpretationBox[
                                StyleBox[\(2\^-\),
                                  FontWeight->"Bold"],
                                Schiebe[ 2, "-"],
                                Editable->True]}], "-", "1"}], ")"}]}], "+", 
                      RowBox[{\((\[Nu]\_1 - \[Nu]\_2 + 1)\), 
                        InterpretationBox[
                          StyleBox[\(1\^+\),
                            FontWeight->"Bold"],
                          Schiebe[ 1, "+"],
                          Editable->True], 
                        InterpretationBox[
                          StyleBox[\(3\^-\),
                            FontWeight->"Bold"],
                          Schiebe[ 3, "-"],
                          Editable->True]}]}], ")"}]}], "+", "\n", "\t\t\t", 
                RowBox[{\(m\_3\), 
                  RowBox[{"(", 
                    RowBox[{
                      
                      RowBox[{\((d - \[Nu]\_1 - 2  \[Nu]\_2 - \[Nu]\_3 - 1)\),
                         
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              InterpretationBox[
                                StyleBox[\(1\^+\),
                                  FontWeight->"Bold"],
                                Schiebe[ 1, "+"],
                                Editable->True], 
                              InterpretationBox[
                                StyleBox[\(3\^-\),
                                  FontWeight->"Bold"],
                                Schiebe[ 3, "-"],
                                Editable->True]}], "-", "1"}], ")"}]}], "+", 
                      RowBox[{\((\[Nu]\_1 - \[Nu]\_3 + 1)\), 
                        InterpretationBox[
                          StyleBox[\(1\^+\),
                            FontWeight->"Bold"],
                          Schiebe[ 1, "+"],
                          Editable->True], 
                        InterpretationBox[
                          StyleBox[\(2\^-\),
                            FontWeight->"Bold"],
                          Schiebe[ 2, "-"],
                          Editable->True]}]}], ")"}]}]}], ")"}], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["K",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TKI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3]}],
              Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
    \(s\_92 = OperatorApplyK[e\_92]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (93)", "Subsection",
  CellTags->"T1.6.80.1"],

Cell[TextData[{
  "( ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\((m\_1 == 0)\)\  && \ \((m\_2 == 
                m\_3)\)\)\(\ \)\(\ \)\()\)\)\ \[DoubleLongRightArrow]\ \((\ \
\[CapitalDelta]\_\(1, 2, 3\) == 0\ )\)\)]]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(e\_93\), "=", 
        RowBox[{
          RowBox[{
          "2", \(m\_2\%2\), \((d - 2  \[Nu]\_1 - 2)\), \((d - 
                2  \[Nu]\_1 - \[Nu]\_2 - \[Nu]\_3 - 1)\), \((d - 
                2  \[Nu]\_1 - \[Nu]\_2 - \[Nu]\_3)\), 
            InterpretationBox[
              StyleBox[\(1\^+\),
                FontWeight->"Bold"],
              Schiebe[ 1, "+"],
              Editable->True], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["K",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TKI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3]}],
              Editable->True]}], "==", 
          
          RowBox[{\((d - 2  \[Nu]\_1 - 2  \[Nu]\_3)\), \((d - 2  \[Nu]\_1 - 
                2  \[Nu]\_2)\), \((d - \[Nu]\_1 - \[Nu]\_2 - \[Nu]\_3)\), 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["K",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TKI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3]}],
              Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
    \(s\_93 = OperatorApplyK[e\_93]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (93)", "Subsection",
  CellTags->"T1.6.81.1"],

Cell[BoxData[
    \(h\_93 = s\_93 /. \[Nu]\_1 -> \[Nu]\_1 - 1\)], "Input"],

Cell[BoxData[
    \(f\_93 = 
      MakeFun[h\_93, "\<(93)\>", 
        IFF[\[Nu]\_1 > 1 && m\_2 =!= 0], {m1 :> 0, m3 :> m2}]\)], "Input"],

Cell["CheckTJIRecursion not applicable.", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (94)", "Subsection",
  CellTags->"T1.6.82.1"],

Cell[TextData[{
  "general ",
  Cell[BoxData[
      \(m\_i\%2\)]]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(e\_94\), "=", 
        RowBox[{
          RowBox[{\(\[CapitalDelta]\_\(1, 2, 6\)\), \(\[Nu]\_1\), 
            InterpretationBox[
              StyleBox[\(1\^+\),
                FontWeight->"Bold"],
              Schiebe[ 1, "+"],
              Editable->True], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["B",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TBI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2]}],
              Editable->True]}], "==", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{\(u\_\(6, 1, 2\)\), 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{\(\[Nu]\_1\), 
                        InterpretationBox[
                          StyleBox[\(1\^+\),
                            FontWeight->"Bold"],
                          Schiebe[ 1, "+"],
                          Editable->True], 
                        InterpretationBox[
                          StyleBox[\(2\^-\),
                            FontWeight->"Bold"],
                          Schiebe[ 2, "-"],
                          Editable->True]}], "-", "d", "+", \(\[Nu]\_1\), 
                      "+", \(2  \[Nu]\_2\)}], ")"}]}], "+", 
                RowBox[{"2", \(m\_2\%2\), 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{\(\[Nu]\_2\), 
                        InterpretationBox[
                          StyleBox[\(2\^+\),
                            FontWeight->"Bold"],
                          Schiebe[ 2, "+"],
                          Editable->True], 
                        InterpretationBox[
                          StyleBox[\(1\^-\),
                            FontWeight->"Bold"],
                          Schiebe[ 1, "-"],
                          Editable->True]}], "-", "d", "+", \(2  \[Nu]\_1\), 
                      "+", \(\[Nu]\_2\)}], ")"}]}]}], ")"}], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["B",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TBI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2]}],
              Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
    \(s\_94 = OperatorApplyB[e\_94]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (94)", "Subsection",
  CellTags->"T1.6.83.1"],

Cell[BoxData[
    \(h\_94 = s\_94 /. \[Nu]\_1 -> \[Nu]\_1 - 1\)], "Input"],

Cell[BoxData[
    \(f\_94 = 
      MakeFun[h\_94, "\<(94)\>", 
        IFF[\[CapitalDelta]\_\(1, 2, 6\) =!= 0 && \[Nu]\_1 > 1]]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (9401)", "Subsection",
  CellTags->"T1.6.84.1"],

Cell[BoxData[
    \(n\_9401 = \(s\_94 /. \[CapitalDelta]\_\(1, 2, 6\) -> 0\) /. 
        u\_\(6, 1, 2\) -> 0\)], "Input"],

Cell[BoxData[
    \(h\_9401 = \(-n\_9401[\([2, 2]\)]\) == n\_9401[\([2, 1]\)]\)], "Input"],

Cell[BoxData[
    \(f\_9401 = 
      MakeFun[h\_9401, "\<(9401)\>", 
        IFF[\[CapitalDelta]\_\(1, 2, 6\) === 0 && u\_\(6, 1, 2\) === 0 && 
            m2 =!= 0]]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (9402)", "Subsection",
  CellTags->"T1.6.85.1"],

Cell[BoxData[
    \(n\_9402 = 
      Interchange[\(s\_94 /. \[CapitalDelta]\_\(1, 2, 6\) -> 0\) /. 
          u\_\(6, 1, 2\) -> 0, 1 \[LeftRightArrow] 2]\)], "Input"],

Cell[BoxData[
    \(h\_9402 = \(-n\_9402[\([2, 1]\)]\) == n\_9402[\([2, 2]\)]\)], "Input"],

Cell[BoxData[
    \(f\_9402 = 
      MakeFun[h\_9402, "\<(9402)\>", 
        IFF[\[CapitalDelta]\_\(1, 2, 6\) === 0 && u\_\(6, 1, 2\) === 0 && 
            m1 =!= 0]]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (95)", "Subsection",
  CellTags->"T1.6.86.1"],

Cell[TextData[{
  "general ",
  Cell[BoxData[
      \(m\_i\%2\)]]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(e\_95\), "=", 
        RowBox[{
          RowBox[{"2", 
            InterpretationBox[\(p\^2\),
              PP], \(\[Nu]\_1\), 
            InterpretationBox[
              StyleBox[\(1\^+\),
                FontWeight->"Bold"],
              Schiebe[ 1, "+"],
              Editable->True], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["B",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TBI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2]}],
              Editable->True]}], "==", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{\(u\_\(1, 2, 6\)\), "+", 
                InterpretationBox[
                  StyleBox[\(1\^-\),
                    FontWeight->"Bold"],
                  Schiebe[ 1, "-"],
                  Editable->True], "-", 
                InterpretationBox[
                  StyleBox[\(2\^-\),
                    FontWeight->"Bold"],
                  Schiebe[ 2, "-"],
                  Editable->True]}], ")"}], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["B",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox[\(d - 2\),
                    "TraditionalForm"], ")"}]],
              TBI[ 
                Plus[ -2, d], {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2]}],
              Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
    \(s\_95 = OperatorApplyB[e\_95]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (95)", "Subsection",
  CellTags->"T1.6.87.1"],

Cell[BoxData[
    \(h\_95 = s\_95 /. \[Nu]\_1 -> \[Nu]\_1 - 1\)], "Input"],

Cell[BoxData[
    \(f\_95 = 
      MakeFun[h\_95, "\<(95)\>", 
        IFF[\[Nu]\_1 > 1\  && \ 
            MatchQ[d, _Symbol + _Integer?Positive]]]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (96)", "Subsection",
  CellTags->"T1.6.88.1"],

Cell[TextData[{
  "general ",
  Cell[BoxData[
      \(m\_i\%2\)]]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(e\_96\), "=", 
        RowBox[{
          RowBox[{"2", 
            InterpretationBox[\(p\^2\),
              PP], \((d - \[Nu]\_1 - \[Nu]\_2 - 1)\), 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["B",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TBI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2]}],
              Editable->True]}], "==", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{\(\[CapitalDelta]\_\(1, 2, 6\)\), "+", 
                RowBox[{\(u\_\(1, 2, 6\)\), 
                  InterpretationBox[
                    StyleBox[\(1\^-\),
                      FontWeight->"Bold"],
                    Schiebe[ 1, "-"],
                    Editable->True]}], "+", 
                RowBox[{\(u\_\(2, 1, 6\)\), 
                  InterpretationBox[
                    StyleBox[\(2\^-\),
                      FontWeight->"Bold"],
                    Schiebe[ 2, "-"],
                    Editable->True]}]}], ")"}], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["B",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox[\(d - 2\),
                    "TraditionalForm"], ")"}]],
              TBI[ 
                Plus[ -2, d], {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2]}],
              Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
    \(s\_96 = OperatorApplyB[e\_96]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (96)", "Subsection",
  CellTags->"T1.6.89.1"],

Cell[BoxData[
    \(h\_96 = s\_96\)], "Input"],

Cell[BoxData[
    \(f\_96 = 
      MakeFun[h\_96, "\<(96)\>", 
        IFF[\ MatchQ[d, _Symbol + _Integer\ ?Positive]], n1 :> 1]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (97)", "Subsection",
  CellTags->"T1.6.90.1"],

Cell[TextData[{
  "general ",
  Cell[BoxData[
      \(m\_i\%2\)]]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(e\_97\), "=", 
        RowBox[{
          RowBox[{"2", \(m\_1\%2\), \(\[Nu]\_1\), 
            InterpretationBox[
              StyleBox[\(1\^+\),
                FontWeight->"Bold"],
              Schiebe[ 1, "+"],
              Editable->True], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["A",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                FormBox[\(\[Nu]\_1\),
                  "TraditionalForm"], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TAI[ d, {
                Subscript[ \[Nu], 1]}],
              Editable->True]}], "==", 
          RowBox[{\((d - 2  \[Nu]\_1)\), 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["A",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                FormBox[\(\[Nu]\_1\),
                  "TraditionalForm"], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TAI[ d, {
                Subscript[ \[Nu], 1]}],
              Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
    \(s\_97 = OperatorApplyA[e\_97]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (97)", "Subsection",
  CellTags->"T1.6.91.1"],

Cell[BoxData[
    \(h\_97 = s\_97 /. \[Nu]\_1 -> \[Nu]\_1 - 1\)], "Input"],

Cell[BoxData[
    \(f\_97 = 
      MakeFun[h\_97, "\<(97)\>", 
        IFF[\[Nu]\_1 > 1 && \ MatchQ[d, _Symbol\ ]]]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (98)", "Subsection",
  CellTags->"T1.6.92.1"],

Cell[TextData[{
  "general ",
  Cell[BoxData[
      \(m\_i\%2\)]]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(e\_98\), "=", 
        RowBox[{
          RowBox[{\((d - 2  \[Nu]\_1)\), 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["A",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                FormBox[\(\[Nu]\_1\),
                  "TraditionalForm"], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TAI[ d, {
                Subscript[ \[Nu], 1]}],
              Editable->True]}], "==", 
          RowBox[{\(-2\), \(m\_1\%2\), 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["A",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                FormBox[\(\[Nu]\_1\),
                  "TraditionalForm"], 
                RowBox[{"(", 
                  FormBox[\(d - 2\),
                    "TraditionalForm"], ")"}]],
              TAI[ 
                Plus[ -2, d], {
                Subscript[ \[Nu], 1]}],
              Editable->True]}]}]}], ";"}]], "Input"],

Cell[BoxData[
    \(s\_98 = OperatorApplyA[e\_98]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (98)", "Subsection",
  CellTags->"T1.6.93.1"],

Cell[BoxData[
    \(h\_98 = s\_98\)], "Input"],

Cell[BoxData[
    \(f\_98 = 
      MakeFun[h\_98, "\<(98)\>", 
        IFF[MatchQ[d, _Symbol\  + _Integer?Positive]]]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (99)", "Subsection",
  CellTags->"T1.6.94.1"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`m\_1 = M, \ p\^2 = M\^2, 
    m\_2 = \(m\_3 = 0\)\)]]], "Text"],

Cell[TextData[{
  "Herleitung in three.nb ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          RowBox[{\(-\[Nu]\_1\), " ", \((d - 2\ \[Nu]\_2 - 2\ \[Nu]\_3)\), 
            " ", \((d - \[Nu]\_2 - \[Nu]\_3 - 1)\), " ", 
            SubsuperscriptBox[
              StyleBox["J",
                SingleLetterItalics->False,
                FontWeight->"Bold"], 
              RowBox[{
                StyleBox[
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"],
                  FontColor->RGBColor[0, 0, 1]], 
                FormBox[\(\[Nu]\_2\),
                  "TraditionalForm"], 
                FormBox[\(\[Nu]\_3\),
                  "TraditionalForm"]}], 
              RowBox[{"(", 
                FormBox["d",
                  "TraditionalForm"], ")"}]]}], "==", 
          
          RowBox[{\(\[Nu]\_2\), " ", \((\(-d\) + 2\ \[Nu]\_2 + 2)\), 
            " ", \((\(-2\)\ d + \[Nu]\_1 + 2\ \[Nu]\_2 + 2\ \[Nu]\_3 + 2)\), 
            " ", 
            SubsuperscriptBox[
              StyleBox["J",
                SingleLetterItalics->False,
                FontWeight->"Bold"], 
              RowBox[{
                FormBox[\(\[Nu]\_1\),
                  "TraditionalForm"], 
                StyleBox[
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"],
                  FontColor->RGBColor[0, 0, 1]], 
                FormBox[\(\[Nu]\_3\),
                  "TraditionalForm"]}], 
              RowBox[{"(", 
                FormBox["d",
                  "TraditionalForm"], ")"}]]}]}], TraditionalForm]]]
}], "Text"],

Cell[BoxData[
    RowBox[{\(e\_99\), "=", 
      RowBox[{
        RowBox[{\(\[Nu]\_1\), " ", \((d - 2\ \[Nu]\_2 - 2\ \[Nu]\_3)\), 
          " ", \((d - \[Nu]\_2 - \[Nu]\_3 - 1)\), " ", 
          InterpretationBox[
            StyleBox[\(1\^+\),
              FontWeight->"Bold"],
            Schiebe[ 1, "+"],
            Editable->True], 
          InterpretationBox[
            SubsuperscriptBox[
              StyleBox["J",
                SingleLetterItalics->False,
                FontWeight->"Bold"], 
              RowBox[{
                FormBox[\(\[Nu]\_1\),
                  "TraditionalForm"], 
                FormBox[\(\[Nu]\_2\),
                  "TraditionalForm"], 
                FormBox[\(\[Nu]\_3\),
                  "TraditionalForm"]}], 
              RowBox[{"(", 
                FormBox["d",
                  "TraditionalForm"], ")"}]],
            TJI[ d, {
              Subscript[ \[Nu], 1], 
              Subscript[ \[Nu], 2], 
              Subscript[ \[Nu], 3]}],
            Editable->True]}], "==", 
        RowBox[{\(-\[Nu]\_2\), " ", \((\(-d\) + 2\ \[Nu]\_2 + 2)\), 
          " ", \((\(-2\)\ d + \[Nu]\_1 + 2\ \[Nu]\_2 + 2\ \[Nu]\_3 + 2)\), 
          InterpretationBox[
            StyleBox[\(2\^+\),
              FontWeight->"Bold"],
            Schiebe[ 2, "+"],
            Editable->True], 
          InterpretationBox[
            SubsuperscriptBox[
              StyleBox["J",
                SingleLetterItalics->False,
                FontWeight->"Bold"], 
              RowBox[{
                FormBox[\(\[Nu]\_1\),
                  "TraditionalForm"], 
                FormBox[\(\[Nu]\_2\),
                  "TraditionalForm"], 
                FormBox[\(\[Nu]\_3\),
                  "TraditionalForm"]}], 
              RowBox[{"(", 
                FormBox["d",
                  "TraditionalForm"], ")"}]],
            TJI[ d, {
              Subscript[ \[Nu], 1], 
              Subscript[ \[Nu], 2], 
              Subscript[ \[Nu], 3]}],
            Editable->True]}]}]}]], "Input"],

Cell[BoxData[
    \(s\_99 = OperatorApplyJ[e\_99]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (99)", "Subsection",
  CellTags->"T1.6.95.1"],

Cell[BoxData[
    \(h\_99 = s\_99 /. \[Nu]\_1 -> \[Nu]\_1 - 1\)], "Input"],

Cell[BoxData[
    \(f\_99 = 
      MakeFun[h\_99, "\<(99)\>", 
        IFF[m1^2 === PP && \[Nu]\_1 > 1], {m2 :> 0, m3 :> 0}]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (9912)", "Subsection",
  CellTags->"T1.6.96.1"],

Cell[BoxData[
    \(h\_9912 = 
      Interchange[s\_99 /. \[Nu]\_1 -> \[Nu]\_1 - 1, 
        1 \[LeftRightArrow] 2]\)], "Input"],

Cell[BoxData[
    \(f\_9912 = 
      MakeFun[h\_9912, "\<(9912)\>", 
        IFF[m2^2 === PP && \[Nu]\_2 > 1], {m1 :> 0, m3 :> 0}]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (9913)", "Subsection",
  CellTags->"T1.6.97.1"],

Cell[BoxData[
    \(h\_9913 = 
      Interchange[s\_99 /. \[Nu]\_1 -> \[Nu]\_1 - 1, 
        1 \[LeftRightArrow] 3]\)], "Input"],

Cell[BoxData[
    \(f\_9913 = 
      MakeFun[h\_9913, "\<(9913)\>", 
        IFF[m3^2 === PP && \[Nu]\_3 > 1], {m1 :> 0, m2 :> 0}]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (100)", "Subsection",
  CellTags->"T1.6.98.1"],

Cell["Herleitung in three.nb ", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
        "2", " ", \(m\_2\%2\), " ", \((1 - \[Nu]\_2)\), " ", \(\[Nu]\_2\), 
          " ", 
          InterpretationBox[
            SubsuperscriptBox[
              StyleBox["J",
                SingleLetterItalics->False,
                FontWeight->"Bold"], 
              RowBox[{
                FormBox[\(\[Nu]\_1\),
                  "TraditionalForm"], 
                StyleBox[
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"],
                  FontColor->RGBColor[0, 0, 1]], 
                FormBox[\(\[Nu]\_3\),
                  "TraditionalForm"]}], 
              RowBox[{"(", 
                FormBox["d",
                  "TraditionalForm"], ")"}]],
            TJI[ d, {
              Subscript[ \[Nu], 1], 
              Plus[ 1, 
                Subscript[ \[Nu], 2]], 
              Subscript[ \[Nu], 3]}],
            Editable->True]}], "==", 
        RowBox[{
          RowBox[{\((d - 2\ \[Nu]\_2)\), " ", \((1 - \[Nu]\_2)\), " ", 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["J",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TJI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3]}],
              Editable->True]}], "-", 
          RowBox[{\(\[Nu]\_1\), " ", \((\(-d\) + 2\ \[Nu]\_1 + 2)\), " ", 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["J",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  StyleBox[
                    FormBox[\(\[Nu]\_1\),
                      "TraditionalForm"],
                    FontColor->RGBColor[0, 0, 1]], 
                  StyleBox[
                    FormBox[\(\[Nu]\_2\),
                      "TraditionalForm"],
                    FontColor->RGBColor[1, 0, 0]], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TJI[ d, {
                Plus[ 1, 
                  Subscript[ \[Nu], 1]], 
                Plus[ -1, 
                  Subscript[ \[Nu], 2]], 
                Subscript[ \[Nu], 3]}],
              Editable->True]}]}]}], TraditionalForm]], "Input"]], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`m\_1 = 0\)]]], "Text"],

Cell[BoxData[
    RowBox[{\(e\_100\), "=", 
      RowBox[{
        RowBox[{
        "2", " ", \(m\_2\%2\), " ", \((1 - \[Nu]\_2)\), " ", \(\[Nu]\_2\), 
          " ", 
          InterpretationBox[
            StyleBox[\(2\^+\),
              FontWeight->"Bold"],
            Schiebe[ 2, "+"],
            Editable->True], 
          InterpretationBox[
            SubsuperscriptBox[
              StyleBox["J",
                SingleLetterItalics->False,
                FontWeight->"Bold"], 
              RowBox[{
                FormBox[\(\[Nu]\_1\),
                  "TraditionalForm"], 
                FormBox[\(\[Nu]\_2\),
                  "TraditionalForm"], 
                FormBox[\(\[Nu]\_3\),
                  "TraditionalForm"]}], 
              RowBox[{"(", 
                FormBox["d",
                  "TraditionalForm"], ")"}]],
            TJI[ d, {
              Subscript[ \[Nu], 1], 
              Subscript[ \[Nu], 2], 
              Subscript[ \[Nu], 3]}],
            Editable->True]}], "==", 
        RowBox[{
          RowBox[{\((d - 2\ \[Nu]\_2)\), " ", \((1 - \[Nu]\_2)\), " ", 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["J",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TJI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3]}],
              Editable->True]}], "-", 
          RowBox[{\(\[Nu]\_1\), " ", \((\(-d\) + 2\ \[Nu]\_1 + 2)\), " ", 
            InterpretationBox[
              StyleBox[\(1\^+\),
                FontWeight->"Bold"],
              Schiebe[ 1, "+"],
              Editable->True], 
            InterpretationBox[
              StyleBox[\(2\^-\),
                FontWeight->"Bold"],
              Schiebe[ 2, "-"],
              Editable->True], 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["J",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\(\[Nu]\_1\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TJI[ d, {
                Subscript[ \[Nu], 1], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3]}],
              Editable->True]}]}]}]}]], "Input"],

Cell[BoxData[
    \(s\_100 = OperatorApplyJ[e\_100]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (100)", "Subsection",
  CellTags->"T1.6.99.1"],

Cell[BoxData[
    \(h\_100 = s\_100\)], "Input"],

Cell[BoxData[
    \(f\_100 = 
      MakeFun[h\_100 /. \[Nu]\_2 -> \[Nu]\_2 - 1, "\<(100)\>", 
        IFF[\[Nu]\_2 > 2 && m2 =!= 0], m1 :> 0]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CheckTJIRecursion[f\_100]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`"Off"\)], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (1002)", "Subsection",
  CellTags->"T1.6.100.1"],

Cell[BoxData[
    \(h\_1002 = Interchange[s\_100, 1 \[LeftRightArrow] 3]\)], "Input"],

Cell[BoxData[
    \(f\_1002 = 
      MakeFun[h\_1002 /. \[Nu]\_2 -> \[Nu]\_2 - 1, "\<(1002)\>", 
        IFF[\[Nu]\_2 > 2 && m2 =!= 0], m3 :> 0]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CheckTJIRecursion[f\_1002]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`"Off"\)], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (1003)", "Subsection",
  CellTags->"T1.6.101.1"],

Cell[BoxData[
    \(h\_1003 = 
      Interchange[s\_100, 1 \[LeftRightArrow] 3, 
        1 \[LeftRightArrow] 2]\)], "Input"],

Cell[BoxData[
    \(f\_1003 = 
      MakeFun[h\_1003 /. \[Nu]\_1 -> \[Nu]\_1 - 1, "\<(1003)\>", 
        IFF[\[Nu]\_1 > 2 && m1 =!= 0], m3 :> 0]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CheckTJIRecursion[f\_1003]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`"Off"\)], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (1004)", "Subsection",
  CellTags->"T1.6.102.1"],

Cell[BoxData[
    \(h\_1004 = Interchange[s\_100, 1 \[LeftRightArrow] 2]\)], "Input"],

Cell[BoxData[
    \(f\_1004 = 
      MakeFun[h\_1004 /. \[Nu]\_1 -> \[Nu]\_1 - 1, "\<(1004)\>", 
        IFF[\[Nu]\_1 > 2 && m1 =!= 0], m2 :> 0]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CheckTJIRecursion[f\_1004]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`"Off"\)], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (1005)", "Subsection",
  CellTags->"T1.6.103.1"],

Cell[BoxData[
    \(h\_1005 = Interchange[s\_100, 2 \[LeftRightArrow] 3]\)], "Input"],

Cell[BoxData[
    \(f\_1005 = 
      MakeFun[h\_1005 /. \[Nu]\_3 -> \[Nu]\_3 - 1, "\<(1005)\>", 
        IFF[\[Nu]\_3 > 2 && m3 =!= 0], m1 :> 0]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CheckTJIRecursion[f\_1005]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`"Off"\)], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (1006)", "Subsection",
  CellTags->"T1.6.104.1"],

Cell[BoxData[
    \(h\_1006 = 
      Interchange[s\_100, 2 \[LeftRightArrow] 3, 
        1 \[LeftRightArrow] 2]\)], "Input"],

Cell[BoxData[
    \(f\_1006 = 
      MakeFun[h\_1006 /. \[Nu]\_3 -> \[Nu]\_3 - 1, "\<(1006)\>", 
        IFF[\[Nu]\_3 > 2 && m3 =!= 0], m2 :> 0]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CheckTJIRecursion[f\_1006]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`"Off"\)], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (150)", "Subsection",
  CellTags->"T1.6.105.1"],

Cell[BoxData[
    \(TextForm\`\[Nu]\_4 = \(-1\)\)], "Text"],

Cell[BoxData[
    \(TextForm\`\((\(q\_2\)\(-\)\(p\)\(\ \))\)\^2 - m\_4\%2 = \ q\_2\%2 - 
      m\_2\%2 - 2  p\ q\_2 + p\^2 + m\_2\%2 - m\_4\%2\)], "Text"],

Cell[BoxData[
    \(s\_150 = 
      TFI[d, PP, {{n1, m1}, {n2, m2}, {n3, m3}, {\(-1\), m4}, {n5, m5}}] == 
        TFI[d, PP, {{n1, m1}, {n2 - 1, m2}, {n3, m3}, {0, 0}, {n5, m5}}] - 
          2  TFI[d, 
              PP, {0, 0, 0, 1, 
                0}, {{n1, m1}, {n2, m2}, {n3, m3}, {0, 0}, {n5, 
                  m5}}] + \((PP + m2^2 - m4^2)\) 
            TFI[d, PP, {{n1, m1}, {n2, m2}, {n3, m3}, {0, 0}, {n5, 
                  m5}}]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (150)", "Subsection",
  CellTags->"T1.6.106.1"],

Cell[BoxData[
    \(h\_150 = s\_150\)], "Input"],

Cell[BoxData[
    \(f\_150 = MakeFun[h\_150, "\<(150)\>"]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (151)", "Subsection",
  CellTags->"T1.6.107.1"],

Cell[BoxData[
    \(TextForm\`\[Nu]\_4 = \(-1\)\)], "Text"],

Cell[BoxData[
    \(TextForm\`\((\(q\_2\)\(-\)\(p\)\(\ \))\)\^2 - m\_4\%2 = \ q\_2\%2 - 
      m\_2\%2 - 2  p\ q\_2 + p\^2 + m\_2\%2 - m\_4\%2\)], "Text"],

Cell[BoxData[
    \(s\_151 = 
      TFI[d, PP, 
          DP, {a, b}, {{n1, m1}, {n2, m2}, {n3, m3}, {\(-1\), m4}, {n5, 
              m5}}] == TFI[d, PP, 
            DP, {a, b}, {{n1, m1}, {n2 - 1, m2}, {n3, m3}, {0, 0}, {n5, 
                m5}}] - 
          2  TFI[d, PP, 
              DP, {a, b}, {0, 0, 0, 1, 
                0}, {{n1, m1}, {n2, m2}, {n3, m3}, {0, 0}, {n5, 
                  m5}}] + \((PP + m2^2 - m4^2)\) 
            TFI[d, PP, 
              DP, {a, b}, {{n1, m1}, {n2, m2}, {n3, m3}, {0, 0}, {n5, 
                  m5}}]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (151)", "Subsection",
  CellTags->"T1.6.108.1"],

Cell[BoxData[
    \(h\_151 = s\_151\)], "Input"],

Cell[BoxData[
    \(f\_151 = 
      ReplacePart[
        MakeFun[h\_151, "\<(151)\>"], {a_, b_}, {1, 1, 4}]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (152)", "Subsection",
  CellTags->"T1.6.109.1"],

Cell[BoxData[
    \(TextForm\`\[Nu]\_4 = \(-1\)\)], "Text"],

Cell[BoxData[
    \(TextForm\`\((\(q\_2\)\(-\)\(p\)\(\ \))\)\^2 - m\_4\%2 = \ q\_2\%2 - 
      m\_2\%2 - 2  p\ q\_2 + p\^2 + m\_2\%2 - m\_4\%2\)], "Text"],

Cell[BoxData[
    \(s\_152 = 
      TVI[d, PP, {{n1, m1}, {n2, m2}, {n3, m3}, {\(-1\), m4}}] == 
        TVI[d, PP, {{n1, m1}, {n2 - 1, m2}, {n3, m3}, {0, 0}}] - 
          2  TFI[d, 
              PP, {0, 0, 0, 1, 
                0}, {{0, 0}, {n2, m2}, {n3, m3}, {0, 0}, {n1, m1}}] + \((PP + 
                m2^2 - m4^2)\) 
            TVI[d, PP, {{n1, m1}, {n2, m2}, {n3, m3}, {0, 0}}]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (152)", "Subsection",
  CellTags->"T1.6.110.1"],

Cell[BoxData[
    \(h\_152 = s\_152\)], "Input"],

Cell[BoxData[
    \(f\_152 = MakeFun[h\_152, "\<(152)\>"]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (153)", "Subsection",
  CellTags->"T1.6.111.1"],

Cell[BoxData[
    \(TextForm\`\[Nu]\_2 = \(-1\)\)], "Text"],

Cell[BoxData[
    \(s\_153 = 
      TVI[d, PP, {{n1, m1}, {\(-1\), m2}, {n3, m3}, {n4, m4}}] == \n\t\tTFI[
            d, \ PP, {0, 1, 0, 0, 
              0}, \ {{0, 0}, {0, 0}, {n3, m3}, {n4, m4}, {n1, m1}}] + 
          m2^2\ TVI[d, \ 
              PP, \ {{n1, m1}, {0, 0}, {n3, m3}, {n4, m4}}]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (153)", "Subsection",
  CellTags->"T1.6.112.1"],

Cell[BoxData[
    \(h\_153 = s\_153\)], "Input"],

Cell[BoxData[
    \(f\_153 = MakeFun[h\_153, "\<(153)\>"]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (200)", "Subsection",
  CellTags->"T1.6.113.1"],

Cell["Derivation in TJRspecial.nb", "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`m\_3 = \(m\_2 = m\_1\), \ p\^2 = m\_1\%2\)]]], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(s\_200\), "=", 
        RowBox[{
          RowBox[{
          "16", " ", \(m\_1\%2\), " ", \(\[Nu]\_1\), 
            " ", \((d - \[Nu]\_1 - \[Nu]\_2 - \[Nu]\_3)\), " ", 
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["J",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  StyleBox[
                    FormBox[\(\[Nu]\_1\),
                      "TraditionalForm"],
                    FontColor->RGBColor[0, 0, 1]], 
                  FormBox[\(\[Nu]\_2\),
                    "TraditionalForm"], 
                  FormBox[\(\[Nu]\_3\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d",
                    "TraditionalForm"], ")"}]],
              TJI[ d, {
                Plus[ 1, 
                  Subscript[ \[Nu], 1]], 
                Subscript[ \[Nu], 2], 
                Subscript[ \[Nu], 3]}],
              Editable->True]}], "==", 
          RowBox[{
            
            RowBox[{\(-\((1 + 3\ d - 3\ \[Nu]\_1 - 4\ \[Nu]\_2)\)\), 
              " ", \(\[Nu]\_3\), " ", 
              InterpretationBox[
                SubsuperscriptBox[
                  StyleBox["J",
                    SingleLetterItalics->False,
                    FontWeight->"Bold"], 
                  RowBox[{
                    StyleBox[
                      FormBox[\(\[Nu]\_1\),
                        "TraditionalForm"],
                      FontColor->RGBColor[1, 0, 0]], 
                    FormBox[\(\[Nu]\_2\),
                      "TraditionalForm"], 
                    StyleBox[
                      FormBox[\(\[Nu]\_3\),
                        "TraditionalForm"],
                      FontColor->RGBColor[0, 0, 1]]}], 
                  RowBox[{"(", 
                    FormBox["d",
                      "TraditionalForm"], ")"}]],
                TJI[ d, {
                  Plus[ -1, 
                    Subscript[ \[Nu], 1]], 
                  Subscript[ \[Nu], 2], 
                  Plus[ 1, 
                    Subscript[ \[Nu], 3]]}],
                Editable->True]}], "-", 
            
            RowBox[{\(\[Nu]\_2\), 
              " ", \((1 + 3\ d - 3\ \[Nu]\_1 - 4\ \[Nu]\_3)\), " ", 
              InterpretationBox[
                SubsuperscriptBox[
                  StyleBox["J",
                    SingleLetterItalics->False,
                    FontWeight->"Bold"], 
                  RowBox[{
                    StyleBox[
                      FormBox[\(\[Nu]\_1\),
                        "TraditionalForm"],
                      FontColor->RGBColor[1, 0, 0]], 
                    StyleBox[
                      FormBox[\(\[Nu]\_2\),
                        "TraditionalForm"],
                      FontColor->RGBColor[0, 0, 1]], 
                    FormBox[\(\[Nu]\_3\),
                      "TraditionalForm"]}], 
                  RowBox[{"(", 
                    FormBox["d",
                      "TraditionalForm"], ")"}]],
                TJI[ d, {
                  Plus[ -1, 
                    Subscript[ \[Nu], 1]], 
                  Plus[ 1, 
                    Subscript[ \[Nu], 2]], 
                  Subscript[ \[Nu], 3]}],
                Editable->True]}], "+", 
            
            RowBox[{\((\(-1\) + 2\ d - \[Nu]\_1 - 2\ \[Nu]\_2)\), 
              " ", \(\[Nu]\_3\), " ", 
              InterpretationBox[
                SubsuperscriptBox[
                  StyleBox["J",
                    SingleLetterItalics->False,
                    FontWeight->"Bold"], 
                  RowBox[{
                    FormBox[\(\[Nu]\_1\),
                      "TraditionalForm"], 
                    StyleBox[
                      FormBox[\(\[Nu]\_2\),
                        "TraditionalForm"],
                      FontColor->RGBColor[1, 0, 0]], 
                    StyleBox[
                      FormBox[\(\[Nu]\_3\),
                        "TraditionalForm"],
                      FontColor->RGBColor[0, 0, 1]]}], 
                  RowBox[{"(", 
                    FormBox["d",
                      "TraditionalForm"], ")"}]],
                TJI[ d, {
                  Subscript[ \[Nu], 1], 
                  Plus[ -1, 
                    Subscript[ \[Nu], 2]], 
                  Plus[ 1, 
                    Subscript[ \[Nu], 3]]}],
                Editable->True]}], "-", 
            
            RowBox[{\((\(-6\)\ d\^2 + 22\ d\ \[Nu]\_1 - 
                  16\ \[Nu]\_1\%2 - \[Nu]\_2 + 6\ d\ \[Nu]\_2 - 
                  13\ \[Nu]\_1\ \[Nu]\_2 - \[Nu]\_3 + 6\ d\ \[Nu]\_3 - 
                  13\ \[Nu]\_1\ \[Nu]\_3 - 4\ \[Nu]\_2\ \[Nu]\_3)\), " ", 
              InterpretationBox[
                SubsuperscriptBox[
                  StyleBox["J",
                    SingleLetterItalics->False,
                    FontWeight->"Bold"], 
                  RowBox[{
                    FormBox[\(\[Nu]\_1\),
                      "TraditionalForm"], 
                    FormBox[\(\[Nu]\_2\),
                      "TraditionalForm"], 
                    FormBox[\(\[Nu]\_3\),
                      "TraditionalForm"]}], 
                  RowBox[{"(", 
                    FormBox["d",
                      "TraditionalForm"], ")"}]],
                TJI[ d, {
                  Subscript[ \[Nu], 1], 
                  Subscript[ \[Nu], 2], 
                  Subscript[ \[Nu], 3]}],
                Editable->True]}], "+", 
            
            RowBox[{\(\[Nu]\_2\), 
              " ", \((\(-1\) + 2\ d - \[Nu]\_1 - 2\ \[Nu]\_3)\), " ", 
              InterpretationBox[
                SubsuperscriptBox[
                  StyleBox["J",
                    SingleLetterItalics->False,
                    FontWeight->"Bold"], 
                  RowBox[{
                    FormBox[\(\[Nu]\_1\),
                      "TraditionalForm"], 
                    StyleBox[
                      FormBox[\(\[Nu]\_2\),
                        "TraditionalForm"],
                      FontColor->RGBColor[0, 0, 1]], 
                    StyleBox[
                      FormBox[\(\[Nu]\_3\),
                        "TraditionalForm"],
                      FontColor->RGBColor[1, 0, 0]]}], 
                  RowBox[{"(", 
                    FormBox["d",
                      "TraditionalForm"], ")"}]],
                TJI[ d, {
                  Subscript[ \[Nu], 1], 
                  Plus[ 1, 
                    Subscript[ \[Nu], 2]], 
                  Plus[ -1, 
                    Subscript[ \[Nu], 3]]}],
                Editable->True]}]}]}]}], ";"}]], "Input"],

Cell[BoxData[
    \(TextForm\`Due\ to\ sorting\ \ \[Nu]\_1 \[GreaterSlantEqual] \[Nu]\_2 \
\[GreaterSlantEqual] \[Nu]\_3\ \ by\ TJI\ only\ this\ rule\ is\ \(\(necessary\
\)\(.\)\)\)], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (200)", "Subsection",
  CellTags->"T1.6.114.1"],

Cell[BoxData[
    \(h\_200 = s\_200 /. \[Nu]\_1 -> \[Nu]\_1 - 1\)], "Input"],

Cell[BoxData[
    RowBox[{\(f\_200\), "=", 
      RowBox[{
        StyleBox["MakeFun",
          FontColor->RGBColor[1, 0.6, 0.6]], "[", 
        RowBox[{\(h\_200\), ",", "\"\<(200)\>\"", ",", 
          RowBox[{
            StyleBox["IFF",
              FontColor->RGBColor[0.6, 0.4, 1]], 
            "[", \(\[Nu]\_1 > 1 && m1 =!= 0 && PP === m1^2\), "]"}], 
          ",", \({m2 :> m1, m3 :> m1}\)}], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (201)", "Subsection",
  CellTags->"T1.6.115.1"],

Cell["\<\
Subscript[f, 201] = 
  HoldForm[TJR[d_, PP_, 
     {{(n1_)?PQ, 0}, 
      {(n2_)?PQ, 0}, 
      {(n3_)?PQ, m3_}}] := 
    (TComment[\"(201)\", 
        TJIC[d, 
         {{n1, 0}, {n2, 0}, 
          {n3, m3}}]]; 
       -(((d - n1 - n2)*
          (-2 - d + 
         2*n1 + 2*n2)*
          (3*d - 2*n1 - 
         2*n2 - 2*n3)*
          (-1 - d + n1 + 
          n2 + n3)*
          TJI[d, PP, 
          {{-1 + n1, 0}, 
          {n2, 0}, {n3, m3}}]
)/(2*m3^2*(d - 2*n1)*
          (-1 + n1)*
          (2*d - 2*n1 - 
          2*n2 - n3)*
          (1 + 2*d - 2*n1 - 
          2*n2 - n3)))) /; 
     n1 > 1 && m3 =!= 0 && 
      PP === m3^2]\
\>", "Input",
  Editable->False]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFun (202)", "Subsection",
  CellTags->"T1.6.116.1"],

Cell["\<\
Subscript[f, 202] = 
  HoldForm[TJR[d_, PP_, 
     {{(n1_)?PQ, 0}, 
      {(n3_)?PQ, m3_}, 
      {(n2_)?PQ, 0}}] := 
    (TComment[\"(202)\", 
        TJIC[d, 
         {{n1, 0}, {n2, 0}, 
          {n3, m3}}]]; 
       -(((d - n1 - n2)*
          (-2 - d + 2*n1 + 
          2*n2)*
          (3*d - 2*n1 - 
          2*n2 - 2*n3)*
          (-1 - d + n1 + 
          n2 + n3)*
          TJI[d, m3^2, 
          {{-1 + n1, 0}, 
          {n2, 0}, {n3, m3}}
])/(2*m3^2*(d - 2*n1)*
          (-1 + n1)*
          (2*d - 2*n1 - 
          2*n2 - n3)*
          (1 + 2*d - 2*n1 - 
          2*n2 - n3)))) /; 
     n1 > 1 && m3 =!= 0 && 
      PP === m3^2]\
\>", "Input",
  Editable->False]
}, Open  ]],

Cell[CellGroupData[{

Cell[" MakeFun (203)", "Subsection",
  CellTags->"T1.6.117.1"],

Cell[BoxData[
    \(Subscript[f, \ 203]\  = 
      HoldForm[\n\t\t\ TJR[d_, \ 
            0, \ {{\((n1_)\)?PQ, \ 0}, \ {\((n2_)\)?PQ, \ 
                m2_}, \ \n\ \ \ \ {\((n3_)\)?PQ, \ 
                m2_}}]\  := \((\n\t\t\t\t\ TComment["\<(203)\>", \ \n\ \ \ \ \
\ \ \ \ TJIC[d, 
                0, \ {{n1, \ 0}, \ {n2, \ m2}, \ {n3, \ 
                    m2}}]]; \ \n\t\t\t\t\((\((d\  - \ 
                      2*\((\(-1\)\  + \ n1\  + \ 
                            n2)\))\)*\n\ \ \ \ \ \((1\  + \ d\  - \ n1\  - \ 
                      n2\  - \ n3)\)*\n\ \ \ \ \ \((d\  - \ 
                      2*\((\(-1\)\  + \ n1\  + \ n3)\))\)*\n\ \ \ \ \ TJR[
                    d, \ 0, \ {{\(-1\)\  + \ n1, \ 0}, \ {n2, \ 
                        m2}, \ \n\ \ \ \ \ \ \ {n3, \ m2}}])\)/\n\ \ \ \((2*
                  m2^2*\((d\  - \ 2*n1)\)*\n\ \ \ \ \ \((1\  + \ d\  - \ 
                      2*n1\  - \ n2\  - \ n3)\)*\n\ \ \ \ \ \((2\  + \ 
                      d\  - \ 2*n1\  - \ n2\  - \ 
                      n3)\))\)\n\t\t\t\n\t\t\t)\)]\)], "Input",
  Editable->False]
}, Open  ]],

Cell[CellGroupData[{

Cell[" MakeFun (204)", "Subsection",
  CellTags->"T1.6.118.1"],

Cell[BoxData[
    \(Subscript[f, \ 204]\  = 
      HoldForm[\n\t\t\ TJR[d_, \ 
            0, \ {\ {\((n2_)\)?PQ, \ m2_}, \ {\((n1_)\)?PQ, \ 
                0}, \n\ \ \ \ {\((n3_)\)?PQ, \ 
                m2_}}]\  := \((\n\t\ TComment["\<(204)\>", \ \n\ \ \ \ \ \ \ \
\ TJIC[d, 0, \ {\ {n2, \ m2}, \ {n1, \ 0}, {n3, \ 
                    m2}}]]; \ \n\t\((\((d\  - \ 
                      2*\((\(-1\)\  + \ n1\  + \ 
                            n2)\))\)*\n\ \ \ \ \ \((1\  + \ d\  - \ n1\  - \ 
                      n2\  - \ n3)\)*\n\ \ \ \ \ \((d\  - \ 
                      2*\((\(-1\)\  + \ n1\  + \ n3)\))\)*\n\ \ \ \ \ TJR[
                    d, \ 0, \ {{\(-1\)\  + \ n1, \ 0}, \ {n2, \ 
                        m2}, \ \n\ \ \ \ \ \ \ {n3, \ m2}}])\)/\n\ \ \ \((2*
                  m2^2*\((d\  - \ 2*n1)\)*\n\ \ \ \ \ \((1\  + \ d\  - \ 
                      2*n1\  - \ n2\  - \ n3)\)*\n\ \ \ \ \ \((2\  + \ 
                      d\  - \ 2*n1\  - \ n2\  - \ 
                      n3)\))\)\n\t\t\t)\)]\)], "Input",
  Editable->False]
}, Open  ]],

Cell[CellGroupData[{

Cell[" MakeFun (205)", "Subsection",
  CellTags->"T1.6.119.1"],

Cell[BoxData[
    \(Subscript[f, \ 205]\  = 
      HoldForm[\n\t\t\ TJR[d_, \ 
            0, \ {\ {\((n2_)\)?PQ, \ m2_}, \n\ \ \ \ {\((n3_)\)?PQ, \ 
                m2_}, \ {\((n1_)\)?PQ, \ 
                0}}]\  := \((\n\t\ TComment["\<(205)\>", \ \n\ \ \ \ \ \ \ \ \
TJIC[d, 0, \ {\ {n2, \ m2}, {n3, \ m2}, \ {n1, \ 
                    0}}]]; \ \n\((\((d\  - \ 
                      2*\((\(-1\)\  + \ n1\  + \ 
                            n2)\))\)*\n\ \ \ \ \ \((1\  + \ d\  - \ n1\  - \ 
                      n2\  - \ n3)\)*\n\ \ \ \ \ \((d\  - \ 
                      2*\((\(-1\)\  + \ n1\  + \ n3)\))\)*\n\ \ \ \ \ TJR[
                    d, \ 0, \ {{\(-1\)\  + \ n1, \ 0}, \ {n2, \ 
                        m2}, \ \n\ \ \ \ \ \ \ {n3, \ m2}}])\)/\n\ \ \ \((2*
                  m2^2*\((d\  - \ 2*n1)\)*\n\ \ \ \ \ \((1\  + \ d\  - \ 
                      2*n1\  - \ n2\  - \ n3)\)*\n\ \ \ \ \ \((2\  + \ 
                      d\  - \ 2*n1\  - \ n2\  - \ 
                      n3)\))\)\n\t\t\t)\)]\)], "Input",
  Editable->False]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input (1xxxx)", "Subsection",
  CellTags->"T1.6.120.1"],

Cell["\<\
If[MatchQ[$RankLimit, {_Integer?NonNegative, 
     _Integer?NonNegative}], 
   $TarasovTdeltaplimit = $RankLimit[[1]]; 
    ($TarasovTplimit = $RankLimit[[2]]; ), 
   $TarasovTdeltaplimit = 2; $TarasovTplimit = 2]; \
\>", "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"tarti", "=", 
      RowBox[{"Timing", "[", 
        RowBox[{"Do", "[", 
          RowBox[{
            RowBox[{"If", "[", 
              RowBox[{\(0 < a + b + r + es\), ",", 
                RowBox[{\(WriteString["\<stdout\>", {a, b, r, es}]\), ";", 
                  RowBox[{"Set", "@@", 
                    RowBox[{"{", 
                      
                      RowBox[{\(s\_\(10\^4 + 1000\ a + 100\ b + 10\ r + 
                              es\)\), ",", 
                        RowBox[{
                          RowBox[{
                            RowBox[{
                              StyleBox["TFI",
                                FontColor->RGBColor[1, 0.6, 0]], "[", 
                              RowBox[{"d", ",", 
                                InterpretationBox[\(p\^2\),
                                  PP], ",", "DP", ",", \({a, b}\), 
                                ",", \({0, 0, r, es, 0}\), ",", 
                                RowBox[{"{", 
                                  RowBox[{
                                    RowBox[{"{", 
                                      RowBox[{"n1", ",", 
                                        InterpretationBox[\(m\_1\),
                                        m1]}], "}"}], ",", 
                                    RowBox[{"{", 
                                      RowBox[{"n2", ",", 
                                        InterpretationBox[\(m\_2\),
                                        m2]}], "}"}], ",", 
                                    RowBox[{"{", 
                                      RowBox[{"n3", ",", 
                                        InterpretationBox[\(m\_3\),
                                        m3]}], "}"}], ",", 
                                    RowBox[{"{", 
                                      RowBox[{"n4", ",", 
                                        InterpretationBox[\(m\_4\),
                                        m4]}], "}"}], ",", 
                                    RowBox[{"{", 
                                      RowBox[{"n5", ",", 
                                        InterpretationBox[\(m\_5\),
                                        m5]}], "}"}]}], "}"}]}], "]"}], "==", 
                            
                            RowBox[{"ApplyTarasovT", "[", 
                              RowBox[{
                                RowBox[{"TarasovT", "[", 
                                  RowBox[{
                                  "a", ",", "b", ",", "r", ",", "es", ",", 
                                    InterpretationBox[\(p\^2\),
                                      PP], ",", "DP"}], "]"}], ",", 
                                RowBox[{"STLI", "[", 
                                  RowBox[{"d", ",", 
                                    InterpretationBox[\(p\^2\),
                                      PP], ",", 
                                    RowBox[{"{", 
                                      RowBox[{
                                        RowBox[{"{", 
                                        RowBox[{"n1", ",", 
                                        InterpretationBox[\(m\_1\),
                                        m1]}], "}"}], ",", 
                                        RowBox[{"{", 
                                        RowBox[{"n2", ",", 
                                        InterpretationBox[\(m\_2\),
                                        m2]}], "}"}], ",", 
                                        RowBox[{"{", 
                                        RowBox[{"n3", ",", 
                                        InterpretationBox[\(m\_3\),
                                        m3]}], "}"}], ",", 
                                        RowBox[{"{", 
                                        RowBox[{"n4", ",", 
                                        InterpretationBox[\(m\_4\),
                                        m4]}], "}"}], ",", 
                                        RowBox[{"{", 
                                        RowBox[{"n5", ",", 
                                        InterpretationBox[\(m\_5\),
                                        m5]}], "}"}]}], "}"}]}], "]"}]}], 
                              "]"}]}], "/.", 
                          RowBox[{"STLI", "\[Rule]", 
                            StyleBox["TFI",
                              FontColor->RGBColor[1, 0.6, 0]]}]}]}], 
                      "}"}]}]}]}], "]"}], 
            ",", \({a, 0, $TarasovTdeltaplimit}\), 
            ",", \({b, 0, $TarasovTdeltaplimit - a}\), 
            ",", \({r, 0, $TarasovTplimit}\), 
            ",", \({es, 0, $TarasovTplimit - r}\)}], "]"}], "]"}]}]], "Input"],

Cell["\<\
{0, 0, 0, 1}{0, 0, 0, 2}{0, 0, 0, 3}{0, 0, 0, 4}{0, 0, 0, 5}{0, 0, \
0, 6}{0, 0, 1, 0}{0, 0, 1, 1}{0, 0, 1, 2}{0, 0, 1, 3}{0, 0, 1, 4}{0, 0, 1, \
5}{0, 0, 2, 0}{0, 0, 2, 1}{0, 0, 2, 2}{0, 0, 2, 3}{0, 0, 2, 4}{0, 0, 3, 0}{0, \
0, 3, 1}{0, 0, 3, 2}{0, 0, 3, 3}{0, 0, 4, 0}{0, 0, 4, 1}{0, 0, 4, 2}{0, 0, 5, \
0}{0, 0, 5, 1}{0, 0, 6, 0}\
\>", "Print"]
}, Open  ]],

Cell[BoxData[
    \(Share[]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(matarti = 
      Timing[Do[
          If[0 < ia + ib + ir + es, 
            WriteString["\<stdout\>", {ia, ib, ir, es}]; 
            Set[f\_\(10\^4 + 1000\ ia + 100\ ib + 10\ ir + es\), 
              MakeFun[s\_\(10\^4 + 1000\ ia + 100\ ib + 10\ ir + es\), \
"\<(1\>" <> ToString[ia] <> ToString[ib] <> ToString[ir] <> 
                    ToString[es] <> "\<)\>"] /. PQ :> PNQ]], {ia, 
            0, \ $TarasovTdeltaplimit}, {ib, 
            0, $TarasovTdeltaplimit - ia}, {ir, 0, \ \ $TarasovTplimit}, {es, 
            0, $TarasovTplimit - ir}]]\)], "Input"],

Cell["\<\
{0, 0, 0, 1}{0, 0, 0, 2}{0, 0, 0, 3}{0, 0, 0, 4}{0, 0, 0, 5}{0, 0, \
0, 6}{0, 0, 1, 0}{0, 0, 1, 1}{0, 0, 1, 2}{0, 0, 1, 3}{0, 0, 1, 4}{0, 0, 1, \
5}{0, 0, 2, 0}{0, 0, 2, 1}{0, 0, 2, 2}{0, 0, 2, 3}{0, 0, 2, 4}{0, 0, 3, 0}{0, \
0, 3, 1}{0, 0, 3, 2}{0, 0, 3, 3}{0, 0, 4, 0}{0, 0, 4, 1}{0, 0, 4, 2}{0, 0, 5, \
0}{0, 0, 5, 1}{0, 0, 6, 0}\
\>", "Print"]
}, Open  ]],

Cell[BoxData[
    \(Share[]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["symmetry", "Subsection",
  CellTags->"Tsymmetry"],

Cell["\<\
TVR[d_, pp_, {a_, b_, c_, z_}] := 
  TVR[d, pp, {c, b, a, z}] /;  !OrderedQ[{a, c}]\
\>", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["special TVR reductions", "Subsection",
  CellTags->"specialTVR"],

Cell["\<\
TVR[2 + d_Symbol, pp_, {{1, m1_}, {1, m1_}, {2, 0}, {1, m1_}}] := 
   ((-6*m1^2 + 2*d*m1^2 + 3*pp)*TAI[d, 0, {{1, m1}}]^2)/
      (12*(-3 + d)*(-1 + d)*m1^2*pp) + 
     ((4*m1^2 - pp)*TAI[d, 0, {{1, m1}}]*TBI[d, pp, {{1, m1}, {1, m1}}])/
      (4*(-3 + d)*(-1 + d)*m1^2) - 
     ((6*m1^2 - 2*d*m1^2 - 7*pp + 2*d*pp)*
        TJI[d, pp, {{1, m1}, {1, m1}, {1, 0}}])/(6*(-2 + d)*(-1 + d)*pp) + 
     ((-4*m1^2 + pp)*(-6*m1^2 + 2*d*m1^2 + 3*pp)*
        TJI[d, pp, {{2, m1}, {1, m1}, {1, 0}}])/
      (6*(-3 + d)*(-2 + d)*(-1 + d)*pp) /; (m1=!=0)&&(pp=!=0);\
\>", "Input"],

Cell["\<\
TVR[4 + d_Symbol, pp_, {{1, m1_}, {1, m1_}, {2, 0}, {1, m1_}}] := 
   -((-96*d*m1^6 + 352*d^2*m1^6 - 384*d^3*m1^6 + 128*d^4*m1^6 - 
           192*m1^4*pp + 1008*d*m1^4*pp - 1632*d^2*m1^4*pp + 
           912*d^3*m1^4*pp - 144*d^4*m1^4*pp + 288*m1^2*pp^2 - 
           1536*d*m1^2*pp^2 + 2316*d^2*m1^2*pp^2 - 1086*d^3*m1^2*pp^2 + 
           66*d^4*m1^2*pp^2 + 72*d*pp^3 - 166*d^2*pp^3 + 81*d^3*pp^3 + 
           4*d^4*pp^3)*TAI[d, 0, {{1, m1}}]^2)/
      (36*(-1 + d)^2*d^2*(1 + d)*(-4 + 3*d)*(-2 + 3*d)*pp^2) + 
     ((4*m1^2 - pp)^2*TAI[d, 0, {{1, m1}}]*TBI[d, pp, {{1, m1}, {1, m1}}])/
      (4*(-1 + d)^2*d*(1 + d)) - 
     ((288*m1^8 - 1152*d*m1^8 + 1504*d^2*m1^8 - 768*d^3*m1^8 + 
          128*d^4*m1^8 - 816*m1^6*pp + 2480*d*m1^6*pp - 
          2224*d^2*m1^6*pp + 736*d^3*m1^6*pp - 80*d^4*m1^6*pp + 
          864*m1^4*pp^2 - 2196*d*m1^4*pp^2 + 1446*d^2*m1^4*pp^2 - 
          252*d^3*m1^4*pp^2 - 6*d^4*m1^4*pp^2 - 432*m1^2*pp^3 + 
          1086*d*m1^2*pp^3 - 895*d^2*m1^2*pp^3 + 315*d^3*m1^2*pp^3 - 
          44*d^4*m1^2*pp^3 + 4*d*pp^4 - 2*d^2*pp^4 - 4*d^3*pp^4 + 
          2*d^4*pp^4)*TJI[d, pp, {{1, m1}, {1, m1}, {1, 0}}])/
      (18*(-2 + d)*(-1 + d)^2*d*(1 + d)*(-4 + 3*d)*(-2 + 3*d)*pp^2) + 
     (m1^2*(4*m1^2 - pp)*(-96*m1^6 + 352*d*m1^6 - 384*d^2*m1^6 + 
          128*d^3*m1^6 + 240*m1^4*pp - 624*d*m1^4*pp + 384*d^2*m1^4*pp - 
          48*d^3*m1^4*pp - 192*m1^2*pp^2 + 420*d*m1^2*pp^2 - 
          162*d^2*m1^2*pp^2 - 18*d^3*m1^2*pp^2 + 72*pp^3 - 154*d*pp^3 + 
          81*d^2*pp^3 - 8*d^3*pp^3)*TJI[d, pp, {{2, m1}, {1, m1}, {1, 0}}])/
      (18*(-2 + d)*(-1 + d)^2*d*(1 + d)*(-4 + 3*d)*(-2 + 3*d)*pp^2) /; \
(m1=!=0)&&(pp=!=0);\
\>", "Input"],

Cell["\<\
TVR[4 + d_Symbol, pp_, {{1, m1_}, {1, m1_}, {3, 0}, {1, m1_}}] := 
   ((-72*d^2*m1^6 + 144*d^3*m1^6 - 88*d^4*m1^6 + 16*d^5*m1^6 - 
          240*d*m1^4*pp + 572*d^2*m1^4*pp - 398*d^3*m1^4*pp + 
          84*d^4*m1^4*pp - 2*d^5*m1^4*pp - 96*m1^2*pp^2 + 
          480*d*m1^2*pp^2 - 744*d^2*m1^2*pp^2 + 390*d^3*m1^2*pp^2 - 
          50*d^4*m1^2*pp^2 + 4*d^5*m1^2*pp^2 - 24*d*pp^3 + 54*d^2*pp^3 - 
          27*d^3*pp^3)*TAI[d, 0, {{1, m1}}]^2)/
      (24*(-3 + d)*(-1 + d)^2*d*(1 + d)*(-4 + 3*d)*(-2 + 3*d)*m1^2*pp^2) + 
     ((4*m1^2 - pp)^2*TAI[d, 0, {{1, m1}}]*TBI[d, pp, {{1, m1}, {1, m1}}])/
      (8*(-3 + d)*(-1 + d)^2*(1 + d)*m1^2) + 
     ((-72*d*m1^6 + 144*d^2*m1^6 - 88*d^3*m1^6 + 16*d^4*m1^6 - 
          96*m1^4*pp + 260*d*m1^4*pp - 166*d^2*m1^4*pp + 
          12*d^3*m1^4*pp + 6*d^4*m1^4*pp + 160*m1^2*pp^2 - 
          300*d*m1^2*pp^2 + 50*d^2*m1^2*pp^2 + 90*d^3*m1^2*pp^2 - 
          24*d^4*m1^2*pp^2 - 48*pp^3 + 114*d*pp^3 - 67*d^2*pp^3 + 
          4*d^3*pp^3 + 2*d^4*pp^3)*TJI[d, pp, {{1, m1}, {1, m1}, {1, 0}}])/
      (12*(-2 + d)*(-1 + d)^2*(1 + d)*(-4 + 3*d)*(-2 + 3*d)*pp^2) - 
     ((-4*m1^2 + pp)*(72*d*m1^6 - 144*d^2*m1^6 + 88*d^3*m1^6 - 
          16*d^4*m1^6 + 96*m1^4*pp - 236*d*m1^4*pp + 122*d^2*m1^4*pp + 
          12*d^3*m1^4*pp - 10*d^4*m1^4*pp - 96*m1^2*pp^2 + 
          180*d*m1^2*pp^2 - 30*d^2*m1^2*pp^2 - 46*d^3*m1^2*pp^2 + 
          8*d^4*m1^2*pp^2 + 24*pp^3 - 54*d*pp^3 + 27*d^2*pp^3)*
        TJI[d, pp, {{2, m1}, {1, m1}, {1, 0}}])/
(12*(-3 + d)*(-2 + d)*(-1 + d)^2*(1 + d)*(-4 + 3*d)*(-2 + 3*d)*pp^2) /; \
(m1=!=0)&&(pp=!=0);\
\>", "Input"],

Cell["\<\
TVR[6 + d_Symbol, pp_, 
    {{1, m1_}, {1, m1_}, {4, 0}, {1, m1_}}] := 
   ((2304*d*m1^10 - 4608*d^2*m1^10 - 3520*d^3*m1^10 + 6976*d^4*m1^10 + 
          1472*d^5*m1^10 - 2624*d^6*m1^10 - 256*d^7*m1^10 + 
          256*d^8*m1^10 + 4608*m1^8*pp - 9600*d*m1^8*pp - 
          7680*d^2*m1^8*pp + 9312*d^3*m1^8*pp + 11680*d^4*m1^8*pp - 
          6560*d^5*m1^8*pp - 2880*d^6*m1^8*pp + 1088*d^7*m1^8*pp + 
          32*d^8*m1^8*pp + 6912*m1^6*pp^2 - 35712*d*m1^6*pp^2 + 
          1056*d^2*m1^6*pp^2 + 85296*d^3*m1^6*pp^2 - 
          37032*d^4*m1^6*pp^2 - 20484*d^5*m1^6*pp^2 + 
          8700*d^6*m1^6*pp^2 - 12*d^7*m1^6*pp^2 - 84*d^8*m1^6*pp^2 - 
          20736*m1^4*pp^3 + 58752*d*m1^4*pp^3 + 40560*d^2*m1^4*pp^3 - 
          150536*d^3*m1^4*pp^3 + 18980*d^4*m1^4*pp^3 + 
          48946*d^5*m1^4*pp^3 - 6748*d^6*m1^4*pp^3 - 146*d^7*m1^4*pp^3 + 
          128*d^8*m1^4*pp^3 + 3456*m1^2*pp^4 - 13824*d*m1^2*pp^4 - 
          4176*d^2*m1^2*pp^4 + 35784*d^3*m1^2*pp^4 - 
          8332*d^4*m1^2*pp^4 - 10162*d^5*m1^2*pp^4 + 
          1122*d^6*m1^2*pp^4 - 80*d^7*m1^2*pp^4 - 8*d^8*m1^2*pp^4 + 
          864*d*pp^5 - 216*d^2*pp^5 - 2268*d^3*pp^5 + 486*d^4*pp^5 + 
          729*d^5*pp^5)*TAI[d, 0, {{1, m1}}]^2)/
      (432*(-3 + d)*(-1 + d)^2*d^2*(1 + d)*(2 + d)*(3 + d)*(-4 + 3*d)*
        (-2 + 3*d)*(2 + 3*d)*m1^2*pp^3) + 
     ((4*m1^2 - pp)^3*TAI[d, 0, {{1, m1}}]*TBI[d, pp, {{1, m1}, {1, m1}}])/
      (16*(-3 + d)*(-1 + d)^2*d*(1 + d)*(3 + d)*m1^2) - 
     ((-1152*m1^10 + 2880*d*m1^10 + 320*d^2*m1^10 - 3648*d^3*m1^10 + 
          1088*d^4*m1^10 + 768*d^5*m1^10 - 256*d^6*m1^10 - 192*m1^8*pp + 
          1312*d*m1^8*pp + 2080*d^2*m1^8*pp - 6880*d^3*m1^8*pp + 
          4032*d^4*m1^8*pp - 192*d^5*m1^8*pp - 160*d^6*m1^8*pp + 
          6336*m1^6*pp^2 - 6960*d*m1^6*pp^2 - 16960*d^2*m1^6*pp^2 + 
          17292*d^3*m1^6*pp^2 - 1828*d^4*m1^6*pp^2 - 828*d^5*m1^6*pp^2 + 
          68*d^6*m1^6*pp^2 - 9504*m1^4*pp^3 + 3624*d*m1^4*pp^3 + 
          26104*d^2*m1^4*pp^3 - 10938*d^3*m1^4*pp^3 - 
          4976*d^4*m1^4*pp^3 + 330*d^5*m1^4*pp^3 + 400*d^6*m1^4*pp^3 + 
          6336*m1^2*pp^4 - 3640*d*m1^2*pp^4 - 14584*d^2*m1^2*pp^4 + 
          9190*d^3*m1^2*pp^4 + 1374*d^4*m1^2*pp^4 - 600*d^5*m1^2*pp^4 - 
          56*d^6*m1^2*pp^4 - 864*pp^5 + 732*d*pp^5 + 1864*d^2*pp^5 - 
          1695*d^3*pp^5 + 148*d^4*pp^5 + 36*d^5*pp^5 + 4*d^6*pp^5)*
        TJI[d, pp, {{1, m1}, {1, m1}, {1, 0}}])/
      (216*(-2 + d)*(-1 + d)^2*d*(1 + d)*(3 + d)*(-4 + 3*d)*(-2 + 3*d)*
        (2 + 3*d)*pp^3) + ((-4*m1^2 + pp)*
        (1152*m1^10 - 2880*d*m1^10 - 320*d^2*m1^10 + 3648*d^3*m1^10 - 
          1088*d^4*m1^10 - 768*d^5*m1^10 + 256*d^6*m1^10 + 576*m1^8*pp - 
          2208*d*m1^8*pp - 2304*d^2*m1^8*pp + 8000*d^3*m1^8*pp - 
          4256*d^4*m1^8*pp - 32*d^5*m1^8*pp + 224*d^6*m1^8*pp - 
          6336*m1^6*pp^2 + 6288*d*m1^6*pp^2 + 16320*d^2*m1^6*pp^2 - 
          14868*d^3*m1^6*pp^2 + 684*d^4*m1^6*pp^2 + 804*d^5*m1^6*pp^2 - 
          12*d^6*m1^6*pp^2 + 6912*m1^4*pp^3 - 3192*d*m1^4*pp^3 - 
          18160*d^2*m1^4*pp^3 + 7950*d^3*m1^4*pp^3 + 3128*d^4*m1^4*pp^3 - 
          78*d^5*m1^4*pp^3 - 160*d^6*m1^4*pp^3 - 3456*m1^2*pp^4 + 
          1800*d*m1^2*pp^4 + 8136*d^2*m1^2*pp^4 - 4322*d^3*m1^2*pp^4 - 
          1042*d^4*m1^2*pp^4 + 128*d^5*m1^2*pp^4 + 16*d^6*m1^2*pp^4 + 
          432*pp^5 - 324*d*pp^5 - 972*d^2*pp^5 + 729*d^3*pp^5)*
        TJI[d, pp, {{2, m1}, {1, m1}, {1, 0}}])/
      (216*(-3 + d)*(-2 + d)*(-1 + d)^2*d*(1 + d)*(3 + d)*(-4 + 3*d)*
        (-2 + 3*d)*(2 + 3*d)*pp^3) /; (m1=!=0)&&(pp=!=0);\
\>", "Input"],

Cell["\<\
 TVR[6 + d_Symbol, pp_, {{2, m1_}, {1, m1_}, {3, 0}, {1, m1_}}] := 
   -((-1536*d*m1^10 + 2560*d^2*m1^10 + 3200*d^3*m1^10 - 3584*d^4*m1^10 - 
           2176*d^5*m1^10 + 1024*d^6*m1^10 + 512*d^7*m1^10 - 
           3072*m1^8*pp + 6528*d*m1^8*pp + 5376*d^2*m1^8*pp - 
           7520*d^3*m1^8*pp - 5568*d^4*m1^8*pp + 3232*d^5*m1^8*pp + 
           1344*d^6*m1^8*pp - 320*d^7*m1^8*pp - 2304*m1^6*pp^2 + 
           13824*d*m1^6*pp^2 + 192*d^2*m1^6*pp^2 - 31584*d^3*m1^6*pp^2 + 
           11232*d^4*m1^6*pp^2 + 8088*d^5*m1^6*pp^2 - 
           2304*d^6*m1^6*pp^2 - 24*d^7*m1^6*pp^2 + 6912*m1^4*pp^3 - 
           19584*d*m1^4*pp^3 - 12688*d^2*m1^4*pp^3 + 
           50584*d^3*m1^4*pp^3 - 7516*d^4*m1^4*pp^3 - 
           16982*d^5*m1^4*pp^3 + 2564*d^6*m1^4*pp^3 + 310*d^7*m1^4*pp^3 - 
           1152*m1^2*pp^4 + 4608*d*m1^2*pp^4 + 1392*d^2*m1^2*pp^4 - 
           11896*d^3*m1^2*pp^4 + 2820*d^4*m1^2*pp^4 + 
           3374*d^5*m1^2*pp^4 - 414*d^6*m1^2*pp^4 + 8*d^7*m1^2*pp^4 - 
           288*d*pp^5 + 72*d^2*pp^5 + 756*d^3*pp^5 - 162*d^4*pp^5 - 
           243*d^5*pp^5)*TAI[d, 0, {{1, m1}}]^2)/
      (144*(-1 + d)^2*d^2*(1 + d)*(2 + d)*(3 + d)*(-4 + 3*d)*(-2 + 3*d)*
        (2 + 3*d)*m1^2*pp^3) + 
     ((4*m1^2 - pp)^3*TAI[d, 0, {{1, m1}}]*TBI[d, pp, {{1, m1}, {1, m1}}])/
      (16*(-1 + d)^2*d*(1 + d)*(3 + d)*m1^2) - 
     ((2304*m1^10 - 5760*d*m1^10 - 640*d^2*m1^10 + 7296*d^3*m1^10 - 
          2176*d^4*m1^10 - 1536*d^5*m1^10 + 512*d^6*m1^10 - 
          1344*m1^8*pp + 1120*d*m1^8*pp - 1376*d^2*m1^8*pp + 
          5280*d^3*m1^8*pp - 4896*d^4*m1^8*pp + 1280*d^5*m1^8*pp - 
          64*d^6*m1^8*pp - 5184*m1^6*pp^2 + 7584*d*m1^6*pp^2 + 
          14800*d^2*m1^6*pp^2 - 21496*d^3*m1^6*pp^2 + 
          6120*d^4*m1^6*pp^2 + 280*d^5*m1^6*pp^2 - 184*d^6*m1^6*pp^2 + 
          9504*m1^4*pp^3 - 3720*d*m1^4*pp^3 - 27296*d^2*m1^4*pp^3 + 
          15378*d^3*m1^4*pp^3 + 4114*d^4*m1^4*pp^3 - 666*d^5*m1^4*pp^3 - 
          674*d^6*m1^4*pp^3 - 6336*m1^2*pp^4 + 5720*d*m1^2*pp^4 + 
          13712*d^2*m1^2*pp^4 - 13926*d^3*m1^2*pp^4 + 
          1284*d^4*m1^2*pp^4 + 946*d^5*m1^2*pp^4 - 80*d^6*m1^2*pp^4 + 
          864*pp^5 - 1020*d*pp^5 - 1636*d^2*pp^5 + 2311*d^3*pp^5 - 
          693*d^4*pp^5 + 20*d^5*pp^5 + 4*d^6*pp^5)*
        TJI[d, pp, {{1, m1}, {1, m1}, {1, 0}}])/
      (72*(-2 + d)*(-1 + d)^2*d*(1 + d)*(3 + d)*(-4 + 3*d)*(-2 + 3*d)*
        (2 + 3*d)*pp^3) + ((4*m1^2 - pp)*
        (-768*m1^10 + 1664*d*m1^10 + 768*d^2*m1^10 - 2176*d^3*m1^10 + 
          512*d^5*m1^10 + 192*m1^8*pp + 288*d*m1^8*pp + 704*d^2*m1^8*pp - 
          2272*d^3*m1^8*pp + 1024*d^4*m1^8*pp + 64*d^5*m1^8*pp + 
          1920*m1^6*pp^2 - 1824*d*m1^6*pp^2 - 5472*d^2*m1^6*pp^2 + 
          4584*d^3*m1^6*pp^2 - 168*d^5*m1^6*pp^2 - 2304*m1^4*pp^3 + 
          616*d*m1^4*pp^3 + 6192*d^2*m1^4*pp^3 - 1946*d^3*m1^4*pp^3 - 
          1128*d^4*m1^4*pp^3 - 230*d^5*m1^4*pp^3 + 1152*m1^2*pp^4 - 
          600*d*m1^2*pp^4 - 2744*d^2*m1^2*pp^4 + 1414*d^3*m1^2*pp^4 + 
          374*d^4*m1^2*pp^4 - 16*d^5*m1^2*pp^4 - 144*pp^5 + 108*d*pp^5 + 
          324*d^2*pp^5 - 243*d^3*pp^5)*
        TJI[d, pp, {{2, m1}, {1, m1}, {1, 0}}])/
      (72*(-2 + d)*(-1 + d)^2*d*(1 + d)*(3 + d)*(-4 + 3*d)*(-2 + 3*d)*
        (2 + 3*d)*pp^3) /; (m1=!=0)&&(pp=!=0);\
\>", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["five -> four", "Subsection",
  CellTags->"T1.6.121.1"],

Cell[BoxData[
    \(TFI[d_, \ 
        PP_ /; Head[PP] =!= List, {\ {0, \ m1_}, \ {n2_, \ 
            m2_}, \ \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ {n3_, \ m3_}, \ {n4_, \ 
            m4_}, \ \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ {n5_, \ m5_}\ }]\  := \ \n
      TVI[d, PP, \ {{n5, m5}, \ {n2, m2}, \ {n3, m3}, \ {n4, m4}}]\)], "Input"],

Cell[BoxData[
    \(TFI[
        d_, \ \ PP_ /; 
          Head[PP] =!= List, {\ {\((n2_)\), \ m2_}, {0, \ 
            m1_}, \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ {\((n4_)\), \ m4_}, \ {\((n3_)\), \ 
            m3_}, \ \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ {\((n5_)\), \ m5_}\ }]\  := \ \n
      TVI[d, PP, \ {{n5, m5}, \ {n2, m2}, \ {n3, m3}, \ {n4, m4}}]\)], "Input"],

Cell[BoxData[
    \(TFI[
        d_, \ \ \ PP_ /; 
          Head[PP] =!= List, {\ {\((n3_)\), \ m3_}, \ {\((n4_)\), \ 
            m4_}, \n\t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
{0, \ m1_}, \ {\((n2_)\), \ 
            m2_}, \ \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ {\((n5_)\), \ m5_}\ }]\  := \ \n
      TVI[d, PP, \ {{n5, m5}, \ {n2, m2}, \ {n3, m3}, \ {n4, m4}}]\)], "Input"],

Cell[BoxData[
    \(TFI[
        d_, \ \ \ PP_ /; 
          Head[PP] =!= List, {\ {\((n4_)\), \ m4_}, {\((n3_)\), \ 
            m3_}, \n\t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
{\((n2_)\), \ m2_}, \ {0, \ 
            m1_}, \ \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ {\((n5_)\), \ m5_}\ }]\  := \ \n
      TVI[d, PP, \ {{n5, m5}, \ {n2, m2}, \ {n3, m3}, \ {n4, m4}}]\)], "Input"],

Cell["\<\

TFI[d_,  PP_/;Head[PP]=!=List,{{(n1_), m1_}, 

    {(n2_), m2_}, 

    {(n3_), m3_}, 

    {(n4_), m4_}, {0, m5_}}] := 

  TBI[d, PP, {{n1, m1}, {n3, m3}}]*

   TBI[d, PP, {{n2, m2}, {n4, m4}}]
\
\>", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["four -> three", "Subsection",
  CellTags->"T1.6.122.1"],

Cell[BoxData[
    \(TVI[d_, \ 
        PP_, {\ {0, \ m1_}, \ {n2_, \ 
            m2_}, \ \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ {n3_, \ m3_}, \ {n4_, \ m4_}\ }]\  := \ \n
      TAI[d, 0, {{n3, m3}}]\ TBI[d, PP, {{n2, m2}, {n4, m4}}]\)], "Input"],

Cell[BoxData[
    \(TVI[d_, \ 
        PP_, {\ {n1_, \ m1_}, \ {n2_, \ 
            m2_}, \ \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ {0, \ m3_}, \ {n4_, \ m4_}\ }]\  := \ \n
      TAI[d, 0, {{n1, m1}}]\ TBI[d, PP, {{n2, m2}, {n4, m4}}]\)], "Input"],

Cell["\<\
TVI[d_, PP_, {{n1_, m1_}, {0, m2_}, {n3_, m3_}, {n4_, m4_}}] := 
  TJI[d, 0, {{n1, m1}, {n3, m3}, {n4, m4}}]\
\>", "Input"],

Cell[BoxData[
    \(TVI[d_, \ 
        PP_, {\ {n1_, \ m1_}, \ {n2_, \ 
            m2_}, \ \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ {n3_, \ m3_}, \ {0, \ m4_}\ }]\  := \ \n
      TJI[d, PP, \ {{n2, m2}, {n1, m1}, {n3, m3}\ }]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["three -> two", "Subsection",
  CellTags->"T1.6.123.1"],

Cell[BoxData[
    \(TJI[d_, \ 
        PP_, {\ {0, \ m1_}, \ {\((n2_)\), \ m2_}, \ {\((n3_)\), \ 
            m3_}\ }]\  := \ \n
      TAI[d, 0, {{n2, m2}}]\ \ TAI[d, 0, {{n3, m3}}]\)], "Input"],

Cell[BoxData[
    \(TJI[d_, \ 
        PP_, {\ {\((n1_)\), \ m1_}, \ {0, \ m2_}, \ {\((n3_)\), \ 
            m3_}\ }]\  := \ \n
      TAI[d, 0, {{n1, m1}}]\ \ TAI[d, 0, {{n3, m3}}]\)], "Input"],

Cell[BoxData[
    \(TJI[d_, \ 
        PP_, {\ {\((n1_)\), \ m1_}, \ {\((n2_)\), \ m2_}, \ {0, \ 
            m3_}\ }]\  := \ \n
      TAI[d, 0, {{n1, m1}}]\ \ TAI[d, 0, {{n2, m2}}]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["two -> one", "Subsection",
  CellTags->"T1.6.124.1"],

Cell[BoxData[
    \(\(\(\(TBI[d_, \ 
        PP_, {\ {0, \ m1_}, \ {\((n2_)\), \ 
            m2_}\ }]\)\(\ \)\)\(:=\)\(\ \)\(\n\)\(TAI[d, 
        0, {{n2, m2}}]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(\(TBI[d_, \ 
        PP_, {\ {\((n1_)\), \ m1_}, \ {0, \ 
            m2_}\ }]\)\(\ \)\)\(:=\)\(\ \)\(\n\)\(TAI[d, 
        0, {{n1, m1}}]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(TAI[d_, {{n_Integer, m_}}] := TAI[d, 0, {{n, m}}];\)\)], "Input"],

Cell[BoxData[
    \(\(TAI[d_, {n_Integer, m_}] := TAI[d, 0, {{n, m}}];\)\)], "Input"],

Cell[BoxData[
    \(\(TAI[d_, 0, {n_Integer, m_}] := TAI[d, 0, {{n, m}}];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["TarcerRecurse and TFIRecurse", "Section",
  CellDingbat->"\[FilledSmallCircle]",
  CellTags->"T1.7.1"],

Cell[CellGroupData[{

Cell["TFIRecurse & TFISimplify", "Subsection",
  CellTags->"T1.7.1.1"],

Cell["This cancels scalar products.", "Text"],

Cell[BoxData[
    \(\($TLRComment = False;\)\)], "Input"],

Cell[BoxData[
    \(\(TLRComment[s_String] := 
        WriteString["\<stdout\>", s, "\< \>"] /; $TLRComment === 
            True;\)\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(applytlrules[y_, fun_]\), " ", ":=", 
        RowBox[{"fun", "[", 
          RowBox[{
            RowBox[{
              RowBox[{"y", " ", "/.", 
                RowBox[{
                  StyleBox["TFI",
                    FontColor->RGBColor[1, 0.6, 0]], "->", "TLR"}]}], "/.", 
              "TLRules"}], "/.", 
            RowBox[{"TLR", "->", 
              StyleBox["TFI",
                FontColor->RGBColor[1, 0.6, 0]]}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
    \(\(TFIRecurse[z_, f_ : Identity]\  := \ 
        FixedPoint[\ applytlrules[#, f] &, z, 1000];\)\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(applytlrules2[y_, fun_]\), " ", ":=", 
        RowBox[{"fun", "[", 
          RowBox[{
            RowBox[{
              RowBox[{"y", " ", "/.", 
                RowBox[{
                  StyleBox["TFI",
                    FontColor->RGBColor[1, 0.6, 0]], "->", "TLR"}]}], "/.", 
              "TLRules2"}], "/.", 
            RowBox[{"TLR", "->", 
              StyleBox["TFI",
                FontColor->RGBColor[1, 0.6, 0]]}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
    \(\(TFISimplify[z_, f_ : Identity]\  := \ 
        FixedPoint[\ applytlrules2[#, f] &, z, 1000];\)\)], "Input"],

Cell["\<\
TFIRecurse[z_]:=z/.TFI\[Rule]TLR//.TLRules/.TLR\[Rule]TFI;\
\>", \
"Text"],

Cell[BoxData[
    \(\(ExpandMaybe = Identity;\)\)], "Input"],

Cell[BoxData[
    \(\(fN[li_List] := \(fN[li] = 
          li /. {0, _} \[RuleDelayed] {0, 0}\);\)\)], "Input"],

Cell["\<\
RM: new Feb. 1999  
need TLR[ ...]:= rule;
(copy from TFI definition) (in order to get e.g. 
TarcerRecurse[TFI[D,pp,{1,1,1,1,1},{{1,0},{1,M},{0,0},{1,m},{1,M}}]]
to work)\
\>", "Text",
  CellTags->"TLRdef"],

Cell[BoxData[
    \(\(TLR[depp__, {a___, b_Integer, c___}] := 
        TLR[depp, {a, {b, 0}, c}];\)\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(tlrule[1]\), "=", 
        RowBox[{\(TLR[d_, pp_, {0, 0, 0, 0, 0}, pr_]\), "\[RuleDelayed]", 
          RowBox[{"(", 
            RowBox[{\(NoTLRComment["\<tlrule1\>"]\), ";", 
              RowBox[{
                StyleBox["TFI",
                  FontColor->RGBColor[1, 0.6, 0]], "[", \(d, pp, 
                pr /. {0, _} \[RuleDelayed] {0, 0}\), "]"}]}], ")"}]}]}], 
      ";"}]], "Input"],

Cell["(* q1^2 *)", "Text"],

Cell[BoxData[
    \(\(tlrule[2] = 
        TLR[dpp__, {v_?PQ, w_, x_, y_, z_}, {{n1_?PQ, m1_}, nm2_, nm3_, nm4_, 
              nm5_}] \[RuleDelayed] \((TLRComment["\<tlrule2\>"]; 
            ExpandMaybe[
              If[v \[LessEqual] n1, 
                If[m1 === 0, 
                  TLR[dpp, {0, w, x, y, z}, {{n1 - v, 0}, nm2, nm3, nm4, 
                      nm5}], \[Sum]\+\(i = 0\)\%v Binomial[v, i]\ TLR[
                        dpp, \ {0, w, x, y, z}, {fN[{n1 - i, m1}], nm2, nm3, 
                          nm4, nm5}]\ \((m1\^2)\)\^\(v - i\)], 
                If[m1 === 0, 
                  TLR[dpp, {v - n1, w, x, y, z}, {{0, 0}, nm2, nm3, nm4, 
                      nm5}], \[Sum]\+\(i = 0\)\%n1 Binomial[n1, i]\ TLR[
                        dpp, {v - n1, w, x, y, z}, {fN[{n1 - i, m1}], nm2, 
                          nm3, nm4, 
                          nm5}]\ \((m1\^2)\)\^\(n1 - i\)]]])\);\)\)], "Input"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`q\_2\%2\)]]], "Text"],

Cell[BoxData[
    \(\(tlrule[3] = 
        TLR[dpp__, {v_, w_?PQ, x_, y_, z_}, {nm1_, {n2_?PQ, m2_}, nm3_, nm4_, 
              nm5_}] \[RuleDelayed] \((TLRComment["\<tlrule3\>"]; 
            ExpandMaybe[
              If[w \[LessEqual] n2, 
                If[m2 === 0, 
                  TLR[dpp, {v, 0, x, y, z}, {nm1, {n2 - w, 0}, nm3, nm4, 
                      nm5}], \[Sum]\+\(i = 0\)\%w Binomial[w, i]\ TLR[
                        dpp, {v, 0, x, y, z}, {nm1, fN[{n2 - i, m2}], nm3, 
                          nm4, nm5}]\ \((m2\^2)\)\^\(w - i\)], 
                If[m2 === 0, 
                  TLR[dpp, {v, w - n2, x, y, z}, {nm1, {0, 0}, nm3, nm4, 
                      nm5}], \[Sum]\+\(i = 0\)\%n2 Binomial[n2, i]\ TLR[
                        dpp, {v, w - n2, x, y, z}, {nm1, fN[{n2 - i, m2}], 
                          nm3, nm4, 
                          nm5}]\ \((m2\^2)\)\^\(n2 - i\)]]])\);\)\)], "Input"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`p\[CenterDot]q\_1\)]]], "Text"],

Cell[BoxData[
    \(\(tlrule[4] = 
        TLR[dpp__, {v_, w_, x_?PQ, y_, z_}, {{n1_?PQ, m1_}, 
              nm2_, {n3_?PQ, m3_}, nm4_, 
              nm5_}] \[RuleDelayed] \((TLRComment["\<tlrule4\>"]; 
            ExpandMaybe[
              1\/2\ TLR[
                    dpp, {v + 1, w, x - 1, y, z}, {{n1, m1}, nm2, {n3, m3}, 
                      nm4, nm5}] - 
                1\/2\ TLR[
                    dpp, {v, w, x - 1, y, z}, {{n1, m1}, nm2, 
                      fN[{n3 - 1, m3}], nm4, nm5}] + 
                1\/2\ \(({dpp}\[LeftDoubleBracket]2\[RightDoubleBracket] - 
                      m3\^2)\)\ TLR[
                    dpp, {v, w, x - 1, y, z}, {{n1, m1}, nm2, {n3, m3}, nm4, 
                      nm5}]])\);\)\)], "Input"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`p\[CenterDot]q\_2\)]]], "Text"],

Cell[BoxData[
    \(\(tlrule[5] = 
        TLR[dpp__, {v_, w_, x_, y_?PQ, z_}, {{n1_, m1_}, {n2_?PQ, m2_}, 
              nm3_, {n4_?PQ, m4_}, 
              nm5_}] \[RuleDelayed] \((TLRComment["\<tlrule5\>"]; 
            ExpandMaybe[
              1\/2\ TLR[
                    dpp, {v, w + 1, x, y - 1, z}, {{n1, m1}, {n2, m2}, 
                      nm3, {n4, m4}, nm5}] - 
                1\/2\ TLR[
                    dpp, {v, w, x, y - 1, z}, {{n1, m1}, {n2, m2}, nm3, 
                      fN[{n4 - 1, m4}], nm5}] + 
                1\/2\ \(({dpp}\[LeftDoubleBracket]2\[RightDoubleBracket] - 
                      m4\^2)\)\ TLR[
                    dpp, {v, w, x, y - 1, z}, {{n1, m1}, {n2, m2}, 
                      nm3, {n4, m4}, nm5}]])\);\)\)], "Input"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`q\_1\[CenterDot]q\_2\)]]], "Text"],

Cell[BoxData[
    \(\(tlrule[6] = 
        TLR[dpp__, {v_, w_, x_, y_, z_?PQ}, {{n1_, m1_}, {n2_, m2_}, nm3_, 
              nm4_, {n5_?PQ, 
                m5_}}] \[RuleDelayed] \((TLRComment["\<tlrule6\>"]; 
            ExpandMaybe[
              1\/2\ TLR[
                    dpp, {v + 1, w, x, y, z - 1}, {{n1, m1}, {n2, m2}, nm3, 
                      nm4, {n5, m5}}] - 
                1\/2\ TLR[
                    dpp, {v, w, x, y, z - 1}, {{n1, m1}, {n2, m2}, nm3, nm4, 
                      fN[{n5 - 1, m5}]}] + 
                1\/2\ TLR[
                    dpp, {v, w + 1, x, y, z - 1}, {{n1, m1}, {n2, m2}, nm3, 
                      nm4, {n5, m5}}] - 
                1\/2\ m5\^2\ TLR[
                    dpp, {v, w, x, y, z - 1}, {{n1, m1}, {n2, m2}, nm3, 
                      nm4, {n5, m5}}]])\);\)\)], "Input"],

Cell["(* q1.q1  --> q1.p *)", "Text"],

Cell[BoxData[
    \(\(tlrule[7] = 
        TLR[d_, pp_, 
            dp___, {v_?PQ, w_, x_, y_, z_}, {{0, _}, nm2_, {n3_?PQ, m3_}, 
              nm4_, nm5_}] \[RuleDelayed] \((TLRComment["\<tlrule7\>"]; 
            ExpandMaybe[
              TLR[d, pp, 
                  dp, {v - 1, w, x, y, z}, {{0, 0}, nm2, fN[{n3 - 1, m3}], 
                    nm4, nm5}] + 
                2\ TLR[d, pp, 
                    dp, {v - 1, w, x + 1, y, z}, {{0, 0}, nm2, {n3, m3}, nm4, 
                      nm5}] - \((pp - m3\^2)\)\ TLR[d, pp, 
                    dp, {v - 1, w, x, y, z}, {{0, 0}, nm2, {n3, m3}, nm4, 
                      nm5}]])\);\)\)], "Input"],

Cell["(* q2.q2  --> q2.p *)", "Text"],

Cell[BoxData[
    \(\(tlrule[8] = 
        TLR[d_, pp_, 
            dp___, {v_, w_?PQ, x_, y_, z_}, {nm1_, {0, _}, 
              nm3_, {n4_?PQ, m4_}, 
              nm5_}] \[RuleDelayed] \((TLRComment["\<tlrule8\>"]; 
            ExpandMaybe[
              TLR[d, pp, 
                  dp, {v, w - 1, x, y, z}, {nm1, {0, 0}, nm3, 
                    fN[{n4 - 1, m4}], nm5}] + 
                2\ TLR[d, pp, 
                    dp, {v, w - 1, x, y + 1, z}, {nm1, {0, 0}, nm3, {n4, m4}, 
                      nm5}] - \((pp - m4\^2)\)\ TLR[d, pp, 
                    dp, {v, w - 1, x, y, z}, {nm1, {0, 0}, nm3, {n4, m4}, 
                      nm5}]])\);\)\)], "Input"],

Cell["(* eq. (3) - (5) *)", "Text"],

Cell[BoxData[
    \(\(tlrule[9] = 
        TLR[d_, pp_, {v_, w_, x_, y_, z_?PQ}, {nm1_, nm2_, nm3_, 
              nm4_, {0, _}}] \[RuleDelayed] \((TLRComment["\<tlrule9\>"]; 
            FunctionExpand[
              ExpandMaybe[\[Sum]\+\(k = 0\)\%\(Floor[z\/2]\)\(\[Sum]\+\(i = 0\
\)\%k\(\[Sum]\+\(j = 0\)\%k\((Gamma[k + 1\/2]\ Gamma[d\/2 - 1\/2]\ Binomial[
                              z, 2\ k]\ Binomial[k, i]\ Binomial[k, 
                              j]\ \((\(-1\))\)\^\(i + j\)\ pp\^\(i + j - z\)\ \
TLR[d, pp, {v + i, w + j, x + z - 2\ i, y + z - 2\ j, 0}, {nm1, nm2, nm3, 
                                nm4, {0, 0}}])\)/\((Gamma[1\/2]\ Gamma[
                              k + d\/2 - 1\/2])\)\)\)]])\);\)\)], "Input"],

Cell[" OLD trule[10]:", "Text"],

Cell["\<\
tlrule[10] = 
(* (9) and (10) *)
TLR[d_, pp_, {v_,w_,x_?PQ,y_?PQ,z_}, {{n1_?PQ,m1_},{n2_?PQ,m2_}, 
                                {0,_},{0,_},nm5_}] :>  
( TLRComment[\"tlrule10\"]; 0 /; OddQ[x+y] );\
\>", "Text"],

Cell["New tlrule[10]:", "Text"],

Cell["\<\
tlrule[10] = 
   TLR[d_, pp_, {v_, w_, (x_)?PNQ, (y_)?PNQ, z_}, 
     {{(n1_)?PQ, m1_}, {(n2_)?PQ, m2_}, {0, _}, {0, _}, nm5_}] :> \
(TLRComment[\"tlrule10\"]; 0 /; OddQ[x + y]); \
\>", "Input"],

Cell["\<\
Bug in  tlrule[11] and tlrule[12] fixed on Feb. 26th 1998 by \
R.Scharf 
with thanks to York Schroeder for locating the bug.\
\>", "Text"],

Cell["\<\

tlrule[11] = 
TLR[d_, pp_, {v_,w_,x_?PQ,y_?PQ,z_}, {nm1_,nm2_,{0,_},{0,_},{(n5_)?PQ, m5_}}] \
:> 
(
TLRComment[\"tlrule11\"];
 ExpandMaybe[
 pp/(d+x+y-2)( (x-1) TLR[d, pp, {v+1,w,x-2,y,z}, 
                         {{n1,m1},{n2,m2},{0,0},{0,0},{n5,m5}}] +
                   y TLR[d, pp, {v,w,x-1,y-1,z+1}, 
                         {nm1,nm2,{0,0},{0,0},{n5,m5}}]
             )
           ] /; EvenQ[x+y] && x > 1
);\
\>", "Input"],

Cell["\<\

tlrule[12] = 
TLR[d_, pp_, {v_,w_,x_?PQ,y_?PQ,z_}, {nm1_,nm2_,{0,_},{0,_},{(n5_)?PQ, m5_}}] \
:> 
(
TLRComment[\"tlrule12\"];
 ExpandMaybe[
 pp/(d+x+y-2)( (y-1) TLR[d, pp, {v,w+1,x,y-2,z}, 
                         {{n1,m1},{n2,m2},{0,0},{0,0},{n5,m5}}] +
                   x TLR[d, pp, {v,w,x-1,y-1,z+1}, 
                         {nm1,nm2,{0,0},{0,0},{n5,m5}}]
             )
           ] /; EvenQ[x+y] && y > 1
);\
\>", "Input"],

Cell["(*symm.   1 <-> 3  &&  2 <-> 4 *)", "Text"],

Cell[BoxData[
    \(\(tlrule[13] = 
        TLR[d_, pp_, {0, 0, 0, y_?PQ, 0}, {nm1_, {0, 0}, nm3_, {n4_?PQ, m4_}, 
              nm5_}] \[RuleDelayed] \((TLRComment["\<tlrule13\>"]; \
\[Sum]\+\(i = 0\)\%y Binomial[y, i]\ pp\^\(y - i\)\ \((\(-1\))\)\^i\ TLR[d, 
                  pp, {0, 0, 0, i, 0}, {nm3, {n4, m4}, nm1, {0, 0}, 
                    nm5}])\);\)\)], "Input"],

Cell["(*symm.   1 <-> 3  &&  2 <-> 4 *)", "Text"],

Cell[BoxData[
    \(\(tlrule[14] = 
        TLR[d_, pp_, {0, 0, x_?PQ, 0, 0}, {{0, 0}, nm2_, {n3_?PQ, m3_}, nm4_, 
              nm5_}] \[RuleDelayed] \((TLRComment["\<tlrule14\>"]; \
\[Sum]\+\(i = 0\)\%x Binomial[x, i]\ pp\^\(x - i\)\ \((\(-1\))\)\^i\ TLR[d, 
                  pp, {0, 0, i, 0, 0}, {{n3, m3}, nm4, {0, 0}, nm2, 
                    nm5}])\);\)\)], "Input"],

Cell["(* 0's *)", "Text"],

Cell[BoxData[
    \(\(tlrule[15] = 
        HoldPattern[
            TLR[d_, pp_, {v_, w_, x_, y_, 
                z_}, {{n1_, 0}, {n2_, 
                  0}, {0, _}, {0, _}, {0, _}}]] \[RuleDelayed] \
\((TLRComment["\<tlrule15\>"]; 0)\);\)\)], "Input"],

Cell[BoxData[
    \(\(tlrule[16] = 
        TLR[d_, pp_, {0, 0, x_?PQ, y_?PQ, 
              0}, {{n1_, _}, {n2_, _}, {0, _}, {0, _}, {0, _}}] \
\[RuleDelayed] \((TLRComment["\<tlrule16\>"]; 
            0 /; OddQ[x] || OddQ[y])\);\)\)], "Input"],

Cell["bug in tlrule[17] fixedApril 23rd 1999", "Text",
  CellTags->"tlrule17"],

Cell[BoxData[
    \(\(tlrule[17] = 
        TLR[d_, pp_, {a_?PQ, b_, 0, de_, 
              0}, {{0, _}, {n2_, m2_}, {0, _}, {n4_, m4_}, {n5_, 
                m5_}}] \[RuleDelayed] \((TLRComment["\<tlrule17\>"]; \[Sum]\+\
\(i = 0\)\%a\(\[Sum]\+\(j = 0\)\%i Binomial[a, i]\ Binomial[i, 
                    j]\ \((1 + \((\(-1\))\)\^j)\)\ 2\^\(j - 1\)\ TLR[d, 
                    pp, {a - i, b + i - j, 0, de, 
                      j}, {{n5, m5}, {n2, m2}, {0, 0}, {n4, m4}, {0, 
                        0}}]\))\);\)\)], "Input"],

Cell[BoxData[
    \(\(tlrule[18] = 
        TLR[d_, pp_, 
            dp_, {a_?PNQ, b_?PNQ}, {1, 0, 0, 0, 
              0}, {{0, 0}, {n2_, m2_}, {n3_, m3_}, {n4_, m4_}, {n5_, 
                m5_}}] \[RuleDelayed] \((TLRComment["\<tlrule18\>"]; \[Sum]\+\
\(i = 0\)\%a\(\[Sum]\+\(j = 0\)\%b Binomial[a, i]\ Binomial[b, 
                    j]\ \((\((pp + m3\^2)\)\ TLR[d, pp, 
                          dp, {i, 
                            j}, {{n3, m3}, {n4, m4}, {0, 0}, {n2, m2}, {n5, 
                              m5}}] + 
                      TLR[d, pp, 
                        dp, {i, 
                          j}, {{n3 - 1, m3}, {n4, m4}, {0, 0}, {n2, m2}, {n5, 
                            m5}}] - 
                      2\ TLR[d, pp, 
                          dp, {i, j}, {0, 0, 1, 0, 
                            0}, {{n3, m3}, {n4, m4}, {0, 0}, {n2, m2}, {n5, 
                              m5}}])\)\ \((\(-1\))\)\^\(i + j\)\ dp\^\(a + b \
- i - j\)\))\);\)\)], "Input"],

Cell[BoxData[
    \(\(tlrule[19] = 
        TLR[d_, pp_, 
            dp_, {a_?PNQ, b_?PNQ}, {0, 1, 0, 0, 
              0}, {{n1_, m1_}, {0, 0}, {n3_, m3_}, {n4_, m4_}, {n5_, 
                m5_}}] \[RuleDelayed] \((TLRComment["\<tlrule18\>"]; \[Sum]\+\
\(i = 0\)\%a\(\[Sum]\+\(j = 0\)\%b Binomial[a, i]\ Binomial[b, 
                    j]\ \((\((pp + m4\^2)\)\ TLR[d, pp, 
                          dp, {i, 
                            j}, {{n3, m3}, {n4, m4}, {n1, m1}, {0, 0}, {n5, 
                              m5}}] + 
                      TLR[d, pp, 
                        dp, {i, 
                          j}, {{n3, m3}, {n4 - 1, m4}, {n1, m1}, {0, 0}, {n5, 
                            m5}}] - 
                      2\ TLR[d, pp, 
                          dp, {i, j}, {0, 0, 0, 1, 
                            0}, {{n3, m3}, {n4, m4}, {n1, m1}, {0, 0}, {n5, 
                              m5}}])\)\ \((\(-1\))\)\^\(i + j\)\ dp\^\(a + b \
- i - j\)\))\);\)\)], "Input"],

Cell["(* q1.q1  --> q1.p *)", "Text"],

Cell[BoxData[
    \(\(tlrule[20] = 
        TLR[d_, pp_, {v_?PQ, w_, x_, y_, 0}, {{0, _}, nm2_, {0, _}, 
              nm4_, {n5_?PQ, 
                m5_}}] \[RuleDelayed] \((TLRComment["\<tlrule20\>"]; \[Sum]\+\
\(j = 0\)\%x\(\[Sum]\+\(i = 0\)\%v\(\[Sum]\+\(r = 0\)\%i Binomial[i, 
                      r]\ Binomial[v, i]\ Binomial[x, j]\ 2\^r\ TLR[d, 
                      pp, {v - i, \(-r\) + i + w, j, x - j + y, 
                        r}, {{n5, m5}, nm2, 0, nm4, 0}]\)\))\);\)\)], "Input"],

Cell[BoxData[
    \(\(tlrule[21] = 
        TLR[d_, pp_, {v_, w_?PQ, x_, y_, 0}, {nm1_, {0, _}, nm3_, {0, _}, 
              nm5_}] \[RuleDelayed] \((TLRComment["\<tlrule21\>"]; 
            TLR[d, pp, {w, v, y, x, 0}, {{0, 0}, nm1, {0, 0}, nm3, 
                nm5}])\);\)\)], "Input"],

Cell[BoxData[
    \(\(tlrule[22] = 
        TLR[d_, pp_, 
            dp_, {0, b_?PNQ}, {0, w_?PNQ, 0, y_?PNQ, 1}, {nm1_, nm2_, nm3_, 
              nm4_, {0, 
                0}}] \[RuleDelayed] \((TLRComment["\<tlrule22\>"]; \(1\/pp\) \
\((TLR[d, pp, dp, {0, b}, {0, w, 1, y + 1, 0}, {nm1, nm2, nm3, 
                    nm4, {0, 0}}])\))\);\)\)], "Input"],

Cell[TextData[{
  "Using  FeynCalc : \n\n",
  Cell[BoxData[
      \(TIDL[{{k1, \[Mu]}, {k1, \[Nu]}}, {p}]\)], "Input"],
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[
            RowBox[{
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"(", 
                      FormBox[
                        RowBox[{
                          FormBox["k1",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["p",
                            "TraditionalForm"]}],
                        "TraditionalForm"], ")"}], "2"], "-", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["k1",
                        "TraditionalForm"], "2"], " ", 
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"]}]}], ")"}]}], 
            RowBox[{\((1 - D)\), " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"]}]], "-", 
          FractionBox[
            RowBox[{
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"D", " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        FormBox[
                          RowBox[{
                            FormBox["k1",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["p",
                              "TraditionalForm"]}],
                          "TraditionalForm"], ")"}], "2"]}], "-", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["k1",
                        "TraditionalForm"], "2"], " ", 
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"]}]}], ")"}]}], 
            RowBox[{\((1 - D)\), " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "4"]}]]}], TraditionalForm]], 
    "Output"],
  "\n",
  Cell[BoxData[
      \(Collect2[Calc[\ FVD[OPEDelta, \[Mu]] FVD[k2, \[Nu]] %], {k1, k2}]\)], 
    "Input"],
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[
            RowBox[{
              RowBox[{
                FormBox["k2",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"]}], " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  FormBox[
                    RowBox[{
                      FormBox["k1",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["p",
                        "TraditionalForm"]}],
                    "TraditionalForm"], ")"}], "2"]}], 
            RowBox[{\((1 - D)\), " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"]}]], "-", 
          FractionBox[
            RowBox[{"D", " ", 
              RowBox[{
                FormBox["k2",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["p",
                  "TraditionalForm"]}], " ", 
              RowBox[{
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["p",
                  "TraditionalForm"]}], " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  FormBox[
                    RowBox[{
                      FormBox["k1",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["p",
                        "TraditionalForm"]}],
                    "TraditionalForm"], ")"}], "2"]}], 
            RowBox[{\((1 - D)\), " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "4"]}]], "-", 
          FractionBox[
            RowBox[{
              SuperscriptBox[
                FormBox["k1",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{
                FormBox["k2",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"]}]}], \(1 - D\)], "+", 
          FractionBox[
            RowBox[{
              SuperscriptBox[
                FormBox["k1",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{
                FormBox["k2",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["p",
                  "TraditionalForm"]}], " ", 
              RowBox[{
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["p",
                  "TraditionalForm"]}]}], 
            RowBox[{\((1 - D)\), " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"]}]]}], TraditionalForm]], 
    "Output"],
  "\n"
}], "Text"],

Cell[BoxData[
    \(\(tlrule[23] = 
        TLR[d_, pp_, 
            dp_, {1, b_?PNQ}, {0, w_?PNQ, 0, y_?PNQ, 1}, {nm1_, nm2_, nm3_, 
              nm4_, {0, 
                0}}] \[RuleDelayed] \((TLRComment["\<tlrule23\>"]; \
\(1\/\(\((1 - d)\) pp\)\) \((TLR[d, pp, 
                    dp, {0, b + 1}, {0, w, 2, y, 0}, {nm1, nm2, nm3, 
                      nm4, {0, 0}}])\) - \(\(d\ \ dp\)\/\(\((1 - d)\) 
                      pp\^2\)\) \((TLR[d, pp, 
                    dp, {0, b}, {0, w, 2, y + 1, 0}, {nm1, nm2, nm3, 
                      nm4, {0, 0}}])\) - \(1\/\(1 - d\)\) 
                TLR[d, pp, 
                  dp, {0, b + 1}, {1, w, 0, y, 0}, {nm1, nm2, nm3, 
                    nm4, {0, 0}}] + \(dp\/\(\((1 - d)\) pp\)\) 
                TLR[d, pp, 
                  dp, {0, b}, {1, w, 0, y + 1, 0}, {nm1, nm2, nm3, 
                    nm4, {0, 0}}])\);\)\)], "Input"],

Cell[TextData[{
  Cell[BoxData[
      \(TIDL[{{k1, \[Mu]}, {k1, \[Nu]}, {k1, \[Rho]}}, {p}]\)], "Input"],
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"-", 
            FractionBox[
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["k1",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["p",
                    "TraditionalForm"]}], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{\((D + 2)\), " ", 
                      SuperscriptBox[
                        RowBox[{"(", 
                          FormBox[
                            RowBox[{
                              FormBox["k1",
                                "TraditionalForm"], "\[NoBreak]", 
                              "\[CenterDot]", "\[NoBreak]", 
                              FormBox["p",
                                "TraditionalForm"]}],
                            "TraditionalForm"], ")"}], "2"]}], "-", 
                    RowBox[{"3", " ", 
                      SuperscriptBox[
                        FormBox["k1",
                          "TraditionalForm"], "2"], " ", 
                      SuperscriptBox[
                        FormBox["p",
                          "TraditionalForm"], "2"]}]}], ")"}]}], 
              RowBox[{\((1 - D)\), " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "6"]}]]}], "+", 
          FractionBox[
            RowBox[{
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              RowBox[{
                FormBox["k1",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["p",
                  "TraditionalForm"]}], " ", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"(", 
                      FormBox[
                        RowBox[{
                          FormBox["k1",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["p",
                            "TraditionalForm"]}],
                        "TraditionalForm"], ")"}], "2"], "-", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["k1",
                        "TraditionalForm"], "2"], " ", 
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"]}]}], ")"}]}], 
            RowBox[{\((1 - D)\), " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "4"]}]], "+", 
          FractionBox[
            RowBox[{
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Rho]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Nu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["k1",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["p",
                  "TraditionalForm"]}], " ", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"(", 
                      FormBox[
                        RowBox[{
                          FormBox["k1",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["p",
                            "TraditionalForm"]}],
                        "TraditionalForm"], ")"}], "2"], "-", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["k1",
                        "TraditionalForm"], "2"], " ", 
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"]}]}], ")"}]}], 
            RowBox[{\((1 - D)\), " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "4"]}]], "+", 
          FractionBox[
            RowBox[{
              SuperscriptBox["g", 
                RowBox[{
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"], "\[NoBreak]", 
                  FormBox[
                    FormBox["\[Nu]",
                      "TraditionalForm"],
                    "TraditionalForm"]}]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Rho]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["k1",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["p",
                  "TraditionalForm"]}], " ", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"(", 
                      FormBox[
                        RowBox[{
                          FormBox["k1",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["p",
                            "TraditionalForm"]}],
                        "TraditionalForm"], ")"}], "2"], "-", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["k1",
                        "TraditionalForm"], "2"], " ", 
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"]}]}], ")"}]}], 
            RowBox[{\((1 - D)\), " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "4"]}]]}], TraditionalForm]], 
    "Output"],
  "\n",
  Cell[BoxData[
      \(Collect2[
        Calc[\ FVD[OPEDelta, \[Mu]] FVD[OPEDelta, \[Nu]] 
            FVD[k2, \[Rho]] %], {k1, k2}]\)], "Input"],
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[
            RowBox[{"2", " ", 
              RowBox[{
                FormBox["k2",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"]}], " ", 
              RowBox[{
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["p",
                  "TraditionalForm"]}], " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  FormBox[
                    RowBox[{
                      FormBox["k1",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["p",
                        "TraditionalForm"]}],
                    "TraditionalForm"], ")"}], "3"]}], 
            RowBox[{\((1 - D)\), " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "4"]}]], "-", 
          FractionBox[
            RowBox[{\((D + 2)\), " ", 
              RowBox[{
                FormBox["k2",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["p",
                  "TraditionalForm"]}], " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  FormBox[
                    RowBox[{
                      FormBox["\[CapitalDelta]",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["p",
                        "TraditionalForm"]}],
                    "TraditionalForm"], ")"}], "2"], " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  FormBox[
                    RowBox[{
                      FormBox["k1",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["p",
                        "TraditionalForm"]}],
                    "TraditionalForm"], ")"}], "3"]}], 
            RowBox[{\((1 - D)\), " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "6"]}]], "-", 
          FractionBox[
            RowBox[{"2", " ", 
              SuperscriptBox[
                FormBox["k1",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{
                FormBox["k2",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"]}], " ", 
              RowBox[{
                FormBox["\[CapitalDelta]",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["p",
                  "TraditionalForm"]}], " ", 
              RowBox[{
                FormBox["k1",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["p",
                  "TraditionalForm"]}]}], 
            RowBox[{\((1 - D)\), " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"]}]], "+", 
          FractionBox[
            RowBox[{"3", " ", 
              SuperscriptBox[
                FormBox["k1",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{
                FormBox["k2",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["p",
                  "TraditionalForm"]}], " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  FormBox[
                    RowBox[{
                      FormBox["\[CapitalDelta]",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["p",
                        "TraditionalForm"]}],
                    "TraditionalForm"], ")"}], "2"], " ", 
              RowBox[{
                FormBox["k1",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["p",
                  "TraditionalForm"]}]}], 
            RowBox[{\((1 - D)\), " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "4"]}]]}], TraditionalForm]], "Output"]
}], "Text"],

Cell[BoxData[
    \(\(tlrule[24] = 
        TLR[d_, pp_, 
            dp_, {2, b_?PNQ}, {0, w_?PNQ, 0, y_?PNQ, 1}, {nm1_, nm2_, nm3_, 
              nm4_, {0, 0}}] \[RuleDelayed] \((TLRComment["\<tlrule24\>"]; 
            2  dp \(\( 1\/\(\((1 - d)\) pp\^2\)\) \((TLR[d, pp, 
                      dp, {0, b + 1}, {0, w, 3, y, 0}, {nm1, nm2, nm3, 
                        nm4, {0, 0}}])\)\) - \(\(\((d + 
                          2)\)\ \ dp\^2\)\/\(\((1 - d)\) pp\^3\)\) \((TLR[d, 
                    pp, dp, {0, b}, {0, w, 3, y + 1, 0}, {nm1, nm2, nm3, 
                      nm4, {0, 0}}])\) - \(\(2  dp\)\/\(\((1 - d)\) pp\)\) 
                TLR[d, pp, 
                  dp, {0, b + 1}, {1, w, 1, y, 0}, {nm1, nm2, nm3, 
                    nm4, {0, 0}}] + \(\(3  dp\^2\)\/\(\((1 - d)\) pp\^2\)\) 
                TLR[d, pp, 
                  dp, {0, b}, {1, w, 1, y + 1, 0}, {nm1, nm2, nm3, 
                    nm4, {0, 0}}])\);\)\)], "Input"],

Cell["Symmetry 1 <--> 2; added February 21 1999 by R.M.", "Text"],

Cell[BoxData[
    \(\(\(tlrule[25] = 
        TLR[dim_, 
            pp_, \ {a_, \ b_, \ \((c_)\)?PNQ, \ \((d_)\)?PQ, \ 
              0}, \ \(\({nm1_, \ nm2_, \ nm3_, \ {0, \ _}, \ 
              nm5_}\)\(\n\)\)\ \ \ ]\  :> \((TLRComment["\<tlrule25\>"]; \ 
              TLR[dim, \ 
                pp, \ {b, a, \ d, \ c, \ 0}, \ {nm2, \ nm1, \ {0, 0}, \ 
                  nm3, \ nm5}])\)\  /; \ d\  > \ c;\)\(\n\)\)\)], "Input"],

Cell[BoxData[
    \(\(TLRules = Array[tlrule, 25];\)\)], "Input"],

Cell[BoxData[
    \(\(TLRules2 = Drop[TLRules, {9, 9}];\)\)], "Input"],

Cell[BoxData[
    \(\(TLR[__, {{_, _}, {0, _}, {_, _}, {0, _}, {_, 0}}] := 0;\)\)], "Input"],

Cell[BoxData[
    \(\(TLR[__, {{0, _}, {_, _}, {0, _}, {_, _}, {_, 0}}] := 0;\)\)], "Input"],

Cell[BoxData[
    \(\(TLR[__, {{0, _}, {_, _}, {_, 0}, {_, _}, {0, _}}] := 0;\)\)], "Input"],

Cell[BoxData[
    \(\(TLR[__, {{_, 0}, {_, _}, {0, _}, {_, _}, {0, _}}] := 0;\)\)], "Input"],

Cell[BoxData[
    \(\(TLR[__, {{_, _}, {_, 0}, {_, _}, {0, _}, {0, _}}] := 0;\)\)], "Input"],

Cell[BoxData[
    \(\(TLR[__, {{_, _}, {0, _}, {_, _}, {_, 0}, {0, _}}] := 0;\)\)], "Input"],

Cell[BoxData[
    \(\(SetAttributes[seeetDelayed, HoldAll];\)\)], "Input"],

Cell[BoxData[
    \(seeetDelayed[TLR[a__], b_] := SetDelayed @@ {TLR[a], b}\)], "Input"],

Cell[BoxData[
    \(\(lis1 = 
        Permutations[{{0, _}, {0, _}, {0, _}, {_, _}, {_, 0}}];\)\)], "Input"],

Cell[BoxData[
    \(\(lis2 = 
        Table[TLR[__, 
                lis1\[LeftDoubleBracket]
                  i\[RightDoubleBracket]] \[RuleDelayed] 0, {i, 
              Length[lis1]}] /. 
          RuleDelayed \[Rule] seeetDelayed;\)\)], "Input"],

Cell[BoxData[
    \(\(Clear[lis1, lis2];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["T*IS", "Subsection",
  CellTags->"T1.7.2.1"],

Cell["\<\
These functions below are never used.
They can serve as tests.\
\>", "Text"],

Cell[BoxData[
    \(TJIS[d_, 
        Power[M_, \ 
          2], \ {{\[Alpha]_, 0}, {\[Beta]_, 0}, {\[Gamma]_, 
            0}}] := \(\(SMu\^2\) \((\(\((\(-1\))\)\^\(\[Alpha] + \[Beta] + \
\[Gamma] + 1\)\/\((\(-\ M\^2\))\)\^\(\[Alpha] + \[Beta] + \[Gamma] - 4\)\) 
            Exp[\(-I\)\ Pi\ \((d - 
                    4)\)]\ \(Gamma[\[Alpha] + \[Beta] + \[Gamma] - 
                    d]\/Gamma[\(3\/2\) 
                      d - \[Alpha] - \[Beta] - \[Gamma]]\) \(Gamma[
                  d\/2 - \[Alpha]]\/Gamma[\[Alpha]]\) \(Gamma[
                  d\/2 - \[Beta]]\/Gamma[\[Beta]]\) 
            Gamma[d\/2 - \[Gamma]]\/Gamma[\[Gamma]])\)\(\n\)\)\)], "Input"],

Cell[BoxData[
    \(TJIS[d_, 
        Power[M_, \ 
          2], \ {{\[Beta]_, 0}, {\[Gamma]_, 0}, {\[Alpha]_, M_}}] := \n\t
      TJIS[d, M^2, {{\[Alpha], M}, {\[Beta], 0}, {\[Gamma], 0}}]\)], "Input"],

Cell[BoxData[
    \(TJIS[d_, 
        Power[M_, \ 
          2], \ {{\[Beta]_, 0}, {\[Alpha]_, M_}, {\[Gamma]_, 0}}] := \n\t
      TJIS[d, M^2, {{\[Alpha], M}, {\[Beta], 0}, {\[Gamma], 0}}]\)], "Input"],

Cell[BoxData[
    \(TJIS[d_, 
        Power[M_, \ 
          2], \ {{\[Alpha]_, M_}, {\[Beta]_, 0}, {\[Gamma]_, 
            0}}] := \n\(SMu\^2\/\((M\^2)\)\^\(\[Alpha] + \[Beta] + \[Gamma] - \
4\)\) \(\((\(-1\))\)\^\(\[Alpha] + \[Beta] + \[Gamma] + 
              1\)\) \(Gamma[\[Alpha] + \[Beta] + \[Gamma] - 
                d]\/\(Gamma[\[Alpha]] Gamma[\[Beta]] 
              Gamma[\[Gamma]]\)\) \(\(Gamma[d\/2 - \[Gamma]] 
              Gamma[d\/2 - \[Beta]]\)\/Gamma[
              d - \[Beta] - \[Gamma]]\) \(Gamma[\[Beta] + \[Gamma] - d\/2] \
Gamma[2\ d - \[Alpha] - 2  \[Beta] - 2  \[Gamma]]\)\/Gamma[\(3  d\)\/2 - \
\[Alpha] - \[Beta] - \[Gamma]]\)], "Input"],

Cell[BoxData[
    \(TJIS[d_, 0, \ {{\[Beta]_, 0}, {\[Alpha]_, M_}, {\[Gamma]_, 0}}] := 
      TJIS[d, 0, {{\[Alpha], M}, {\[Beta], 0}, {\[Gamma], 0}}]\)], "Input"],

Cell[BoxData[
    \(TJIS[d_, 0, \ {{\[Beta]_, 0}, {\[Gamma]_, 0}, {\[Alpha]_, M_}}] := 
      TJIS[d, 0, {{\[Alpha], M}, {\[Beta], 0}, {\[Gamma], 0}}]\)], "Input"],

Cell[BoxData[
    \(TJIS[d_, 
        0, \ {{\[Alpha]_, M_}, {\[Beta]_, 0}, {\[Gamma]_, 
            0}}] := \n\(SMu\^2\/\((M\^2)\)\^\(\[Alpha] + \[Beta] + \[Gamma] - \
4\)\) \(\((\(-1\))\)\^\(\[Alpha] + \[Beta] + \[Gamma] + 
              1\)\) \(Gamma[\[Alpha] + \[Beta] + \[Gamma] - 
                d]\/\(Gamma[\[Alpha]] Gamma[\[Beta]] 
              Gamma[\[Gamma]]\)\) \((Gamma[\[Beta] + \[Gamma] - d/2] 
              Gamma[d/2 - \[Beta]] Gamma[d/2 - \[Gamma]])\)/
          Gamma[d/2]\)], "Input"],

Cell[BoxData[
    \(TJIS[d_, 0, \ {{\[Beta]_, M_}, {\[Alpha]_, 0}, {\[Gamma]_, M_}}] := 
      TJIS[d, 0, {{\[Alpha], 0}, {\[Beta], M}, {\[Gamma], M}}]\)], "Input"],

Cell[BoxData[
    \(TJIS[d_, 0, \ {{\[Beta]_, M_}, {\[Gamma]_, M_}, {\[Alpha]_, 0}}] := 
      TJIS[d, 0, {{\[Alpha], 0}, {\[Beta], M}, {\[Gamma], M}}]\)], "Input"],

Cell[BoxData[
    \(TJIS[d_, 
        0, \ {{\[Alpha]_, 0}, {\[Beta]_, M_}, {\[Gamma]_, 
            M_}}] := \n\(SMu\^2\/\((M\^2)\)\^\(\[Alpha] + \[Beta] + \[Gamma] \
- 4\)\) \(\((\(-1\))\)\^\(\[Alpha] + \[Beta] + \[Gamma] + 
              1\)\) \(Gamma[\[Alpha] + \[Beta] + \[Gamma] - 
                d]\/\(Gamma[\[Beta]] Gamma[\[Gamma]]\)\) \(Gamma[
              d\/2 - \[Alpha]]\/Gamma[
              d\/2]\) \(Gamma[\[Alpha] + \[Gamma] - d\/2] Gamma[\[Alpha] + \
\[Beta] - d\/2]\)\/Gamma[2  \[Alpha] + \[Beta] + \[Gamma] - d]\)], "Input"],

Cell[BoxData[
    \(TJIS[d_, 
        0, {{\[Alpha]_, 0}, {\[Beta]_, M_}, {\[Gamma]_, 
            M_}}] := \((SMu\^2\ \((\(-1\))\)\^\(\[Alpha] + \[Beta] + \[Gamma] \
+ 1\)\ Gamma[\[Alpha] + \[Beta] + \[Gamma] - d]\ Gamma[
              d\/2 - \[Alpha]]\ \((Gamma[\[Alpha] + \[Gamma] - 
                    d\/2]\ Gamma[\[Alpha] + \[Beta] - 
                    d\/2])\))\)/\((\((M\^2)\)\^\(\[Alpha] + \[Beta] + \
\[Gamma] - 4\)\ \((Gamma[\[Beta]]\ Gamma[\[Gamma]])\)\ Gamma[d\/2]\ Gamma[
              2\ \[Alpha] + \[Beta] + \[Gamma] - d])\)\)], "Input"],

Cell["(2.65)", "Text"],

Cell[BoxData[
    \(TAIS[d_, 
        0, {{1, M_}}] := \ \(-I\)\ \ M\^2\ \ SMu\ Gamma[\((4 - d)\)/2 - 
            1]\)], "Input"],

Cell[BoxData[
    \(\(TBIS[d_, 0, {{\[Alpha]_, 0}, {\[Beta]_, 0}}] := 0;\)\)], "Input"],

Cell[BoxData[
    \(TBIS[d_, 
        Power[M_, \ 
          2], {{\[Alpha]_, 0}, {\[Beta]_, 
            0}}] := \(\(\(I\)\(\ \)\) \(SMu\)\(\ \)\(*\)\((\(\((\(-1\))\)\^\(\
\[Alpha] + \[Beta]\)\/\((\(-\ M\^2\))\)\^\(\[Alpha] + \[Beta] - 2\)\) 
            Exp[\(-I\)\ Pi\ \((d - 4)\)/
                  2]\ \(Gamma[\[Alpha] + \[Beta] - d/2]\/\(Gamma[\[Alpha]] 
                  Gamma[\[Beta]]\)\) \(Gamma[d/2 - \[Alpha]] Gamma[d/2 - \
\[Beta]]\)\/Gamma[d - \[Alpha] - \[Beta]])\)\(\n\)\)\)], "Input"],

Cell[BoxData[
    \(TJIS[d_Symbol, M_\^2, {{1, M_}, {1, M_}, {1, M_}}] := 
      M\^2\ SMu\^2\ \((\(-\(6\/\((\(-4\) + d)\)\^2\)\) + 
            17\/\(2\ \((\(-4\) + d)\)\) + 
            1\/8\ \((\(-59\) - 
                  2\ \[Pi]\^2)\) + \((\(-4\) + d)\)\^3\ TJI111e + \(1\/1920\) \
\((\((\(-4\) + d)\)\^2\ \((16755 - 4750\ \[Pi]\^2 - 14\ \[Pi]\^4 + 
                      3840\ \[Pi]\^2\ Log[2] - 12080\ Zeta[3])\))\) + 
            1\/96\ \((\(-4\) + d)\)\ \((195 + 98\ \[Pi]\^2 - 
                  48\ Zeta[3])\))\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TComment", "Subsection",
  CellTags->"T1.7.3.1"],

Cell[BoxData[
    \(\($CommentNotebook = True;\)\)], "Input"],

Cell[BoxData[
    \(TComment[s_String, b_] := 
      If[If[\(\(\[InvisibleSpace]\)\(! \((ValueQ[$TarcerRecursed])\)\)\), \
$TarcerRecursed = {}]; \(\(\[InvisibleSpace]\)\(! \((MemberQ[$TarcerRecursed, \
{s, b}])\)\)\), AppendTo[$TarcerRecursed, {s, b}]; 
          If[$Notebooks && $CommentNotebook === True, 
            If[$commentnb === False, $commentnb = True; $cnb = 
                NotebookCreate[
                  StyleDefinitions \[Rule] "\<NaturalColor.nb\>", 
                  Magnification \[Rule] 1.5]; 
              SetOptions[$cnb, 
                WindowMargins \[Rule] {{0, Automatic}, {Automatic, 0}}]; 
              SetOptions[$cnb, WindowSize \[Rule] {500, 300}]; 
              NotebookWrite[$cnb, 
                Cell[BoxData[
                    ToBoxes[b /. TFIC \[Rule] TFI, 
                      StandardForm]], "\<Input\>", 
                  CellDingbat \[Rule] s <> "\< \>"]], 
              NotebookWrite[$cnb, 
                Cell[BoxData[
                    ToBoxes[b /. TFIC \[Rule] TFI, 
                      StandardForm]], "\<Input\>", 
                  CellDingbat \[Rule] s <> "\< \>"]]], 
            Print[s, 
              b /. {TFIC \[RuleDelayed] TFI, TVIC \[RuleDelayed] TVI, 
                  TJIC \[RuleDelayed] TJI, TBIC \[RuleDelayed] TBI, 
                  TAIC \[RuleDelayed] TAI}]]] /; $Comment === True\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["$TTable", "Subsection",
  CellTags->"$TTable"],

Cell[BoxData[
    \(\($TTable = {};\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TarcerRecurse", "Subsection",
  CellTags->"T1.7.4.1"],

Cell[BoxData[
    \(\(FEPrint[a__String] := 
        Print[a]\  /; \ $Notebooks === False;\)\)], "Input"],

Cell[BoxData[
    \(\(FEPrint[a__String] := 
        If[Head[$cnb] === NotebookObject, \n\t\tNotebookWrite[$cnb, 
              Cell[StringJoin @@ {a}, "\<SmallText\>"]]; \n\t
            SelectionMove[$cnb, After, Cell]] /; $Notebooks === 
            True;\)\)], "Input"],

Cell[BoxData[
    \(\(Options[TarcerRecurse] = {Factor \[Rule] Factor, 
          TimeConstraint -> Infinity, Table :> $TTable, Together -> Together, 
          Replace -> {}};\)\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(TarcerRecurse[z_, opts___]\), ":=", 
        RowBox[{"Catch", "[", 
          RowBox[{
            StyleBox["Block",
              FontSize->16,
              FontWeight->"Bold",
              FontColor->RGBColor[1, 0.2, 0.2]], "[", 
            
            RowBox[{\({basisdone, factorfun, fertig, dummm1, dummm2, getvars, 
                te, time, cutoff, tog, ttable, facfun, nexp, oldexpr, rec, 
                special, sti, tl, tcheck, tjrd, tvrd, together, 
                vars, $cc = 0, $cv}\), ",", "\n", "\t\t\t", 
              
              RowBox[{\(time\  = \ AbsoluteTime[]\), ";", "\n", 
                "\t\t\t", \(ttable = \(Table /. {opts}\) /. 
                    Options[TarcerRecurse]\), ";", "\n", 
                "\t\t\t", \(If[\(! MatchQ[ttable, {__RuleDelayed}]\), 
                  ttable = {}]\), ";", "\n", 
                "\t\t\t", \(special = \(Replace /. {opts}\) /. 
                    Options[TarcerRecurse]\), ";", "\n", 
                "\t\t\t", \(cutoff = \(TimeConstraint /. {opts}\) /. 
                    Options[TarcerRecurse]\), ";", "\n", 
                "\t\t\t", \(together = \(Together /. {opts}\) /. 
                    Options[TarcerRecurse]\), 
                ";", \(factorfun = \(Factor /. {opts}\) /. 
                    Options[TarcerRecurse]\), ";", \($commentnb = False\), 
                ";", \(tog = \((\((If[#1 > 1001, 
                              If[$Comment, 
                                FEPrint["\<coefficient # \>" <> 
                                    If[ValueQ[$cv], ToString[$cc], "\<\>"] <> 
                                    If[ValueQ[$cv], "\< (\>" <> 
                                        ToString[$cv] <> "\<)\>", "\<\>"] <> \
"\< simplified, \>", ToString[#1]]]]; #2)\) &)\)[LeafCount[#1], \($cc++\); 
                      together[#1]] &\), 
                ";", \(If[\(\(\[InvisibleSpace]\)\(! \
\((ValueQ[$TarcerRecursed])\)\)\), $TarcerRecursed = {}]\), 
                ";", \($TarcerRecursed = {}\), ";", 
                RowBox[{"If", "[", "\[InvisibleSpace]", 
                  
                  RowBox[{\(! \((MemberQ[$ContextPath, \
"\<HighEnergyPhysics`FeynCalc`ToTFi`\>"])\)\), ",", \(t0 = z\), ",", 
                    RowBox[{"t0", "=", 
                      
                      RowBox[{\(HighEnergyPhysics`FeynCalc`ToTFi`ToTFi[z]\), "/.",
                         
                        RowBox[{"{", 
                          RowBox[{
                            RowBox[{
                            "HighEnergyPhysics`FeynCalc`TFi`TFi", 
                              "\[RuleDelayed]", 
                              StyleBox["TFI",
                                FontColor->RGBColor[1, 0.6, 0]]}], 
                            ",", \(HighEnergyPhysics`FeynCalc`ToTFi`ToTFi \
\[RuleDelayed] Identity\)}], "}"}]}]}]}], "]"}], ";", "\n", 
                "\t\t\t", \(If[ttable =!= {}, t0 = t0 /. ttable]\), ";", "\n",
                 "\t\t\t", 
                RowBox[{"getvars", "=", 
                  RowBox[{
                    RowBox[{"Select", "[", 
                      RowBox[{\(Variables[#1]\), ",", 
                        RowBox[{
                          RowBox[{"MatchQ", "[", 
                            RowBox[{"#1", ",", 
                              RowBox[{
                                RowBox[{
                                  StyleBox["TFI",
                                    FontColor->RGBColor[1, 0.6, 0]], "[", 
                                  "__", "]"}], "|", 
                                RowBox[{
                                  StyleBox["TVI",
                                    FontColor->RGBColor[0.2, 0.4, 0.8]], "[", 
                                  "__", "]"}], "|", \(TJI[__]\), 
                                "|", \(TBI[__]\), "|", \(TAI[__]\)}]}], "]"}],
                           "&"}]}], "]"}], "&"}]}], ";", "\n", 
                "\t\t\t", \(If[\(! FreeQ[t0, TFI]\), 
                  t0 = Collect[t0 = TFIRecurse[t0] /. ttable, getvars[t0], 
                      tog]]\), ";", "\n", 
                "\t\t\t", \(If[\(! FreeQ[t0, 
                      TVI[_Plus, __]]\), \n\t\t\ttvrd = 
                    Select[DownValues[
                          TVR], \(! FreeQ[#, TVI[_ - 2, __]]\) &] /. 
                      TVR -> TVI; \n\t\t\t\tt0 = 
                    Collect[
                      t0 = \(\(\(t0 /. tvrd\) /. tvrd\) /. tvrd\) /. tvrd, 
                      getvars[t0], 
                      tog]; \n\t\t\t\tIf[\(! FreeQ[t0, TVI[_Plus, __]]\), \t
                    t0 = Collect[t0 = t0 //. tvrd, getvars[t0], tog]]]\), ";",
                 "\n", "\t\t\t\t", "\n", 
                "\t\t\t", \(tjrd = 
                  Select[DownValues[TJR], \(! FreeQ[#, TJI[_ - 2, __]]\) &] /. 
                    TJR -> TJI\), ";", "\n", "\t\t\t", "\n", 
                "\t\t\t", \(If[\(! FreeQ[t0, 
                      TJI[_Plus, __]]\), \n\t\t\ttjrd = 
                    Select[DownValues[
                          TJR], \(! FreeQ[#, TJI[_ - 2, __]]\) &] /. 
                      TJR -> TJI; \n\t\t\t\tt0 = 
                    Collect[
                      t0 = \(\(\(t0 /. tjrd\) /. tjrd\) /. tjrd\) /. tjrd, 
                      getvars[t0], 
                      tog]; \n\t\t\t\tIf[\(! FreeQ[t0, TJI[_Plus, __]]\), \t
                    t0 = Collect[t0 = t0 //. tjrd, getvars[t0], tog]]]\), ";",
                 "\n", "\t\t\t", "\n", 
                "\t\t\t", \(rec[expr_, {ti_, tr_}] := \((sti = ToString[ti]; 
                    tcheck = \(\(\[InvisibleSpace]\)\(! \((FreeQ[expr, 
                            ti])\)\)\); oldexpr =  . ; nexp = expr; 
                    While[tcheck === True && oldexpr =!= nexp, 
                      oldexpr = nexp; 
                      If[$Comment, \((If[#1 === 1, 
                                FEPrint[
                                  sti <> "\< level, there is 1 \>" <> sti], 
                                FEPrint[sti <> "\< level, there are \>", 
                                  ToString[#1], "\< \>" <> 
                                    sti <> "\<'s \>"]] &)\)[
                          Count[nexp, 
                            ti[__], \(-1\)]]]; \n\t\t\t\t\n\t\t\t\t\t\tnexp = \
\(nexp /. ti \[Rule] tr\) /. 
                          tr \[Rule] ti; \n\t\t\t\t\t\t\tIf[\(! FreeQ[nexp, 
                            TJI[_Plus, __]]\), 
                        nexp = 
                          nexp //. tjrd]; \n\t\t\t\t\t\t\n\t\t\t\t\t\ttvars = 
                        getvars[nexp]; $cc = 0; $cv = Length[tvars]; 
                      nexp = Collect[nexp, tvars, tog]; \n\t\t\t\t\t\tIf[
                        cutuff =!= Infinity, 
                        If[AbsoluteTime[] - time > cutoff, 
                          Throw[$Failed]]]; \n\t\t\t\t\t\t\n\t\t\t\t\t\t\
tcheck = \[InvisibleSpace]\(! \((FreeQ[nexp, ti])\)\);]; nexp)\)\), 
                ";", \(basisdone = 0\), ";", 
                RowBox[{"tl", "=", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{"{", 
                        RowBox[{
                          StyleBox["TFI",
                            FontColor->RGBColor[1, 0.6, 0]], ",", 
                          StyleBox["TFR",
                            FontColor->RGBColor[0, 0.6, 0]]}], "}"}], ",", 
                      RowBox[{"{", 
                        RowBox[{
                          StyleBox["TVI",
                            FontColor->RGBColor[0.2, 0.4, 0.8]], ",", 
                          StyleBox["TVR",
                            FontColor->RGBColor[0.2, 0.8, 1]]}], "}"}], 
                      ",", \({TJI, TJR}\), ",", \({TBI, TBR}\), 
                      ",", \({TAI, TAR}\)}], "}"}]}], 
                ";", \(Do[
                  t0 = rec[t0, tl\[LeftDoubleBracket]i\[RightDoubleBracket]]; 
                  If[Head[t0] === Plus, 
                    fertig = 
                      Select[t0, \(\(\[InvisibleSpace]\)\(! \((FreeQ[#1, 
                              tl\[LeftDoubleBracket]i, 
                                1\[RightDoubleBracket]])\)\)\)]; 
                    basisdone = basisdone + fertig; t0 = t0 - fertig], {i, 
                    Length[tl]}]\), ";", \(t0 = t0 + basisdone\), 
                ";", \($cv =  . \), 
                ";", \(t0 = 
                  Collect[
                    t0, {TAI[__], TAI[a1__]\ TAI[a2__], TAI[__], TBI[__], 
                      TJI[__], TVI[__], TFI[__]}, factorfun]\), 
                ";", \(If[$Comment, 
                  FEPrint["\<the result has \>", 
                    ToString[
                      Length[t0 + dummm1 + dummm2] - 2], "\< terms\>"]]\), 
                ";", \(If[$Notebooks, 
                  SetSelectedNotebook[EvaluationNotebook[]]]\), ";", "t0"}]}],
             "]"}], "]"}]}], ";"}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["TarcerExpand", "Section",
  CellDingbat->"\[FilledSmallCircle]",
  CellTags->"T1.8.1"],

Cell[BoxData[
    \(\(Options[TarcerExpand] = {\n\t\tTarcerReduce :> $BasisIntegrals, \n\t
          TarcerRecurse -> False, Zeta -> True};\)\)], "Input"],

Cell[BoxData[
    \(\(TarcerExpand[expr_, d_Symbol -> fe_ /; Length[Variables[fe]] === 1, 
          ru___Rule] := TarcerExpand[expr, d\  -> fe, 0, ru];\)\)], "Input"],

Cell[BoxData[
    RowBox[{\(TarcerExpand[expr_, 
        d_Symbol \[Rule] fe_ /; Length[Variables[fe]] === 1, 
        order_Integer?NonNegative, opts___Rule]\), ":=", 
      RowBox[{
        StyleBox["Block",
          FontSize->16,
          FontWeight->"Bold",
          FontColor->RGBColor[1, 0.2, 0.2]], "[", 
        RowBox[{\({}\), ",", 
          RowBox[{"Catch", "[", 
            
            RowBox[{\(e = First[Variables[fe]]\), 
              ";", \({ints, recurse, 
                  zeta2replace} = {TarcerReduce, TarcerRecurse, Zeta} /. 
                  Flatten[{opts, Options[TarcerExpand]}]\), 
              ";", \(If[
                zeta2replace =!= True && 
                  MemberQ[$ContextPath, \
"\<HighEnergyPhysics`FeynCalc`Zeta2`\>"], z2rule = {}, 
                z2rule = \[Pi]\^2 \[RuleDelayed] 
                    6\ ToExpression["\<HighEnergyPhysics`FeynCalc`Zeta2`Zeta2\
\>"]]\), ";", \(ints = Flatten[ints]\), 
              ";", \(If[recurse =!= True, ta0 = expr, 
                ta0 = TarcerRecurse[expr]]\), ";", 
              RowBox[{"t1", "=", 
                RowBox[{\(ta0 /. ints\), "/.", 
                  RowBox[{
                    InterpretationBox["any_",
                      PreFactor[ 
                        Pattern[ FE`Conversion`Private`any, 
                          Blank[ ]]],
                      Editable->False], "\[RuleDelayed]", 
                    InterpretationBox["any",
                      PreFactor[ FE`Conversion`Private`any],
                      Editable->False]}]}]}], 
              ";", \(vars = Select[Variables[t1], Length[#1] > 0 &]\), ";", 
              RowBox[{"If", "[", 
                RowBox[{
                  RowBox[{"\[InvisibleSpace]", "!", 
                    RowBox[{"(", 
                      RowBox[{"FreeQ", "[", 
                        RowBox[{"vars", ",", 
                          RowBox[{
                            StyleBox["TFI",
                              FontColor->RGBColor[1, 0.6, 0]], "|", 
                            StyleBox["TVI",
                              FontColor->RGBColor[0.2, 0.4, 0.8]], "|", "TJI",
                             "|", "TKI", "|", "TBI", "|", "TAI"}]}], "]"}], 
                      ")"}]}], ",", 
                  
                  RowBox[{\(Print["\<Returning the list of remaining \
integrals.\>"]\), ";", 
                    RowBox[{"Throw", "[", 
                      RowBox[{"Select", "[", 
                        RowBox[{"vars", ",", 
                          RowBox[{
                            RowBox[{"\[InvisibleSpace]", "!", 
                              RowBox[{"(", 
                                RowBox[{"FreeQ", "[", 
                                  RowBox[{"#1", ",", 
                                    RowBox[{
                                      StyleBox["TFI",
                                        FontColor->RGBColor[1, 0.6, 0]], "|", 
                                      
                                      StyleBox["TVI",
                                        FontColor->RGBColor[0.2, 0.4, 0.8]], 
                                      "|", "TJI", "|", "TKI", "|", "TBI", "|",
                                       "TAI"}]}], "]"}], ")"}]}], "&"}]}], 
                        "]"}], "]"}]}]}], "]"}], 
              ";", \(t1 = t1 /. d \[Rule] fe\), 
              ";", \(polygafu[2, 1] = \(-2\)\ Zeta[3]\), 
              ";", \(polygafu[2, 2] = 2 - 2\ Zeta[3]\), 
              ";", \(polygafu[x_, y_] := \(polygafu[x, y] = 
                  FunctionExpand[PolyGamma[x, y]]\)\), 
              ";", \(t2 = 
                Normal[t1 + O[e]\^\(order + 1\)] /. 
                  PolyGamma \[Rule] polygafu\), ";", 
              RowBox[{"t3", "=", 
                RowBox[{
                  RowBox[{\(Collect[t2, e, Expand[#1] /. z2rule &]\), "//.", 
                    RowBox[{"{", 
                      RowBox[{
                        RowBox[{
                          InterpretationBox["a_",
                            PreFactor[ 
                              Pattern[ FE`Conversion`Private`a, 
                                Blank[ ]]],
                            Editable->False], " ", 
                          InterpretationBox["b_",
                            PreFactor[ 
                              Pattern[ FE`Conversion`Private`b, 
                                Blank[ ]]],
                            Editable->False]}], "\[RuleDelayed]", 
                        InterpretationBox[\(a\ b\),
                          PreFactor[ 
                            Times[ 
                            FE`Conversion`Private`a, 
                              FE`Conversion`Private`b]],
                          Editable->False]}], "}"}]}], "/.", 
                  RowBox[{
                    InterpretationBox["c_",
                      PreFactor[ 
                        Pattern[ FE`Conversion`Private`c, 
                          Blank[ ]]],
                      Editable->False], "\[RuleDelayed]", 
                    InterpretationBox["c",
                      PreFactor[ FE`Conversion`Private`c],
                      Editable->False]}]}]}], ";", 
              RowBox[{"prec", "=", 
                RowBox[{"Union", "[", 
                  RowBox[{"Cases", "[", 
                    RowBox[{"t3", ",", 
                      InterpretationBox["_",
                        PreFactor[ 
                          Blank[ ]],
                        Editable->False], ",", \(-1\)}], "]"}], "]"}]}], ";", 
              
              RowBox[{"If", "[", 
                RowBox[{\(Length[prec] === 1\), ",", 
                  RowBox[{"If", "[", 
                    RowBox[{\(Head[t3] === Plus\), ",", 
                      
                      RowBox[{\(mass = 
                          Select[
                            Variables[
                              prec\[LeftDoubleBracket]1, 
                                1\[RightDoubleBracket]], 
                            FreeQ[#1, SEpsilon] &]\), 
                        ";", \(If[Length[mass] === 1, 
                          If[FreeQ[First[t3], First[mass]], massfactor = 1, 
                            massfactor = 
                              First[mass]\^Exponent[First[t3], First[mass]]], 
                          massfactor = 1]\), ";", \(delpfactor = 1\), ";", 
                        RowBox[{"delp", "=", 
                          RowBox[{"Variables", "[", 
                            RowBox[{\(First[t3]\/massfactor\), "/.", 
                              RowBox[{"{", 
                                RowBox[{
                                  RowBox[{
                                    InterpretationBox["__",
                                      PreFactor[ 
                                        BlankSequence[ ]],
                                      Editable->False], "\[RuleDelayed]", 
                                    "1"}], 
                                  ",", \(ToExpression["\<HighEnergyPhysics`\
Tarcer`Zeta2`Zeta2\>"] \[Rule] Zeta[2]\)}], "}"}]}], "]"}]}], 
                        ";", \(If[Length[delp] === 1, delp = First[delp]; 
                          If[Length[t3] === 
                              Length[
                                Select[
                                  t3, \(\(\[InvisibleSpace]\)\(! \((FreeQ[#1, 
                                        delp])\)\)\) &]], 
                            delpfactor = delp\^Exponent[First[t3], delp]]]\), 
                        ";", \(t3 = \((\(massfactor\ delpfactor\ First[prec] /. 
                                  Prefactor1 \[Rule] 
                                    Identity\) /. {\((m_\^2)\)\^n_\ \
m_\^j_?EvenQ \[RuleDelayed] \((m\^2)\)\^\(n + j\/2\)})\)\ \
Collect[\((#1\/\(First[prec]\ massfactor\ delpfactor\) &)\) /@ t3, e, 
                              Expand]\)}]}], "]"}]}], "]"}], 
              ";", \(t3 /. Prefactor1 \[Rule] Identity\)}], "]"}]}], 
        "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Construct T's", "Section",
  CellDingbat->"\[FilledSmallCircle]",
  CellTags->"T1.9.1"],

Cell[CellGroupData[{

Cell["remember", "Subsection",
  CellTags->"T1.9.1.1"],

Cell["The function remember is not used by default.", "Text"],

Cell[BoxData[
    \(\(tfch = {TFR :> Hold[TFR], TVR :> Hold[TVR], TJR :> Hold[TJR], 
          TBR :> Hold[TBR], TAR :> Hold[TAR], 
          TComment :> Hold[TComment]};\)\)], "Input"],

Cell[BoxData[
    \(\(rtfch = Map[Reverse, tfch];\)\)], "Input"],

Cell[BoxData[
    \(\(SetAttributes[condrest, HoldRest];\)\)], "Input"],

Cell[BoxData[
    \(\(Clear[remember];\)\)], "Input"],

Cell[BoxData[
    \(\(remember[zi_HoldForm] := 
        Block[{z = zi /. tfch}, 
          If[\(\(\[InvisibleSpace]\)\(! \((FreeQ[z, 
                  Condition])\)\)\), \(\(\(\(Hold[
                        HoldForm]\)[\(Hold[SetDelayed]\)[
                        z\[LeftDoubleBracket]1, 1\[RightDoubleBracket], 
                        ReplacePart[
                          z\[LeftDoubleBracket]1, 2\[RightDoubleBracket], 
                          Prepend[
                            Extract[z, {1, 2, 1}, 
                              Hold], \(\(\(z\[LeftDoubleBracket]1, 
                                      1\[RightDoubleBracket] /. 
                                    PatternTest \[Rule] pt\) /. 
                                  pt[a_, b_] \[RuleDelayed] a\) /. 
                                Pattern \[Rule] pat\) /. 
                              pat[a_, b_] \[RuleDelayed] a], 1]]] /. 
                    Hold[HoldForm] \[Rule] HoldForm\) /. rtfch\) /. 
                Hold[SetDelayed] \[Rule] SetDelayed\) /. 
              Hold \[Rule] 
                Set, \(\(\(\(Hold[HoldForm]\)[\(Hold[SetDelayed]\)[
                        z\[LeftDoubleBracket]1, 1\[RightDoubleBracket], 
                        Prepend[
                          Extract[z, {1, 2}, 
                            Hold], \(\(\(z\[LeftDoubleBracket]1, 
                                    1\[RightDoubleBracket] /. 
                                  PatternTest \[Rule] pt\) /. 
                                pt[a_, b_] \[RuleDelayed] a\) /. 
                              Pattern \[Rule] pat\) /. 
                            pat[a_, b_] \[RuleDelayed] a]]] /. 
                    Hold[HoldForm] \[Rule] HoldForm\) /. rtfch\) /. 
                Hold[SetDelayed] \[Rule] SetDelayed\) /. 
              Hold \[Rule] Set]];\)\)], "Input"],

Cell[BoxData[
    \($TarasovTdeltaplimit\)], "Input"],

Cell[BoxData[
    \(\(aa2\  = \ 
        Array[f\_# &, \ 
          10000 + \(($TarasovTdeltaplimit + 1)\)\ 1000];\)\)], "Input"],

Cell[BoxData[
    \(\(bb12 = Select[aa2, Head[#] =!= Subscript &];\)\)], "Input"],

Cell[BoxData[
    \(\(Clear[aa2];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Print["\<there are \>", 
      Length[bb12], "\< recursion equations for $RankLimit = \>", $RankLimit]\
\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("there are "\[InvisibleSpace]103\[InvisibleSpace]" \
recursion equations for $RankLimit = "\[InvisibleSpace]{0, 6}\),
        SequenceForm[ 
        "there are ", 103, " recursion equations for $RankLimit = ", {0, 6}],
        Editable->False], TraditionalForm]], "Print"]
}, Open  ]],

Cell[BoxData[
    \(\(If[Global`$Remember\  === \ True, Global`RCHECK = True; \ 
        nb\  = Map[remember, bb12], nb = bb12];\)\)], "Input"],

Cell[BoxData[
    \(\(Clear[bb12];\)\)], "Input"],

Cell[BoxData[
    \(\(ReleaseHold[nb];\)\)], "Input"],

Cell[BoxData[
    \(Unset[$Post]\)], "Input"],

Cell[BoxData[
    \(\($Comment = True;\)\)], "Input"],

Cell[BoxData[
    \(\(End[];\)\)], "Input"],

Cell[BoxData[
    \(\(EndPackage[];\)\)], "Input"],

Cell[BoxData[
    \(\(If[\(! ValueQ[HighEnergyPhysics`FeynCalc`$FeynCalcDirectory]\), 
        BeginPackage["\<HighEnergyPhysics`general`Zeta2`\>"]; \n
        Zeta2::usage = \n"\<Zeta2 denotes Zeta[2].\>"; \n
        Begin["\<`Private`\>"]; \nZeta2\  /: \ N[Zeta2]\  = \ N[Zeta[2]]; \n
        Zeta2 /: MakeBoxes[Zeta2, fmt_] := 
          InterpretationBox @@ {\ \ RowBox[{"\<\[Zeta]\>", "\<(\>", 
                    2, "\<)\>"}], Zeta2, Editable -> False}\nEnd[]; \n\ 
        EndPackage[];];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["$BasisIntegrals", "Section",
  CellDingbat->"\[EmptySmallCircle]",
  CellTags->"T1.10.1"],

Cell["\<\
This a (incomplete) set of basis integrals. You can add your \
favorite integrals here.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
$BasisIntegrals = 
  {TAI[d_, 0, {{1, M_}}] :> 
    -I*E^(1/2*(4 - d)*EulerGamma)*M^2*
     Gamma[-1 + (4 - d)/2]*
     Prefactor1[(M^2)^(1/2*(-4 + d))*
       SEpsilon[d]], 
       
       TBI[d_, pp_, {{1, 0},{1, 0}}] :> 
   (I*E^(((4 - d)*EulerGamma)/2 - 
         I/2*(-4 + d)*Pi)*Gamma[2 - d/2]*
      Gamma[-1 + d/2]^2*
      Prefactor1[(pp)^((-4 + d)/2)*
        SEpsilon[d]])/Gamma[-2 + d],
        
        TJI[d_, pp_, {{1,0},{1,0},{1,0}}] :>-((pp*Gamma[3 - d]*Gamma[-1 + \
d/2]^3*
    E^((4 - d)*EulerGamma)*  Prefactor1[
        (pp)^(-4 + d)*SEpsilon[d]^2])/
    (E^(I*(-4 + d)*Pi)*Gamma[-3 + (3*d)/2])
),
    
          TJI[d_, M_^2, {{1,M_},{1,0},{1,0}}] :>(M^2*Gamma[3 - d]*Gamma[2 - \
d/2]*
    Gamma[-1 + d/2]^2*Gamma[-5 + 2*d]*E^((4 - d)*EulerGamma)*
    Prefactor1[
      (M^2)^(-4 + d)*SEpsilon[d]^2])/
  (Gamma[-2 + d]*Gamma[-3 + (3*d)/2]),
  
  TJI[d_Symbol, (M_)^2, 
  {{1, M_}, {1, M_}, {1, M_}}]:>M^2*Prefactor1[
    (M^2)^(-4 + d)*SEpsilon[d]^2]*
  (-6/(-4 + d)^2 + 17/(2*(-4 + d)) + 
    (-59 - 2*Pi^2)/8 + 
    (-4 + d)^3*TJI111e + 
    ((-4 + d)^2*(16755 - 4750*Pi^2 - 
         14*Pi^4 + 3840*Pi^2*Log[2] - 
         12080*Zeta[3]))/1920 + 
    ((-4 + d)*(195 + 98*Pi^2 - 
         48*Zeta[3]))/96),
         
         TJI[d_, 0, {{1, M_}, {1, M_}, {1, 0}}]:>(M^2*Gamma[3 - d]*Gamma[2 - \
d/2]^2*
    Gamma[-1 + d/2]*E^((4 - d)*EulerGamma)*
    Prefactor1[
      (M^2)^(-4 + d)*SEpsilon[d]^2])/
  (Gamma[4 - d]*Gamma[d/2]),
  
  TJI[d_, 0, {{1,M_},{1,0},{1,0}}] :>(M^2*Gamma[3 - d]*Gamma[2 - d/2]*
    Gamma[-1 + d/2]^2*E^((4 - d)*EulerGamma)*
    Prefactor1[
      (M^2)^(-4 + d)*SEpsilon[d]^2])/
  Gamma[d/2]
        }\
\>", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["A",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                FormBox[\({1, M_}\),
                  "TraditionalForm"], 
                RowBox[{"(", 
                  FormBox["d_",
                    "TraditionalForm"], ")"}]],
              TAI[ 
                Pattern[ d, 
                  Blank[ ]], 0, {{1, 
                Pattern[ M, 
                  Blank[ ]]}}],
              Editable->True], "\[RuleDelayed]", 
            RowBox[{\(-\[ImaginaryI]\), " ", 
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{\(1\/2\), " ", \((4 - d)\), " ", 
                  TagBox["\[DoubledGamma]",
                    (EulerGamma&)]}]], " ", \(M\^2\), 
              " ", \(\[CapitalGamma](\(4 - d\)\/2 - 1)\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{\(\((M\^2)\)\^\(\(d - 4\)\/2\)\), " ", 
                    InterpretationBox[
                      StyleBox[\(S\_d\),
                        FontWeight->"Bold"],
                      SEpsilon[ d],
                      Editable->False]}],
                  Prefactor1[ 
                    Times[ 
                      Power[ 
                        Power[ M, 2], 
                        Times[ 
                          Rational[ 1, 2], 
                          Plus[ -4, d]]], 
                      SEpsilon[ d]]],
                  Editable->False], ")"}]}]}], ",", 
          RowBox[{
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["B",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\({1, 0}\),
                    "TraditionalForm"], 
                  FormBox[\({1, 0}\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d_",
                    "TraditionalForm"], ")"}]],
              TBI[ 
                Pattern[ d, 
                  Blank[ ]], 
                Pattern[ pp, 
                  Blank[ ]], {{1, 0}, {1, 0}}],
              Editable->True], "\[RuleDelayed]", 
            FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
                SuperscriptBox["\[ExponentialE]", 
                  RowBox[{
                    RowBox[{\(1\/2\), " ", \((4 - d)\), " ", 
                      TagBox["\[DoubledGamma]",
                        (EulerGamma&)]}], 
                    "-", \(1\/2\ \[ImaginaryI]\ \((d - 4)\)\ \[Pi]\)}]], 
                " ", \(\[CapitalGamma](2 - d\/2)\), 
                " ", \(\(\[CapitalGamma](d\/2 - 1)\)\^2\), " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{\(pp\^\(\(d - 4\)\/2\)\), " ", 
                      InterpretationBox[
                        StyleBox[\(S\_d\),
                          FontWeight->"Bold"],
                        SEpsilon[ d],
                        Editable->False]}],
                    Prefactor1[ 
                      Times[ 
                        Power[ pp, 
                          Times[ 
                            Rational[ 1, 2], 
                            Plus[ -4, d]]], 
                        SEpsilon[ d]]],
                    Editable->False], ")"}]}], \(\[CapitalGamma](d - 2)\)]}], 
          ",", 
          RowBox[{
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["J",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\({1, 0}\),
                    "TraditionalForm"], 
                  FormBox[\({1, 0}\),
                    "TraditionalForm"], 
                  FormBox[\({1, 0}\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d_",
                    "TraditionalForm"], ")"}]],
              TJI[ 
                Pattern[ d, 
                  Blank[ ]], 
                Pattern[ pp, 
                  Blank[ ]], {{1, 0}, {1, 0}, {1, 0}}],
              Editable->True], "\[RuleDelayed]", 
            RowBox[{"-", 
              FractionBox[
                RowBox[{
                "pp", " ", \(\[CapitalGamma](3 - d)\), 
                  " ", \(\(\[CapitalGamma](d\/2 - 1)\)\^3\), " ", 
                  SuperscriptBox["\[ExponentialE]", 
                    RowBox[{\((4 - d)\), " ", 
                      TagBox["\[DoubledGamma]",
                        (EulerGamma&)]}]], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{\(pp\^\(d - 4\)\), " ", 
                        InterpretationBox[
                          StyleBox[\(S\_d\%2\),
                            FontWeight->"Bold"],
                          SEpsilon[ d],
                          Editable->False]}],
                      Prefactor1[ 
                        Times[ 
                          Power[ pp, 
                            Plus[ -4, d]], 
                          Power[ 
                            SEpsilon[ d], 2]]],
                      Editable->False], 
                    ")"}]}], \(\[ExponentialE]\^\(\[ImaginaryI]\ \((d - 4)\)\ \
\[Pi]\)\ \(\[CapitalGamma](\(3\ d\)\/2 - 3)\)\)]}]}], ",", 
          RowBox[{
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["J",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\({1, M_}\),
                    "TraditionalForm"], 
                  FormBox[\({1, 0}\),
                    "TraditionalForm"], 
                  FormBox[\({1, 0}\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d_",
                    "TraditionalForm"], ")"}]],
              TJI[ 
                Pattern[ d, 
                  Blank[ ]], 
                Power[ 
                  Pattern[ M, 
                    Blank[ ]], 2], {{1, 
                Pattern[ M, 
                  Blank[ ]]}, {1, 0}, {1, 0}}],
              Editable->True], "\[RuleDelayed]", 
            FractionBox[
              
              RowBox[{\(M\^2\), " ", \(\[CapitalGamma](3 - d)\), 
                " ", \(\[CapitalGamma](2 - d\/2)\), 
                " ", \(\(\[CapitalGamma](d\/2 - 1)\)\^2\), 
                " ", \(\[CapitalGamma](2\ d - 5)\), " ", 
                SuperscriptBox["\[ExponentialE]", 
                  RowBox[{\((4 - d)\), " ", 
                    TagBox["\[DoubledGamma]",
                      (EulerGamma&)]}]], " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{\(\((M\^2)\)\^\(d - 4\)\), " ", 
                      InterpretationBox[
                        StyleBox[\(S\_d\%2\),
                          FontWeight->"Bold"],
                        SEpsilon[ d],
                        Editable->False]}],
                    Prefactor1[ 
                      Times[ 
                        Power[ 
                          Power[ M, 2], 
                          Plus[ -4, d]], 
                        Power[ 
                          SEpsilon[ d], 2]]],
                    Editable->False], ")"}]}], \(\(\[CapitalGamma](
                  d - 2)\)\ \(\[CapitalGamma](\(3\ d\)\/2 - 3)\)\)]}], ",", 
          RowBox[{
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["J",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\({1, M_}\),
                    "TraditionalForm"], 
                  FormBox[\({1, M_}\),
                    "TraditionalForm"], 
                  FormBox[\({1, M_}\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d_Symbol",
                    "TraditionalForm"], ")"}]],
              TJI[ 
                Pattern[ d, 
                  Blank[ Symbol]], 
                Power[ 
                  Pattern[ M, 
                    Blank[ ]], 2], {{1, 
                Pattern[ M, 
                  Blank[ ]]}, {1, 
                Pattern[ M, 
                  Blank[ ]]}, {1, 
                Pattern[ M, 
                  Blank[ ]]}}],
              Editable->True], "\[RuleDelayed]", 
            RowBox[{\(M\^2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{\(\((M\^2)\)\^\(d - 4\)\), " ", 
                    InterpretationBox[
                      StyleBox[\(S\_d\%2\),
                        FontWeight->"Bold"],
                      SEpsilon[ d],
                      Editable->False]}],
                  Prefactor1[ 
                    Times[ 
                      Power[ 
                        Power[ M, 2], 
                        Plus[ -4, d]], 
                      Power[ 
                        SEpsilon[ d], 2]]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                
                RowBox[{\(TJI111e\ \((d - 4)\)\^3\), 
                  "+", \(1\/8\ \((\(-59\) - 2\ \[Pi]\^2)\)\), "+", 
                  RowBox[{\(1\/96\), " ", \((d - 4)\), " ", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{\(-48\), " ", 
                          TagBox[
                            RowBox[{"\[Zeta]", "(", 
                              TagBox["3",
                                (Editable -> True)], ")"}],
                            InterpretTemplate[ Zeta[ #]&]]}], 
                        "+", \(98\ \[Pi]\^2\), "+", "195"}], ")"}]}], "+", 
                  FractionBox[
                    RowBox[{\(\((d - 4)\)\^2\), " ", 
                      RowBox[{"(", 
                        
                        RowBox[{\(3840\ \[Pi]\^2\ \(log(2)\)\), 
                          "-", \(14\ \[Pi]\^4\), "-", \(4750\ \[Pi]\^2\), "-",
                           
                          RowBox[{"12080", " ", 
                            TagBox[
                              RowBox[{"\[Zeta]", "(", 
                                TagBox["3",
                                  (Editable -> True)], ")"}],
                              InterpretTemplate[ Zeta[ #]&]]}], "+", 
                          "16755"}], ")"}]}], "1920"], 
                  "+", \(17\/\(2\ \((d - 4)\)\)\), 
                  "-", \(6\/\((d - 4)\)\^2\)}], ")"}]}]}], ",", 
          RowBox[{
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["K",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\({1, M_}\),
                    "TraditionalForm"], 
                  FormBox[\({1, M_}\),
                    "TraditionalForm"], 
                  FormBox[\({1, 0}\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d_",
                    "TraditionalForm"], ")"}]],
              TJI[ 
                Pattern[ d, 
                  Blank[ ]], 0, {{1, 
                Pattern[ M, 
                  Blank[ ]]}, {1, 
                Pattern[ M, 
                  Blank[ ]]}, {1, 0}}],
              Editable->True], "\[RuleDelayed]", 
            FractionBox[
              
              RowBox[{\(M\^2\), " ", \(\[CapitalGamma](3 - d)\), 
                " ", \(\(\[CapitalGamma](2 - d\/2)\)\^2\), 
                " ", \(\[CapitalGamma](d\/2 - 1)\), " ", 
                SuperscriptBox["\[ExponentialE]", 
                  RowBox[{\((4 - d)\), " ", 
                    TagBox["\[DoubledGamma]",
                      (EulerGamma&)]}]], " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{\(\((M\^2)\)\^\(d - 4\)\), " ", 
                      InterpretationBox[
                        StyleBox[\(S\_d\%2\),
                          FontWeight->"Bold"],
                        SEpsilon[ d],
                        Editable->False]}],
                    Prefactor1[ 
                      Times[ 
                        Power[ 
                          Power[ M, 2], 
                          Plus[ -4, d]], 
                        Power[ 
                          SEpsilon[ d], 2]]],
                    Editable->False], ")"}]}], \(\(\[CapitalGamma](
                  4 - d)\)\ \(\[CapitalGamma](d\/2)\)\)]}], ",", 
          RowBox[{
            InterpretationBox[
              SubsuperscriptBox[
                StyleBox["K",
                  SingleLetterItalics->False,
                  FontWeight->"Bold"], 
                RowBox[{
                  FormBox[\({1, M_}\),
                    "TraditionalForm"], 
                  FormBox[\({1, 0}\),
                    "TraditionalForm"], 
                  FormBox[\({1, 0}\),
                    "TraditionalForm"]}], 
                RowBox[{"(", 
                  FormBox["d_",
                    "TraditionalForm"], ")"}]],
              TJI[ 
                Pattern[ d, 
                  Blank[ ]], 0, {{1, 
                Pattern[ M, 
                  Blank[ ]]}, {1, 0}, {1, 0}}],
              Editable->True], "\[RuleDelayed]", 
            FractionBox[
              
              RowBox[{\(M\^2\), " ", \(\[CapitalGamma](3 - d)\), 
                " ", \(\[CapitalGamma](2 - d\/2)\), 
                " ", \(\(\[CapitalGamma](d\/2 - 1)\)\^2\), " ", 
                SuperscriptBox["\[ExponentialE]", 
                  RowBox[{\((4 - d)\), " ", 
                    TagBox["\[DoubledGamma]",
                      (EulerGamma&)]}]], " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{\(\((M\^2)\)\^\(d - 4\)\), " ", 
                      InterpretationBox[
                        StyleBox[\(S\_d\%2\),
                          FontWeight->"Bold"],
                        SEpsilon[ d],
                        Editable->False]}],
                    Prefactor1[ 
                      Times[ 
                        Power[ 
                          Power[ M, 2], 
                          Plus[ -4, d]], 
                        Power[ 
                          SEpsilon[ d], 2]]],
                    Editable->False], ")"}]}], \(\[CapitalGamma](d\/2)\)]}]}],
         "}"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Save tarcer*.mx file", "Section",
  CellDingbat->"\[FilledSmallCircle]",
  CellTags->"T1.11.1"],

Cell[BoxData[
    \(\(Share[];\)\)], "Input"],

Cell["\<\
DumpSave[StringJoin[\"tarcer\", StringJoin @@ 
     ToString /@ $RankLimit, \".mx\"], 
   {$ContextPath, HighEnergyPhysics`Tarcer`Cayley, 
    HighEnergyPhysics`Tarcer`CayleyD, 
    HighEnergyPhysics`Tarcer`Cayleyu, 
    HighEnergyPhysics`Tarcer`Prefactor1, 
    HighEnergyPhysics`Tarcer`TarcerRecurse, 
    HighEnergyPhysics`Tarcer`TFIRecurse, 
    HighEnergyPhysics`Tarcer`TFISimplify, 
    HighEnergyPhysics`Tarcer`SEpsilon, 
    HighEnergyPhysics`Tarcer`TarcerExpand, 
    HighEnergyPhysics`Tarcer`TarcerReduce, 
    HighEnergyPhysics`Tarcer`TAI, 
    HighEnergyPhysics`Tarcer`TAR, 
    HighEnergyPhysics`Tarcer`TBI, 
    HighEnergyPhysics`Tarcer`TBR, 
    HighEnergyPhysics`Tarcer`TFI, 
    HighEnergyPhysics`Tarcer`TFR, 
    HighEnergyPhysics`Tarcer`TJI, 
    HighEnergyPhysics`Tarcer`TJR, 
    HighEnergyPhysics`Tarcer`TKI, 
    HighEnergyPhysics`Tarcer`TVI, 
    HighEnergyPhysics`Tarcer`TVR, 
    HighEnergyPhysics`Tarcer`$BasisIntegrals, 
    HighEnergyPhysics`Tarcer`$Comment, 
    HighEnergyPhysics`Tarcer`$CommentNotebook, 
    HighEnergyPhysics`Tarcer`$RankLimit, 
    HighEnergyPhysics`Tarcer`$TTable, 
    HighEnergyPhysics`Tarcer`Private`applytlrules, 
    HighEnergyPhysics`Tarcer`Private`applytlrules2,
    HighEnergyPhysics`Tarcer`Private`ExpandMaybe, 
    HighEnergyPhysics`Tarcer`Private`FactorC, 
    HighEnergyPhysics`Tarcer`Private`FEPrint, 
    HighEnergyPhysics`Tarcer`Private`fN, 
    HighEnergyPhysics`Tarcer`Private`mbt, 
    HighEnergyPhysics`Tarcer`Private`PNQ, 
    HighEnergyPhysics`Tarcer`Private`PQ, 
    HighEnergyPhysics`Tarcer`Private`ta, 
    HighEnergyPhysics`Tarcer`Private`TA, 
    HighEnergyPhysics`Tarcer`Private`TAIC, 
    HighEnergyPhysics`Tarcer`Private`TBIC, 
    HighEnergyPhysics`Tarcer`Private`TComment, 
    HighEnergyPhysics`Tarcer`Private`TLRComment, 
    HighEnergyPhysics`Tarcer`Private`TFIC, 
    HighEnergyPhysics`Tarcer`Private`TJIC, 
    HighEnergyPhysics`Tarcer`Private`TLR, 
    HighEnergyPhysics`Tarcer`Private`tlrule, 
    HighEnergyPhysics`Tarcer`Private`redblue, 
    HighEnergyPhysics`Tarcer`Private`TLRules, 
    HighEnergyPhysics`Tarcer`Private`TLRules2, 
    HighEnergyPhysics`Tarcer`Private`TVIC, 
    HighEnergyPhysics`Tarcer`Private`$TLRComment, 
    HighEnergyPhysics`FeynCalc`Zeta2`Zeta2}]; \
\>", "Input",
  Editable->True],

Cell[BoxData[
    \(\($HistoryLength = \[Infinity];\)\)], "Input"],

Cell["\<\
This gives the absolute time (in minutes) to run this \
notebook.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Round[AbsoluteTime[] - HighEnergyPhysics`Tarcer`Private`atime]/
        60. \ min\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.9166666666666666`\ min\)], "Output"]
}, Open  ]],

Cell["Display the size of the generated file:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(filename\  = \ "\<tarcer\>" <> \((Apply[StringJoin, 
            ToString /@ $RankLimit])\) <> "\<.mx\>"\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`"tarcer06.mx"\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FileByteCount[filename]\ Byte\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`1674536\ Byte\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Directory[]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`"F:\\fjob\\Mathematica\\4.0\\AddOns\\Applications\\\
HighEnergyPhysics\\tarcer"\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MaxMemoryUsed[]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`11855232\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MemoryInUse[]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`7725504\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimeUsed[]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`54.19700000000001`\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\ \)], "Input"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
WindowToolbars->{},
WindowSize->{845, 605},
WindowMargins->{{43, Automatic}, {Automatic, 19}},
CellLabelAutoDelete->True,
Magnification->1
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "T1.1"->{
    Cell[1739, 51, 73, 2, 105, "Title",
      CellTags->"T1.1"]},
  "T1.2"->{
    Cell[1995, 63, 434, 14, 109, "Text",
      CellTags->"T1.2"]},
  "T1.1.1"->{
    Cell[29922, 1063, 93, 2, 53, "Section",
      CellTags->"T1.1.1"]},
  "T1.2.1.1"->{
    Cell[33579, 1182, 78, 1, 43, "Subsubsection",
      CellTags->"T1.2.1.1"]},
  "T1.2.1"->{
    Cell[34221, 1202, 86, 2, 53, "Section",
      CellTags->"T1.2.1"]},
  "T1.3.1"->{
    Cell[40102, 1352, 112, 2, 53, "Section",
      CellTags->"T1.3.1"]},
  "T1.3.1.1"->{
    Cell[42176, 1426, 63, 1, 47, "Subsection",
      CellTags->"T1.3.1.1"]},
  "T1.3.2.1"->{
    Cell[66851, 2022, 58, 1, 47, "Subsection",
      CellTags->"T1.3.2.1"]},
  "T1.3.3.1"->{
    Cell[71524, 2110, 59, 1, 47, "Subsection",
      CellTags->"T1.3.3.1"]},
  "T1.3.4.1"->{
    Cell[75778, 2200, 60, 1, 47, "Subsection",
      CellTags->"T1.3.4.1"]},
  "T1.3.5.1"->{
    Cell[76563, 2222, 54, 1, 47, "Subsection",
      CellTags->"T1.3.5.1"]},
  "T1.3.6.1"->{
    Cell[81410, 2324, 59, 1, 47, "Subsection",
      CellTags->"T1.3.6.1"]},
  "T1.3.7.1"->{
    Cell[81995, 2341, 50, 1, 47, "Subsection",
      CellTags->"T1.3.7.1"]},
  "T1.3.7.1.1"->{
    Cell[82160, 2349, 57, 1, 43, "Subsubsection",
      CellTags->"T1.3.7.1.1"]},
  "T1.3.7.2.1"->{
    Cell[84800, 2440, 53, 1, 43, "Subsubsection",
      CellTags->"T1.3.7.2.1"]},
  "T1.3.7.3.1"->{
    Cell[84964, 2449, 54, 1, 43, "Subsubsection",
      CellTags->"T1.3.7.3.1"]},
  "T1.3.7.4.1"->{
    Cell[85184, 2461, 58, 1, 43, "Subsubsection",
      CellTags->"T1.3.7.4.1"]},
  "T1.3.7.5.1"->{
    Cell[85356, 2470, 54, 1, 43, "Subsubsection",
      CellTags->"T1.3.7.5.1"]},
  "T1.3.7.6.1"->{
    Cell[88192, 2561, 54, 1, 43, "Subsubsection",
      CellTags->"T1.3.7.6.1"]},
  "T1.3.7.7.1"->{
    Cell[88813, 2582, 54, 1, 43, "Subsubsection",
      CellTags->"T1.3.7.7.1"]},
  "T1.3.7.8.1"->{
    Cell[89566, 2607, 54, 1, 43, "Subsubsection",
      CellTags->"T1.3.7.8.1"]},
  "T1.4.1"->{
    Cell[89899, 2623, 104, 2, 53, "Section",
      CellTags->"T1.4.1"]},
  "T1.4.1.1"->{
    Cell[91884, 2672, 116, 3, 46, "Subsection",
      CellTags->"T1.4.1.1"]},
  "T1.4.2.1"->{
    Cell[92328, 2691, 114, 3, 46, "Subsection",
      CellTags->"T1.4.2.1"]},
  "T1.4.3.1"->{
    Cell[94550, 2760, 205, 6, 46, "Subsection",
      CellTags->"T1.4.3.1"]},
  "T1.4.4.1"->{
    Cell[99237, 2883, 223, 6, 59, "Subsection",
      CellTags->"T1.4.4.1"]},
  "T1.5.1"->{
    Cell[111623, 3204, 97, 2, 53, "Section",
      CellTags->"T1.5.1"]},
  "T1.5.1.1"->{
    Cell[111745, 3210, 65, 1, 47, "Subsection",
      CellTags->"T1.5.1.1"]},
  "T1.5.1.1.1"->{
    Cell[172152, 4376, 62, 1, 43, "Subsubsection",
      CellTags->"T1.5.1.1.1"]},
  "T1.5.2.1"->{
    Cell[175608, 4464, 59, 1, 47, "Subsection",
      CellTags->"T1.5.2.1"]},
  "T1.5.2.1.1"->{
    Cell[176947, 4491, 53, 1, 43, "Subsubsection",
      CellTags->"T1.5.2.1.1"]},
  "T1.5.3.1"->{
    Cell[182948, 4641, 60, 1, 47, "Subsection",
      CellTags->"T1.5.3.1"]},
  "T1.5.3.1.1"->{
    Cell[183354, 4657, 68, 1, 43, "Subsubsection",
      CellTags->"T1.5.3.1.1"]},
  "T1.5.3.2.1"->{
    Cell[186424, 4722, 68, 1, 43, "Subsubsection",
      CellTags->"T1.5.3.2.1"]},
  "T1.6.1"->{
    Cell[188896, 4781, 140, 2, 53, "Section",
      CellTags->"T1.6.1"]},
  "T1.6.1.1"->{
    Cell[189336, 4796, 56, 1, 47, "Subsection",
      CellTags->"T1.6.1.1"]},
  "T1.6.2.1"->{
    Cell[196945, 4984, 58, 1, 47, "Subsection",
      CellTags->"T1.6.2.1"]},
  "T1.6.2.1.1"->{
    Cell[197112, 4992, 139, 5, 43, "Subsubsection",
      CellTags->"T1.6.2.1.1"]},
  "T1.6.2.2.1"->{
    Cell[198379, 5032, 139, 5, 43, "Subsubsection",
      CellTags->"T1.6.2.2.1"]},
  "T1.6.2.3.1"->{
    Cell[199718, 5073, 139, 5, 43, "Subsubsection",
      CellTags->"T1.6.2.3.1"]},
  "T1.6.2.4.1"->{
    Cell[201057, 5114, 139, 5, 43, "Subsubsection",
      CellTags->"T1.6.2.4.1"]},
  "T1.6.3.1"->{
    Cell[202408, 5156, 58, 1, 47, "Subsection",
      CellTags->"T1.6.3.1"]},
  "T1.6.4.1"->{
    Cell[206201, 5263, 159, 5, 47, "Subsection",
      CellTags->"T1.6.4.1"]},
  "T1.6.5.1"->{
    Cell[206846, 5287, 58, 1, 47, "Subsection",
      CellTags->"T1.6.5.1"]},
  "T1.6.6.1"->{
    Cell[210639, 5394, 159, 5, 47, "Subsection",
      CellTags->"T1.6.6.1"]},
  "T1.6.7.1"->{
    Cell[211284, 5418, 159, 5, 47, "Subsection",
      CellTags->"T1.6.7.1"]},
  "T1.6.8.1"->{
    Cell[212071, 5447, 159, 5, 47, "Subsection",
      CellTags->"T1.6.8.1"]},
  "T1.6.9.1"->{
    Cell[212858, 5476, 56, 1, 47, "Subsection",
      CellTags->"T1.6.9.1"]},
  "T1.6.10.1"->{
    Cell[219711, 5645, 59, 1, 47, "Subsection",
      CellTags->"T1.6.10.1"]},
  "T1.6.11.1"->{
    Cell[220976, 5684, 57, 1, 47, "Subsection",
      CellTags->"T1.6.11.1"]},
  "T1.6.12.1"->{
    Cell[225279, 5812, 57, 1, 47, "Subsection",
      CellTags->"T1.6.12.1"]},
  "T1.6.13.1"->{
    Cell[229582, 5940, 57, 1, 47, "Subsection",
      CellTags->"T1.6.13.1"]},
  "T1.6.14.1"->{
    Cell[237057, 6121, 68, 1, 47, "Subsection",
      CellTags->"T1.6.14.1"]},
  "T1.6.15.1"->{
    Cell[237474, 6137, 59, 1, 47, "Subsection",
      CellTags->"T1.6.15.1"]},
  "T1.6.16.1"->{
    Cell[260228, 6681, 57, 1, 47, "Subsection",
      CellTags->"T1.6.16.1"]},
  "T1.6.17.1"->{
    Cell[264261, 6794, 59, 1, 47, "Subsection",
      CellTags->"T1.6.17.1"]},
  "T1.6.18.1"->{
    Cell[265036, 6827, 57, 1, 47, "Subsection",
      CellTags->"T1.6.18.1"]},
  "T1.6.19.1"->{
    Cell[270548, 6975, 59, 1, 47, "Subsection",
      CellTags->"T1.6.19.1"]},
  "T1.6.20.1"->{
    Cell[271308, 7006, 59, 1, 47, "Subsection",
      CellTags->"T1.6.20.1"]},
  "T1.6.21.1"->{
    Cell[272096, 7038, 57, 1, 47, "Subsection",
      CellTags->"T1.6.21.1"]},
  "T1.6.22.1"->{
    Cell[275517, 7138, 59, 1, 47, "Subsection",
      CellTags->"T1.6.22.1"]},
  "T1.6.23.1"->{
    Cell[276219, 7167, 57, 1, 47, "Subsection",
      CellTags->"T1.6.23.1"]},
  "T1.6.24.1"->{
    Cell[280353, 7284, 59, 1, 47, "Subsection",
      CellTags->"T1.6.24.1"]},
  "T1.6.25.1"->{
    Cell[281079, 7314, 57, 1, 47, "Subsection",
      CellTags->"T1.6.25.1"]},
  "T1.6.26.1"->{
    Cell[284768, 7420, 59, 1, 47, "Subsection",
      CellTags->"T1.6.26.1"]},
  "T1.6.27.1"->{
    Cell[285500, 7450, 57, 1, 47, "Subsection",
      CellTags->"T1.6.27.1"]},
  "T1.6.28.1"->{
    Cell[290877, 7596, 59, 1, 47, "Subsection",
      CellTags->"T1.6.28.1"]},
  "T1.6.29.1"->{
    Cell[291851, 7625, 58, 1, 47, "Subsection",
      CellTags->"T1.6.29.1"]},
  "T1.6.30.1"->{
    Cell[295273, 7725, 59, 1, 47, "Subsection",
      CellTags->"T1.6.30.1"]},
  "T1.6.31.1"->{
    Cell[295994, 7754, 58, 1, 47, "Subsection",
      CellTags->"T1.6.31.1"]},
  "T1.6.32.1"->{
    Cell[301217, 7917, 59, 1, 47, "Subsection",
      CellTags->"T1.6.32.1"]},
  "T1.6.33.1"->{
    Cell[302371, 7964, 61, 1, 47, "Subsection",
      CellTags->"T1.6.33.1"]},
  "T1.6.34.1"->{
    Cell[303571, 8011, 58, 1, 47, "Subsection",
      CellTags->"T1.6.34.1"]},
  "T1.6.35.1"->{
    Cell[309196, 8168, 59, 1, 47, "Subsection",
      CellTags->"T1.6.35.1"]},
  "T1.6.36.1"->{
    Cell[310458, 8209, 58, 1, 47, "Subsection",
      CellTags->"T1.6.36.1"]},
  "T1.6.37.1"->{
    Cell[317187, 8376, 59, 1, 47, "Subsection",
      CellTags->"T1.6.37.1"]},
  "T1.6.38.1"->{
    Cell[319001, 8444, 61, 1, 47, "Subsection",
      CellTags->"T1.6.38.1"]},
  "T1.6.39.1"->{
    Cell[320831, 8502, 61, 1, 47, "Subsection",
      CellTags->"T1.6.39.1"]},
  "T1.6.40.1"->{
    Cell[321909, 8538, 61, 1, 47, "Subsection",
      CellTags->"T1.6.40.1"]},
  "T1.6.41.1"->{
    Cell[322755, 8566, 58, 1, 47, "Subsection",
      CellTags->"T1.6.41.1"]},
  "T1.6.42.1"->{
    Cell[327871, 8706, 59, 1, 47, "Subsection",
      CellTags->"T1.6.42.1"]},
  "T1.6.43.1"->{
    Cell[328747, 8739, 68, 1, 47, "Subsection",
      CellTags->"T1.6.43.1"]},
  "T1.6.44.1"->{
    Cell[334509, 8899, 57, 1, 47, "Subsection",
      CellTags->"T1.6.44.1"]},
  "T1.6.45.1"->{
    Cell[349165, 9308, 59, 1, 47, "Subsection",
      CellTags->"T1.6.45.1"]},
  "T1.6.46.1"->{
    Cell[349995, 9341, 61, 1, 47, "Subsection",
      CellTags->"T1.6.46.1"]},
  "T1.6.47.1"->{
    Cell[350897, 9376, 57, 1, 47, "Subsection",
      CellTags->"T1.6.47.1"]},
  "T1.6.48.1"->{
    Cell[356881, 9531, 59, 1, 47, "Subsection",
      CellTags->"T1.6.48.1"]},
  "T1.6.49.1"->{
    Cell[357723, 9564, 61, 1, 47, "Subsection",
      CellTags->"T1.6.49.1"]},
  "T1.6.50.1"->{
    Cell[358641, 9599, 57, 1, 47, "Subsection",
      CellTags->"T1.6.50.1"]},
  "T1.6.51.1"->{
    Cell[371215, 9909, 59, 1, 47, "Subsection",
      CellTags->"T1.6.51.1"]},
  "T1.6.52.1"->{
    Cell[371902, 9936, 57, 1, 47, "Subsection",
      CellTags->"T1.6.52.1"]},
  "T1.6.53.1"->{
    Cell[377266, 10082, 59, 1, 47, "Subsection",
      CellTags->"T1.6.53.1"]},
  "T1.6.54.1"->{
    Cell[377809, 10107, 61, 1, 47, "Subsection",
      CellTags->"T1.6.54.1"]},
  "T1.6.55.1"->{
    Cell[378387, 10132, 61, 1, 47, "Subsection",
      CellTags->"T1.6.55.1"]},
  "T1.6.56.1"->{
    Cell[378965, 10157, 57, 1, 47, "Subsection",
      CellTags->"T1.6.56.1"]},
  "T1.6.57.1"->{
    Cell[384839, 10318, 59, 1, 47, "Subsection",
      CellTags->"T1.6.57.1"]},
  "T1.6.58.1"->{
    Cell[385324, 10341, 57, 1, 47, "Subsection",
      CellTags->"T1.6.58.1"]},
  "T1.6.59.1"->{
    Cell[389944, 10467, 59, 1, 47, "Subsection",
      CellTags->"T1.6.59.1"]},
  "T1.6.60.1"->{
    Cell[390461, 10492, 57, 1, 47, "Subsection",
      CellTags->"T1.6.60.1"]},
  "T1.6.61.1"->{
    Cell[395599, 10632, 59, 1, 47, "Subsection",
      CellTags->"T1.6.61.1"]},
  "T1.6.62.1"->{
    Cell[396207, 10658, 61, 1, 47, "Subsection",
      CellTags->"T1.6.62.1"]},
  "T1.6.63.1"->{
    Cell[396850, 10684, 61, 1, 47, "Subsection",
      CellTags->"T1.6.63.1"]},
  "T1.6.64.1"->{
    Cell[397517, 10711, 57, 1, 47, "Subsection",
      CellTags->"T1.6.64.1"]},
  "T1.6.65.1"->{
    Cell[408119, 10975, 59, 1, 47, "Subsection",
      CellTags->"T1.6.65.1"]},
  "T1.6.66.1"->{
    Cell[408674, 11000, 61, 1, 47, "Subsection",
      CellTags->"T1.6.66.1"]},
  "T1.6.67.1"->{
    Cell[409275, 11026, 61, 1, 47, "Subsection",
      CellTags->"T1.6.67.1"]},
  "T1.6.68.1"->{
    Cell[409876, 11052, 57, 1, 47, "Subsection",
      CellTags->"T1.6.68.1"]},
  "T1.6.69.1"->{
    Cell[416796, 11228, 59, 1, 47, "Subsection",
      CellTags->"T1.6.69.1"]},
  "T1.6.70.1"->{
    Cell[417344, 11253, 57, 1, 47, "Subsection",
      CellTags->"T1.6.70.1"]},
  "T1.6.70.1.1"->{
    Cell[417426, 11258, 56, 1, 43, "Subsubsection",
      CellTags->"T1.6.70.1.1"]},
  "T1.6.70.2.1"->{
    Cell[419264, 11314, 56, 1, 43, "Subsubsection",
      CellTags->"T1.6.70.2.1"]},
  "T1.6.71.1"->{
    Cell[425800, 11497, 59, 1, 47, "Subsection",
      CellTags->"T1.6.71.1"]},
  "T1.6.72.1"->{
    Cell[426164, 11514, 57, 1, 47, "Subsection",
      CellTags->"T1.6.72.1"]},
  "T1.6.73.1"->{
    Cell[435540, 11740, 59, 1, 47, "Subsection",
      CellTags->"T1.6.73.1"]},
  "T1.6.74.1"->{
    Cell[435885, 11756, 57, 1, 47, "Subsection",
      CellTags->"T1.6.74.1"]},
  "T1.6.75.1"->{
    Cell[447365, 12078, 60, 1, 47, "Subsection",
      CellTags->"T1.6.75.1"]},
  "T1.6.76.1"->{
    Cell[447757, 12095, 60, 1, 47, "Subsection",
      CellTags->"T1.6.76.1"]},
  "T1.6.77.1"->{
    Cell[448212, 12113, 60, 1, 47, "Subsection",
      CellTags->"T1.6.77.1"]},
  "T1.6.78.1"->{
    Cell[448603, 12130, 60, 1, 47, "Subsection",
      CellTags->"T1.6.78.1"]},
  "T1.6.79.1"->{
    Cell[449025, 12147, 57, 1, 47, "Subsection",
      CellTags->"T1.6.79.1"]},
  "T1.6.80.1"->{
    Cell[454357, 12286, 57, 1, 47, "Subsection",
      CellTags->"T1.6.80.1"]},
  "T1.6.81.1"->{
    Cell[456859, 12360, 59, 1, 47, "Subsection",
      CellTags->"T1.6.81.1"]},
  "T1.6.82.1"->{
    Cell[457224, 12376, 57, 1, 47, "Subsection",
      CellTags->"T1.6.82.1"]},
  "T1.6.83.1"->{
    Cell[460484, 12469, 59, 1, 47, "Subsection",
      CellTags->"T1.6.83.1"]},
  "T1.6.84.1"->{
    Cell[460800, 12483, 61, 1, 47, "Subsection",
      CellTags->"T1.6.84.1"]},
  "T1.6.85.1"->{
    Cell[461297, 12502, 61, 1, 47, "Subsection",
      CellTags->"T1.6.85.1"]},
  "T1.6.86.1"->{
    Cell[461839, 12522, 57, 1, 47, "Subsection",
      CellTags->"T1.6.86.1"]},
  "T1.6.87.1"->{
    Cell[464185, 12598, 59, 1, 47, "Subsection",
      CellTags->"T1.6.87.1"]},
  "T1.6.88.1"->{
    Cell[464522, 12613, 57, 1, 47, "Subsection",
      CellTags->"T1.6.88.1"]},
  "T1.6.89.1"->{
    Cell[466852, 12686, 59, 1, 47, "Subsection",
      CellTags->"T1.6.89.1"]},
  "T1.6.90.1"->{
    Cell[467141, 12700, 57, 1, 47, "Subsection",
      CellTags->"T1.6.90.1"]},
  "T1.6.91.1"->{
    Cell[468669, 12753, 59, 1, 47, "Subsection",
      CellTags->"T1.6.91.1"]},
  "T1.6.92.1"->{
    Cell[468973, 12767, 57, 1, 47, "Subsection",
      CellTags->"T1.6.92.1"]},
  "T1.6.93.1"->{
    Cell[470359, 12816, 59, 1, 47, "Subsection",
      CellTags->"T1.6.93.1"]},
  "T1.6.94.1"->{
    Cell[470637, 12830, 57, 1, 47, "Subsection",
      CellTags->"T1.6.94.1"]},
  "T1.6.95.1"->{
    Cell[474585, 12947, 59, 1, 47, "Subsection",
      CellTags->"T1.6.95.1"]},
  "T1.6.96.1"->{
    Cell[474898, 12961, 61, 1, 47, "Subsection",
      CellTags->"T1.6.96.1"]},
  "T1.6.97.1"->{
    Cell[475273, 12977, 61, 1, 47, "Subsection",
      CellTags->"T1.6.97.1"]},
  "T1.6.98.1"->{
    Cell[475648, 12993, 58, 1, 47, "Subsection",
      CellTags->"T1.6.98.1"]},
  "T1.6.99.1"->{
    Cell[481817, 13171, 60, 1, 47, "Subsection",
      CellTags->"T1.6.99.1"]},
  "T1.6.100.1"->{
    Cell[482275, 13194, 62, 1, 47, "Subsection",
      CellTags->"T1.6.100.1"]},
  "T1.6.101.1"->{
    Cell[482776, 13217, 62, 1, 47, "Subsection",
      CellTags->"T1.6.101.1"]},
  "T1.6.102.1"->{
    Cell[483316, 13242, 62, 1, 47, "Subsection",
      CellTags->"T1.6.102.1"]},
  "T1.6.103.1"->{
    Cell[483817, 13265, 62, 1, 47, "Subsection",
      CellTags->"T1.6.103.1"]},
  "T1.6.104.1"->{
    Cell[484318, 13288, 62, 1, 47, "Subsection",
      CellTags->"T1.6.104.1"]},
  "T1.6.105.1"->{
    Cell[484858, 13313, 59, 1, 47, "Subsection",
      CellTags->"T1.6.105.1"]},
  "T1.6.106.1"->{
    Cell[485631, 13337, 61, 1, 47, "Subsection",
      CellTags->"T1.6.106.1"]},
  "T1.6.107.1"->{
    Cell[485853, 13349, 59, 1, 47, "Subsection",
      CellTags->"T1.6.107.1"]},
  "T1.6.108.1"->{
    Cell[486736, 13377, 61, 1, 47, "Subsection",
      CellTags->"T1.6.108.1"]},
  "T1.6.109.1"->{
    Cell[487008, 13391, 59, 1, 47, "Subsection",
      CellTags->"T1.6.109.1"]},
  "T1.6.110.1"->{
    Cell[487728, 13414, 61, 1, 47, "Subsection",
      CellTags->"T1.6.110.1"]},
  "T1.6.111.1"->{
    Cell[487950, 13426, 59, 1, 47, "Subsection",
      CellTags->"T1.6.111.1"]},
  "T1.6.112.1"->{
    Cell[488422, 13443, 61, 1, 47, "Subsection",
      CellTags->"T1.6.112.1"]},
  "T1.6.113.1"->{
    Cell[488644, 13455, 59, 1, 47, "Subsection",
      CellTags->"T1.6.113.1"]},
  "T1.6.114.1"->{
    Cell[495800, 13644, 61, 1, 47, "Subsection",
      CellTags->"T1.6.114.1"]},
  "T1.6.115.1"->{
    Cell[496402, 13665, 61, 1, 47, "Subsection",
      CellTags->"T1.6.115.1"]},
  "T1.6.116.1"->{
    Cell[497195, 13702, 61, 1, 47, "Subsection",
      CellTags->"T1.6.116.1"]},
  "T1.6.117.1"->{
    Cell[497992, 13739, 62, 1, 47, "Subsection",
      CellTags->"T1.6.117.1"]},
  "T1.6.118.1"->{
    Cell[499177, 13766, 62, 1, 47, "Subsection",
      CellTags->"T1.6.118.1"]},
  "T1.6.119.1"->{
    Cell[500325, 13792, 62, 1, 47, "Subsection",
      CellTags->"T1.6.119.1"]},
  "T1.6.120.1"->{
    Cell[501471, 13818, 61, 1, 47, "Subsection",
      CellTags->"T1.6.120.1"]},
  "Tsymmetry"->{
    Cell[507991, 13961, 55, 1, 47, "Subsection",
      CellTags->"Tsymmetry"]},
  "specialTVR"->{
    Cell[508194, 13972, 70, 1, 47, "Subsection",
      CellTags->"specialTVR"]},
  "T1.6.121.1"->{
    Cell[518983, 14160, 60, 1, 47, "Subsection",
      CellTags->"T1.6.121.1"]},
  "T1.6.122.1"->{
    Cell[520988, 14221, 61, 1, 47, "Subsection",
      CellTags->"T1.6.122.1"]},
  "T1.6.123.1"->{
    Cell[522041, 14253, 60, 1, 47, "Subsection",
      CellTags->"T1.6.123.1"]},
  "T1.6.124.1"->{
    Cell[522729, 14277, 58, 1, 47, "Subsection",
      CellTags->"T1.6.124.1"]},
  "T1.7.1"->{
    Cell[523481, 14305, 108, 2, 53, "Section",
      CellTags->"T1.7.1"]},
  "T1.7.1.1"->{
    Cell[523614, 14311, 70, 1, 47, "Subsection",
      CellTags->"T1.7.1.1"]},
  "TLRdef"->{
    Cell[525479, 14374, 216, 7, 109, "Text",
      CellTags->"TLRdef"]},
  "tlrule17"->{
    Cell[535968, 14648, 78, 1, 33, "Text",
      CellTags->"tlrule17"]},
  "T1.7.2.1"->{
    Cell[562496, 15342, 50, 1, 47, "Subsection",
      CellTags->"T1.7.2.1"]},
  "T1.7.3.1"->{
    Cell[567997, 15474, 54, 1, 47, "Subsection",
      CellTags->"T1.7.3.1"]},
  "$TTable"->{
    Cell[569535, 15511, 52, 1, 47, "Subsection",
      CellTags->"$TTable"]},
  "T1.7.4.1"->{
    Cell[569677, 15520, 59, 1, 47, "Subsection",
      CellTags->"T1.7.4.1"]},
  "T1.8.1"->{
    Cell[579292, 15711, 92, 2, 53, "Section",
      CellTags->"T1.8.1"]},
  "T1.9.1"->{
    Cell[587763, 15889, 93, 2, 53, "Section",
      CellTags->"T1.9.1"]},
  "T1.9.1.1"->{
    Cell[587881, 15895, 54, 1, 47, "Subsection",
      CellTags->"T1.9.1.1"]},
  "T1.10.1"->{
    Cell[592068, 16014, 95, 2, 53, "Section",
      CellTags->"T1.10.1"]},
  "T1.11.1"->{
    Cell[608641, 16451, 101, 2, 53, "Section",
      CellTags->"T1.11.1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"T1.1", 613346, 16615},
  {"T1.2", 613424, 16618},
  {"T1.1.1", 613505, 16621},
  {"T1.2.1.1", 613593, 16624},
  {"T1.2.1", 613687, 16627},
  {"T1.3.1", 613773, 16630},
  {"T1.3.1.1", 613862, 16633},
  {"T1.3.2.1", 613955, 16636},
  {"T1.3.3.1", 614048, 16639},
  {"T1.3.4.1", 614141, 16642},
  {"T1.3.5.1", 614234, 16645},
  {"T1.3.6.1", 614327, 16648},
  {"T1.3.7.1", 614420, 16651},
  {"T1.3.7.1.1", 614515, 16654},
  {"T1.3.7.2.1", 614615, 16657},
  {"T1.3.7.3.1", 614715, 16660},
  {"T1.3.7.4.1", 614815, 16663},
  {"T1.3.7.5.1", 614915, 16666},
  {"T1.3.7.6.1", 615015, 16669},
  {"T1.3.7.7.1", 615115, 16672},
  {"T1.3.7.8.1", 615215, 16675},
  {"T1.4.1", 615311, 16678},
  {"T1.4.1.1", 615400, 16681},
  {"T1.4.2.1", 615494, 16684},
  {"T1.4.3.1", 615588, 16687},
  {"T1.4.4.1", 615682, 16690},
  {"T1.5.1", 615774, 16693},
  {"T1.5.1.1", 615863, 16696},
  {"T1.5.1.1.1", 615959, 16699},
  {"T1.5.2.1", 616058, 16702},
  {"T1.5.2.1.1", 616154, 16705},
  {"T1.5.3.1", 616253, 16708},
  {"T1.5.3.1.1", 616349, 16711},
  {"T1.5.3.2.1", 616450, 16714},
  {"T1.6.1", 616547, 16717},
  {"T1.6.1.1", 616637, 16720},
  {"T1.6.2.1", 616731, 16723},
  {"T1.6.2.1.1", 616827, 16726},
  {"T1.6.2.2.1", 616929, 16729},
  {"T1.6.2.3.1", 617031, 16732},
  {"T1.6.2.4.1", 617133, 16735},
  {"T1.6.3.1", 617233, 16738},
  {"T1.6.4.1", 617327, 16741},
  {"T1.6.5.1", 617422, 16744},
  {"T1.6.6.1", 617516, 16747},
  {"T1.6.7.1", 617611, 16750},
  {"T1.6.8.1", 617706, 16753},
  {"T1.6.9.1", 617801, 16756},
  {"T1.6.10.1", 617896, 16759},
  {"T1.6.11.1", 617992, 16762},
  {"T1.6.12.1", 618088, 16765},
  {"T1.6.13.1", 618184, 16768},
  {"T1.6.14.1", 618280, 16771},
  {"T1.6.15.1", 618376, 16774},
  {"T1.6.16.1", 618472, 16777},
  {"T1.6.17.1", 618568, 16780},
  {"T1.6.18.1", 618664, 16783},
  {"T1.6.19.1", 618760, 16786},
  {"T1.6.20.1", 618856, 16789},
  {"T1.6.21.1", 618952, 16792},
  {"T1.6.22.1", 619048, 16795},
  {"T1.6.23.1", 619144, 16798},
  {"T1.6.24.1", 619240, 16801},
  {"T1.6.25.1", 619336, 16804},
  {"T1.6.26.1", 619432, 16807},
  {"T1.6.27.1", 619528, 16810},
  {"T1.6.28.1", 619624, 16813},
  {"T1.6.29.1", 619720, 16816},
  {"T1.6.30.1", 619816, 16819},
  {"T1.6.31.1", 619912, 16822},
  {"T1.6.32.1", 620008, 16825},
  {"T1.6.33.1", 620104, 16828},
  {"T1.6.34.1", 620200, 16831},
  {"T1.6.35.1", 620296, 16834},
  {"T1.6.36.1", 620392, 16837},
  {"T1.6.37.1", 620488, 16840},
  {"T1.6.38.1", 620584, 16843},
  {"T1.6.39.1", 620680, 16846},
  {"T1.6.40.1", 620776, 16849},
  {"T1.6.41.1", 620872, 16852},
  {"T1.6.42.1", 620968, 16855},
  {"T1.6.43.1", 621064, 16858},
  {"T1.6.44.1", 621160, 16861},
  {"T1.6.45.1", 621256, 16864},
  {"T1.6.46.1", 621352, 16867},
  {"T1.6.47.1", 621448, 16870},
  {"T1.6.48.1", 621544, 16873},
  {"T1.6.49.1", 621640, 16876},
  {"T1.6.50.1", 621736, 16879},
  {"T1.6.51.1", 621832, 16882},
  {"T1.6.52.1", 621928, 16885},
  {"T1.6.53.1", 622024, 16888},
  {"T1.6.54.1", 622121, 16891},
  {"T1.6.55.1", 622218, 16894},
  {"T1.6.56.1", 622315, 16897},
  {"T1.6.57.1", 622412, 16900},
  {"T1.6.58.1", 622509, 16903},
  {"T1.6.59.1", 622606, 16906},
  {"T1.6.60.1", 622703, 16909},
  {"T1.6.61.1", 622800, 16912},
  {"T1.6.62.1", 622897, 16915},
  {"T1.6.63.1", 622994, 16918},
  {"T1.6.64.1", 623091, 16921},
  {"T1.6.65.1", 623188, 16924},
  {"T1.6.66.1", 623285, 16927},
  {"T1.6.67.1", 623382, 16930},
  {"T1.6.68.1", 623479, 16933},
  {"T1.6.69.1", 623576, 16936},
  {"T1.6.70.1", 623673, 16939},
  {"T1.6.70.1.1", 623772, 16942},
  {"T1.6.70.2.1", 623876, 16945},
  {"T1.6.71.1", 623978, 16948},
  {"T1.6.72.1", 624075, 16951},
  {"T1.6.73.1", 624172, 16954},
  {"T1.6.74.1", 624269, 16957},
  {"T1.6.75.1", 624366, 16960},
  {"T1.6.76.1", 624463, 16963},
  {"T1.6.77.1", 624560, 16966},
  {"T1.6.78.1", 624657, 16969},
  {"T1.6.79.1", 624754, 16972},
  {"T1.6.80.1", 624851, 16975},
  {"T1.6.81.1", 624948, 16978},
  {"T1.6.82.1", 625045, 16981},
  {"T1.6.83.1", 625142, 16984},
  {"T1.6.84.1", 625239, 16987},
  {"T1.6.85.1", 625336, 16990},
  {"T1.6.86.1", 625433, 16993},
  {"T1.6.87.1", 625530, 16996},
  {"T1.6.88.1", 625627, 16999},
  {"T1.6.89.1", 625724, 17002},
  {"T1.6.90.1", 625821, 17005},
  {"T1.6.91.1", 625918, 17008},
  {"T1.6.92.1", 626015, 17011},
  {"T1.6.93.1", 626112, 17014},
  {"T1.6.94.1", 626209, 17017},
  {"T1.6.95.1", 626306, 17020},
  {"T1.6.96.1", 626403, 17023},
  {"T1.6.97.1", 626500, 17026},
  {"T1.6.98.1", 626597, 17029},
  {"T1.6.99.1", 626694, 17032},
  {"T1.6.100.1", 626792, 17035},
  {"T1.6.101.1", 626891, 17038},
  {"T1.6.102.1", 626990, 17041},
  {"T1.6.103.1", 627089, 17044},
  {"T1.6.104.1", 627188, 17047},
  {"T1.6.105.1", 627287, 17050},
  {"T1.6.106.1", 627386, 17053},
  {"T1.6.107.1", 627485, 17056},
  {"T1.6.108.1", 627584, 17059},
  {"T1.6.109.1", 627683, 17062},
  {"T1.6.110.1", 627782, 17065},
  {"T1.6.111.1", 627881, 17068},
  {"T1.6.112.1", 627980, 17071},
  {"T1.6.113.1", 628079, 17074},
  {"T1.6.114.1", 628178, 17077},
  {"T1.6.115.1", 628277, 17080},
  {"T1.6.116.1", 628376, 17083},
  {"T1.6.117.1", 628475, 17086},
  {"T1.6.118.1", 628574, 17089},
  {"T1.6.119.1", 628673, 17092},
  {"T1.6.120.1", 628772, 17095},
  {"Tsymmetry", 628870, 17098},
  {"specialTVR", 628968, 17101},
  {"T1.6.121.1", 629067, 17104},
  {"T1.6.122.1", 629166, 17107},
  {"T1.6.123.1", 629265, 17110},
  {"T1.6.124.1", 629364, 17113},
  {"T1.7.1", 629459, 17116},
  {"T1.7.1.1", 629550, 17119},
  {"TLRdef", 629643, 17122},
  {"tlrule17", 629732, 17125},
  {"T1.7.2.1", 629821, 17128},
  {"T1.7.3.1", 629916, 17131},
  {"$TTable", 630010, 17134},
  {"T1.7.4.1", 630104, 17137},
  {"T1.8.1", 630197, 17140},
  {"T1.9.1", 630285, 17143},
  {"T1.9.1.1", 630375, 17146},
  {"T1.10.1", 630469, 17149},
  {"T1.11.1", 630559, 17152}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 73, 2, 105, "Title",
  CellTags->"T1.1"],
Cell[1815, 55, 177, 6, 33, "Text"],
Cell[1995, 63, 434, 14, 109, "Text",
  CellTags->"T1.2"],
Cell[2432, 79, 55, 1, 33, "Text"],
Cell[2490, 82, 131, 3, 33, "Text"],
Cell[2624, 87, 137, 3, 33, "Text"],
Cell[2764, 92, 186, 6, 33, "Text"],
Cell[2953, 100, 158, 6, 33, "Text"],
Cell[3114, 108, 171, 6, 33, "Text"],
Cell[3288, 116, 162, 6, 33, "Text"],
Cell[3453, 124, 162, 6, 33, "Text"],
Cell[3618, 132, 162, 6, 33, "Text"],
Cell[3783, 140, 167, 6, 33, "Text"],
Cell[3953, 148, 156, 3, 33, "Text"],
Cell[4112, 153, 1081, 21, 261, "Text"],
Cell[5196, 176, 147, 3, 33, "Text"],
Cell[5346, 181, 499, 10, 109, "Text"],
Cell[5848, 193, 94, 3, 33, "Text"],
Cell[5945, 198, 176, 4, 33, "Text"],
Cell[6124, 204, 228, 6, 52, "Text"],
Cell[6355, 212, 55, 1, 30, "Input"],
Cell[6413, 215, 180, 4, 33, "Text"],
Cell[6596, 221, 212, 4, 52, "Text"],
Cell[6811, 227, 262, 8, 33, "Text"],

Cell[CellGroupData[{
Cell[7098, 239, 75, 1, 53, "Section"],
Cell[7176, 242, 102, 2, 33, "Text"],
Cell[7281, 246, 95, 2, 33, "Text"],
Cell[7379, 250, 120, 2, 33, "Text"],
Cell[7502, 254, 121, 2, 33, "Text"],
Cell[7626, 258, 108, 2, 33, "Text"],
Cell[7737, 262, 103, 2, 33, "Text"],
Cell[7843, 266, 104, 2, 33, "Text"],
Cell[7950, 270, 105, 2, 33, "Text"],
Cell[8058, 274, 99, 2, 33, "Text"],
Cell[8160, 278, 104, 2, 33, "Text"],
Cell[8267, 282, 95, 2, 33, "Text"],
Cell[8365, 286, 104, 2, 28, "SmallText"],
Cell[8472, 290, 100, 2, 28, "SmallText"],
Cell[8575, 294, 101, 2, 28, "SmallText"],
Cell[8679, 298, 105, 2, 28, "SmallText"],
Cell[8787, 302, 101, 2, 28, "SmallText"],
Cell[8891, 306, 101, 2, 28, "SmallText"],
Cell[8995, 310, 101, 2, 28, "SmallText"],
Cell[9099, 314, 101, 2, 28, "SmallText"],
Cell[9203, 318, 113, 2, 33, "Text"],
Cell[9319, 322, 143, 3, 33, "Text"],
Cell[9465, 327, 141, 3, 33, "Text"],
Cell[9609, 332, 530, 15, 34, "Text"],
Cell[10142, 349, 547, 15, 34, "Text"],
Cell[10692, 366, 106, 2, 33, "Text"],
Cell[10801, 370, 110, 2, 33, "Text"],
Cell[10914, 374, 109, 2, 28, "SmallText"],
Cell[11026, 378, 189, 7, 33, "Text"],
Cell[11218, 387, 100, 2, 28, "SmallText"],
Cell[11321, 391, 105, 2, 33, "Text"],
Cell[11429, 395, 115, 2, 28, "SmallText"],
Cell[11547, 399, 115, 2, 28, "SmallText"],
Cell[11665, 403, 151, 3, 33, "Text"],
Cell[11819, 408, 101, 2, 33, "Text"],
Cell[11923, 412, 103, 2, 33, "Text"],
Cell[12029, 416, 485, 13, 31, "SmallText"],
Cell[12517, 431, 485, 13, 31, "SmallText"],
Cell[13005, 446, 485, 13, 31, "SmallText"],
Cell[13493, 461, 485, 13, 31, "SmallText"],
Cell[13981, 476, 103, 2, 33, "Text"],
Cell[14087, 480, 523, 15, 37, "Text"],
Cell[14613, 497, 103, 2, 33, "Text"],
Cell[14719, 501, 523, 15, 37, "Text"],
Cell[15245, 518, 523, 15, 37, "Text"],
Cell[15771, 535, 523, 15, 37, "Text"],
Cell[16297, 552, 101, 2, 33, "Text"],
Cell[16401, 556, 104, 2, 33, "Text"],
Cell[16508, 560, 102, 2, 33, "Text"],
Cell[16613, 564, 102, 2, 33, "Text"],
Cell[16718, 568, 102, 2, 33, "Text"],
Cell[16823, 572, 113, 2, 33, "Text"],
Cell[16939, 576, 104, 2, 33, "Text"],
Cell[17046, 580, 102, 2, 33, "Text"],
Cell[17151, 584, 104, 2, 33, "Text"],
Cell[17258, 588, 102, 2, 33, "Text"],
Cell[17363, 592, 104, 2, 33, "Text"],
Cell[17470, 596, 104, 2, 33, "Text"],
Cell[17577, 600, 102, 2, 33, "Text"],
Cell[17682, 604, 104, 2, 33, "Text"],
Cell[17789, 608, 102, 2, 33, "Text"],
Cell[17894, 612, 104, 2, 33, "Text"],
Cell[18001, 616, 102, 2, 33, "Text"],
Cell[18106, 620, 104, 2, 33, "Text"],
Cell[18213, 624, 102, 2, 33, "Text"],
Cell[18318, 628, 104, 2, 33, "Text"],
Cell[18425, 632, 102, 2, 33, "Text"],
Cell[18530, 636, 104, 2, 33, "Text"],
Cell[18637, 640, 102, 2, 33, "Text"],
Cell[18742, 644, 104, 2, 33, "Text"],
Cell[18849, 648, 106, 2, 33, "Text"],
Cell[18958, 652, 102, 2, 33, "Text"],
Cell[19063, 656, 104, 2, 33, "Text"],
Cell[19170, 660, 102, 2, 33, "Text"],
Cell[19275, 664, 104, 2, 33, "Text"],
Cell[19382, 668, 106, 2, 33, "Text"],
Cell[19491, 672, 106, 2, 33, "Text"],
Cell[19600, 676, 106, 2, 33, "Text"],
Cell[19709, 680, 102, 2, 33, "Text"],
Cell[19814, 684, 104, 2, 33, "Text"],
Cell[19921, 688, 113, 2, 33, "Text"],
Cell[20037, 692, 102, 2, 33, "Text"],
Cell[20142, 696, 104, 2, 33, "Text"],
Cell[20249, 700, 106, 2, 33, "Text"],
Cell[20358, 704, 102, 2, 33, "Text"],
Cell[20463, 708, 104, 2, 33, "Text"],
Cell[20570, 712, 106, 2, 33, "Text"],
Cell[20679, 716, 102, 2, 33, "Text"],
Cell[20784, 720, 104, 2, 33, "Text"],
Cell[20891, 724, 102, 2, 33, "Text"],
Cell[20996, 728, 104, 2, 33, "Text"],
Cell[21103, 732, 106, 2, 33, "Text"],
Cell[21212, 736, 106, 2, 33, "Text"],
Cell[21321, 740, 102, 2, 33, "Text"],
Cell[21426, 744, 104, 2, 33, "Text"],
Cell[21533, 748, 102, 2, 33, "Text"],
Cell[21638, 752, 104, 2, 33, "Text"],
Cell[21745, 756, 102, 2, 33, "Text"],
Cell[21850, 760, 104, 2, 33, "Text"],
Cell[21957, 764, 106, 2, 33, "Text"],
Cell[22066, 768, 106, 2, 33, "Text"],
Cell[22175, 772, 102, 2, 33, "Text"],
Cell[22280, 776, 104, 2, 33, "Text"],
Cell[22387, 780, 106, 2, 33, "Text"],
Cell[22496, 784, 106, 2, 33, "Text"],
Cell[22605, 788, 102, 2, 33, "Text"],
Cell[22710, 792, 104, 2, 33, "Text"],
Cell[22817, 796, 102, 2, 33, "Text"],
Cell[22922, 800, 103, 2, 28, "SmallText"],
Cell[23028, 804, 103, 2, 28, "SmallText"],
Cell[23134, 808, 104, 2, 33, "Text"],
Cell[23241, 812, 102, 2, 33, "Text"],
Cell[23346, 816, 104, 2, 33, "Text"],
Cell[23453, 820, 102, 2, 33, "Text"],
Cell[23558, 824, 105, 2, 33, "Text"],
Cell[23666, 828, 105, 2, 33, "Text"],
Cell[23774, 832, 105, 2, 33, "Text"],
Cell[23882, 836, 105, 2, 33, "Text"],
Cell[23990, 840, 102, 2, 33, "Text"],
Cell[24095, 844, 102, 2, 33, "Text"],
Cell[24200, 848, 104, 2, 33, "Text"],
Cell[24307, 852, 102, 2, 33, "Text"],
Cell[24412, 856, 104, 2, 33, "Text"],
Cell[24519, 860, 106, 2, 33, "Text"],
Cell[24628, 864, 106, 2, 33, "Text"],
Cell[24737, 868, 102, 2, 33, "Text"],
Cell[24842, 872, 104, 2, 33, "Text"],
Cell[24949, 876, 102, 2, 33, "Text"],
Cell[25054, 880, 104, 2, 33, "Text"],
Cell[25161, 884, 102, 2, 33, "Text"],
Cell[25266, 888, 104, 2, 33, "Text"],
Cell[25373, 892, 102, 2, 33, "Text"],
Cell[25478, 896, 104, 2, 33, "Text"],
Cell[25585, 900, 102, 2, 33, "Text"],
Cell[25690, 904, 104, 2, 33, "Text"],
Cell[25797, 908, 106, 2, 33, "Text"],
Cell[25906, 912, 106, 2, 33, "Text"],
Cell[26015, 916, 103, 2, 33, "Text"],
Cell[26121, 920, 105, 2, 33, "Text"],
Cell[26229, 924, 107, 2, 33, "Text"],
Cell[26339, 928, 107, 2, 33, "Text"],
Cell[26449, 932, 107, 2, 33, "Text"],
Cell[26559, 936, 107, 2, 33, "Text"],
Cell[26669, 940, 107, 2, 33, "Text"],
Cell[26779, 944, 104, 2, 33, "Text"],
Cell[26886, 948, 106, 2, 33, "Text"],
Cell[26995, 952, 104, 2, 33, "Text"],
Cell[27102, 956, 106, 2, 33, "Text"],
Cell[27211, 960, 104, 2, 33, "Text"],
Cell[27318, 964, 106, 2, 33, "Text"],
Cell[27427, 968, 104, 2, 33, "Text"],
Cell[27534, 972, 106, 2, 33, "Text"],
Cell[27643, 976, 104, 2, 33, "Text"],
Cell[27750, 980, 106, 2, 33, "Text"],
Cell[27859, 984, 106, 2, 33, "Text"],
Cell[27968, 988, 106, 2, 33, "Text"],
Cell[28077, 992, 106, 2, 33, "Text"],
Cell[28186, 996, 106, 2, 33, "Text"],
Cell[28295, 1000, 106, 2, 33, "Text"],
Cell[28404, 1004, 106, 2, 33, "Text"],
Cell[28513, 1008, 105, 2, 33, "Text"],
Cell[28621, 1012, 106, 2, 33, "Text"],
Cell[28730, 1016, 105, 2, 33, "Text"],
Cell[28838, 1020, 103, 2, 33, "Text"],
Cell[28944, 1024, 117, 2, 33, "Text"],
Cell[29064, 1028, 101, 2, 33, "Text"],
Cell[29168, 1032, 95, 2, 33, "Text"],
Cell[29266, 1036, 99, 2, 33, "Text"],
Cell[29368, 1040, 104, 2, 33, "Text"],
Cell[29475, 1044, 101, 2, 33, "Text"],
Cell[29579, 1048, 102, 2, 33, "Text"],
Cell[29684, 1052, 105, 2, 33, "Text"],
Cell[29792, 1056, 93, 2, 33, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29922, 1063, 93, 2, 53, "Section",
  CellTags->"T1.1.1"],
Cell[30018, 1067, 342, 10, 60, "SmallText"],
Cell[30363, 1079, 118, 3, 33, "Text"],
Cell[30484, 1084, 1703, 43, 87, "Text"],
Cell[32190, 1129, 222, 5, 90, "Text"],
Cell[32415, 1136, 50, 1, 30, "Input"],
Cell[32468, 1139, 64, 1, 30, "Input"],
Cell[32535, 1142, 89, 1, 30, "Input"],
Cell[32627, 1145, 56, 1, 30, "Input"],
Cell[32686, 1148, 107, 3, 33, "Text"],
Cell[32796, 1153, 178, 5, 30, "Input"],
Cell[32977, 1160, 220, 6, 28, "SmallText"],
Cell[33200, 1168, 233, 4, 50, "Input"],
Cell[33436, 1174, 57, 1, 30, "Input"],
Cell[33496, 1177, 58, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[33579, 1182, 78, 1, 43, "Subsubsection",
  CellTags->"T1.2.1.1"],
Cell[33660, 1185, 512, 11, 109, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[34221, 1202, 86, 2, 53, "Section",
  CellTags->"T1.2.1"],
Cell[34310, 1206, 83, 1, 30, "Input"],
Cell[34396, 1209, 257, 4, 70, "Input"],
Cell[34656, 1215, 631, 9, 170, "Input"],
Cell[35290, 1226, 157, 2, 50, "Input"],
Cell[35450, 1230, 120, 2, 30, "Input"],
Cell[35573, 1234, 135, 2, 30, "Input"],
Cell[35711, 1238, 135, 2, 30, "Input"],
Cell[35849, 1242, 147, 2, 30, "Input"],
Cell[35999, 1246, 123, 2, 30, "Input"],
Cell[36125, 1250, 303, 4, 70, "Input"],
Cell[36431, 1256, 211, 3, 70, "Input"],
Cell[36645, 1261, 227, 3, 70, "Input"],
Cell[36875, 1266, 176, 3, 50, "Input"],
Cell[37054, 1271, 172, 3, 50, "Input"],
Cell[37229, 1276, 194, 3, 50, "Input"],
Cell[37426, 1281, 177, 3, 50, "Input"],
Cell[37606, 1286, 168, 3, 50, "Input"],
Cell[37777, 1291, 149, 2, 30, "Input"],
Cell[37929, 1295, 149, 2, 30, "Input"],
Cell[38081, 1299, 149, 2, 30, "Input"],
Cell[38233, 1303, 149, 2, 30, "Input"],
Cell[38385, 1307, 149, 2, 30, "Input"],
Cell[38537, 1311, 449, 6, 130, "Input"],
Cell[38989, 1319, 189, 3, 70, "Input"],
Cell[39181, 1324, 182, 3, 70, "Input"],
Cell[39366, 1329, 144, 2, 30, "Input"],
Cell[39513, 1333, 248, 3, 70, "Input"],
Cell[39764, 1338, 179, 3, 70, "Input"],
Cell[39946, 1343, 60, 1, 30, "Input"],
Cell[40009, 1346, 56, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[40102, 1352, 112, 2, 53, "Section",
  CellTags->"T1.3.1"],
Cell[40217, 1356, 798, 24, 33, "Text"],
Cell[41018, 1382, 57, 1, 30, "Input"],
Cell[41078, 1385, 73, 0, 33, "Text"],
Cell[41154, 1387, 61, 1, 30, "Input"],
Cell[41218, 1390, 115, 3, 33, "Text"],
Cell[41336, 1395, 58, 1, 30, "Input"],
Cell[41397, 1398, 754, 24, 33, "Text"],

Cell[CellGroupData[{
Cell[42176, 1426, 63, 1, 47, "Subsection",
  CellTags->"T1.3.1.1"],
Cell[42242, 1429, 60, 1, 30, "Input"],
Cell[42305, 1432, 265, 5, 70, "Input"],
Cell[42573, 1439, 265, 5, 70, "Input"],
Cell[42841, 1446, 174, 3, 50, "Input"],
Cell[43018, 1451, 115, 3, 33, "Text"],
Cell[43136, 1456, 213, 4, 50, "Input"],
Cell[43352, 1462, 208, 4, 30, "Input"],
Cell[43563, 1468, 225, 4, 50, "Input"],
Cell[43791, 1474, 256, 5, 50, "Input"],
Cell[44050, 1481, 146, 2, 30, "Input"],
Cell[44199, 1485, 163, 2, 30, "Input"],
Cell[44365, 1489, 205, 4, 50, "Input"],
Cell[44573, 1495, 182, 3, 50, "Input"],
Cell[44758, 1500, 513, 13, 138, "Input"],
Cell[45274, 1515, 108, 2, 30, "Input"],
Cell[45385, 1519, 108, 2, 30, "Input"],
Cell[45496, 1523, 108, 2, 30, "Input"],
Cell[45607, 1527, 108, 2, 30, "Input"],
Cell[45718, 1531, 108, 2, 30, "Input"],
Cell[45829, 1535, 76, 1, 30, "Input"],
Cell[45908, 1538, 79, 1, 30, "Input"],
Cell[45990, 1541, 119, 2, 30, "Input"],
Cell[46112, 1545, 311, 7, 50, "Input"],
Cell[46426, 1554, 154, 3, 30, "Input"],
Cell[46583, 1559, 179, 3, 30, "Input"],
Cell[46765, 1564, 119, 2, 30, "Input"],
Cell[46887, 1568, 154, 3, 30, "Input"],
Cell[47044, 1573, 311, 7, 50, "Input"],
Cell[47358, 1582, 596, 11, 110, "Input"],
Cell[47957, 1595, 686, 12, 150, "Input"],
Cell[48646, 1609, 621, 12, 130, "Input"],
Cell[49270, 1623, 702, 13, 130, "Input"],
Cell[49975, 1638, 202, 3, 30, "Input"],
Cell[50180, 1643, 728, 13, 130, "Input"],
Cell[50911, 1658, 619, 11, 110, "Input"],
Cell[51533, 1671, 426, 8, 90, "Input"],
Cell[51962, 1681, 619, 11, 110, "Input"],
Cell[52584, 1694, 172, 3, 30, "Input"],
Cell[52759, 1699, 426, 8, 90, "Input"],
Cell[53188, 1709, 550, 10, 110, "Input"],
Cell[53741, 1721, 135, 2, 30, "Input"],
Cell[53879, 1725, 546, 10, 110, "Input"],
Cell[54428, 1737, 108, 2, 30, "Input"],
Cell[54539, 1741, 107, 3, 52, "Text"],
Cell[54649, 1746, 630, 11, 130, "Input"],
Cell[55282, 1759, 628, 11, 130, "Input"],
Cell[55913, 1772, 624, 12, 130, "Input"],
Cell[56540, 1786, 707, 13, 130, "Input"],
Cell[57250, 1801, 733, 13, 130, "Input"],
Cell[57986, 1816, 637, 12, 110, "Input"],
Cell[58626, 1830, 428, 8, 90, "Input"],
Cell[59057, 1840, 553, 10, 110, "Input"],
Cell[59613, 1852, 549, 10, 110, "Input"],
Cell[60165, 1864, 627, 11, 110, "Input"],
Cell[60795, 1877, 625, 11, 110, "Input"],
Cell[61423, 1890, 621, 12, 130, "Input"],
Cell[62047, 1904, 702, 13, 130, "Input"],
Cell[62752, 1919, 728, 13, 130, "Input"],
Cell[63483, 1934, 619, 11, 110, "Input"],
Cell[64105, 1947, 426, 8, 90, "Input"],
Cell[64534, 1957, 550, 10, 110, "Input"],
Cell[65087, 1969, 546, 10, 110, "Input"],
Cell[65636, 1981, 115, 2, 30, "Input"],
Cell[65754, 1985, 115, 2, 30, "Input"],
Cell[65872, 1989, 115, 2, 30, "Input"],
Cell[65990, 1993, 115, 2, 30, "Input"],
Cell[66108, 1997, 115, 2, 30, "Input"],
Cell[66226, 2001, 133, 2, 31, "Input"],
Cell[66362, 2005, 121, 2, 30, "Input"],
Cell[66486, 2009, 214, 4, 50, "Input"],
Cell[66703, 2015, 111, 2, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[66851, 2022, 58, 1, 47, "Subsection",
  CellTags->"T1.3.2.1"],
Cell[66912, 2025, 4575, 80, 1279, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[71524, 2110, 59, 1, 47, "Subsection",
  CellTags->"T1.3.3.1"],
Cell[71586, 2113, 591, 10, 154, "Input"],
Cell[72180, 2125, 591, 10, 154, "Input"],
Cell[72774, 2137, 591, 10, 154, "Input"],
Cell[73368, 2149, 591, 10, 154, "Input"],
Cell[73962, 2161, 591, 10, 154, "Input"],
Cell[74556, 2173, 591, 10, 154, "Input"],
Cell[75150, 2185, 591, 10, 154, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[75778, 2200, 60, 1, 47, "Subsection",
  CellTags->"T1.3.4.1"],
Cell[75841, 2203, 685, 14, 130, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[76563, 2222, 54, 1, 47, "Subsection",
  CellTags->"T1.3.5.1"],
Cell[76620, 2225, 129, 3, 48, "Input"],
Cell[76752, 2230, 2089, 37, 470, "Input"],
Cell[78844, 2269, 193, 3, 50, "Input"],
Cell[79040, 2274, 306, 9, 29, "Text"],
Cell[79349, 2285, 2024, 34, 363, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[81410, 2324, 59, 1, 47, "Subsection",
  CellTags->"T1.3.6.1"],
Cell[81472, 2327, 486, 9, 130, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[81995, 2341, 50, 1, 47, "Subsection",
  CellTags->"T1.3.7.1"],
Cell[82048, 2344, 87, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[82160, 2349, 57, 1, 43, "Subsubsection",
  CellTags->"T1.3.7.1.1"],
Cell[82220, 2352, 779, 28, 37, "Text"],
Cell[83002, 2382, 217, 4, 50, "Input"],
Cell[83222, 2388, 154, 3, 30, "Input"],
Cell[83379, 2393, 156, 3, 30, "Input"],
Cell[83538, 2398, 160, 3, 30, "Input"],
Cell[83701, 2403, 150, 3, 30, "Input"],
Cell[83854, 2408, 158, 3, 30, "Input"],
Cell[84015, 2413, 148, 3, 30, "Input"],
Cell[84166, 2418, 148, 3, 30, "Input"],
Cell[84317, 2423, 156, 3, 30, "Input"],
Cell[84476, 2428, 152, 3, 30, "Input"],
Cell[84631, 2433, 132, 2, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[84800, 2440, 53, 1, 43, "Subsubsection",
  CellTags->"T1.3.7.2.1"],
Cell[84856, 2443, 71, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[84964, 2449, 54, 1, 43, "Subsubsection",
  CellTags->"T1.3.7.3.1"],
Cell[85021, 2452, 51, 1, 30, "Input"],
Cell[85075, 2455, 72, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[85184, 2461, 58, 1, 43, "Subsubsection",
  CellTags->"T1.3.7.4.1"],
Cell[85245, 2464, 74, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[85356, 2470, 54, 1, 43, "Subsubsection",
  CellTags->"T1.3.7.5.1"],
Cell[85413, 2473, 112, 2, 30, "Input"],
Cell[85528, 2477, 121, 2, 30, "Input"],
Cell[85652, 2481, 76, 1, 30, "Input"],
Cell[85731, 2484, 152, 2, 30, "Input"],
Cell[85886, 2488, 134, 2, 30, "Input"],
Cell[86023, 2492, 133, 2, 30, "Input"],
Cell[86159, 2496, 116, 2, 30, "Input"],
Cell[86278, 2500, 167, 2, 50, "Input"],
Cell[86448, 2504, 92, 1, 30, "Input"],
Cell[86543, 2507, 92, 1, 30, "Input"],
Cell[86638, 2510, 92, 1, 30, "Input"],
Cell[86733, 2513, 92, 1, 30, "Input"],
Cell[86828, 2516, 92, 1, 30, "Input"],
Cell[86923, 2519, 92, 1, 30, "Input"],
Cell[87018, 2522, 92, 1, 30, "Input"],
Cell[87113, 2525, 92, 1, 30, "Input"],
Cell[87208, 2528, 92, 1, 30, "Input"],
Cell[87303, 2531, 92, 1, 30, "Input"],
Cell[87398, 2534, 92, 1, 30, "Input"],
Cell[87493, 2537, 92, 1, 30, "Input"],
Cell[87588, 2540, 92, 1, 30, "Input"],
Cell[87683, 2543, 92, 1, 30, "Input"],
Cell[87778, 2546, 92, 1, 30, "Input"],
Cell[87873, 2549, 92, 1, 30, "Input"],
Cell[87968, 2552, 92, 1, 30, "Input"],
Cell[88063, 2555, 92, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[88192, 2561, 54, 1, 43, "Subsubsection",
  CellTags->"T1.3.7.6.1"],
Cell[88249, 2564, 375, 7, 70, "Input"],
Cell[88627, 2573, 72, 1, 30, "Input"],
Cell[88702, 2576, 74, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[88813, 2582, 54, 1, 43, "Subsubsection",
  CellTags->"T1.3.7.7.1"],
Cell[88870, 2585, 590, 14, 70, "Input"],
Cell[89463, 2601, 66, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[89566, 2607, 54, 1, 43, "Subsubsection",
  CellTags->"T1.3.7.8.1"],
Cell[89623, 2610, 215, 6, 30, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[89899, 2623, 104, 2, 53, "Section",
  CellTags->"T1.4.1"],
Cell[90006, 2627, 574, 11, 89, "Input"],
Cell[90583, 2640, 923, 15, 206, "Input"],
Cell[91509, 2657, 136, 4, 33, "Text"],
Cell[91648, 2663, 147, 2, 31, "Input"],
Cell[91798, 2667, 61, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[91884, 2672, 116, 3, 46, "Subsection",
  CellTags->"T1.4.1.1"],
Cell[92003, 2677, 213, 6, 30, "Input"],
Cell[92219, 2685, 72, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[92328, 2691, 114, 3, 46, "Subsection",
  CellTags->"T1.4.2.1"],
Cell[92445, 2696, 113, 5, 37, "Text"],
Cell[92561, 2703, 1952, 52, 72, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[94550, 2760, 205, 6, 46, "Subsection",
  CellTags->"T1.4.3.1"],
Cell[94758, 2768, 2381, 57, 94, "Input"],
Cell[97142, 2827, 157, 4, 30, "Input"],
Cell[97302, 2833, 1123, 24, 72, "Input"],
Cell[98428, 2859, 772, 19, 52, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[99237, 2883, 223, 6, 59, "Subsection",
  CellTags->"T1.4.4.1"],
Cell[99463, 2891, 3158, 73, 92, "Input"],
Cell[102624, 2966, 2826, 70, 93, "Input"],
Cell[105453, 3038, 2826, 70, 93, "Input"],
Cell[108282, 3110, 2826, 70, 93, "Input"],
Cell[111111, 3182, 157, 4, 30, "Input"],
Cell[111271, 3188, 157, 4, 30, "Input"],
Cell[111431, 3194, 143, 4, 30, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[111623, 3204, 97, 2, 53, "Section",
  CellTags->"T1.5.1"],

Cell[CellGroupData[{
Cell[111745, 3210, 65, 1, 47, "Subsection",
  CellTags->"T1.5.1.1"],
Cell[111813, 3213, 131, 3, 52, "Text"],
Cell[111947, 3218, 67, 0, 33, "Text"],
Cell[112017, 3220, 154, 5, 33, "Text"],
Cell[112174, 3227, 1216, 20, 135, "Input"],
Cell[113393, 3249, 1328, 22, 113, "Input"],
Cell[114724, 3273, 105, 2, 30, "Input"],
Cell[114832, 3277, 87, 1, 30, "Input"],
Cell[114922, 3280, 120, 2, 30, "Input"],
Cell[115045, 3284, 111, 2, 30, "Input"],
Cell[115159, 3288, 87, 1, 30, "Input"],
Cell[115249, 3291, 129, 2, 30, "Input"],
Cell[115381, 3295, 71, 1, 33, "Input"],
Cell[115455, 3298, 59, 0, 30, "Input"],
Cell[115517, 3300, 78, 1, 30, "Input"],
Cell[115598, 3303, 78, 1, 30, "Input"],
Cell[115679, 3306, 79, 1, 30, "Input"],
Cell[115761, 3309, 92, 1, 30, "Input"],
Cell[115856, 3312, 80, 1, 30, "Input"],
Cell[115939, 3315, 80, 1, 30, "Input"],
Cell[116022, 3318, 694, 11, 110, "Input"],
Cell[116719, 3331, 51, 1, 30, "Input"],
Cell[116773, 3334, 191, 4, 50, "Input"],
Cell[116967, 3340, 79, 1, 30, "Input"],
Cell[117049, 3343, 76, 0, 33, "Text"],
Cell[117128, 3345, 202, 6, 30, "Input"],
Cell[117333, 3353, 152, 4, 30, "Input"],
Cell[117488, 3359, 9785, 176, 404, "Input"],
Cell[127276, 3537, 9131, 163, 382, "Input"],
Cell[136410, 3702, 12045, 216, 514, "Input"],
Cell[148458, 3920, 11116, 201, 412, "Input"],
Cell[159577, 4123, 10160, 183, 494, "Input"],
Cell[169740, 4308, 68, 1, 30, "Input"],
Cell[169811, 4311, 804, 19, 70, "Input"],
Cell[170618, 4332, 753, 19, 70, "Input"],
Cell[171374, 4353, 753, 19, 70, "Input"],

Cell[CellGroupData[{
Cell[172152, 4376, 62, 1, 43, "Subsubsection",
  CellTags->"T1.5.1.1.1"],
Cell[172217, 4379, 2700, 62, 194, "Input"],
Cell[174920, 4443, 151, 2, 30, "Input"],
Cell[175074, 4447, 143, 2, 30, "Input"],
Cell[175220, 4451, 153, 2, 30, "Input"],
Cell[175376, 4455, 183, 3, 30, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[175608, 4464, 59, 1, 47, "Subsection",
  CellTags->"T1.5.2.1"],
Cell[175670, 4467, 1252, 20, 242, "Input"],

Cell[CellGroupData[{
Cell[176947, 4491, 53, 1, 43, "Subsubsection",
  CellTags->"T1.5.2.1.1"],
Cell[177003, 4494, 132, 2, 30, "Input"],
Cell[177138, 4498, 143, 2, 30, "Input"],
Cell[177284, 4502, 135, 3, 30, "Input"],
Cell[177422, 4507, 251, 9, 37, "Text"],
Cell[177676, 4518, 20, 0, 33, "Text"],
Cell[177699, 4520, 1281, 26, 93, "Input"],
Cell[178983, 4548, 20, 0, 33, "Text"],
Cell[179006, 4550, 759, 12, 93, "Input"],
Cell[179768, 4564, 20, 0, 33, "Text"],
Cell[179791, 4566, 552, 10, 73, "Input"],
Cell[180346, 4578, 20, 0, 33, "Text"],
Cell[180369, 4580, 549, 9, 97, "Input"],
Cell[180921, 4591, 20, 0, 33, "Text"],
Cell[180944, 4593, 799, 14, 106, "Input"],
Cell[181746, 4609, 20, 0, 33, "Text"],
Cell[181769, 4611, 1130, 24, 93, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[182948, 4641, 60, 1, 47, "Subsection",
  CellTags->"T1.5.3.1"],
Cell[183011, 4644, 176, 4, 33, "Text"],
Cell[183190, 4650, 139, 3, 52, "Text"],

Cell[CellGroupData[{
Cell[183354, 4657, 68, 1, 43, "Subsubsection",
  CellTags->"T1.5.3.1.1"],
Cell[183425, 4660, 369, 8, 67, "Input"],
Cell[183797, 4670, 781, 13, 177, "Input"],
Cell[184581, 4685, 1806, 32, 458, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[186424, 4722, 68, 1, 43, "Subsubsection",
  CellTags->"T1.5.3.2.1"],
Cell[186495, 4725, 304, 6, 67, "Input"],
Cell[186802, 4733, 185, 3, 50, "Input"],
Cell[186990, 4738, 62, 1, 30, "Input"],
Cell[187055, 4741, 1780, 33, 437, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[188896, 4781, 140, 2, 53, "Section",
  CellTags->"T1.6.1"],
Cell[189039, 4785, 272, 7, 52, "Text"],

Cell[CellGroupData[{
Cell[189336, 4796, 56, 1, 47, "Subsection",
  CellTags->"T1.6.1.1"],
Cell[189395, 4799, 77, 4, 33, "Text"],
Cell[189475, 4805, 7368, 171, 74, "Input"],
Cell[196846, 4978, 62, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[196945, 4984, 58, 1, 47, "Subsection",
  CellTags->"T1.6.2.1"],
Cell[197006, 4987, 81, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[197112, 4992, 139, 5, 43, "Subsubsection",
  CellTags->"T1.6.2.1.1"],
Cell[197254, 4999, 1088, 28, 34, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[198379, 5032, 139, 5, 43, "Subsubsection",
  CellTags->"T1.6.2.2.1"],
Cell[198521, 5039, 1160, 29, 34, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[199718, 5073, 139, 5, 43, "Subsubsection",
  CellTags->"T1.6.2.3.1"],
Cell[199860, 5080, 1160, 29, 34, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[201057, 5114, 139, 5, 43, "Subsubsection",
  CellTags->"T1.6.2.4.1"],
Cell[201199, 5121, 1160, 29, 34, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[202408, 5156, 58, 1, 47, "Subsection",
  CellTags->"T1.6.3.1"],
Cell[202469, 5159, 73, 1, 30, "Input"],
Cell[202545, 5162, 132, 2, 30, "Text"],
Cell[202680, 5166, 3415, 89, 32, "Input"],
Cell[206098, 5257, 66, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[206201, 5263, 159, 5, 47, "Subsection",
  CellTags->"T1.6.4.1"],
Cell[206363, 5270, 50, 1, 30, "Input"],
Cell[206416, 5273, 393, 9, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[206846, 5287, 58, 1, 47, "Subsection",
  CellTags->"T1.6.5.1"],
Cell[206907, 5290, 73, 1, 30, "Input"],
Cell[206983, 5293, 132, 2, 30, "Text"],
Cell[207118, 5297, 3415, 89, 32, "Input"],
Cell[210536, 5388, 66, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[210639, 5394, 159, 5, 47, "Subsection",
  CellTags->"T1.6.6.1"],
Cell[210801, 5401, 50, 1, 30, "Input"],
Cell[210854, 5404, 393, 9, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[211284, 5418, 159, 5, 47, "Subsection",
  CellTags->"T1.6.7.1"],
Cell[211446, 5425, 62, 1, 30, "Input"],
Cell[211511, 5428, 127, 3, 30, "Input"],
Cell[211641, 5433, 393, 9, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[212071, 5447, 159, 5, 47, "Subsection",
  CellTags->"T1.6.8.1"],
Cell[212233, 5454, 62, 1, 30, "Input"],
Cell[212298, 5457, 127, 3, 30, "Input"],
Cell[212428, 5462, 393, 9, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[212858, 5476, 56, 1, 47, "Subsection",
  CellTags->"T1.6.9.1"],
Cell[212917, 5479, 77, 4, 33, "Text"],
Cell[212997, 5485, 6612, 152, 94, "Input"],
Cell[219612, 5639, 62, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[219711, 5645, 59, 1, 47, "Subsection",
  CellTags->"T1.6.10.1"],
Cell[219773, 5648, 79, 1, 30, "Input"],
Cell[219855, 5651, 1084, 28, 34, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[220976, 5684, 57, 1, 47, "Subsection",
  CellTags->"T1.6.11.1"],
Cell[221036, 5687, 454, 20, 33, "Text"],
Cell[221493, 5709, 3684, 95, 32, "Input"],
Cell[225180, 5806, 62, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[225279, 5812, 57, 1, 47, "Subsection",
  CellTags->"T1.6.12.1"],
Cell[225339, 5815, 454, 20, 33, "Text"],
Cell[225796, 5837, 3684, 95, 32, "Input"],
Cell[229483, 5934, 62, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[229582, 5940, 57, 1, 47, "Subsection",
  CellTags->"T1.6.13.1"],
Cell[229642, 5943, 7313, 170, 95, "Input"],
Cell[236958, 6115, 62, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[237057, 6121, 68, 1, 47, "Subsection",
  CellTags->"T1.6.14.1"],
Cell[237128, 6124, 201, 4, 30, "Input"],
Cell[237332, 6130, 105, 2, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[237474, 6137, 59, 1, 47, "Subsection",
  CellTags->"T1.6.15.1"],
Cell[237536, 6140, 22655, 536, 9624, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[260228, 6681, 57, 1, 47, "Subsection",
  CellTags->"T1.6.16.1"],
Cell[260288, 6684, 77, 4, 33, "Text"],
Cell[260368, 6690, 3791, 96, 32, "Input"],
Cell[264162, 6788, 62, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[264261, 6794, 59, 1, 47, "Subsection",
  CellTags->"T1.6.17.1"],
Cell[264323, 6797, 38, 1, 30, "Input"],
Cell[264364, 6800, 79, 1, 30, "Input"],
Cell[264446, 6803, 401, 10, 30, "Input"],

Cell[CellGroupData[{
Cell[264872, 6817, 57, 1, 30, "Input"],
Cell[264932, 6820, 55, 1, 25, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[265036, 6827, 57, 1, 47, "Subsection",
  CellTags->"T1.6.18.1"],
Cell[265096, 6830, 77, 4, 33, "Text"],
Cell[265176, 6836, 5270, 131, 95, "Input"],
Cell[270449, 6969, 62, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[270548, 6975, 59, 1, 47, "Subsection",
  CellTags->"T1.6.19.1"],
Cell[270610, 6978, 105, 2, 30, "Input"],
Cell[270718, 6982, 401, 10, 30, "Input"],

Cell[CellGroupData[{
Cell[271144, 6996, 57, 1, 30, "Input"],
Cell[271204, 6999, 55, 1, 25, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[271308, 7006, 59, 1, 47, "Subsection",
  CellTags->"T1.6.20.1"],
Cell[271370, 7009, 133, 3, 30, "Input"],
Cell[271506, 7014, 401, 10, 30, "Input"],

Cell[CellGroupData[{
Cell[271932, 7028, 57, 1, 30, "Input"],
Cell[271992, 7031, 55, 1, 25, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[272096, 7038, 57, 1, 47, "Subsection",
  CellTags->"T1.6.21.1"],
Cell[272156, 7041, 77, 4, 33, "Text"],
Cell[272236, 7047, 3179, 83, 54, "Input"],
Cell[275418, 7132, 62, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[275517, 7138, 59, 1, 47, "Subsection",
  CellTags->"T1.6.22.1"],
Cell[275579, 7141, 79, 1, 30, "Input"],
Cell[275661, 7144, 369, 9, 30, "Input"],

Cell[CellGroupData[{
Cell[276055, 7157, 57, 1, 30, "Input"],
Cell[276115, 7160, 55, 1, 25, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[276219, 7167, 57, 1, 47, "Subsection",
  CellTags->"T1.6.23.1"],
Cell[276279, 7170, 77, 4, 33, "Text"],
Cell[276359, 7176, 3892, 100, 54, "Input"],
Cell[280254, 7278, 62, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[280353, 7284, 59, 1, 47, "Subsection",
  CellTags->"T1.6.24.1"],
Cell[280415, 7287, 79, 1, 30, "Input"],
Cell[280497, 7290, 393, 10, 30, "Input"],

Cell[CellGroupData[{
Cell[280915, 7304, 57, 1, 30, "Input"],
Cell[280975, 7307, 55, 1, 25, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[281079, 7314, 57, 1, 47, "Subsection",
  CellTags->"T1.6.25.1"],
Cell[281139, 7317, 77, 4, 33, "Text"],
Cell[281219, 7323, 3447, 89, 54, "Input"],
Cell[284669, 7414, 62, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[284768, 7420, 59, 1, 47, "Subsection",
  CellTags->"T1.6.26.1"],
Cell[284830, 7423, 79, 1, 30, "Input"],
Cell[284912, 7426, 399, 10, 30, "Input"],

Cell[CellGroupData[{
Cell[285336, 7440, 57, 1, 30, "Input"],
Cell[285396, 7443, 55, 1, 25, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[285500, 7450, 57, 1, 47, "Subsection",
  CellTags->"T1.6.27.1"],
Cell[285560, 7453, 169, 7, 33, "Text"],
Cell[285732, 7462, 5043, 126, 96, "Input"],
Cell[290778, 7590, 62, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[290877, 7596, 59, 1, 47, "Subsection",
  CellTags->"T1.6.28.1"],
Cell[290939, 7599, 46, 1, 30, "Input"],
Cell[290988, 7602, 773, 16, 93, "Input"],
Cell[291764, 7620, 50, 0, 33, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[291851, 7625, 58, 1, 47, "Subsection",
  CellTags->"T1.6.29.1"],
Cell[291912, 7628, 77, 4, 33, "Text"],
Cell[291992, 7634, 3179, 83, 54, "Input"],
Cell[295174, 7719, 62, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[295273, 7725, 59, 1, 47, "Subsection",
  CellTags->"T1.6.30.1"],
Cell[295335, 7728, 79, 1, 30, "Input"],
Cell[295417, 7731, 376, 9, 30, "Input"],

Cell[CellGroupData[{
Cell[295818, 7744, 69, 1, 30, "Input"],
Cell[295890, 7747, 55, 1, 25, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[295994, 7754, 58, 1, 47, "Subsection",
  CellTags->"T1.6.31.1"],
Cell[296055, 7757, 292, 14, 33, "Text"],
Cell[296350, 7773, 2494, 68, 32, "Input"],
Cell[298847, 7843, 62, 1, 30, "Input"],
Cell[298912, 7846, 2268, 66, 54, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[301217, 7917, 59, 1, 47, "Subsection",
  CellTags->"T1.6.32.1"],
Cell[301279, 7920, 291, 14, 33, "Text"],
Cell[301573, 7936, 46, 1, 30, "Input"],
Cell[301622, 7939, 659, 18, 30, "Input"],
Cell[302284, 7959, 50, 0, 33, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[302371, 7964, 61, 1, 47, "Subsection",
  CellTags->"T1.6.33.1"],
Cell[302435, 7967, 291, 14, 33, "Text"],
Cell[302729, 7983, 84, 1, 30, "Input"],
Cell[302816, 7986, 665, 18, 30, "Input"],
Cell[303484, 8006, 50, 0, 33, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[303571, 8011, 58, 1, 47, "Subsection",
  CellTags->"T1.6.34.1"],
Cell[303632, 8014, 394, 17, 52, "Text"],
Cell[304029, 8033, 5065, 127, 96, "Input"],
Cell[309097, 8162, 62, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[309196, 8168, 59, 1, 47, "Subsection",
  CellTags->"T1.6.35.1"],
Cell[309258, 8171, 105, 2, 30, "Input"],
Cell[309366, 8175, 1002, 27, 31, "Input"],
Cell[310371, 8204, 50, 0, 33, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[310458, 8209, 58, 1, 47, "Subsection",
  CellTags->"T1.6.36.1"],
Cell[310519, 8212, 209, 7, 52, "Text"],
Cell[310731, 8221, 6354, 147, 75, "Input"],
Cell[317088, 8370, 62, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[317187, 8376, 59, 1, 47, "Subsection",
  CellTags->"T1.6.37.1"],
Cell[317249, 8379, 178, 7, 33, "Text"],
Cell[317430, 8388, 61, 1, 30, "Input"],
Cell[317494, 8391, 563, 14, 30, "Input"],

Cell[CellGroupData[{
Cell[318082, 8409, 57, 1, 30, "Input"],
Cell[318142, 8412, 55, 1, 25, "Print"]
}, Open  ]],
Cell[318212, 8416, 643, 16, 30, "Input"],
Cell[318858, 8434, 106, 5, 90, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[319001, 8444, 61, 1, 47, "Subsection",
  CellTags->"T1.6.38.1"],
Cell[319065, 8447, 111, 2, 30, "Input"],
Cell[319179, 8451, 425, 11, 30, "Input"],
Cell[319607, 8464, 50, 1, 30, "Input"],
Cell[319660, 8467, 76, 1, 30, "Input"],
Cell[319739, 8470, 52, 1, 30, "Input"],
Cell[319794, 8473, 128, 2, 30, "Input"],
Cell[319925, 8477, 816, 18, 31, "Input"],
Cell[320744, 8497, 50, 0, 33, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[320831, 8502, 61, 1, 47, "Subsection",
  CellTags->"T1.6.39.1"],
Cell[320895, 8505, 111, 2, 30, "Input"],
Cell[321009, 8509, 66, 1, 30, "Input"],
Cell[321078, 8512, 52, 1, 30, "Input"],
Cell[321133, 8515, 128, 2, 30, "Input"],
Cell[321264, 8519, 555, 12, 31, "Input"],
Cell[321822, 8533, 50, 0, 33, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[321909, 8538, 61, 1, 47, "Subsection",
  CellTags->"T1.6.40.1"],
Cell[321973, 8541, 141, 2, 30, "Input"],
Cell[322117, 8545, 128, 2, 30, "Input"],
Cell[322248, 8549, 417, 10, 30, "Input"],
Cell[322668, 8561, 50, 0, 33, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[322755, 8566, 58, 1, 47, "Subsection",
  CellTags->"T1.6.41.1"],
Cell[322816, 8569, 77, 4, 33, "Text"],
Cell[322896, 8575, 4873, 123, 75, "Input"],
Cell[327772, 8700, 62, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[327871, 8706, 59, 1, 47, "Subsection",
  CellTags->"T1.6.42.1"],
Cell[327933, 8709, 162, 3, 30, "Input"],
Cell[328098, 8714, 460, 11, 30, "Input"],

Cell[CellGroupData[{
Cell[328583, 8729, 57, 1, 30, "Input"],
Cell[328643, 8732, 55, 1, 25, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[328747, 8739, 68, 1, 47, "Subsection",
  CellTags->"T1.6.43.1"],
Cell[328818, 8742, 111, 3, 33, "Text"],
Cell[328932, 8747, 77, 4, 33, "Text"],
Cell[329012, 8753, 5395, 138, 75, "Input"],
Cell[334410, 8893, 62, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[334509, 8899, 57, 1, 47, "Subsection",
  CellTags->"T1.6.44.1"],
Cell[334569, 8902, 77, 4, 33, "Text"],
Cell[334649, 8908, 4938, 127, 75, "Input"],
Cell[339590, 9037, 9473, 263, 56, "Text"],
Cell[349066, 9302, 62, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[349165, 9308, 59, 1, 47, "Subsection",
  CellTags->"T1.6.45.1"],
Cell[349227, 9311, 132, 3, 30, "Input"],
Cell[349362, 9316, 444, 11, 30, "Input"],

Cell[CellGroupData[{
Cell[349831, 9331, 57, 1, 30, "Input"],
Cell[349891, 9334, 55, 1, 25, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[349995, 9341, 61, 1, 47, "Subsection",
  CellTags->"T1.6.46.1"],
Cell[350059, 9344, 194, 5, 30, "Input"],
Cell[350256, 9351, 450, 11, 30, "Input"],

Cell[CellGroupData[{
Cell[350731, 9366, 59, 1, 30, "Input"],
Cell[350793, 9369, 55, 1, 25, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[350897, 9376, 57, 1, 47, "Subsection",
  CellTags->"T1.6.47.1"],
Cell[350957, 9379, 77, 4, 33, "Text"],
Cell[351037, 9385, 5742, 138, 75, "Input"],
Cell[356782, 9525, 62, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[356881, 9531, 59, 1, 47, "Subsection",
  CellTags->"T1.6.48.1"],
Cell[356943, 9534, 132, 3, 30, "Input"],
Cell[357078, 9539, 456, 11, 30, "Input"],

Cell[CellGroupData[{
Cell[357559, 9554, 57, 1, 30, "Input"],
Cell[357619, 9557, 55, 1, 25, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[357723, 9564, 61, 1, 47, "Subsection",
  CellTags->"T1.6.49.1"],
Cell[357787, 9567, 194, 5, 30, "Input"],
Cell[357984, 9574, 466, 11, 50, "Input"],

Cell[CellGroupData[{
Cell[358475, 9589, 59, 1, 30, "Input"],
Cell[358537, 9592, 55, 1, 25, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[358641, 9599, 57, 1, 47, "Subsection",
  CellTags->"T1.6.50.1"],
Cell[358701, 9602, 77, 4, 33, "Text"],
Cell[358781, 9608, 12332, 293, 161, "Input"],
Cell[371116, 9903, 62, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[371215, 9909, 59, 1, 47, "Subsection",
  CellTags->"T1.6.51.1"],
Cell[371277, 9912, 46, 1, 30, "Input"],
Cell[371326, 9915, 432, 11, 30, "Input"],
Cell[371761, 9928, 104, 3, 52, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[371902, 9936, 57, 1, 47, "Subsection",
  CellTags->"T1.6.52.1"],
Cell[371962, 9939, 157, 7, 33, "Text"],
Cell[372122, 9948, 5042, 126, 91, "Input"],
Cell[377167, 10076, 62, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[377266, 10082, 59, 1, 47, "Subsection",
  CellTags->"T1.6.53.1"],
Cell[377328, 10085, 147, 3, 30, "Input"],
Cell[377478, 10090, 142, 3, 30, "Input"],

Cell[CellGroupData[{
Cell[377645, 10097, 57, 1, 30, "Input"],
Cell[377705, 10100, 55, 1, 25, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[377809, 10107, 61, 1, 47, "Subsection",
  CellTags->"T1.6.54.1"],
Cell[377873, 10110, 172, 3, 30, "Input"],
Cell[378048, 10115, 148, 3, 30, "Input"],

Cell[CellGroupData[{
Cell[378221, 10122, 59, 1, 30, "Input"],
Cell[378283, 10125, 55, 1, 25, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[378387, 10132, 61, 1, 47, "Subsection",
  CellTags->"T1.6.55.1"],
Cell[378451, 10135, 172, 3, 30, "Input"],
Cell[378626, 10140, 148, 3, 30, "Input"],

Cell[CellGroupData[{
Cell[378799, 10147, 59, 1, 30, "Input"],
Cell[378861, 10150, 55, 1, 25, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[378965, 10157, 57, 1, 47, "Subsection",
  CellTags->"T1.6.56.1"],
Cell[379025, 10160, 147, 7, 33, "Text"],
Cell[379175, 10169, 5562, 141, 75, "Input"],
Cell[384740, 10312, 62, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[384839, 10318, 59, 1, 47, "Subsection",
  CellTags->"T1.6.57.1"],
Cell[384901, 10321, 89, 1, 30, "Input"],
Cell[384993, 10324, 142, 3, 30, "Input"],

Cell[CellGroupData[{
Cell[385160, 10331, 57, 1, 30, "Input"],
Cell[385220, 10334, 55, 1, 25, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[385324, 10341, 57, 1, 47, "Subsection",
  CellTags->"T1.6.58.1"],
Cell[385384, 10344, 138, 6, 33, "Text"],
Cell[385525, 10352, 4317, 107, 96, "Input"],
Cell[389845, 10461, 62, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[389944, 10467, 59, 1, 47, "Subsection",
  CellTags->"T1.6.59.1"],
Cell[390006, 10470, 105, 2, 30, "Input"],
Cell[390114, 10474, 158, 4, 30, "Input"],

Cell[CellGroupData[{
Cell[390297, 10482, 57, 1, 30, "Input"],
Cell[390357, 10485, 55, 1, 25, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[390461, 10492, 57, 1, 47, "Subsection",
  CellTags->"T1.6.60.1"],
Cell[390521, 10495, 156, 7, 33, "Text"],
Cell[390680, 10504, 4817, 120, 75, "Input"],
Cell[395500, 10626, 62, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[395599, 10632, 59, 1, 47, "Subsection",
  CellTags->"T1.6.61.1"],
Cell[395661, 10635, 169, 3, 30, "Input"],
Cell[395833, 10640, 185, 4, 30, "Input"],

Cell[CellGroupData[{
Cell[396043, 10648, 57, 1, 30, "Input"],
Cell[396103, 10651, 55, 1, 25, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[396207, 10658, 61, 1, 47, "Subsection",
  CellTags->"T1.6.62.1"],
Cell[396271, 10661, 194, 3, 30, "Input"],
Cell[396468, 10666, 191, 4, 30, "Input"],

Cell[CellGroupData[{
Cell[396684, 10674, 59, 1, 30, "Input"],
Cell[396746, 10677, 55, 1, 25, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[396850, 10684, 61, 1, 47, "Subsection",
  CellTags->"T1.6.63.1"],
Cell[396914, 10687, 218, 4, 30, "Input"],
Cell[397135, 10693, 191, 4, 30, "Input"],

Cell[CellGroupData[{
Cell[397351, 10701, 59, 1, 30, "Input"],
Cell[397413, 10704, 55, 1, 25, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[397517, 10711, 57, 1, 47, "Subsection",
  CellTags->"T1.6.64.1"],
Cell[397577, 10714, 146, 7, 33, "Text"],
Cell[397726, 10723, 10108, 237, 175, "Input"],
Cell[407837, 10962, 62, 1, 30, "Input"],
Cell[407902, 10965, 50, 1, 30, "Input"],
Cell[407955, 10968, 127, 2, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[408119, 10975, 59, 1, 47, "Subsection",
  CellTags->"T1.6.65.1"],
Cell[408181, 10978, 116, 2, 30, "Input"],
Cell[408300, 10982, 185, 4, 30, "Input"],

Cell[CellGroupData[{
Cell[408510, 10990, 57, 1, 30, "Input"],
Cell[408570, 10993, 55, 1, 25, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[408674, 11000, 61, 1, 47, "Subsection",
  CellTags->"T1.6.66.1"],
Cell[408738, 11003, 152, 3, 30, "Input"],
Cell[408893, 11008, 191, 4, 30, "Input"],

Cell[CellGroupData[{
Cell[409109, 11016, 59, 1, 30, "Input"],
Cell[409171, 11019, 55, 1, 25, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[409275, 11026, 61, 1, 47, "Subsection",
  CellTags->"T1.6.67.1"],
Cell[409339, 11029, 152, 3, 30, "Input"],
Cell[409494, 11034, 191, 4, 30, "Input"],

Cell[CellGroupData[{
Cell[409710, 11042, 59, 1, 30, "Input"],
Cell[409772, 11045, 55, 1, 25, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[409876, 11052, 57, 1, 47, "Subsection",
  CellTags->"T1.6.68.1"],
Cell[409936, 11055, 138, 6, 33, "Text"],
Cell[410077, 11063, 6617, 157, 97, "Input"],
Cell[416697, 11222, 62, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[416796, 11228, 59, 1, 47, "Subsection",
  CellTags->"T1.6.69.1"],
Cell[416858, 11231, 116, 2, 30, "Input"],
Cell[416977, 11235, 178, 4, 30, "Input"],

Cell[CellGroupData[{
Cell[417180, 11243, 57, 1, 30, "Input"],
Cell[417240, 11246, 55, 1, 25, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[417344, 11253, 57, 1, 47, "Subsection",
  CellTags->"T1.6.70.1"],

Cell[CellGroupData[{
Cell[417426, 11258, 56, 1, 43, "Subsubsection",
  CellTags->"T1.6.70.1.1"],
Cell[417485, 11261, 72, 1, 30, "Input"],
Cell[417560, 11264, 193, 4, 31, "Input"],
Cell[417756, 11270, 269, 4, 31, "Input"],
Cell[418028, 11276, 941, 24, 73, "Input"],
Cell[418972, 11302, 83, 1, 31, "Input"],
Cell[419058, 11305, 83, 1, 31, "Input"],
Cell[419144, 11308, 83, 1, 31, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[419264, 11314, 56, 1, 43, "Subsubsection",
  CellTags->"T1.6.70.2.1"],
Cell[419323, 11317, 779, 18, 63, "Input"],
Cell[420105, 11337, 83, 1, 31, "Input"],
Cell[420191, 11340, 83, 1, 31, "Input"],
Cell[420277, 11343, 83, 1, 31, "Input"],
Cell[420363, 11346, 47, 1, 30, "Input"],
Cell[420413, 11349, 85, 5, 33, "Text"],
Cell[420501, 11356, 5185, 132, 118, "Input"],
Cell[425689, 11490, 62, 1, 30, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[425800, 11497, 59, 1, 47, "Subsection",
  CellTags->"T1.6.71.1"],
Cell[425862, 11500, 46, 1, 30, "Input"],
Cell[425911, 11503, 164, 4, 30, "Input"],
Cell[426078, 11509, 49, 0, 33, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[426164, 11514, 57, 1, 47, "Subsection",
  CellTags->"T1.6.72.1"],
Cell[426224, 11517, 85, 5, 33, "Text"],
Cell[426312, 11524, 9126, 208, 264, "Input"],
Cell[435441, 11734, 62, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[435540, 11740, 59, 1, 47, "Subsection",
  CellTags->"T1.6.73.1"],
Cell[435602, 11743, 51, 1, 30, "Input"],
Cell[435656, 11746, 140, 3, 30, "Input"],
Cell[435799, 11751, 49, 0, 33, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[435885, 11756, 57, 1, 47, "Subsection",
  CellTags->"T1.6.74.1"],
Cell[435945, 11759, 77, 4, 33, "Text"],
Cell[436025, 11765, 2490, 68, 32, "Input"],
Cell[438518, 11835, 66, 1, 30, "Input"],
Cell[438587, 11838, 2377, 65, 32, "Input"],
Cell[440967, 11905, 66, 1, 30, "Input"],
Cell[441036, 11908, 2600, 67, 32, "Input"],
Cell[443639, 11977, 66, 1, 30, "Input"],
Cell[443708, 11980, 3551, 90, 32, "Input"],
Cell[447262, 12072, 66, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[447365, 12078, 60, 1, 47, "Subsection",
  CellTags->"T1.6.75.1"],
Cell[447428, 12081, 77, 1, 30, "Input"],
Cell[447508, 12084, 160, 4, 30, "Input"],
Cell[447671, 12090, 49, 0, 33, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[447757, 12095, 60, 1, 47, "Subsection",
  CellTags->"T1.6.76.1"],
Cell[447820, 12098, 124, 2, 30, "Input"],
Cell[447947, 12102, 176, 4, 30, "Input"],
Cell[448126, 12108, 49, 0, 33, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[448212, 12113, 60, 1, 47, "Subsection",
  CellTags->"T1.6.77.1"],
Cell[448275, 12116, 49, 1, 30, "Input"],
Cell[448327, 12119, 187, 4, 30, "Input"],
Cell[448517, 12125, 49, 0, 33, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[448603, 12130, 60, 1, 47, "Subsection",
  CellTags->"T1.6.78.1"],
Cell[448666, 12133, 77, 1, 30, "Input"],
Cell[448746, 12136, 190, 4, 30, "Input"],
Cell[448939, 12142, 49, 0, 33, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[449025, 12147, 57, 1, 47, "Subsection",
  CellTags->"T1.6.79.1"],
Cell[449085, 12150, 135, 4, 33, "Text"],
Cell[449223, 12156, 66, 1, 30, "Input"],
Cell[449292, 12159, 187, 3, 30, "Text"],
Cell[449482, 12164, 4773, 114, 54, "Input"],
Cell[454258, 12280, 62, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[454357, 12286, 57, 1, 47, "Subsection",
  CellTags->"T1.6.80.1"],
Cell[454417, 12289, 236, 6, 33, "Text"],
Cell[454656, 12297, 2101, 55, 32, "Input"],
Cell[456760, 12354, 62, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[456859, 12360, 59, 1, 47, "Subsection",
  CellTags->"T1.6.81.1"],
Cell[456921, 12363, 74, 1, 30, "Input"],
Cell[456998, 12366, 137, 3, 30, "Input"],
Cell[457138, 12371, 49, 0, 33, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[457224, 12376, 57, 1, 47, "Subsection",
  CellTags->"T1.6.82.1"],
Cell[457284, 12379, 77, 4, 33, "Text"],
Cell[457364, 12385, 3018, 76, 32, "Input"],
Cell[460385, 12463, 62, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[460484, 12469, 59, 1, 47, "Subsection",
  CellTags->"T1.6.83.1"],
Cell[460546, 12472, 74, 1, 30, "Input"],
Cell[460623, 12475, 140, 3, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[460800, 12483, 61, 1, 47, "Subsection",
  CellTags->"T1.6.84.1"],
Cell[460864, 12486, 121, 2, 30, "Input"],
Cell[460988, 12490, 90, 1, 30, "Input"],
Cell[461081, 12493, 179, 4, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[461297, 12502, 61, 1, 47, "Subsection",
  CellTags->"T1.6.85.1"],
Cell[461361, 12505, 166, 3, 30, "Input"],
Cell[461530, 12510, 90, 1, 30, "Input"],
Cell[461623, 12513, 179, 4, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[461839, 12522, 57, 1, 47, "Subsection",
  CellTags->"T1.6.86.1"],
Cell[461899, 12525, 77, 4, 33, "Text"],
Cell[461979, 12531, 2104, 59, 32, "Input"],
Cell[464086, 12592, 62, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[464185, 12598, 59, 1, 47, "Subsection",
  CellTags->"T1.6.87.1"],
Cell[464247, 12601, 74, 1, 30, "Input"],
Cell[464324, 12604, 161, 4, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[464522, 12613, 57, 1, 47, "Subsection",
  CellTags->"T1.6.88.1"],
Cell[464582, 12616, 77, 4, 33, "Text"],
Cell[464662, 12622, 2088, 56, 32, "Input"],
Cell[466753, 12680, 62, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[466852, 12686, 59, 1, 47, "Subsection",
  CellTags->"T1.6.89.1"],
Cell[466914, 12689, 46, 1, 30, "Input"],
Cell[466963, 12692, 141, 3, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[467141, 12700, 57, 1, 47, "Subsection",
  CellTags->"T1.6.90.1"],
Cell[467201, 12703, 77, 4, 33, "Text"],
Cell[467281, 12709, 1286, 36, 32, "Input"],
Cell[468570, 12747, 62, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[468669, 12753, 59, 1, 47, "Subsection",
  CellTags->"T1.6.91.1"],
Cell[468731, 12756, 74, 1, 30, "Input"],
Cell[468808, 12759, 128, 3, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[468973, 12767, 57, 1, 47, "Subsection",
  CellTags->"T1.6.92.1"],
Cell[469033, 12770, 77, 4, 33, "Text"],
Cell[469113, 12776, 1144, 32, 32, "Input"],
Cell[470260, 12810, 62, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[470359, 12816, 59, 1, 47, "Subsection",
  CellTags->"T1.6.93.1"],
Cell[470421, 12819, 46, 1, 30, "Input"],
Cell[470470, 12822, 130, 3, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[470637, 12830, 57, 1, 47, "Subsection",
  CellTags->"T1.6.94.1"],
Cell[470697, 12833, 114, 2, 29, "Text"],
Cell[470814, 12837, 1616, 44, 35, "Text"],
Cell[472433, 12883, 2050, 56, 32, "Input"],
Cell[474486, 12941, 62, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[474585, 12947, 59, 1, 47, "Subsection",
  CellTags->"T1.6.95.1"],
Cell[474647, 12950, 74, 1, 30, "Input"],
Cell[474724, 12953, 137, 3, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[474898, 12961, 61, 1, 47, "Subsection",
  CellTags->"T1.6.96.1"],
Cell[474962, 12964, 128, 3, 30, "Input"],
Cell[475093, 12969, 143, 3, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[475273, 12977, 61, 1, 47, "Subsection",
  CellTags->"T1.6.97.1"],
Cell[475337, 12980, 128, 3, 30, "Input"],
Cell[475468, 12985, 143, 3, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[475648, 12993, 58, 1, 47, "Subsection",
  CellTags->"T1.6.98.1"],
Cell[475709, 12996, 39, 0, 33, "Text"],
Cell[475751, 12998, 2876, 77, 33, "Text"],
Cell[478630, 13077, 73, 1, 29, "Text"],
Cell[478706, 13080, 3007, 83, 32, "Input"],
Cell[481716, 13165, 64, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[481817, 13171, 60, 1, 47, "Subsection",
  CellTags->"T1.6.99.1"],
Cell[481880, 13174, 48, 1, 30, "Input"],
Cell[481931, 13177, 154, 3, 30, "Input"],

Cell[CellGroupData[{
Cell[482110, 13184, 58, 1, 30, "Input"],
Cell[482171, 13187, 55, 1, 25, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[482275, 13194, 62, 1, 47, "Subsection",
  CellTags->"T1.6.100.1"],
Cell[482340, 13197, 85, 1, 30, "Input"],
Cell[482428, 13200, 157, 3, 30, "Input"],

Cell[CellGroupData[{
Cell[482610, 13207, 59, 1, 30, "Input"],
Cell[482672, 13210, 55, 1, 25, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[482776, 13217, 62, 1, 47, "Subsection",
  CellTags->"T1.6.101.1"],
Cell[482841, 13220, 124, 3, 30, "Input"],
Cell[482968, 13225, 157, 3, 30, "Input"],

Cell[CellGroupData[{
Cell[483150, 13232, 59, 1, 30, "Input"],
Cell[483212, 13235, 55, 1, 25, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[483316, 13242, 62, 1, 47, "Subsection",
  CellTags->"T1.6.102.1"],
Cell[483381, 13245, 85, 1, 30, "Input"],
Cell[483469, 13248, 157, 3, 30, "Input"],

Cell[CellGroupData[{
Cell[483651, 13255, 59, 1, 30, "Input"],
Cell[483713, 13258, 55, 1, 25, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[483817, 13265, 62, 1, 47, "Subsection",
  CellTags->"T1.6.103.1"],
Cell[483882, 13268, 85, 1, 30, "Input"],
Cell[483970, 13271, 157, 3, 30, "Input"],

Cell[CellGroupData[{
Cell[484152, 13278, 59, 1, 30, "Input"],
Cell[484214, 13281, 55, 1, 25, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[484318, 13288, 62, 1, 47, "Subsection",
  CellTags->"T1.6.104.1"],
Cell[484383, 13291, 124, 3, 30, "Input"],
Cell[484510, 13296, 157, 3, 30, "Input"],

Cell[CellGroupData[{
Cell[484692, 13303, 59, 1, 30, "Input"],
Cell[484754, 13306, 55, 1, 25, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[484858, 13313, 59, 1, 47, "Subsection",
  CellTags->"T1.6.105.1"],
Cell[484920, 13316, 59, 1, 31, "Text"],
Cell[484982, 13319, 154, 2, 33, "Text"],
Cell[485139, 13323, 455, 9, 90, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[485631, 13337, 61, 1, 47, "Subsection",
  CellTags->"T1.6.106.1"],
Cell[485695, 13340, 48, 1, 30, "Input"],
Cell[485746, 13343, 70, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[485853, 13349, 59, 1, 47, "Subsection",
  CellTags->"T1.6.107.1"],
Cell[485915, 13352, 59, 1, 31, "Text"],
Cell[485977, 13355, 154, 2, 33, "Text"],
Cell[486134, 13359, 565, 13, 90, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[486736, 13377, 61, 1, 47, "Subsection",
  CellTags->"T1.6.108.1"],
Cell[486800, 13380, 48, 1, 30, "Input"],
Cell[486851, 13383, 120, 3, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[487008, 13391, 59, 1, 47, "Subsection",
  CellTags->"T1.6.109.1"],
Cell[487070, 13394, 59, 1, 31, "Text"],
Cell[487132, 13397, 154, 2, 33, "Text"],
Cell[487289, 13401, 402, 8, 90, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[487728, 13414, 61, 1, 47, "Subsection",
  CellTags->"T1.6.110.1"],
Cell[487792, 13417, 48, 1, 30, "Input"],
Cell[487843, 13420, 70, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[487950, 13426, 59, 1, 47, "Subsection",
  CellTags->"T1.6.111.1"],
Cell[488012, 13429, 59, 1, 31, "Text"],
Cell[488074, 13432, 311, 6, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[488422, 13443, 61, 1, 47, "Subsection",
  CellTags->"T1.6.112.1"],
Cell[488486, 13446, 48, 1, 30, "Input"],
Cell[488537, 13449, 70, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[488644, 13455, 59, 1, 47, "Subsection",
  CellTags->"T1.6.113.1"],
Cell[488706, 13458, 43, 0, 33, "Text"],
Cell[488752, 13460, 105, 1, 30, "Text"],
Cell[488860, 13463, 6709, 171, 76, "Input"],
Cell[495572, 13636, 191, 3, 31, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[495800, 13644, 61, 1, 47, "Subsection",
  CellTags->"T1.6.114.1"],
Cell[495864, 13647, 76, 1, 30, "Input"],
Cell[495943, 13650, 422, 10, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[496402, 13665, 61, 1, 47, "Subsection",
  CellTags->"T1.6.115.1"],
Cell[496466, 13668, 692, 29, 498, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[497195, 13702, 61, 1, 47, "Subsection",
  CellTags->"T1.6.116.1"],
Cell[497259, 13705, 696, 29, 498, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[497992, 13739, 62, 1, 47, "Subsection",
  CellTags->"T1.6.117.1"],
Cell[498057, 13742, 1083, 19, 310, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[499177, 13766, 62, 1, 47, "Subsection",
  CellTags->"T1.6.118.1"],
Cell[499242, 13769, 1046, 18, 290, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[500325, 13792, 62, 1, 47, "Subsection",
  CellTags->"T1.6.119.1"],
Cell[500390, 13795, 1044, 18, 290, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[501471, 13818, 61, 1, 47, "Subsection",
  CellTags->"T1.6.120.1"],
Cell[501535, 13821, 240, 6, 102, "Input"],

Cell[CellGroupData[{
Cell[501800, 13831, 4713, 86, 176, "Input"],
Cell[506516, 13919, 357, 6, 76, "Print"]
}, Open  ]],
Cell[506888, 13928, 40, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[506953, 13933, 586, 11, 131, "Input"],
Cell[507542, 13946, 357, 6, 76, "Print"]
}, Open  ]],
Cell[507914, 13955, 40, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[507991, 13961, 55, 1, 47, "Subsection",
  CellTags->"Tsymmetry"],
Cell[508049, 13964, 108, 3, 48, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[508194, 13972, 70, 1, 47, "Subsection",
  CellTags->"specialTVR"],
Cell[508267, 13975, 579, 11, 192, "Input"],
Cell[508849, 13988, 1683, 27, 462, "Input"],
Cell[510535, 14017, 1597, 26, 444, "Input"],
Cell[512135, 14045, 3547, 56, 1002, "Input"],
Cell[515685, 14103, 3261, 52, 930, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[518983, 14160, 60, 1, 47, "Subsection",
  CellTags->"T1.6.121.1"],
Cell[519046, 14163, 394, 7, 90, "Input"],
Cell[519443, 14172, 427, 8, 90, "Input"],
Cell[519873, 14182, 427, 8, 90, "Input"],
Cell[520303, 14192, 425, 8, 90, "Input"],
Cell[520731, 14202, 220, 14, 246, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[520988, 14221, 61, 1, 47, "Subsection",
  CellTags->"T1.6.122.1"],
Cell[521052, 14224, 273, 5, 70, "Input"],
Cell[521328, 14231, 273, 5, 70, "Input"],
Cell[521604, 14238, 133, 3, 48, "Input"],
Cell[521740, 14243, 264, 5, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[522041, 14253, 60, 1, 47, "Subsection",
  CellTags->"T1.6.123.1"],
Cell[522104, 14256, 194, 4, 50, "Input"],
Cell[522301, 14262, 194, 4, 50, "Input"],
Cell[522498, 14268, 194, 4, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[522729, 14277, 58, 1, 47, "Subsection",
  CellTags->"T1.6.124.1"],
Cell[522790, 14280, 185, 4, 50, "Input"],
Cell[522978, 14286, 185, 4, 50, "Input"],
Cell[523166, 14292, 87, 1, 30, "Input"],
Cell[523256, 14295, 85, 1, 30, "Input"],
Cell[523344, 14298, 88, 1, 30, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[523481, 14305, 108, 2, 53, "Section",
  CellTags->"T1.7.1"],

Cell[CellGroupData[{
Cell[523614, 14311, 70, 1, 47, "Subsection",
  CellTags->"T1.7.1.1"],
Cell[523687, 14314, 45, 0, 33, "Text"],
Cell[523735, 14316, 57, 1, 30, "Input"],
Cell[523795, 14319, 145, 3, 30, "Input"],
Cell[523943, 14324, 501, 13, 30, "Input"],
Cell[524447, 14339, 127, 2, 30, "Input"],
Cell[524577, 14343, 503, 13, 30, "Input"],
Cell[525083, 14358, 129, 2, 30, "Input"],
Cell[525215, 14362, 84, 3, 33, "Text"],
Cell[525302, 14367, 60, 1, 30, "Input"],
Cell[525365, 14370, 111, 2, 30, "Input"],
Cell[525479, 14374, 216, 7, 109, "Text",
  CellTags->"TLRdef"],
Cell[525698, 14383, 112, 2, 30, "Input"],
Cell[525813, 14387, 438, 10, 30, "Input"],
Cell[526254, 14399, 26, 0, 33, "Text"],
Cell[526283, 14401, 928, 16, 203, "Input"],
Cell[527214, 14419, 72, 1, 30, "Text"],
Cell[527289, 14422, 926, 16, 203, "Input"],
Cell[528218, 14440, 82, 1, 29, "Text"],
Cell[528303, 14443, 750, 15, 158, "Input"],
Cell[529056, 14460, 82, 1, 29, "Text"],
Cell[529141, 14463, 771, 15, 158, "Input"],
Cell[529915, 14480, 85, 1, 29, "Text"],
Cell[530003, 14483, 836, 17, 192, "Input"],
Cell[530842, 14502, 37, 0, 33, "Text"],
Cell[530882, 14504, 658, 13, 113, "Input"],
Cell[531543, 14519, 37, 0, 33, "Text"],
Cell[531583, 14521, 673, 14, 113, "Input"],
Cell[532259, 14537, 35, 0, 33, "Text"],
Cell[532297, 14539, 730, 11, 274, "Input"],
Cell[533030, 14552, 31, 0, 33, "Text"],
Cell[533064, 14554, 224, 6, 109, "Text"],
Cell[533291, 14562, 31, 0, 33, "Text"],
Cell[533325, 14564, 204, 5, 84, "Input"],
Cell[533532, 14571, 148, 4, 52, "Text"],
Cell[533683, 14577, 443, 15, 246, "Input"],
Cell[534129, 14594, 443, 15, 246, "Input"],
Cell[534575, 14611, 49, 0, 33, "Text"],
Cell[534627, 14613, 374, 6, 116, "Input"],
Cell[535004, 14621, 49, 0, 33, "Text"],
Cell[535056, 14623, 374, 6, 116, "Input"],
Cell[535433, 14631, 25, 0, 33, "Text"],
Cell[535461, 14633, 255, 6, 50, "Input"],
Cell[535719, 14641, 246, 5, 50, "Input"],
Cell[535968, 14648, 78, 1, 33, "Text",
  CellTags->"tlrule17"],
Cell[536049, 14651, 530, 9, 168, "Input"],
Cell[536582, 14662, 986, 19, 271, "Input"],
Cell[537571, 14683, 986, 19, 271, "Input"],
Cell[538560, 14704, 37, 0, 33, "Text"],
Cell[538600, 14706, 499, 8, 168, "Input"],
Cell[539102, 14716, 287, 5, 50, "Input"],
Cell[539392, 14723, 358, 7, 65, "Input"],
Cell[539753, 14732, 6408, 176, 162, "Text"],
Cell[546164, 14910, 895, 17, 171, "Input"],
Cell[547062, 14929, 12636, 333, 105, "Text"],
Cell[559701, 15264, 954, 16, 216, "Input"],
Cell[560658, 15282, 65, 0, 33, "Text"],
Cell[560726, 15284, 432, 8, 70, "Input"],
Cell[561161, 15294, 65, 1, 30, "Input"],
Cell[561229, 15297, 70, 1, 30, "Input"],
Cell[561302, 15300, 92, 1, 30, "Input"],
Cell[561397, 15303, 92, 1, 30, "Input"],
Cell[561492, 15306, 92, 1, 30, "Input"],
Cell[561587, 15309, 92, 1, 30, "Input"],
Cell[561682, 15312, 92, 1, 30, "Input"],
Cell[561777, 15315, 92, 1, 30, "Input"],
Cell[561872, 15318, 74, 1, 30, "Input"],
Cell[561949, 15321, 88, 1, 30, "Input"],
Cell[562040, 15324, 108, 2, 30, "Input"],
Cell[562151, 15328, 250, 6, 30, "Input"],
Cell[562404, 15336, 55, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[562496, 15342, 50, 1, 47, "Subsection",
  CellTags->"T1.7.2.1"],
Cell[562549, 15345, 86, 3, 52, "Text"],
Cell[562638, 15350, 668, 12, 105, "Input"],
Cell[563309, 15364, 202, 4, 50, "Input"],
Cell[563514, 15370, 202, 4, 50, "Input"],
Cell[563719, 15376, 668, 12, 129, "Input"],
Cell[564390, 15390, 163, 2, 30, "Input"],
Cell[564556, 15394, 163, 2, 30, "Input"],
Cell[564722, 15398, 505, 9, 69, "Input"],
Cell[565230, 15409, 164, 2, 30, "Input"],
Cell[565397, 15413, 164, 2, 30, "Input"],
Cell[565564, 15417, 545, 9, 82, "Input"],
Cell[566112, 15428, 556, 9, 97, "Input"],
Cell[566671, 15439, 22, 0, 33, "Text"],
Cell[566696, 15441, 130, 3, 30, "Input"],
Cell[566829, 15446, 87, 1, 30, "Input"],
Cell[566919, 15449, 501, 9, 91, "Input"],
Cell[567423, 15460, 537, 9, 100, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[567997, 15474, 54, 1, 47, "Subsection",
  CellTags->"T1.7.3.1"],
Cell[568054, 15477, 61, 1, 30, "Input"],
Cell[568118, 15480, 1380, 26, 250, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[569535, 15511, 52, 1, 47, "Subsection",
  CellTags->"$TTable"],
Cell[569590, 15514, 50, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[569677, 15520, 59, 1, 47, "Subsection",
  CellTags->"T1.7.4.1"],
Cell[569739, 15523, 105, 2, 30, "Input"],
Cell[569847, 15527, 273, 5, 70, "Input"],
Cell[570123, 15534, 191, 3, 50, "Input"],
Cell[570317, 15539, 8926, 166, 1050, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[579292, 15711, 92, 2, 53, "Section",
  CellTags->"T1.8.1"],
Cell[579387, 15715, 154, 2, 70, "Input"],
Cell[579544, 15719, 167, 2, 50, "Input"],
Cell[579714, 15723, 8012, 161, 525, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[587763, 15889, 93, 2, 53, "Section",
  CellTags->"T1.9.1"],

Cell[CellGroupData[{
Cell[587881, 15895, 54, 1, 47, "Subsection",
  CellTags->"T1.9.1.1"],
Cell[587938, 15898, 61, 0, 33, "Text"],
Cell[588002, 15900, 185, 3, 50, "Input"],
Cell[588190, 15905, 64, 1, 30, "Input"],
Cell[588257, 15908, 71, 1, 30, "Input"],
Cell[588331, 15911, 53, 1, 30, "Input"],
Cell[588387, 15914, 1836, 32, 190, "Input"],
Cell[590226, 15948, 53, 1, 30, "Input"],
Cell[590282, 15951, 129, 3, 30, "Input"],
Cell[590414, 15956, 81, 1, 30, "Input"],
Cell[590498, 15959, 48, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[590571, 15964, 137, 3, 30, "Input"],
Cell[590711, 15969, 325, 6, 25, "Print"]
}, Open  ]],
Cell[591051, 15978, 143, 2, 30, "Input"],
Cell[591197, 15982, 49, 1, 30, "Input"],
Cell[591249, 15985, 53, 1, 30, "Input"],
Cell[591305, 15988, 45, 1, 30, "Input"],
Cell[591353, 15991, 53, 1, 30, "Input"],
Cell[591409, 15994, 43, 1, 30, "Input"],
Cell[591455, 15997, 50, 1, 30, "Input"],
Cell[591508, 16000, 511, 8, 210, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[592068, 16014, 95, 2, 53, "Section",
  CellTags->"T1.10.1"],
Cell[592166, 16018, 111, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[592302, 16025, 1676, 54, 912, "Input"],
Cell[593981, 16081, 14611, 364, 397, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[608641, 16451, 101, 2, 53, "Section",
  CellTags->"T1.11.1"],
Cell[608745, 16455, 45, 1, 30, "Input"],
Cell[608793, 16458, 2310, 55, 966, "Input"],
Cell[611106, 16515, 66, 1, 30, "Input"],
Cell[611175, 16518, 89, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[611289, 16525, 114, 2, 30, "Input"],
Cell[611406, 16529, 75, 1, 29, "Output"]
}, Open  ]],
Cell[611496, 16533, 55, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[611576, 16537, 137, 2, 30, "Input"],
Cell[611716, 16541, 64, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[611817, 16547, 62, 1, 30, "Input"],
Cell[611882, 16550, 64, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[611983, 16556, 44, 1, 30, "Input"],
Cell[612030, 16559, 130, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[612197, 16566, 48, 1, 30, "Input"],
Cell[612248, 16569, 59, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[612344, 16575, 46, 1, 30, "Input"],
Cell[612393, 16578, 58, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[612488, 16584, 43, 1, 30, "Input"],
Cell[612534, 16587, 69, 1, 29, "Output"]
}, Open  ]],
Cell[612618, 16591, 35, 1, 30, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

